/* Copyright 2022 - 2025 R. Thomas
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
#ifndef LIEF_ASM_RISCV_REGISTER_H
#define LIEF_ASM_RISCV_REGISTER_H
namespace LIEF {
namespace assembly {
namespace riscv {
enum class REG;
const char* get_register_name(REG r);

enum class REG {
  NoRegister = 0,
  FFLAGS = 1,
  FRM = 2,
  SF_VCIX_STATE = 3,
  SSP = 4,
  VL = 5,
  VLENB = 6,
  VTYPE = 7,
  VXRM = 8,
  VXSAT = 9,
  DUMMY_REG_PAIR_WITH_X0 = 10,
  V0 = 11,
  V1 = 12,
  V2 = 13,
  V3 = 14,
  V4 = 15,
  V5 = 16,
  V6 = 17,
  V7 = 18,
  V8 = 19,
  V9 = 20,
  V10 = 21,
  V11 = 22,
  V12 = 23,
  V13 = 24,
  V14 = 25,
  V15 = 26,
  V16 = 27,
  V17 = 28,
  V18 = 29,
  V19 = 30,
  V20 = 31,
  V21 = 32,
  V22 = 33,
  V23 = 34,
  V24 = 35,
  V25 = 36,
  V26 = 37,
  V27 = 38,
  V28 = 39,
  V29 = 40,
  V30 = 41,
  V31 = 42,
  X0 = 43,
  X1 = 44,
  X2 = 45,
  X3 = 46,
  X4 = 47,
  X5 = 48,
  X6 = 49,
  X7 = 50,
  X8 = 51,
  X9 = 52,
  X10 = 53,
  X11 = 54,
  X12 = 55,
  X13 = 56,
  X14 = 57,
  X15 = 58,
  X16 = 59,
  X17 = 60,
  X18 = 61,
  X19 = 62,
  X20 = 63,
  X21 = 64,
  X22 = 65,
  X23 = 66,
  X24 = 67,
  X25 = 68,
  X26 = 69,
  X27 = 70,
  X28 = 71,
  X29 = 72,
  X30 = 73,
  X31 = 74,
  F0_D = 75,
  F1_D = 76,
  F2_D = 77,
  F3_D = 78,
  F4_D = 79,
  F5_D = 80,
  F6_D = 81,
  F7_D = 82,
  F8_D = 83,
  F9_D = 84,
  F10_D = 85,
  F11_D = 86,
  F12_D = 87,
  F13_D = 88,
  F14_D = 89,
  F15_D = 90,
  F16_D = 91,
  F17_D = 92,
  F18_D = 93,
  F19_D = 94,
  F20_D = 95,
  F21_D = 96,
  F22_D = 97,
  F23_D = 98,
  F24_D = 99,
  F25_D = 100,
  F26_D = 101,
  F27_D = 102,
  F28_D = 103,
  F29_D = 104,
  F30_D = 105,
  F31_D = 106,
  F0_F = 107,
  F1_F = 108,
  F2_F = 109,
  F3_F = 110,
  F4_F = 111,
  F5_F = 112,
  F6_F = 113,
  F7_F = 114,
  F8_F = 115,
  F9_F = 116,
  F10_F = 117,
  F11_F = 118,
  F12_F = 119,
  F13_F = 120,
  F14_F = 121,
  F15_F = 122,
  F16_F = 123,
  F17_F = 124,
  F18_F = 125,
  F19_F = 126,
  F20_F = 127,
  F21_F = 128,
  F22_F = 129,
  F23_F = 130,
  F24_F = 131,
  F25_F = 132,
  F26_F = 133,
  F27_F = 134,
  F28_F = 135,
  F29_F = 136,
  F30_F = 137,
  F31_F = 138,
  F0_H = 139,
  F1_H = 140,
  F2_H = 141,
  F3_H = 142,
  F4_H = 143,
  F5_H = 144,
  F6_H = 145,
  F7_H = 146,
  F8_H = 147,
  F9_H = 148,
  F10_H = 149,
  F11_H = 150,
  F12_H = 151,
  F13_H = 152,
  F14_H = 153,
  F15_H = 154,
  F16_H = 155,
  F17_H = 156,
  F18_H = 157,
  F19_H = 158,
  F20_H = 159,
  F21_H = 160,
  F22_H = 161,
  F23_H = 162,
  F24_H = 163,
  F25_H = 164,
  F26_H = 165,
  F27_H = 166,
  F28_H = 167,
  F29_H = 168,
  F30_H = 169,
  F31_H = 170,
  X0_H = 171,
  X1_H = 172,
  X2_H = 173,
  X3_H = 174,
  X4_H = 175,
  X5_H = 176,
  X6_H = 177,
  X7_H = 178,
  X8_H = 179,
  X9_H = 180,
  X10_H = 181,
  X11_H = 182,
  X12_H = 183,
  X13_H = 184,
  X14_H = 185,
  X15_H = 186,
  X16_H = 187,
  X17_H = 188,
  X18_H = 189,
  X19_H = 190,
  X20_H = 191,
  X21_H = 192,
  X22_H = 193,
  X23_H = 194,
  X24_H = 195,
  X25_H = 196,
  X26_H = 197,
  X27_H = 198,
  X28_H = 199,
  X29_H = 200,
  X30_H = 201,
  X31_H = 202,
  X0_Pair = 203,
  X0_W = 204,
  X1_W = 205,
  X2_W = 206,
  X3_W = 207,
  X4_W = 208,
  X5_W = 209,
  X6_W = 210,
  X7_W = 211,
  X8_W = 212,
  X9_W = 213,
  X10_W = 214,
  X11_W = 215,
  X12_W = 216,
  X13_W = 217,
  X14_W = 218,
  X15_W = 219,
  X16_W = 220,
  X17_W = 221,
  X18_W = 222,
  X19_W = 223,
  X20_W = 224,
  X21_W = 225,
  X22_W = 226,
  X23_W = 227,
  X24_W = 228,
  X25_W = 229,
  X26_W = 230,
  X27_W = 231,
  X28_W = 232,
  X29_W = 233,
  X30_W = 234,
  X31_W = 235,
  V0M2 = 236,
  V0M4 = 237,
  V0M8 = 238,
  V2M2 = 239,
  V4M2 = 240,
  V4M4 = 241,
  V6M2 = 242,
  V8M2 = 243,
  V8M4 = 244,
  V8M8 = 245,
  V10M2 = 246,
  V12M2 = 247,
  V12M4 = 248,
  V14M2 = 249,
  V16M2 = 250,
  V16M4 = 251,
  V16M8 = 252,
  V18M2 = 253,
  V20M2 = 254,
  V20M4 = 255,
  V22M2 = 256,
  V24M2 = 257,
  V24M4 = 258,
  V24M8 = 259,
  V26M2 = 260,
  V28M2 = 261,
  V28M4 = 262,
  V30M2 = 263,
  X2_X3 = 264,
  X4_X5 = 265,
  X6_X7 = 266,
  X8_X9 = 267,
  X10_X11 = 268,
  X12_X13 = 269,
  X14_X15 = 270,
  X16_X17 = 271,
  X18_X19 = 272,
  X20_X21 = 273,
  X22_X23 = 274,
  X24_X25 = 275,
  X26_X27 = 276,
  X28_X29 = 277,
  X30_X31 = 278,
  V1_V2 = 279,
  V2_V3 = 280,
  V3_V4 = 281,
  V4_V5 = 282,
  V5_V6 = 283,
  V6_V7 = 284,
  V7_V8 = 285,
  V8_V9 = 286,
  V9_V10 = 287,
  V10_V11 = 288,
  V11_V12 = 289,
  V12_V13 = 290,
  V13_V14 = 291,
  V14_V15 = 292,
  V15_V16 = 293,
  V16_V17 = 294,
  V17_V18 = 295,
  V18_V19 = 296,
  V19_V20 = 297,
  V20_V21 = 298,
  V21_V22 = 299,
  V22_V23 = 300,
  V23_V24 = 301,
  V24_V25 = 302,
  V25_V26 = 303,
  V26_V27 = 304,
  V27_V28 = 305,
  V28_V29 = 306,
  V29_V30 = 307,
  V30_V31 = 308,
  V0_V1 = 309,
  V2M2_V4M2 = 310,
  V4M2_V6M2 = 311,
  V6M2_V8M2 = 312,
  V8M2_V10M2 = 313,
  V10M2_V12M2 = 314,
  V12M2_V14M2 = 315,
  V14M2_V16M2 = 316,
  V16M2_V18M2 = 317,
  V18M2_V20M2 = 318,
  V20M2_V22M2 = 319,
  V22M2_V24M2 = 320,
  V24M2_V26M2 = 321,
  V26M2_V28M2 = 322,
  V28M2_V30M2 = 323,
  V0M2_V2M2 = 324,
  V4M4_V8M4 = 325,
  V8M4_V12M4 = 326,
  V12M4_V16M4 = 327,
  V16M4_V20M4 = 328,
  V20M4_V24M4 = 329,
  V24M4_V28M4 = 330,
  V0M4_V4M4 = 331,
  V1_V2_V3 = 332,
  V2_V3_V4 = 333,
  V3_V4_V5 = 334,
  V4_V5_V6 = 335,
  V5_V6_V7 = 336,
  V6_V7_V8 = 337,
  V7_V8_V9 = 338,
  V8_V9_V10 = 339,
  V9_V10_V11 = 340,
  V10_V11_V12 = 341,
  V11_V12_V13 = 342,
  V12_V13_V14 = 343,
  V13_V14_V15 = 344,
  V14_V15_V16 = 345,
  V15_V16_V17 = 346,
  V16_V17_V18 = 347,
  V17_V18_V19 = 348,
  V18_V19_V20 = 349,
  V19_V20_V21 = 350,
  V20_V21_V22 = 351,
  V21_V22_V23 = 352,
  V22_V23_V24 = 353,
  V23_V24_V25 = 354,
  V24_V25_V26 = 355,
  V25_V26_V27 = 356,
  V26_V27_V28 = 357,
  V27_V28_V29 = 358,
  V28_V29_V30 = 359,
  V29_V30_V31 = 360,
  V0_V1_V2 = 361,
  V2M2_V4M2_V6M2 = 362,
  V4M2_V6M2_V8M2 = 363,
  V6M2_V8M2_V10M2 = 364,
  V8M2_V10M2_V12M2 = 365,
  V10M2_V12M2_V14M2 = 366,
  V12M2_V14M2_V16M2 = 367,
  V14M2_V16M2_V18M2 = 368,
  V16M2_V18M2_V20M2 = 369,
  V18M2_V20M2_V22M2 = 370,
  V20M2_V22M2_V24M2 = 371,
  V22M2_V24M2_V26M2 = 372,
  V24M2_V26M2_V28M2 = 373,
  V26M2_V28M2_V30M2 = 374,
  V0M2_V2M2_V4M2 = 375,
  V1_V2_V3_V4 = 376,
  V2_V3_V4_V5 = 377,
  V3_V4_V5_V6 = 378,
  V4_V5_V6_V7 = 379,
  V5_V6_V7_V8 = 380,
  V6_V7_V8_V9 = 381,
  V7_V8_V9_V10 = 382,
  V8_V9_V10_V11 = 383,
  V9_V10_V11_V12 = 384,
  V10_V11_V12_V13 = 385,
  V11_V12_V13_V14 = 386,
  V12_V13_V14_V15 = 387,
  V13_V14_V15_V16 = 388,
  V14_V15_V16_V17 = 389,
  V15_V16_V17_V18 = 390,
  V16_V17_V18_V19 = 391,
  V17_V18_V19_V20 = 392,
  V18_V19_V20_V21 = 393,
  V19_V20_V21_V22 = 394,
  V20_V21_V22_V23 = 395,
  V21_V22_V23_V24 = 396,
  V22_V23_V24_V25 = 397,
  V23_V24_V25_V26 = 398,
  V24_V25_V26_V27 = 399,
  V25_V26_V27_V28 = 400,
  V26_V27_V28_V29 = 401,
  V27_V28_V29_V30 = 402,
  V28_V29_V30_V31 = 403,
  V0_V1_V2_V3 = 404,
  V2M2_V4M2_V6M2_V8M2 = 405,
  V4M2_V6M2_V8M2_V10M2 = 406,
  V6M2_V8M2_V10M2_V12M2 = 407,
  V8M2_V10M2_V12M2_V14M2 = 408,
  V10M2_V12M2_V14M2_V16M2 = 409,
  V12M2_V14M2_V16M2_V18M2 = 410,
  V14M2_V16M2_V18M2_V20M2 = 411,
  V16M2_V18M2_V20M2_V22M2 = 412,
  V18M2_V20M2_V22M2_V24M2 = 413,
  V20M2_V22M2_V24M2_V26M2 = 414,
  V22M2_V24M2_V26M2_V28M2 = 415,
  V24M2_V26M2_V28M2_V30M2 = 416,
  V0M2_V2M2_V4M2_V6M2 = 417,
  V1_V2_V3_V4_V5 = 418,
  V2_V3_V4_V5_V6 = 419,
  V3_V4_V5_V6_V7 = 420,
  V4_V5_V6_V7_V8 = 421,
  V5_V6_V7_V8_V9 = 422,
  V6_V7_V8_V9_V10 = 423,
  V7_V8_V9_V10_V11 = 424,
  V8_V9_V10_V11_V12 = 425,
  V9_V10_V11_V12_V13 = 426,
  V10_V11_V12_V13_V14 = 427,
  V11_V12_V13_V14_V15 = 428,
  V12_V13_V14_V15_V16 = 429,
  V13_V14_V15_V16_V17 = 430,
  V14_V15_V16_V17_V18 = 431,
  V15_V16_V17_V18_V19 = 432,
  V16_V17_V18_V19_V20 = 433,
  V17_V18_V19_V20_V21 = 434,
  V18_V19_V20_V21_V22 = 435,
  V19_V20_V21_V22_V23 = 436,
  V20_V21_V22_V23_V24 = 437,
  V21_V22_V23_V24_V25 = 438,
  V22_V23_V24_V25_V26 = 439,
  V23_V24_V25_V26_V27 = 440,
  V24_V25_V26_V27_V28 = 441,
  V25_V26_V27_V28_V29 = 442,
  V26_V27_V28_V29_V30 = 443,
  V27_V28_V29_V30_V31 = 444,
  V0_V1_V2_V3_V4 = 445,
  V1_V2_V3_V4_V5_V6 = 446,
  V2_V3_V4_V5_V6_V7 = 447,
  V3_V4_V5_V6_V7_V8 = 448,
  V4_V5_V6_V7_V8_V9 = 449,
  V5_V6_V7_V8_V9_V10 = 450,
  V6_V7_V8_V9_V10_V11 = 451,
  V7_V8_V9_V10_V11_V12 = 452,
  V8_V9_V10_V11_V12_V13 = 453,
  V9_V10_V11_V12_V13_V14 = 454,
  V10_V11_V12_V13_V14_V15 = 455,
  V11_V12_V13_V14_V15_V16 = 456,
  V12_V13_V14_V15_V16_V17 = 457,
  V13_V14_V15_V16_V17_V18 = 458,
  V14_V15_V16_V17_V18_V19 = 459,
  V15_V16_V17_V18_V19_V20 = 460,
  V16_V17_V18_V19_V20_V21 = 461,
  V17_V18_V19_V20_V21_V22 = 462,
  V18_V19_V20_V21_V22_V23 = 463,
  V19_V20_V21_V22_V23_V24 = 464,
  V20_V21_V22_V23_V24_V25 = 465,
  V21_V22_V23_V24_V25_V26 = 466,
  V22_V23_V24_V25_V26_V27 = 467,
  V23_V24_V25_V26_V27_V28 = 468,
  V24_V25_V26_V27_V28_V29 = 469,
  V25_V26_V27_V28_V29_V30 = 470,
  V26_V27_V28_V29_V30_V31 = 471,
  V0_V1_V2_V3_V4_V5 = 472,
  V1_V2_V3_V4_V5_V6_V7 = 473,
  V2_V3_V4_V5_V6_V7_V8 = 474,
  V3_V4_V5_V6_V7_V8_V9 = 475,
  V4_V5_V6_V7_V8_V9_V10 = 476,
  V5_V6_V7_V8_V9_V10_V11 = 477,
  V6_V7_V8_V9_V10_V11_V12 = 478,
  V7_V8_V9_V10_V11_V12_V13 = 479,
  V8_V9_V10_V11_V12_V13_V14 = 480,
  V9_V10_V11_V12_V13_V14_V15 = 481,
  V10_V11_V12_V13_V14_V15_V16 = 482,
  V11_V12_V13_V14_V15_V16_V17 = 483,
  V12_V13_V14_V15_V16_V17_V18 = 484,
  V13_V14_V15_V16_V17_V18_V19 = 485,
  V14_V15_V16_V17_V18_V19_V20 = 486,
  V15_V16_V17_V18_V19_V20_V21 = 487,
  V16_V17_V18_V19_V20_V21_V22 = 488,
  V17_V18_V19_V20_V21_V22_V23 = 489,
  V18_V19_V20_V21_V22_V23_V24 = 490,
  V19_V20_V21_V22_V23_V24_V25 = 491,
  V20_V21_V22_V23_V24_V25_V26 = 492,
  V21_V22_V23_V24_V25_V26_V27 = 493,
  V22_V23_V24_V25_V26_V27_V28 = 494,
  V23_V24_V25_V26_V27_V28_V29 = 495,
  V24_V25_V26_V27_V28_V29_V30 = 496,
  V25_V26_V27_V28_V29_V30_V31 = 497,
  V0_V1_V2_V3_V4_V5_V6 = 498,
  V1_V2_V3_V4_V5_V6_V7_V8 = 499,
  V2_V3_V4_V5_V6_V7_V8_V9 = 500,
  V3_V4_V5_V6_V7_V8_V9_V10 = 501,
  V4_V5_V6_V7_V8_V9_V10_V11 = 502,
  V5_V6_V7_V8_V9_V10_V11_V12 = 503,
  V6_V7_V8_V9_V10_V11_V12_V13 = 504,
  V7_V8_V9_V10_V11_V12_V13_V14 = 505,
  V8_V9_V10_V11_V12_V13_V14_V15 = 506,
  V9_V10_V11_V12_V13_V14_V15_V16 = 507,
  V10_V11_V12_V13_V14_V15_V16_V17 = 508,
  V11_V12_V13_V14_V15_V16_V17_V18 = 509,
  V12_V13_V14_V15_V16_V17_V18_V19 = 510,
  V13_V14_V15_V16_V17_V18_V19_V20 = 511,
  V14_V15_V16_V17_V18_V19_V20_V21 = 512,
  V15_V16_V17_V18_V19_V20_V21_V22 = 513,
  V16_V17_V18_V19_V20_V21_V22_V23 = 514,
  V17_V18_V19_V20_V21_V22_V23_V24 = 515,
  V18_V19_V20_V21_V22_V23_V24_V25 = 516,
  V19_V20_V21_V22_V23_V24_V25_V26 = 517,
  V20_V21_V22_V23_V24_V25_V26_V27 = 518,
  V21_V22_V23_V24_V25_V26_V27_V28 = 519,
  V22_V23_V24_V25_V26_V27_V28_V29 = 520,
  V23_V24_V25_V26_V27_V28_V29_V30 = 521,
  V24_V25_V26_V27_V28_V29_V30_V31 = 522,
  V0_V1_V2_V3_V4_V5_V6_V7 = 523,
  NUM_TARGET_REGS = 524,
};

}
}
}
#endif
