/* Copyright 2022 - 2025 R. Thomas
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
#ifndef LIEF_ASM_X86_OPCODE_H
#define LIEF_ASM_X86_OPCODE_H

/* Generated from LLVM: 20.1.2 */

namespace LIEF {
namespace assembly {
namespace x86 {
enum class OPCODE {
  PHI = 0,
  INLINEASM = 1,
  INLINEASM_BR = 2,
  CFI_INSTRUCTION = 3,
  EH_LABEL = 4,
  GC_LABEL = 5,
  ANNOTATION_LABEL = 6,
  KILL = 7,
  EXTRACT_SUBREG = 8,
  INSERT_SUBREG = 9,
  IMPLICIT_DEF = 10,
  INIT_UNDEF = 11,
  SUBREG_TO_REG = 12,
  COPY_TO_REGCLASS = 13,
  DBG_VALUE = 14,
  DBG_VALUE_LIST = 15,
  DBG_INSTR_REF = 16,
  DBG_PHI = 17,
  DBG_LABEL = 18,
  REG_SEQUENCE = 19,
  COPY = 20,
  BUNDLE = 21,
  LIFETIME_START = 22,
  LIFETIME_END = 23,
  PSEUDO_PROBE = 24,
  ARITH_FENCE = 25,
  STACKMAP = 26,
  FENTRY_CALL = 27,
  PATCHPOINT = 28,
  LOAD_STACK_GUARD = 29,
  PREALLOCATED_SETUP = 30,
  PREALLOCATED_ARG = 31,
  STATEPOINT = 32,
  LOCAL_ESCAPE = 33,
  FAULTING_OP = 34,
  PATCHABLE_OP = 35,
  PATCHABLE_FUNCTION_ENTER = 36,
  PATCHABLE_RET = 37,
  PATCHABLE_FUNCTION_EXIT = 38,
  PATCHABLE_TAIL_CALL = 39,
  PATCHABLE_EVENT_CALL = 40,
  PATCHABLE_TYPED_EVENT_CALL = 41,
  ICALL_BRANCH_FUNNEL = 42,
  FAKE_USE = 43,
  MEMBARRIER = 44,
  JUMP_TABLE_DEBUG_INFO = 45,
  CONVERGENCECTRL_ENTRY = 46,
  CONVERGENCECTRL_ANCHOR = 47,
  CONVERGENCECTRL_LOOP = 48,
  CONVERGENCECTRL_GLUE = 49,
  G_ASSERT_SEXT = 50,
  G_ASSERT_ZEXT = 51,
  G_ASSERT_ALIGN = 52,
  G_ADD = 53,
  G_SUB = 54,
  G_MUL = 55,
  G_SDIV = 56,
  G_UDIV = 57,
  G_SREM = 58,
  G_UREM = 59,
  G_SDIVREM = 60,
  G_UDIVREM = 61,
  G_AND = 62,
  G_OR = 63,
  G_XOR = 64,
  G_ABDS = 65,
  G_ABDU = 66,
  G_IMPLICIT_DEF = 67,
  G_PHI = 68,
  G_FRAME_INDEX = 69,
  G_GLOBAL_VALUE = 70,
  G_PTRAUTH_GLOBAL_VALUE = 71,
  G_CONSTANT_POOL = 72,
  G_EXTRACT = 73,
  G_UNMERGE_VALUES = 74,
  G_INSERT = 75,
  G_MERGE_VALUES = 76,
  G_BUILD_VECTOR = 77,
  G_BUILD_VECTOR_TRUNC = 78,
  G_CONCAT_VECTORS = 79,
  G_PTRTOINT = 80,
  G_INTTOPTR = 81,
  G_BITCAST = 82,
  G_FREEZE = 83,
  G_CONSTANT_FOLD_BARRIER = 84,
  G_INTRINSIC_FPTRUNC_ROUND = 85,
  G_INTRINSIC_TRUNC = 86,
  G_INTRINSIC_ROUND = 87,
  G_INTRINSIC_LRINT = 88,
  G_INTRINSIC_LLRINT = 89,
  G_INTRINSIC_ROUNDEVEN = 90,
  G_READCYCLECOUNTER = 91,
  G_READSTEADYCOUNTER = 92,
  G_LOAD = 93,
  G_SEXTLOAD = 94,
  G_ZEXTLOAD = 95,
  G_INDEXED_LOAD = 96,
  G_INDEXED_SEXTLOAD = 97,
  G_INDEXED_ZEXTLOAD = 98,
  G_STORE = 99,
  G_INDEXED_STORE = 100,
  G_ATOMIC_CMPXCHG_WITH_SUCCESS = 101,
  G_ATOMIC_CMPXCHG = 102,
  G_ATOMICRMW_XCHG = 103,
  G_ATOMICRMW_ADD = 104,
  G_ATOMICRMW_SUB = 105,
  G_ATOMICRMW_AND = 106,
  G_ATOMICRMW_NAND = 107,
  G_ATOMICRMW_OR = 108,
  G_ATOMICRMW_XOR = 109,
  G_ATOMICRMW_MAX = 110,
  G_ATOMICRMW_MIN = 111,
  G_ATOMICRMW_UMAX = 112,
  G_ATOMICRMW_UMIN = 113,
  G_ATOMICRMW_FADD = 114,
  G_ATOMICRMW_FSUB = 115,
  G_ATOMICRMW_FMAX = 116,
  G_ATOMICRMW_FMIN = 117,
  G_ATOMICRMW_UINC_WRAP = 118,
  G_ATOMICRMW_UDEC_WRAP = 119,
  G_ATOMICRMW_USUB_COND = 120,
  G_ATOMICRMW_USUB_SAT = 121,
  G_FENCE = 122,
  G_PREFETCH = 123,
  G_BRCOND = 124,
  G_BRINDIRECT = 125,
  G_INVOKE_REGION_START = 126,
  G_INTRINSIC = 127,
  G_INTRINSIC_W_SIDE_EFFECTS = 128,
  G_INTRINSIC_CONVERGENT = 129,
  G_INTRINSIC_CONVERGENT_W_SIDE_EFFECTS = 130,
  G_ANYEXT = 131,
  G_TRUNC = 132,
  G_CONSTANT = 133,
  G_FCONSTANT = 134,
  G_VASTART = 135,
  G_VAARG = 136,
  G_SEXT = 137,
  G_SEXT_INREG = 138,
  G_ZEXT = 139,
  G_SHL = 140,
  G_LSHR = 141,
  G_ASHR = 142,
  G_FSHL = 143,
  G_FSHR = 144,
  G_ROTR = 145,
  G_ROTL = 146,
  G_ICMP = 147,
  G_FCMP = 148,
  G_SCMP = 149,
  G_UCMP = 150,
  G_SELECT = 151,
  G_UADDO = 152,
  G_UADDE = 153,
  G_USUBO = 154,
  G_USUBE = 155,
  G_SADDO = 156,
  G_SADDE = 157,
  G_SSUBO = 158,
  G_SSUBE = 159,
  G_UMULO = 160,
  G_SMULO = 161,
  G_UMULH = 162,
  G_SMULH = 163,
  G_UADDSAT = 164,
  G_SADDSAT = 165,
  G_USUBSAT = 166,
  G_SSUBSAT = 167,
  G_USHLSAT = 168,
  G_SSHLSAT = 169,
  G_SMULFIX = 170,
  G_UMULFIX = 171,
  G_SMULFIXSAT = 172,
  G_UMULFIXSAT = 173,
  G_SDIVFIX = 174,
  G_UDIVFIX = 175,
  G_SDIVFIXSAT = 176,
  G_UDIVFIXSAT = 177,
  G_FADD = 178,
  G_FSUB = 179,
  G_FMUL = 180,
  G_FMA = 181,
  G_FMAD = 182,
  G_FDIV = 183,
  G_FREM = 184,
  G_FPOW = 185,
  G_FPOWI = 186,
  G_FEXP = 187,
  G_FEXP2 = 188,
  G_FEXP10 = 189,
  G_FLOG = 190,
  G_FLOG2 = 191,
  G_FLOG10 = 192,
  G_FLDEXP = 193,
  G_FFREXP = 194,
  G_FNEG = 195,
  G_FPEXT = 196,
  G_FPTRUNC = 197,
  G_FPTOSI = 198,
  G_FPTOUI = 199,
  G_SITOFP = 200,
  G_UITOFP = 201,
  G_FPTOSI_SAT = 202,
  G_FPTOUI_SAT = 203,
  G_FABS = 204,
  G_FCOPYSIGN = 205,
  G_IS_FPCLASS = 206,
  G_FCANONICALIZE = 207,
  G_FMINNUM = 208,
  G_FMAXNUM = 209,
  G_FMINNUM_IEEE = 210,
  G_FMAXNUM_IEEE = 211,
  G_FMINIMUM = 212,
  G_FMAXIMUM = 213,
  G_GET_FPENV = 214,
  G_SET_FPENV = 215,
  G_RESET_FPENV = 216,
  G_GET_FPMODE = 217,
  G_SET_FPMODE = 218,
  G_RESET_FPMODE = 219,
  G_PTR_ADD = 220,
  G_PTRMASK = 221,
  G_SMIN = 222,
  G_SMAX = 223,
  G_UMIN = 224,
  G_UMAX = 225,
  G_ABS = 226,
  G_LROUND = 227,
  G_LLROUND = 228,
  G_BR = 229,
  G_BRJT = 230,
  G_VSCALE = 231,
  G_INSERT_SUBVECTOR = 232,
  G_EXTRACT_SUBVECTOR = 233,
  G_INSERT_VECTOR_ELT = 234,
  G_EXTRACT_VECTOR_ELT = 235,
  G_SHUFFLE_VECTOR = 236,
  G_SPLAT_VECTOR = 237,
  G_STEP_VECTOR = 238,
  G_VECTOR_COMPRESS = 239,
  G_CTTZ = 240,
  G_CTTZ_ZERO_UNDEF = 241,
  G_CTLZ = 242,
  G_CTLZ_ZERO_UNDEF = 243,
  G_CTPOP = 244,
  G_BSWAP = 245,
  G_BITREVERSE = 246,
  G_FCEIL = 247,
  G_FCOS = 248,
  G_FSIN = 249,
  G_FSINCOS = 250,
  G_FTAN = 251,
  G_FACOS = 252,
  G_FASIN = 253,
  G_FATAN = 254,
  G_FATAN2 = 255,
  G_FCOSH = 256,
  G_FSINH = 257,
  G_FTANH = 258,
  G_FSQRT = 259,
  G_FFLOOR = 260,
  G_FRINT = 261,
  G_FNEARBYINT = 262,
  G_ADDRSPACE_CAST = 263,
  G_BLOCK_ADDR = 264,
  G_JUMP_TABLE = 265,
  G_DYN_STACKALLOC = 266,
  G_STACKSAVE = 267,
  G_STACKRESTORE = 268,
  G_STRICT_FADD = 269,
  G_STRICT_FSUB = 270,
  G_STRICT_FMUL = 271,
  G_STRICT_FDIV = 272,
  G_STRICT_FREM = 273,
  G_STRICT_FMA = 274,
  G_STRICT_FSQRT = 275,
  G_STRICT_FLDEXP = 276,
  G_READ_REGISTER = 277,
  G_WRITE_REGISTER = 278,
  G_MEMCPY = 279,
  G_MEMCPY_INLINE = 280,
  G_MEMMOVE = 281,
  G_MEMSET = 282,
  G_BZERO = 283,
  G_TRAP = 284,
  G_DEBUGTRAP = 285,
  G_UBSANTRAP = 286,
  G_VECREDUCE_SEQ_FADD = 287,
  G_VECREDUCE_SEQ_FMUL = 288,
  G_VECREDUCE_FADD = 289,
  G_VECREDUCE_FMUL = 290,
  G_VECREDUCE_FMAX = 291,
  G_VECREDUCE_FMIN = 292,
  G_VECREDUCE_FMAXIMUM = 293,
  G_VECREDUCE_FMINIMUM = 294,
  G_VECREDUCE_ADD = 295,
  G_VECREDUCE_MUL = 296,
  G_VECREDUCE_AND = 297,
  G_VECREDUCE_OR = 298,
  G_VECREDUCE_XOR = 299,
  G_VECREDUCE_SMAX = 300,
  G_VECREDUCE_SMIN = 301,
  G_VECREDUCE_UMAX = 302,
  G_VECREDUCE_UMIN = 303,
  G_SBFX = 304,
  G_UBFX = 305,
  ADD16ri_DB = 306,
  ADD16rr_DB = 307,
  ADD32ri_DB = 308,
  ADD32rr_DB = 309,
  ADD64ri32_DB = 310,
  ADD64rr_DB = 311,
  ADD8ri_DB = 312,
  ADD8rr_DB = 313,
  AVX1_SETALLONES = 314,
  AVX2_SETALLONES = 315,
  AVX512_128_SET0 = 316,
  AVX512_256_SET0 = 317,
  AVX512_512_SET0 = 318,
  AVX512_512_SETALLONES = 319,
  AVX512_512_SEXT_MASK_32 = 320,
  AVX512_512_SEXT_MASK_64 = 321,
  AVX512_FsFLD0F128 = 322,
  AVX512_FsFLD0SD = 323,
  AVX512_FsFLD0SH = 324,
  AVX512_FsFLD0SS = 325,
  AVX_SET0 = 326,
  CALL64m_RVMARKER = 327,
  CALL64pcrel32_RVMARKER = 328,
  CALL64r_RVMARKER = 329,
  FsFLD0F128 = 330,
  FsFLD0SD = 331,
  FsFLD0SH = 332,
  FsFLD0SS = 333,
  INDIRECT_THUNK_CALL32 = 334,
  INDIRECT_THUNK_CALL64 = 335,
  INDIRECT_THUNK_TCRETURN32 = 336,
  INDIRECT_THUNK_TCRETURN64 = 337,
  KSET0D = 338,
  KSET0Q = 339,
  KSET0W = 340,
  KSET1D = 341,
  KSET1Q = 342,
  KSET1W = 343,
  LCMPXCHG16B_NO_RBX = 344,
  LCMPXCHG16B_SAVE_RBX = 345,
  MMX_SET0 = 346,
  MORESTACK_RET = 347,
  MORESTACK_RET_RESTORE_R10 = 348,
  MOV32ImmSExti8 = 349,
  MOV32r0 = 350,
  MOV32r1 = 351,
  MOV32r_1 = 352,
  MOV32ri64 = 353,
  MOV64ImmSExti8 = 354,
  MWAITX = 355,
  MWAITX_SAVE_RBX = 356,
  PLDTILECFGV = 357,
  PLEA32r = 358,
  PLEA64r = 359,
  PT2RPNTLVWZ0RST1V = 360,
  PT2RPNTLVWZ0RSV = 361,
  PT2RPNTLVWZ0T1V = 362,
  PT2RPNTLVWZ0V = 363,
  PT2RPNTLVWZ1RST1V = 364,
  PT2RPNTLVWZ1RSV = 365,
  PT2RPNTLVWZ1T1V = 366,
  PT2RPNTLVWZ1V = 367,
  PTDPBF16PSV = 368,
  PTDPBSSDV = 369,
  PTDPBSUDV = 370,
  PTDPBUSDV = 371,
  PTDPBUUDV = 372,
  PTDPFP16PSV = 373,
  PTILELOADDRST1V = 374,
  PTILELOADDRSV = 375,
  PTILELOADDT1V = 376,
  PTILELOADDV = 377,
  PTILEPAIRLOAD = 378,
  PTILEPAIRSTORE = 379,
  PTILESTOREDV = 380,
  PTILEZEROV = 381,
  RDFLAGS32 = 382,
  RDFLAGS64 = 383,
  SEH_EndPrologue = 384,
  SEH_Epilogue = 385,
  SEH_PushFrame = 386,
  SEH_PushReg = 387,
  SEH_SaveReg = 388,
  SEH_SaveXMM = 389,
  SEH_SetFrame = 390,
  SEH_StackAlign = 391,
  SEH_StackAlloc = 392,
  SETB_C32r = 393,
  SETB_C64r = 394,
  SHLDROT32ri = 395,
  SHLDROT64ri = 396,
  SHRDROT32ri = 397,
  SHRDROT64ri = 398,
  VMOVAPSZ128mr_NOVLX = 399,
  VMOVAPSZ128rm_NOVLX = 400,
  VMOVAPSZ256mr_NOVLX = 401,
  VMOVAPSZ256rm_NOVLX = 402,
  VMOVUPSZ128mr_NOVLX = 403,
  VMOVUPSZ128rm_NOVLX = 404,
  VMOVUPSZ256mr_NOVLX = 405,
  VMOVUPSZ256rm_NOVLX = 406,
  V_SET0 = 407,
  V_SETALLONES = 408,
  WRFLAGS32 = 409,
  WRFLAGS64 = 410,
  XABORT_DEF = 411,
  XOR32_FP = 412,
  XOR64_FP = 413,
  AAA = 414,
  AAD8i8 = 415,
  AADD32mr = 416,
  AADD32mr_EVEX = 417,
  AADD64mr = 418,
  AADD64mr_EVEX = 419,
  AAM8i8 = 420,
  AAND32mr = 421,
  AAND32mr_EVEX = 422,
  AAND64mr = 423,
  AAND64mr_EVEX = 424,
  AAS = 425,
  ABS_F = 426,
  ABS_Fp32 = 427,
  ABS_Fp64 = 428,
  ABS_Fp80 = 429,
  ADC16i16 = 430,
  ADC16mi = 431,
  ADC16mi8 = 432,
  ADC16mi8_EVEX = 433,
  ADC16mi8_ND = 434,
  ADC16mi_EVEX = 435,
  ADC16mi_ND = 436,
  ADC16mr = 437,
  ADC16mr_EVEX = 438,
  ADC16mr_ND = 439,
  ADC16ri = 440,
  ADC16ri8 = 441,
  ADC16ri8_EVEX = 442,
  ADC16ri8_ND = 443,
  ADC16ri_EVEX = 444,
  ADC16ri_ND = 445,
  ADC16rm = 446,
  ADC16rm_EVEX = 447,
  ADC16rm_ND = 448,
  ADC16rr = 449,
  ADC16rr_EVEX = 450,
  ADC16rr_EVEX_REV = 451,
  ADC16rr_ND = 452,
  ADC16rr_ND_REV = 453,
  ADC16rr_REV = 454,
  ADC32i32 = 455,
  ADC32mi = 456,
  ADC32mi8 = 457,
  ADC32mi8_EVEX = 458,
  ADC32mi8_ND = 459,
  ADC32mi_EVEX = 460,
  ADC32mi_ND = 461,
  ADC32mr = 462,
  ADC32mr_EVEX = 463,
  ADC32mr_ND = 464,
  ADC32ri = 465,
  ADC32ri8 = 466,
  ADC32ri8_EVEX = 467,
  ADC32ri8_ND = 468,
  ADC32ri_EVEX = 469,
  ADC32ri_ND = 470,
  ADC32rm = 471,
  ADC32rm_EVEX = 472,
  ADC32rm_ND = 473,
  ADC32rr = 474,
  ADC32rr_EVEX = 475,
  ADC32rr_EVEX_REV = 476,
  ADC32rr_ND = 477,
  ADC32rr_ND_REV = 478,
  ADC32rr_REV = 479,
  ADC64i32 = 480,
  ADC64mi32 = 481,
  ADC64mi32_EVEX = 482,
  ADC64mi32_ND = 483,
  ADC64mi8 = 484,
  ADC64mi8_EVEX = 485,
  ADC64mi8_ND = 486,
  ADC64mr = 487,
  ADC64mr_EVEX = 488,
  ADC64mr_ND = 489,
  ADC64ri32 = 490,
  ADC64ri32_EVEX = 491,
  ADC64ri32_ND = 492,
  ADC64ri8 = 493,
  ADC64ri8_EVEX = 494,
  ADC64ri8_ND = 495,
  ADC64rm = 496,
  ADC64rm_EVEX = 497,
  ADC64rm_ND = 498,
  ADC64rr = 499,
  ADC64rr_EVEX = 500,
  ADC64rr_EVEX_REV = 501,
  ADC64rr_ND = 502,
  ADC64rr_ND_REV = 503,
  ADC64rr_REV = 504,
  ADC8i8 = 505,
  ADC8mi = 506,
  ADC8mi8 = 507,
  ADC8mi_EVEX = 508,
  ADC8mi_ND = 509,
  ADC8mr = 510,
  ADC8mr_EVEX = 511,
  ADC8mr_ND = 512,
  ADC8ri = 513,
  ADC8ri8 = 514,
  ADC8ri_EVEX = 515,
  ADC8ri_ND = 516,
  ADC8rm = 517,
  ADC8rm_EVEX = 518,
  ADC8rm_ND = 519,
  ADC8rr = 520,
  ADC8rr_EVEX = 521,
  ADC8rr_EVEX_REV = 522,
  ADC8rr_ND = 523,
  ADC8rr_ND_REV = 524,
  ADC8rr_REV = 525,
  ADCX32rm = 526,
  ADCX32rm_EVEX = 527,
  ADCX32rm_ND = 528,
  ADCX32rr = 529,
  ADCX32rr_EVEX = 530,
  ADCX32rr_ND = 531,
  ADCX64rm = 532,
  ADCX64rm_EVEX = 533,
  ADCX64rm_ND = 534,
  ADCX64rr = 535,
  ADCX64rr_EVEX = 536,
  ADCX64rr_ND = 537,
  ADD16i16 = 538,
  ADD16mi = 539,
  ADD16mi8 = 540,
  ADD16mi8_EVEX = 541,
  ADD16mi8_ND = 542,
  ADD16mi8_NF = 543,
  ADD16mi8_NF_ND = 544,
  ADD16mi_EVEX = 545,
  ADD16mi_ND = 546,
  ADD16mi_NF = 547,
  ADD16mi_NF_ND = 548,
  ADD16mr = 549,
  ADD16mr_EVEX = 550,
  ADD16mr_ND = 551,
  ADD16mr_NF = 552,
  ADD16mr_NF_ND = 553,
  ADD16ri = 554,
  ADD16ri8 = 555,
  ADD16ri8_EVEX = 556,
  ADD16ri8_ND = 557,
  ADD16ri8_NF = 558,
  ADD16ri8_NF_ND = 559,
  ADD16ri_EVEX = 560,
  ADD16ri_ND = 561,
  ADD16ri_NF = 562,
  ADD16ri_NF_ND = 563,
  ADD16rm = 564,
  ADD16rm_EVEX = 565,
  ADD16rm_ND = 566,
  ADD16rm_NF = 567,
  ADD16rm_NF_ND = 568,
  ADD16rr = 569,
  ADD16rr_EVEX = 570,
  ADD16rr_EVEX_REV = 571,
  ADD16rr_ND = 572,
  ADD16rr_ND_REV = 573,
  ADD16rr_NF = 574,
  ADD16rr_NF_ND = 575,
  ADD16rr_NF_ND_REV = 576,
  ADD16rr_NF_REV = 577,
  ADD16rr_REV = 578,
  ADD32i32 = 579,
  ADD32mi = 580,
  ADD32mi8 = 581,
  ADD32mi8_EVEX = 582,
  ADD32mi8_ND = 583,
  ADD32mi8_NF = 584,
  ADD32mi8_NF_ND = 585,
  ADD32mi_EVEX = 586,
  ADD32mi_ND = 587,
  ADD32mi_NF = 588,
  ADD32mi_NF_ND = 589,
  ADD32mr = 590,
  ADD32mr_EVEX = 591,
  ADD32mr_ND = 592,
  ADD32mr_NF = 593,
  ADD32mr_NF_ND = 594,
  ADD32ri = 595,
  ADD32ri8 = 596,
  ADD32ri8_EVEX = 597,
  ADD32ri8_ND = 598,
  ADD32ri8_NF = 599,
  ADD32ri8_NF_ND = 600,
  ADD32ri_EVEX = 601,
  ADD32ri_ND = 602,
  ADD32ri_NF = 603,
  ADD32ri_NF_ND = 604,
  ADD32rm = 605,
  ADD32rm_EVEX = 606,
  ADD32rm_ND = 607,
  ADD32rm_NF = 608,
  ADD32rm_NF_ND = 609,
  ADD32rr = 610,
  ADD32rr_EVEX = 611,
  ADD32rr_EVEX_REV = 612,
  ADD32rr_ND = 613,
  ADD32rr_ND_REV = 614,
  ADD32rr_NF = 615,
  ADD32rr_NF_ND = 616,
  ADD32rr_NF_ND_REV = 617,
  ADD32rr_NF_REV = 618,
  ADD32rr_REV = 619,
  ADD64i32 = 620,
  ADD64mi32 = 621,
  ADD64mi32_EVEX = 622,
  ADD64mi32_ND = 623,
  ADD64mi32_NF = 624,
  ADD64mi32_NF_ND = 625,
  ADD64mi8 = 626,
  ADD64mi8_EVEX = 627,
  ADD64mi8_ND = 628,
  ADD64mi8_NF = 629,
  ADD64mi8_NF_ND = 630,
  ADD64mr = 631,
  ADD64mr_EVEX = 632,
  ADD64mr_ND = 633,
  ADD64mr_NF = 634,
  ADD64mr_NF_ND = 635,
  ADD64ri32 = 636,
  ADD64ri32_EVEX = 637,
  ADD64ri32_ND = 638,
  ADD64ri32_NF = 639,
  ADD64ri32_NF_ND = 640,
  ADD64ri8 = 641,
  ADD64ri8_EVEX = 642,
  ADD64ri8_ND = 643,
  ADD64ri8_NF = 644,
  ADD64ri8_NF_ND = 645,
  ADD64rm = 646,
  ADD64rm_EVEX = 647,
  ADD64rm_ND = 648,
  ADD64rm_NF = 649,
  ADD64rm_NF_ND = 650,
  ADD64rr = 651,
  ADD64rr_EVEX = 652,
  ADD64rr_EVEX_REV = 653,
  ADD64rr_ND = 654,
  ADD64rr_ND_REV = 655,
  ADD64rr_NF = 656,
  ADD64rr_NF_ND = 657,
  ADD64rr_NF_ND_REV = 658,
  ADD64rr_NF_REV = 659,
  ADD64rr_REV = 660,
  ADD8i8 = 661,
  ADD8mi = 662,
  ADD8mi8 = 663,
  ADD8mi_EVEX = 664,
  ADD8mi_ND = 665,
  ADD8mi_NF = 666,
  ADD8mi_NF_ND = 667,
  ADD8mr = 668,
  ADD8mr_EVEX = 669,
  ADD8mr_ND = 670,
  ADD8mr_NF = 671,
  ADD8mr_NF_ND = 672,
  ADD8ri = 673,
  ADD8ri8 = 674,
  ADD8ri_EVEX = 675,
  ADD8ri_ND = 676,
  ADD8ri_NF = 677,
  ADD8ri_NF_ND = 678,
  ADD8rm = 679,
  ADD8rm_EVEX = 680,
  ADD8rm_ND = 681,
  ADD8rm_NF = 682,
  ADD8rm_NF_ND = 683,
  ADD8rr = 684,
  ADD8rr_EVEX = 685,
  ADD8rr_EVEX_REV = 686,
  ADD8rr_ND = 687,
  ADD8rr_ND_REV = 688,
  ADD8rr_NF = 689,
  ADD8rr_NF_ND = 690,
  ADD8rr_NF_ND_REV = 691,
  ADD8rr_NF_REV = 692,
  ADD8rr_REV = 693,
  ADDPDrm = 694,
  ADDPDrr = 695,
  ADDPSrm = 696,
  ADDPSrr = 697,
  ADDR16_PREFIX = 698,
  ADDR32_PREFIX = 699,
  ADDSDrm = 700,
  ADDSDrm_Int = 701,
  ADDSDrr = 702,
  ADDSDrr_Int = 703,
  ADDSSrm = 704,
  ADDSSrm_Int = 705,
  ADDSSrr = 706,
  ADDSSrr_Int = 707,
  ADDSUBPDrm = 708,
  ADDSUBPDrr = 709,
  ADDSUBPSrm = 710,
  ADDSUBPSrr = 711,
  ADD_F32m = 712,
  ADD_F64m = 713,
  ADD_FI16m = 714,
  ADD_FI32m = 715,
  ADD_FPrST0 = 716,
  ADD_FST0r = 717,
  ADD_Fp32 = 718,
  ADD_Fp32m = 719,
  ADD_Fp64 = 720,
  ADD_Fp64m = 721,
  ADD_Fp64m32 = 722,
  ADD_Fp80 = 723,
  ADD_Fp80m32 = 724,
  ADD_Fp80m64 = 725,
  ADD_FpI16m32 = 726,
  ADD_FpI16m64 = 727,
  ADD_FpI16m80 = 728,
  ADD_FpI32m32 = 729,
  ADD_FpI32m64 = 730,
  ADD_FpI32m80 = 731,
  ADD_FrST0 = 732,
  ADJCALLSTACKDOWN32 = 733,
  ADJCALLSTACKDOWN64 = 734,
  ADJCALLSTACKUP32 = 735,
  ADJCALLSTACKUP64 = 736,
  ADOX32rm = 737,
  ADOX32rm_EVEX = 738,
  ADOX32rm_ND = 739,
  ADOX32rr = 740,
  ADOX32rr_EVEX = 741,
  ADOX32rr_ND = 742,
  ADOX64rm = 743,
  ADOX64rm_EVEX = 744,
  ADOX64rm_ND = 745,
  ADOX64rr = 746,
  ADOX64rr_EVEX = 747,
  ADOX64rr_ND = 748,
  AESDEC128KL = 749,
  AESDEC256KL = 750,
  AESDECLASTrm = 751,
  AESDECLASTrr = 752,
  AESDECWIDE128KL = 753,
  AESDECWIDE256KL = 754,
  AESDECrm = 755,
  AESDECrr = 756,
  AESENC128KL = 757,
  AESENC256KL = 758,
  AESENCLASTrm = 759,
  AESENCLASTrr = 760,
  AESENCWIDE128KL = 761,
  AESENCWIDE256KL = 762,
  AESENCrm = 763,
  AESENCrr = 764,
  AESIMCrm = 765,
  AESIMCrr = 766,
  AESKEYGENASSIST128rm = 767,
  AESKEYGENASSIST128rr = 768,
  AND16i16 = 769,
  AND16mi = 770,
  AND16mi8 = 771,
  AND16mi8_EVEX = 772,
  AND16mi8_ND = 773,
  AND16mi8_NF = 774,
  AND16mi8_NF_ND = 775,
  AND16mi_EVEX = 776,
  AND16mi_ND = 777,
  AND16mi_NF = 778,
  AND16mi_NF_ND = 779,
  AND16mr = 780,
  AND16mr_EVEX = 781,
  AND16mr_ND = 782,
  AND16mr_NF = 783,
  AND16mr_NF_ND = 784,
  AND16ri = 785,
  AND16ri8 = 786,
  AND16ri8_EVEX = 787,
  AND16ri8_ND = 788,
  AND16ri8_NF = 789,
  AND16ri8_NF_ND = 790,
  AND16ri_EVEX = 791,
  AND16ri_ND = 792,
  AND16ri_NF = 793,
  AND16ri_NF_ND = 794,
  AND16rm = 795,
  AND16rm_EVEX = 796,
  AND16rm_ND = 797,
  AND16rm_NF = 798,
  AND16rm_NF_ND = 799,
  AND16rr = 800,
  AND16rr_EVEX = 801,
  AND16rr_EVEX_REV = 802,
  AND16rr_ND = 803,
  AND16rr_ND_REV = 804,
  AND16rr_NF = 805,
  AND16rr_NF_ND = 806,
  AND16rr_NF_ND_REV = 807,
  AND16rr_NF_REV = 808,
  AND16rr_REV = 809,
  AND32i32 = 810,
  AND32mi = 811,
  AND32mi8 = 812,
  AND32mi8_EVEX = 813,
  AND32mi8_ND = 814,
  AND32mi8_NF = 815,
  AND32mi8_NF_ND = 816,
  AND32mi_EVEX = 817,
  AND32mi_ND = 818,
  AND32mi_NF = 819,
  AND32mi_NF_ND = 820,
  AND32mr = 821,
  AND32mr_EVEX = 822,
  AND32mr_ND = 823,
  AND32mr_NF = 824,
  AND32mr_NF_ND = 825,
  AND32ri = 826,
  AND32ri8 = 827,
  AND32ri8_EVEX = 828,
  AND32ri8_ND = 829,
  AND32ri8_NF = 830,
  AND32ri8_NF_ND = 831,
  AND32ri_EVEX = 832,
  AND32ri_ND = 833,
  AND32ri_NF = 834,
  AND32ri_NF_ND = 835,
  AND32rm = 836,
  AND32rm_EVEX = 837,
  AND32rm_ND = 838,
  AND32rm_NF = 839,
  AND32rm_NF_ND = 840,
  AND32rr = 841,
  AND32rr_EVEX = 842,
  AND32rr_EVEX_REV = 843,
  AND32rr_ND = 844,
  AND32rr_ND_REV = 845,
  AND32rr_NF = 846,
  AND32rr_NF_ND = 847,
  AND32rr_NF_ND_REV = 848,
  AND32rr_NF_REV = 849,
  AND32rr_REV = 850,
  AND64i32 = 851,
  AND64mi32 = 852,
  AND64mi32_EVEX = 853,
  AND64mi32_ND = 854,
  AND64mi32_NF = 855,
  AND64mi32_NF_ND = 856,
  AND64mi8 = 857,
  AND64mi8_EVEX = 858,
  AND64mi8_ND = 859,
  AND64mi8_NF = 860,
  AND64mi8_NF_ND = 861,
  AND64mr = 862,
  AND64mr_EVEX = 863,
  AND64mr_ND = 864,
  AND64mr_NF = 865,
  AND64mr_NF_ND = 866,
  AND64ri32 = 867,
  AND64ri32_EVEX = 868,
  AND64ri32_ND = 869,
  AND64ri32_NF = 870,
  AND64ri32_NF_ND = 871,
  AND64ri8 = 872,
  AND64ri8_EVEX = 873,
  AND64ri8_ND = 874,
  AND64ri8_NF = 875,
  AND64ri8_NF_ND = 876,
  AND64rm = 877,
  AND64rm_EVEX = 878,
  AND64rm_ND = 879,
  AND64rm_NF = 880,
  AND64rm_NF_ND = 881,
  AND64rr = 882,
  AND64rr_EVEX = 883,
  AND64rr_EVEX_REV = 884,
  AND64rr_ND = 885,
  AND64rr_ND_REV = 886,
  AND64rr_NF = 887,
  AND64rr_NF_ND = 888,
  AND64rr_NF_ND_REV = 889,
  AND64rr_NF_REV = 890,
  AND64rr_REV = 891,
  AND8i8 = 892,
  AND8mi = 893,
  AND8mi8 = 894,
  AND8mi_EVEX = 895,
  AND8mi_ND = 896,
  AND8mi_NF = 897,
  AND8mi_NF_ND = 898,
  AND8mr = 899,
  AND8mr_EVEX = 900,
  AND8mr_ND = 901,
  AND8mr_NF = 902,
  AND8mr_NF_ND = 903,
  AND8ri = 904,
  AND8ri8 = 905,
  AND8ri_EVEX = 906,
  AND8ri_ND = 907,
  AND8ri_NF = 908,
  AND8ri_NF_ND = 909,
  AND8rm = 910,
  AND8rm_EVEX = 911,
  AND8rm_ND = 912,
  AND8rm_NF = 913,
  AND8rm_NF_ND = 914,
  AND8rr = 915,
  AND8rr_EVEX = 916,
  AND8rr_EVEX_REV = 917,
  AND8rr_ND = 918,
  AND8rr_ND_REV = 919,
  AND8rr_NF = 920,
  AND8rr_NF_ND = 921,
  AND8rr_NF_ND_REV = 922,
  AND8rr_NF_REV = 923,
  AND8rr_REV = 924,
  ANDN32rm = 925,
  ANDN32rm_EVEX = 926,
  ANDN32rm_NF = 927,
  ANDN32rr = 928,
  ANDN32rr_EVEX = 929,
  ANDN32rr_NF = 930,
  ANDN64rm = 931,
  ANDN64rm_EVEX = 932,
  ANDN64rm_NF = 933,
  ANDN64rr = 934,
  ANDN64rr_EVEX = 935,
  ANDN64rr_NF = 936,
  ANDNPDrm = 937,
  ANDNPDrr = 938,
  ANDNPSrm = 939,
  ANDNPSrr = 940,
  ANDPDrm = 941,
  ANDPDrr = 942,
  ANDPSrm = 943,
  ANDPSrr = 944,
  AOR32mr = 945,
  AOR32mr_EVEX = 946,
  AOR64mr = 947,
  AOR64mr_EVEX = 948,
  ARPL16mr = 949,
  ARPL16rr = 950,
  ASAN_CHECK_MEMACCESS = 951,
  AXOR32mr = 952,
  AXOR32mr_EVEX = 953,
  AXOR64mr = 954,
  AXOR64mr_EVEX = 955,
  BEXTR32rm = 956,
  BEXTR32rm_EVEX = 957,
  BEXTR32rm_NF = 958,
  BEXTR32rr = 959,
  BEXTR32rr_EVEX = 960,
  BEXTR32rr_NF = 961,
  BEXTR64rm = 962,
  BEXTR64rm_EVEX = 963,
  BEXTR64rm_NF = 964,
  BEXTR64rr = 965,
  BEXTR64rr_EVEX = 966,
  BEXTR64rr_NF = 967,
  BEXTRI32mi = 968,
  BEXTRI32ri = 969,
  BEXTRI64mi = 970,
  BEXTRI64ri = 971,
  BLCFILL32rm = 972,
  BLCFILL32rr = 973,
  BLCFILL64rm = 974,
  BLCFILL64rr = 975,
  BLCI32rm = 976,
  BLCI32rr = 977,
  BLCI64rm = 978,
  BLCI64rr = 979,
  BLCIC32rm = 980,
  BLCIC32rr = 981,
  BLCIC64rm = 982,
  BLCIC64rr = 983,
  BLCMSK32rm = 984,
  BLCMSK32rr = 985,
  BLCMSK64rm = 986,
  BLCMSK64rr = 987,
  BLCS32rm = 988,
  BLCS32rr = 989,
  BLCS64rm = 990,
  BLCS64rr = 991,
  BLENDPDrmi = 992,
  BLENDPDrri = 993,
  BLENDPSrmi = 994,
  BLENDPSrri = 995,
  BLENDVPDrm0 = 996,
  BLENDVPDrr0 = 997,
  BLENDVPSrm0 = 998,
  BLENDVPSrr0 = 999,
  BLSFILL32rm = 1000,
  BLSFILL32rr = 1001,
  BLSFILL64rm = 1002,
  BLSFILL64rr = 1003,
  BLSI32rm = 1004,
  BLSI32rm_EVEX = 1005,
  BLSI32rm_NF = 1006,
  BLSI32rr = 1007,
  BLSI32rr_EVEX = 1008,
  BLSI32rr_NF = 1009,
  BLSI64rm = 1010,
  BLSI64rm_EVEX = 1011,
  BLSI64rm_NF = 1012,
  BLSI64rr = 1013,
  BLSI64rr_EVEX = 1014,
  BLSI64rr_NF = 1015,
  BLSIC32rm = 1016,
  BLSIC32rr = 1017,
  BLSIC64rm = 1018,
  BLSIC64rr = 1019,
  BLSMSK32rm = 1020,
  BLSMSK32rm_EVEX = 1021,
  BLSMSK32rm_NF = 1022,
  BLSMSK32rr = 1023,
  BLSMSK32rr_EVEX = 1024,
  BLSMSK32rr_NF = 1025,
  BLSMSK64rm = 1026,
  BLSMSK64rm_EVEX = 1027,
  BLSMSK64rm_NF = 1028,
  BLSMSK64rr = 1029,
  BLSMSK64rr_EVEX = 1030,
  BLSMSK64rr_NF = 1031,
  BLSR32rm = 1032,
  BLSR32rm_EVEX = 1033,
  BLSR32rm_NF = 1034,
  BLSR32rr = 1035,
  BLSR32rr_EVEX = 1036,
  BLSR32rr_NF = 1037,
  BLSR64rm = 1038,
  BLSR64rm_EVEX = 1039,
  BLSR64rm_NF = 1040,
  BLSR64rr = 1041,
  BLSR64rr_EVEX = 1042,
  BLSR64rr_NF = 1043,
  BOUNDS16rm = 1044,
  BOUNDS32rm = 1045,
  BSF16rm = 1046,
  BSF16rr = 1047,
  BSF32rm = 1048,
  BSF32rr = 1049,
  BSF64rm = 1050,
  BSF64rr = 1051,
  BSR16rm = 1052,
  BSR16rr = 1053,
  BSR32rm = 1054,
  BSR32rr = 1055,
  BSR64rm = 1056,
  BSR64rr = 1057,
  BSWAP16r_BAD = 1058,
  BSWAP32r = 1059,
  BSWAP64r = 1060,
  BT16mi8 = 1061,
  BT16mr = 1062,
  BT16ri8 = 1063,
  BT16rr = 1064,
  BT32mi8 = 1065,
  BT32mr = 1066,
  BT32ri8 = 1067,
  BT32rr = 1068,
  BT64mi8 = 1069,
  BT64mr = 1070,
  BT64ri8 = 1071,
  BT64rr = 1072,
  BTC16mi8 = 1073,
  BTC16mr = 1074,
  BTC16ri8 = 1075,
  BTC16rr = 1076,
  BTC32mi8 = 1077,
  BTC32mr = 1078,
  BTC32ri8 = 1079,
  BTC32rr = 1080,
  BTC64mi8 = 1081,
  BTC64mr = 1082,
  BTC64ri8 = 1083,
  BTC64rr = 1084,
  BTR16mi8 = 1085,
  BTR16mr = 1086,
  BTR16ri8 = 1087,
  BTR16rr = 1088,
  BTR32mi8 = 1089,
  BTR32mr = 1090,
  BTR32ri8 = 1091,
  BTR32rr = 1092,
  BTR64mi8 = 1093,
  BTR64mr = 1094,
  BTR64ri8 = 1095,
  BTR64rr = 1096,
  BTS16mi8 = 1097,
  BTS16mr = 1098,
  BTS16ri8 = 1099,
  BTS16rr = 1100,
  BTS32mi8 = 1101,
  BTS32mr = 1102,
  BTS32ri8 = 1103,
  BTS32rr = 1104,
  BTS64mi8 = 1105,
  BTS64mr = 1106,
  BTS64ri8 = 1107,
  BTS64rr = 1108,
  BZHI32rm = 1109,
  BZHI32rm_EVEX = 1110,
  BZHI32rm_NF = 1111,
  BZHI32rr = 1112,
  BZHI32rr_EVEX = 1113,
  BZHI32rr_NF = 1114,
  BZHI64rm = 1115,
  BZHI64rm_EVEX = 1116,
  BZHI64rm_NF = 1117,
  BZHI64rr = 1118,
  BZHI64rr_EVEX = 1119,
  BZHI64rr_NF = 1120,
  CALL16m = 1121,
  CALL16m_NT = 1122,
  CALL16r = 1123,
  CALL16r_NT = 1124,
  CALL32m = 1125,
  CALL32m_NT = 1126,
  CALL32r = 1127,
  CALL32r_NT = 1128,
  CALL64m = 1129,
  CALL64m_NT = 1130,
  CALL64pcrel32 = 1131,
  CALL64r = 1132,
  CALL64r_NT = 1133,
  CALLpcrel16 = 1134,
  CALLpcrel32 = 1135,
  CATCHRET = 1136,
  CBW = 1137,
  CCMP16mi = 1138,
  CCMP16mi8 = 1139,
  CCMP16mr = 1140,
  CCMP16ri = 1141,
  CCMP16ri8 = 1142,
  CCMP16rm = 1143,
  CCMP16rr = 1144,
  CCMP16rr_REV = 1145,
  CCMP32mi = 1146,
  CCMP32mi8 = 1147,
  CCMP32mr = 1148,
  CCMP32ri = 1149,
  CCMP32ri8 = 1150,
  CCMP32rm = 1151,
  CCMP32rr = 1152,
  CCMP32rr_REV = 1153,
  CCMP64mi32 = 1154,
  CCMP64mi8 = 1155,
  CCMP64mr = 1156,
  CCMP64ri32 = 1157,
  CCMP64ri8 = 1158,
  CCMP64rm = 1159,
  CCMP64rr = 1160,
  CCMP64rr_REV = 1161,
  CCMP8mi = 1162,
  CCMP8mr = 1163,
  CCMP8ri = 1164,
  CCMP8rm = 1165,
  CCMP8rr = 1166,
  CCMP8rr_REV = 1167,
  CDQ = 1168,
  CDQE = 1169,
  CFCMOV16mr = 1170,
  CFCMOV16rm = 1171,
  CFCMOV16rm_ND = 1172,
  CFCMOV16rr = 1173,
  CFCMOV16rr_ND = 1174,
  CFCMOV16rr_REV = 1175,
  CFCMOV32mr = 1176,
  CFCMOV32rm = 1177,
  CFCMOV32rm_ND = 1178,
  CFCMOV32rr = 1179,
  CFCMOV32rr_ND = 1180,
  CFCMOV32rr_REV = 1181,
  CFCMOV64mr = 1182,
  CFCMOV64rm = 1183,
  CFCMOV64rm_ND = 1184,
  CFCMOV64rr = 1185,
  CFCMOV64rr_ND = 1186,
  CFCMOV64rr_REV = 1187,
  CHS_F = 1188,
  CHS_Fp32 = 1189,
  CHS_Fp64 = 1190,
  CHS_Fp80 = 1191,
  CLAC = 1192,
  CLC = 1193,
  CLD = 1194,
  CLDEMOTE = 1195,
  CLEANUPRET = 1196,
  CLFLUSH = 1197,
  CLFLUSHOPT = 1198,
  CLGI = 1199,
  CLI = 1200,
  CLRSSBSY = 1201,
  CLTS = 1202,
  CLUI = 1203,
  CLWB = 1204,
  CLZERO32r = 1205,
  CLZERO64r = 1206,
  CMC = 1207,
  CMOV16rm = 1208,
  CMOV16rm_ND = 1209,
  CMOV16rr = 1210,
  CMOV16rr_ND = 1211,
  CMOV32rm = 1212,
  CMOV32rm_ND = 1213,
  CMOV32rr = 1214,
  CMOV32rr_ND = 1215,
  CMOV64rm = 1216,
  CMOV64rm_ND = 1217,
  CMOV64rr = 1218,
  CMOV64rr_ND = 1219,
  CMOVBE_F = 1220,
  CMOVBE_Fp32 = 1221,
  CMOVBE_Fp64 = 1222,
  CMOVBE_Fp80 = 1223,
  CMOVB_F = 1224,
  CMOVB_Fp32 = 1225,
  CMOVB_Fp64 = 1226,
  CMOVB_Fp80 = 1227,
  CMOVE_F = 1228,
  CMOVE_Fp32 = 1229,
  CMOVE_Fp64 = 1230,
  CMOVE_Fp80 = 1231,
  CMOVNBE_F = 1232,
  CMOVNBE_Fp32 = 1233,
  CMOVNBE_Fp64 = 1234,
  CMOVNBE_Fp80 = 1235,
  CMOVNB_F = 1236,
  CMOVNB_Fp32 = 1237,
  CMOVNB_Fp64 = 1238,
  CMOVNB_Fp80 = 1239,
  CMOVNE_F = 1240,
  CMOVNE_Fp32 = 1241,
  CMOVNE_Fp64 = 1242,
  CMOVNE_Fp80 = 1243,
  CMOVNP_F = 1244,
  CMOVNP_Fp32 = 1245,
  CMOVNP_Fp64 = 1246,
  CMOVNP_Fp80 = 1247,
  CMOVP_F = 1248,
  CMOVP_Fp32 = 1249,
  CMOVP_Fp64 = 1250,
  CMOVP_Fp80 = 1251,
  CMOV_FR16 = 1252,
  CMOV_FR16X = 1253,
  CMOV_FR32 = 1254,
  CMOV_FR32X = 1255,
  CMOV_FR64 = 1256,
  CMOV_FR64X = 1257,
  CMOV_GR16 = 1258,
  CMOV_GR32 = 1259,
  CMOV_GR8 = 1260,
  CMOV_RFP32 = 1261,
  CMOV_RFP64 = 1262,
  CMOV_RFP80 = 1263,
  CMOV_VK1 = 1264,
  CMOV_VK16 = 1265,
  CMOV_VK2 = 1266,
  CMOV_VK32 = 1267,
  CMOV_VK4 = 1268,
  CMOV_VK64 = 1269,
  CMOV_VK8 = 1270,
  CMOV_VR128 = 1271,
  CMOV_VR128X = 1272,
  CMOV_VR256 = 1273,
  CMOV_VR256X = 1274,
  CMOV_VR512 = 1275,
  CMOV_VR64 = 1276,
  CMP16i16 = 1277,
  CMP16mi = 1278,
  CMP16mi8 = 1279,
  CMP16mr = 1280,
  CMP16ri = 1281,
  CMP16ri8 = 1282,
  CMP16rm = 1283,
  CMP16rr = 1284,
  CMP16rr_REV = 1285,
  CMP32i32 = 1286,
  CMP32mi = 1287,
  CMP32mi8 = 1288,
  CMP32mr = 1289,
  CMP32ri = 1290,
  CMP32ri8 = 1291,
  CMP32rm = 1292,
  CMP32rr = 1293,
  CMP32rr_REV = 1294,
  CMP64i32 = 1295,
  CMP64mi32 = 1296,
  CMP64mi8 = 1297,
  CMP64mr = 1298,
  CMP64ri32 = 1299,
  CMP64ri8 = 1300,
  CMP64rm = 1301,
  CMP64rr = 1302,
  CMP64rr_REV = 1303,
  CMP8i8 = 1304,
  CMP8mi = 1305,
  CMP8mi8 = 1306,
  CMP8mr = 1307,
  CMP8ri = 1308,
  CMP8ri8 = 1309,
  CMP8rm = 1310,
  CMP8rr = 1311,
  CMP8rr_REV = 1312,
  CMPCCXADDmr32 = 1313,
  CMPCCXADDmr32_EVEX = 1314,
  CMPCCXADDmr64 = 1315,
  CMPCCXADDmr64_EVEX = 1316,
  CMPPDrmi = 1317,
  CMPPDrri = 1318,
  CMPPSrmi = 1319,
  CMPPSrri = 1320,
  CMPSB = 1321,
  CMPSDrmi = 1322,
  CMPSDrmi_Int = 1323,
  CMPSDrri = 1324,
  CMPSDrri_Int = 1325,
  CMPSL = 1326,
  CMPSQ = 1327,
  CMPSSrmi = 1328,
  CMPSSrmi_Int = 1329,
  CMPSSrri = 1330,
  CMPSSrri_Int = 1331,
  CMPSW = 1332,
  CMPXCHG16B = 1333,
  CMPXCHG16rm = 1334,
  CMPXCHG16rr = 1335,
  CMPXCHG32rm = 1336,
  CMPXCHG32rr = 1337,
  CMPXCHG64rm = 1338,
  CMPXCHG64rr = 1339,
  CMPXCHG8B = 1340,
  CMPXCHG8rm = 1341,
  CMPXCHG8rr = 1342,
  COMISDrm = 1343,
  COMISDrm_Int = 1344,
  COMISDrr = 1345,
  COMISDrr_Int = 1346,
  COMISSrm = 1347,
  COMISSrm_Int = 1348,
  COMISSrr = 1349,
  COMISSrr_Int = 1350,
  COMP_FST0r = 1351,
  COM_FIPr = 1352,
  COM_FIr = 1353,
  COM_FST0r = 1354,
  COM_FpIr32 = 1355,
  COM_FpIr64 = 1356,
  COM_FpIr80 = 1357,
  COM_Fpr32 = 1358,
  COM_Fpr64 = 1359,
  COM_Fpr80 = 1360,
  CPUID = 1361,
  CQO = 1362,
  CRC32r32m16 = 1363,
  CRC32r32m16_EVEX = 1364,
  CRC32r32m32 = 1365,
  CRC32r32m32_EVEX = 1366,
  CRC32r32m8 = 1367,
  CRC32r32m8_EVEX = 1368,
  CRC32r32r16 = 1369,
  CRC32r32r16_EVEX = 1370,
  CRC32r32r32 = 1371,
  CRC32r32r32_EVEX = 1372,
  CRC32r32r8 = 1373,
  CRC32r32r8_EVEX = 1374,
  CRC32r64m64 = 1375,
  CRC32r64m64_EVEX = 1376,
  CRC32r64m8 = 1377,
  CRC32r64m8_EVEX = 1378,
  CRC32r64r64 = 1379,
  CRC32r64r64_EVEX = 1380,
  CRC32r64r8 = 1381,
  CRC32r64r8_EVEX = 1382,
  CS_PREFIX = 1383,
  CTEST16mi = 1384,
  CTEST16mr = 1385,
  CTEST16ri = 1386,
  CTEST16rr = 1387,
  CTEST32mi = 1388,
  CTEST32mr = 1389,
  CTEST32ri = 1390,
  CTEST32rr = 1391,
  CTEST64mi32 = 1392,
  CTEST64mr = 1393,
  CTEST64ri32 = 1394,
  CTEST64rr = 1395,
  CTEST8mi = 1396,
  CTEST8mr = 1397,
  CTEST8ri = 1398,
  CTEST8rr = 1399,
  CVTDQ2PDrm = 1400,
  CVTDQ2PDrr = 1401,
  CVTDQ2PSrm = 1402,
  CVTDQ2PSrr = 1403,
  CVTPD2DQrm = 1404,
  CVTPD2DQrr = 1405,
  CVTPD2PSrm = 1406,
  CVTPD2PSrr = 1407,
  CVTPS2DQrm = 1408,
  CVTPS2DQrr = 1409,
  CVTPS2PDrm = 1410,
  CVTPS2PDrr = 1411,
  CVTSD2SI64rm = 1412,
  CVTSD2SI64rm_Int = 1413,
  CVTSD2SI64rr = 1414,
  CVTSD2SI64rr_Int = 1415,
  CVTSD2SIrm = 1416,
  CVTSD2SIrm_Int = 1417,
  CVTSD2SIrr = 1418,
  CVTSD2SIrr_Int = 1419,
  CVTSD2SSrm = 1420,
  CVTSD2SSrm_Int = 1421,
  CVTSD2SSrr = 1422,
  CVTSD2SSrr_Int = 1423,
  CVTSI2SDrm = 1424,
  CVTSI2SDrm_Int = 1425,
  CVTSI2SDrr = 1426,
  CVTSI2SDrr_Int = 1427,
  CVTSI2SSrm = 1428,
  CVTSI2SSrm_Int = 1429,
  CVTSI2SSrr = 1430,
  CVTSI2SSrr_Int = 1431,
  CVTSI642SDrm = 1432,
  CVTSI642SDrm_Int = 1433,
  CVTSI642SDrr = 1434,
  CVTSI642SDrr_Int = 1435,
  CVTSI642SSrm = 1436,
  CVTSI642SSrm_Int = 1437,
  CVTSI642SSrr = 1438,
  CVTSI642SSrr_Int = 1439,
  CVTSS2SDrm = 1440,
  CVTSS2SDrm_Int = 1441,
  CVTSS2SDrr = 1442,
  CVTSS2SDrr_Int = 1443,
  CVTSS2SI64rm = 1444,
  CVTSS2SI64rm_Int = 1445,
  CVTSS2SI64rr = 1446,
  CVTSS2SI64rr_Int = 1447,
  CVTSS2SIrm = 1448,
  CVTSS2SIrm_Int = 1449,
  CVTSS2SIrr = 1450,
  CVTSS2SIrr_Int = 1451,
  CVTTPD2DQrm = 1452,
  CVTTPD2DQrr = 1453,
  CVTTPS2DQrm = 1454,
  CVTTPS2DQrr = 1455,
  CVTTSD2SI64rm = 1456,
  CVTTSD2SI64rm_Int = 1457,
  CVTTSD2SI64rr = 1458,
  CVTTSD2SI64rr_Int = 1459,
  CVTTSD2SIrm = 1460,
  CVTTSD2SIrm_Int = 1461,
  CVTTSD2SIrr = 1462,
  CVTTSD2SIrr_Int = 1463,
  CVTTSS2SI64rm = 1464,
  CVTTSS2SI64rm_Int = 1465,
  CVTTSS2SI64rr = 1466,
  CVTTSS2SI64rr_Int = 1467,
  CVTTSS2SIrm = 1468,
  CVTTSS2SIrm_Int = 1469,
  CVTTSS2SIrr = 1470,
  CVTTSS2SIrr_Int = 1471,
  CWD = 1472,
  CWDE = 1473,
  DAA = 1474,
  DAS = 1475,
  DATA16_PREFIX = 1476,
  DEC16m = 1477,
  DEC16m_EVEX = 1478,
  DEC16m_ND = 1479,
  DEC16m_NF = 1480,
  DEC16m_NF_ND = 1481,
  DEC16r = 1482,
  DEC16r_EVEX = 1483,
  DEC16r_ND = 1484,
  DEC16r_NF = 1485,
  DEC16r_NF_ND = 1486,
  DEC16r_alt = 1487,
  DEC32m = 1488,
  DEC32m_EVEX = 1489,
  DEC32m_ND = 1490,
  DEC32m_NF = 1491,
  DEC32m_NF_ND = 1492,
  DEC32r = 1493,
  DEC32r_EVEX = 1494,
  DEC32r_ND = 1495,
  DEC32r_NF = 1496,
  DEC32r_NF_ND = 1497,
  DEC32r_alt = 1498,
  DEC64m = 1499,
  DEC64m_EVEX = 1500,
  DEC64m_ND = 1501,
  DEC64m_NF = 1502,
  DEC64m_NF_ND = 1503,
  DEC64r = 1504,
  DEC64r_EVEX = 1505,
  DEC64r_ND = 1506,
  DEC64r_NF = 1507,
  DEC64r_NF_ND = 1508,
  DEC8m = 1509,
  DEC8m_EVEX = 1510,
  DEC8m_ND = 1511,
  DEC8m_NF = 1512,
  DEC8m_NF_ND = 1513,
  DEC8r = 1514,
  DEC8r_EVEX = 1515,
  DEC8r_ND = 1516,
  DEC8r_NF = 1517,
  DEC8r_NF_ND = 1518,
  DIV16m = 1519,
  DIV16m_EVEX = 1520,
  DIV16m_NF = 1521,
  DIV16r = 1522,
  DIV16r_EVEX = 1523,
  DIV16r_NF = 1524,
  DIV32m = 1525,
  DIV32m_EVEX = 1526,
  DIV32m_NF = 1527,
  DIV32r = 1528,
  DIV32r_EVEX = 1529,
  DIV32r_NF = 1530,
  DIV64m = 1531,
  DIV64m_EVEX = 1532,
  DIV64m_NF = 1533,
  DIV64r = 1534,
  DIV64r_EVEX = 1535,
  DIV64r_NF = 1536,
  DIV8m = 1537,
  DIV8m_EVEX = 1538,
  DIV8m_NF = 1539,
  DIV8r = 1540,
  DIV8r_EVEX = 1541,
  DIV8r_NF = 1542,
  DIVPDrm = 1543,
  DIVPDrr = 1544,
  DIVPSrm = 1545,
  DIVPSrr = 1546,
  DIVR_F32m = 1547,
  DIVR_F64m = 1548,
  DIVR_FI16m = 1549,
  DIVR_FI32m = 1550,
  DIVR_FPrST0 = 1551,
  DIVR_FST0r = 1552,
  DIVR_Fp32m = 1553,
  DIVR_Fp64m = 1554,
  DIVR_Fp64m32 = 1555,
  DIVR_Fp80m32 = 1556,
  DIVR_Fp80m64 = 1557,
  DIVR_FpI16m32 = 1558,
  DIVR_FpI16m64 = 1559,
  DIVR_FpI16m80 = 1560,
  DIVR_FpI32m32 = 1561,
  DIVR_FpI32m64 = 1562,
  DIVR_FpI32m80 = 1563,
  DIVR_FrST0 = 1564,
  DIVSDrm = 1565,
  DIVSDrm_Int = 1566,
  DIVSDrr = 1567,
  DIVSDrr_Int = 1568,
  DIVSSrm = 1569,
  DIVSSrm_Int = 1570,
  DIVSSrr = 1571,
  DIVSSrr_Int = 1572,
  DIV_F32m = 1573,
  DIV_F64m = 1574,
  DIV_FI16m = 1575,
  DIV_FI32m = 1576,
  DIV_FPrST0 = 1577,
  DIV_FST0r = 1578,
  DIV_Fp32 = 1579,
  DIV_Fp32m = 1580,
  DIV_Fp64 = 1581,
  DIV_Fp64m = 1582,
  DIV_Fp64m32 = 1583,
  DIV_Fp80 = 1584,
  DIV_Fp80m32 = 1585,
  DIV_Fp80m64 = 1586,
  DIV_FpI16m32 = 1587,
  DIV_FpI16m64 = 1588,
  DIV_FpI16m80 = 1589,
  DIV_FpI32m32 = 1590,
  DIV_FpI32m64 = 1591,
  DIV_FpI32m80 = 1592,
  DIV_FrST0 = 1593,
  DPPDrmi = 1594,
  DPPDrri = 1595,
  DPPSrmi = 1596,
  DPPSrri = 1597,
  DS_PREFIX = 1598,
  DYN_ALLOCA_32 = 1599,
  DYN_ALLOCA_64 = 1600,
  EH_RETURN = 1601,
  EH_RETURN64 = 1602,
  EH_SjLj_LongJmp32 = 1603,
  EH_SjLj_LongJmp64 = 1604,
  EH_SjLj_SetJmp32 = 1605,
  EH_SjLj_SetJmp64 = 1606,
  EH_SjLj_Setup = 1607,
  ENCLS = 1608,
  ENCLU = 1609,
  ENCLV = 1610,
  ENCODEKEY128 = 1611,
  ENCODEKEY256 = 1612,
  ENDBR32 = 1613,
  ENDBR64 = 1614,
  ENQCMD16 = 1615,
  ENQCMD32 = 1616,
  ENQCMD32_EVEX = 1617,
  ENQCMD64 = 1618,
  ENQCMD64_EVEX = 1619,
  ENQCMDS16 = 1620,
  ENQCMDS32 = 1621,
  ENQCMDS32_EVEX = 1622,
  ENQCMDS64 = 1623,
  ENQCMDS64_EVEX = 1624,
  ENTER = 1625,
  ERETS = 1626,
  ERETU = 1627,
  ES_PREFIX = 1628,
  EXTRACTPSmri = 1629,
  EXTRACTPSrri = 1630,
  EXTRQ = 1631,
  EXTRQI = 1632,
  F2XM1 = 1633,
  FARCALL16i = 1634,
  FARCALL16m = 1635,
  FARCALL32i = 1636,
  FARCALL32m = 1637,
  FARCALL64m = 1638,
  FARJMP16i = 1639,
  FARJMP16m = 1640,
  FARJMP32i = 1641,
  FARJMP32m = 1642,
  FARJMP64m = 1643,
  FBLDm = 1644,
  FBSTPm = 1645,
  FCOM32m = 1646,
  FCOM64m = 1647,
  FCOMP32m = 1648,
  FCOMP64m = 1649,
  FCOMPP = 1650,
  FCOS = 1651,
  FDECSTP = 1652,
  FEMMS = 1653,
  FFREE = 1654,
  FFREEP = 1655,
  FICOM16m = 1656,
  FICOM32m = 1657,
  FICOMP16m = 1658,
  FICOMP32m = 1659,
  FINCSTP = 1660,
  FLDCW16m = 1661,
  FLDENVm = 1662,
  FLDL2E = 1663,
  FLDL2T = 1664,
  FLDLG2 = 1665,
  FLDLN2 = 1666,
  FLDPI = 1667,
  FNCLEX = 1668,
  FNINIT = 1669,
  FNOP = 1670,
  FNSTCW16m = 1671,
  FNSTSW16r = 1672,
  FNSTSWm = 1673,
  FP32_TO_INT16_IN_MEM = 1674,
  FP32_TO_INT32_IN_MEM = 1675,
  FP32_TO_INT64_IN_MEM = 1676,
  FP64_TO_INT16_IN_MEM = 1677,
  FP64_TO_INT32_IN_MEM = 1678,
  FP64_TO_INT64_IN_MEM = 1679,
  FP80_ADDm32 = 1680,
  FP80_ADDr = 1681,
  FP80_TO_INT16_IN_MEM = 1682,
  FP80_TO_INT32_IN_MEM = 1683,
  FP80_TO_INT64_IN_MEM = 1684,
  FPATAN = 1685,
  FPREM = 1686,
  FPREM1 = 1687,
  FPTAN = 1688,
  FRNDINT = 1689,
  FRSTORm = 1690,
  FSAVEm = 1691,
  FSCALE = 1692,
  FSIN = 1693,
  FSINCOS = 1694,
  FSTENVm = 1695,
  FS_PREFIX = 1696,
  FXRSTOR = 1697,
  FXRSTOR64 = 1698,
  FXSAVE = 1699,
  FXSAVE64 = 1700,
  FXTRACT = 1701,
  FYL2X = 1702,
  FYL2XP1 = 1703,
  GETSEC = 1704,
  GF2P8AFFINEINVQBrmi = 1705,
  GF2P8AFFINEINVQBrri = 1706,
  GF2P8AFFINEQBrmi = 1707,
  GF2P8AFFINEQBrri = 1708,
  GF2P8MULBrm = 1709,
  GF2P8MULBrr = 1710,
  GS_PREFIX = 1711,
  HADDPDrm = 1712,
  HADDPDrr = 1713,
  HADDPSrm = 1714,
  HADDPSrr = 1715,
  HLT = 1716,
  HRESET = 1717,
  HSUBPDrm = 1718,
  HSUBPDrr = 1719,
  HSUBPSrm = 1720,
  HSUBPSrr = 1721,
  IDIV16m = 1722,
  IDIV16m_EVEX = 1723,
  IDIV16m_NF = 1724,
  IDIV16r = 1725,
  IDIV16r_EVEX = 1726,
  IDIV16r_NF = 1727,
  IDIV32m = 1728,
  IDIV32m_EVEX = 1729,
  IDIV32m_NF = 1730,
  IDIV32r = 1731,
  IDIV32r_EVEX = 1732,
  IDIV32r_NF = 1733,
  IDIV64m = 1734,
  IDIV64m_EVEX = 1735,
  IDIV64m_NF = 1736,
  IDIV64r = 1737,
  IDIV64r_EVEX = 1738,
  IDIV64r_NF = 1739,
  IDIV8m = 1740,
  IDIV8m_EVEX = 1741,
  IDIV8m_NF = 1742,
  IDIV8r = 1743,
  IDIV8r_EVEX = 1744,
  IDIV8r_NF = 1745,
  ILD_F16m = 1746,
  ILD_F32m = 1747,
  ILD_F64m = 1748,
  ILD_Fp16m32 = 1749,
  ILD_Fp16m64 = 1750,
  ILD_Fp16m80 = 1751,
  ILD_Fp32m32 = 1752,
  ILD_Fp32m64 = 1753,
  ILD_Fp32m80 = 1754,
  ILD_Fp64m32 = 1755,
  ILD_Fp64m64 = 1756,
  ILD_Fp64m80 = 1757,
  IMUL16m = 1758,
  IMUL16m_EVEX = 1759,
  IMUL16m_NF = 1760,
  IMUL16r = 1761,
  IMUL16r_EVEX = 1762,
  IMUL16r_NF = 1763,
  IMUL16rm = 1764,
  IMUL16rm_EVEX = 1765,
  IMUL16rm_ND = 1766,
  IMUL16rm_NF = 1767,
  IMUL16rm_NF_ND = 1768,
  IMUL16rmi = 1769,
  IMUL16rmi8 = 1770,
  IMUL16rmi8_EVEX = 1771,
  IMUL16rmi8_NF = 1772,
  IMUL16rmi_EVEX = 1773,
  IMUL16rmi_NF = 1774,
  IMUL16rr = 1775,
  IMUL16rr_EVEX = 1776,
  IMUL16rr_ND = 1777,
  IMUL16rr_NF = 1778,
  IMUL16rr_NF_ND = 1779,
  IMUL16rri = 1780,
  IMUL16rri8 = 1781,
  IMUL16rri8_EVEX = 1782,
  IMUL16rri8_NF = 1783,
  IMUL16rri_EVEX = 1784,
  IMUL16rri_NF = 1785,
  IMUL32m = 1786,
  IMUL32m_EVEX = 1787,
  IMUL32m_NF = 1788,
  IMUL32r = 1789,
  IMUL32r_EVEX = 1790,
  IMUL32r_NF = 1791,
  IMUL32rm = 1792,
  IMUL32rm_EVEX = 1793,
  IMUL32rm_ND = 1794,
  IMUL32rm_NF = 1795,
  IMUL32rm_NF_ND = 1796,
  IMUL32rmi = 1797,
  IMUL32rmi8 = 1798,
  IMUL32rmi8_EVEX = 1799,
  IMUL32rmi8_NF = 1800,
  IMUL32rmi_EVEX = 1801,
  IMUL32rmi_NF = 1802,
  IMUL32rr = 1803,
  IMUL32rr_EVEX = 1804,
  IMUL32rr_ND = 1805,
  IMUL32rr_NF = 1806,
  IMUL32rr_NF_ND = 1807,
  IMUL32rri = 1808,
  IMUL32rri8 = 1809,
  IMUL32rri8_EVEX = 1810,
  IMUL32rri8_NF = 1811,
  IMUL32rri_EVEX = 1812,
  IMUL32rri_NF = 1813,
  IMUL64m = 1814,
  IMUL64m_EVEX = 1815,
  IMUL64m_NF = 1816,
  IMUL64r = 1817,
  IMUL64r_EVEX = 1818,
  IMUL64r_NF = 1819,
  IMUL64rm = 1820,
  IMUL64rm_EVEX = 1821,
  IMUL64rm_ND = 1822,
  IMUL64rm_NF = 1823,
  IMUL64rm_NF_ND = 1824,
  IMUL64rmi32 = 1825,
  IMUL64rmi32_EVEX = 1826,
  IMUL64rmi32_NF = 1827,
  IMUL64rmi8 = 1828,
  IMUL64rmi8_EVEX = 1829,
  IMUL64rmi8_NF = 1830,
  IMUL64rr = 1831,
  IMUL64rr_EVEX = 1832,
  IMUL64rr_ND = 1833,
  IMUL64rr_NF = 1834,
  IMUL64rr_NF_ND = 1835,
  IMUL64rri32 = 1836,
  IMUL64rri32_EVEX = 1837,
  IMUL64rri32_NF = 1838,
  IMUL64rri8 = 1839,
  IMUL64rri8_EVEX = 1840,
  IMUL64rri8_NF = 1841,
  IMUL8m = 1842,
  IMUL8m_EVEX = 1843,
  IMUL8m_NF = 1844,
  IMUL8r = 1845,
  IMUL8r_EVEX = 1846,
  IMUL8r_NF = 1847,
  IMULZU16rmi = 1848,
  IMULZU16rmi8 = 1849,
  IMULZU16rri = 1850,
  IMULZU16rri8 = 1851,
  IMULZU32rmi = 1852,
  IMULZU32rmi8 = 1853,
  IMULZU32rri = 1854,
  IMULZU32rri8 = 1855,
  IMULZU64rmi32 = 1856,
  IMULZU64rmi8 = 1857,
  IMULZU64rri32 = 1858,
  IMULZU64rri8 = 1859,
  IN16ri = 1860,
  IN16rr = 1861,
  IN32ri = 1862,
  IN32rr = 1863,
  IN8ri = 1864,
  IN8rr = 1865,
  INC16m = 1866,
  INC16m_EVEX = 1867,
  INC16m_ND = 1868,
  INC16m_NF = 1869,
  INC16m_NF_ND = 1870,
  INC16r = 1871,
  INC16r_EVEX = 1872,
  INC16r_ND = 1873,
  INC16r_NF = 1874,
  INC16r_NF_ND = 1875,
  INC16r_alt = 1876,
  INC32m = 1877,
  INC32m_EVEX = 1878,
  INC32m_ND = 1879,
  INC32m_NF = 1880,
  INC32m_NF_ND = 1881,
  INC32r = 1882,
  INC32r_EVEX = 1883,
  INC32r_ND = 1884,
  INC32r_NF = 1885,
  INC32r_NF_ND = 1886,
  INC32r_alt = 1887,
  INC64m = 1888,
  INC64m_EVEX = 1889,
  INC64m_ND = 1890,
  INC64m_NF = 1891,
  INC64m_NF_ND = 1892,
  INC64r = 1893,
  INC64r_EVEX = 1894,
  INC64r_ND = 1895,
  INC64r_NF = 1896,
  INC64r_NF_ND = 1897,
  INC8m = 1898,
  INC8m_EVEX = 1899,
  INC8m_ND = 1900,
  INC8m_NF = 1901,
  INC8m_NF_ND = 1902,
  INC8r = 1903,
  INC8r_EVEX = 1904,
  INC8r_ND = 1905,
  INC8r_NF = 1906,
  INC8r_NF_ND = 1907,
  INCSSPD = 1908,
  INCSSPQ = 1909,
  INSB = 1910,
  INSERTPSrmi = 1911,
  INSERTPSrri = 1912,
  INSERTQ = 1913,
  INSERTQI = 1914,
  INSL = 1915,
  INSW = 1916,
  INT = 1917,
  INT3 = 1918,
  INTO = 1919,
  INVD = 1920,
  INVEPT32 = 1921,
  INVEPT64 = 1922,
  INVEPT64_EVEX = 1923,
  INVLPG = 1924,
  INVLPGA32 = 1925,
  INVLPGA64 = 1926,
  INVLPGB32 = 1927,
  INVLPGB64 = 1928,
  INVPCID32 = 1929,
  INVPCID64 = 1930,
  INVPCID64_EVEX = 1931,
  INVVPID32 = 1932,
  INVVPID64 = 1933,
  INVVPID64_EVEX = 1934,
  IRET = 1935,
  IRET16 = 1936,
  IRET32 = 1937,
  IRET64 = 1938,
  ISTT_FP16m = 1939,
  ISTT_FP32m = 1940,
  ISTT_FP64m = 1941,
  ISTT_Fp16m32 = 1942,
  ISTT_Fp16m64 = 1943,
  ISTT_Fp16m80 = 1944,
  ISTT_Fp32m32 = 1945,
  ISTT_Fp32m64 = 1946,
  ISTT_Fp32m80 = 1947,
  ISTT_Fp64m32 = 1948,
  ISTT_Fp64m64 = 1949,
  ISTT_Fp64m80 = 1950,
  IST_F16m = 1951,
  IST_F32m = 1952,
  IST_FP16m = 1953,
  IST_FP32m = 1954,
  IST_FP64m = 1955,
  IST_Fp16m32 = 1956,
  IST_Fp16m64 = 1957,
  IST_Fp16m80 = 1958,
  IST_Fp32m32 = 1959,
  IST_Fp32m64 = 1960,
  IST_Fp32m80 = 1961,
  IST_Fp64m32 = 1962,
  IST_Fp64m64 = 1963,
  IST_Fp64m80 = 1964,
  Int_eh_sjlj_setup_dispatch = 1965,
  JCC_1 = 1966,
  JCC_2 = 1967,
  JCC_4 = 1968,
  JCXZ = 1969,
  JECXZ = 1970,
  JMP16m = 1971,
  JMP16m_NT = 1972,
  JMP16r = 1973,
  JMP16r_NT = 1974,
  JMP32m = 1975,
  JMP32m_NT = 1976,
  JMP32r = 1977,
  JMP32r_NT = 1978,
  JMP64m = 1979,
  JMP64m_NT = 1980,
  JMP64m_REX = 1981,
  JMP64r = 1982,
  JMP64r_NT = 1983,
  JMP64r_REX = 1984,
  JMPABS64i = 1985,
  JMP_1 = 1986,
  JMP_2 = 1987,
  JMP_4 = 1988,
  JRCXZ = 1989,
  KADDBkk = 1990,
  KADDDkk = 1991,
  KADDQkk = 1992,
  KADDWkk = 1993,
  KANDBkk = 1994,
  KANDDkk = 1995,
  KANDNBkk = 1996,
  KANDNDkk = 1997,
  KANDNQkk = 1998,
  KANDNWkk = 1999,
  KANDQkk = 2000,
  KANDWkk = 2001,
  KCFI_CHECK = 2002,
  KMOVBkk = 2003,
  KMOVBkk_EVEX = 2004,
  KMOVBkm = 2005,
  KMOVBkm_EVEX = 2006,
  KMOVBkr = 2007,
  KMOVBkr_EVEX = 2008,
  KMOVBmk = 2009,
  KMOVBmk_EVEX = 2010,
  KMOVBrk = 2011,
  KMOVBrk_EVEX = 2012,
  KMOVDkk = 2013,
  KMOVDkk_EVEX = 2014,
  KMOVDkm = 2015,
  KMOVDkm_EVEX = 2016,
  KMOVDkr = 2017,
  KMOVDkr_EVEX = 2018,
  KMOVDmk = 2019,
  KMOVDmk_EVEX = 2020,
  KMOVDrk = 2021,
  KMOVDrk_EVEX = 2022,
  KMOVQkk = 2023,
  KMOVQkk_EVEX = 2024,
  KMOVQkm = 2025,
  KMOVQkm_EVEX = 2026,
  KMOVQkr = 2027,
  KMOVQkr_EVEX = 2028,
  KMOVQmk = 2029,
  KMOVQmk_EVEX = 2030,
  KMOVQrk = 2031,
  KMOVQrk_EVEX = 2032,
  KMOVWkk = 2033,
  KMOVWkk_EVEX = 2034,
  KMOVWkm = 2035,
  KMOVWkm_EVEX = 2036,
  KMOVWkr = 2037,
  KMOVWkr_EVEX = 2038,
  KMOVWmk = 2039,
  KMOVWmk_EVEX = 2040,
  KMOVWrk = 2041,
  KMOVWrk_EVEX = 2042,
  KNOTBkk = 2043,
  KNOTDkk = 2044,
  KNOTQkk = 2045,
  KNOTWkk = 2046,
  KORBkk = 2047,
  KORDkk = 2048,
  KORQkk = 2049,
  KORTESTBkk = 2050,
  KORTESTDkk = 2051,
  KORTESTQkk = 2052,
  KORTESTWkk = 2053,
  KORWkk = 2054,
  KSHIFTLBki = 2055,
  KSHIFTLDki = 2056,
  KSHIFTLQki = 2057,
  KSHIFTLWki = 2058,
  KSHIFTRBki = 2059,
  KSHIFTRDki = 2060,
  KSHIFTRQki = 2061,
  KSHIFTRWki = 2062,
  KTESTBkk = 2063,
  KTESTDkk = 2064,
  KTESTQkk = 2065,
  KTESTWkk = 2066,
  KUNPCKBWkk = 2067,
  KUNPCKDQkk = 2068,
  KUNPCKWDkk = 2069,
  KXNORBkk = 2070,
  KXNORDkk = 2071,
  KXNORQkk = 2072,
  KXNORWkk = 2073,
  KXORBkk = 2074,
  KXORDkk = 2075,
  KXORQkk = 2076,
  KXORWkk = 2077,
  LAHF = 2078,
  LAR16rm = 2079,
  LAR16rr = 2080,
  LAR32rm = 2081,
  LAR32rr = 2082,
  LAR64rm = 2083,
  LAR64rr = 2084,
  LCMPXCHG16 = 2085,
  LCMPXCHG16B = 2086,
  LCMPXCHG32 = 2087,
  LCMPXCHG64 = 2088,
  LCMPXCHG8 = 2089,
  LCMPXCHG8B = 2090,
  LDDQUrm = 2091,
  LDMXCSR = 2092,
  LDS16rm = 2093,
  LDS32rm = 2094,
  LDTILECFG = 2095,
  LDTILECFG_EVEX = 2096,
  LD_F0 = 2097,
  LD_F1 = 2098,
  LD_F32m = 2099,
  LD_F64m = 2100,
  LD_F80m = 2101,
  LD_Fp032 = 2102,
  LD_Fp064 = 2103,
  LD_Fp080 = 2104,
  LD_Fp132 = 2105,
  LD_Fp164 = 2106,
  LD_Fp180 = 2107,
  LD_Fp32m = 2108,
  LD_Fp32m64 = 2109,
  LD_Fp32m80 = 2110,
  LD_Fp64m = 2111,
  LD_Fp64m80 = 2112,
  LD_Fp80m = 2113,
  LD_Frr = 2114,
  LEA16r = 2115,
  LEA32r = 2116,
  LEA64_32r = 2117,
  LEA64r = 2118,
  LEAVE = 2119,
  LEAVE64 = 2120,
  LES16rm = 2121,
  LES32rm = 2122,
  LFENCE = 2123,
  LFS16rm = 2124,
  LFS32rm = 2125,
  LFS64rm = 2126,
  LGDT16m = 2127,
  LGDT32m = 2128,
  LGDT64m = 2129,
  LGS16rm = 2130,
  LGS32rm = 2131,
  LGS64rm = 2132,
  LIDT16m = 2133,
  LIDT32m = 2134,
  LIDT64m = 2135,
  LKGS16m = 2136,
  LKGS16r = 2137,
  LLDT16m = 2138,
  LLDT16r = 2139,
  LLWPCB = 2140,
  LLWPCB64 = 2141,
  LMSW16m = 2142,
  LMSW16r = 2143,
  LOADIWKEY = 2144,
  LOCK_ADD16mi = 2145,
  LOCK_ADD16mi8 = 2146,
  LOCK_ADD16mr = 2147,
  LOCK_ADD32mi = 2148,
  LOCK_ADD32mi8 = 2149,
  LOCK_ADD32mr = 2150,
  LOCK_ADD64mi32 = 2151,
  LOCK_ADD64mi8 = 2152,
  LOCK_ADD64mr = 2153,
  LOCK_ADD8mi = 2154,
  LOCK_ADD8mr = 2155,
  LOCK_AND16mi = 2156,
  LOCK_AND16mi8 = 2157,
  LOCK_AND16mr = 2158,
  LOCK_AND32mi = 2159,
  LOCK_AND32mi8 = 2160,
  LOCK_AND32mr = 2161,
  LOCK_AND64mi32 = 2162,
  LOCK_AND64mi8 = 2163,
  LOCK_AND64mr = 2164,
  LOCK_AND8mi = 2165,
  LOCK_AND8mr = 2166,
  LOCK_BTC16m = 2167,
  LOCK_BTC32m = 2168,
  LOCK_BTC64m = 2169,
  LOCK_BTC_RM16rm = 2170,
  LOCK_BTC_RM32rm = 2171,
  LOCK_BTC_RM64rm = 2172,
  LOCK_BTR16m = 2173,
  LOCK_BTR32m = 2174,
  LOCK_BTR64m = 2175,
  LOCK_BTR_RM16rm = 2176,
  LOCK_BTR_RM32rm = 2177,
  LOCK_BTR_RM64rm = 2178,
  LOCK_BTS16m = 2179,
  LOCK_BTS32m = 2180,
  LOCK_BTS64m = 2181,
  LOCK_BTS_RM16rm = 2182,
  LOCK_BTS_RM32rm = 2183,
  LOCK_BTS_RM64rm = 2184,
  LOCK_DEC16m = 2185,
  LOCK_DEC32m = 2186,
  LOCK_DEC64m = 2187,
  LOCK_DEC8m = 2188,
  LOCK_INC16m = 2189,
  LOCK_INC32m = 2190,
  LOCK_INC64m = 2191,
  LOCK_INC8m = 2192,
  LOCK_OR16mi = 2193,
  LOCK_OR16mi8 = 2194,
  LOCK_OR16mr = 2195,
  LOCK_OR32mi = 2196,
  LOCK_OR32mi8 = 2197,
  LOCK_OR32mr = 2198,
  LOCK_OR64mi32 = 2199,
  LOCK_OR64mi8 = 2200,
  LOCK_OR64mr = 2201,
  LOCK_OR8mi = 2202,
  LOCK_OR8mr = 2203,
  LOCK_PREFIX = 2204,
  LOCK_SUB16mi = 2205,
  LOCK_SUB16mi8 = 2206,
  LOCK_SUB16mr = 2207,
  LOCK_SUB32mi = 2208,
  LOCK_SUB32mi8 = 2209,
  LOCK_SUB32mr = 2210,
  LOCK_SUB64mi32 = 2211,
  LOCK_SUB64mi8 = 2212,
  LOCK_SUB64mr = 2213,
  LOCK_SUB8mi = 2214,
  LOCK_SUB8mr = 2215,
  LOCK_XOR16mi = 2216,
  LOCK_XOR16mi8 = 2217,
  LOCK_XOR16mr = 2218,
  LOCK_XOR32mi = 2219,
  LOCK_XOR32mi8 = 2220,
  LOCK_XOR32mr = 2221,
  LOCK_XOR64mi32 = 2222,
  LOCK_XOR64mi8 = 2223,
  LOCK_XOR64mr = 2224,
  LOCK_XOR8mi = 2225,
  LOCK_XOR8mr = 2226,
  LODSB = 2227,
  LODSL = 2228,
  LODSQ = 2229,
  LODSW = 2230,
  LOOP = 2231,
  LOOPE = 2232,
  LOOPNE = 2233,
  LRET16 = 2234,
  LRET32 = 2235,
  LRET64 = 2236,
  LRETI16 = 2237,
  LRETI32 = 2238,
  LRETI64 = 2239,
  LSL16rm = 2240,
  LSL16rr = 2241,
  LSL32rm = 2242,
  LSL32rr = 2243,
  LSL64rm = 2244,
  LSL64rr = 2245,
  LSS16rm = 2246,
  LSS32rm = 2247,
  LSS64rm = 2248,
  LTRm = 2249,
  LTRr = 2250,
  LWPINS32rmi = 2251,
  LWPINS32rri = 2252,
  LWPINS64rmi = 2253,
  LWPINS64rri = 2254,
  LWPVAL32rmi = 2255,
  LWPVAL32rri = 2256,
  LWPVAL64rmi = 2257,
  LWPVAL64rri = 2258,
  LXADD16 = 2259,
  LXADD32 = 2260,
  LXADD64 = 2261,
  LXADD8 = 2262,
  LZCNT16rm = 2263,
  LZCNT16rm_EVEX = 2264,
  LZCNT16rm_NF = 2265,
  LZCNT16rr = 2266,
  LZCNT16rr_EVEX = 2267,
  LZCNT16rr_NF = 2268,
  LZCNT32rm = 2269,
  LZCNT32rm_EVEX = 2270,
  LZCNT32rm_NF = 2271,
  LZCNT32rr = 2272,
  LZCNT32rr_EVEX = 2273,
  LZCNT32rr_NF = 2274,
  LZCNT64rm = 2275,
  LZCNT64rm_EVEX = 2276,
  LZCNT64rm_NF = 2277,
  LZCNT64rr = 2278,
  LZCNT64rr_EVEX = 2279,
  LZCNT64rr_NF = 2280,
  MASKMOVDQU = 2281,
  MASKMOVDQU64 = 2282,
  MASKPAIR16LOAD = 2283,
  MASKPAIR16STORE = 2284,
  MAXCPDrm = 2285,
  MAXCPDrr = 2286,
  MAXCPSrm = 2287,
  MAXCPSrr = 2288,
  MAXCSDrm = 2289,
  MAXCSDrr = 2290,
  MAXCSSrm = 2291,
  MAXCSSrr = 2292,
  MAXPDrm = 2293,
  MAXPDrr = 2294,
  MAXPSrm = 2295,
  MAXPSrr = 2296,
  MAXSDrm = 2297,
  MAXSDrm_Int = 2298,
  MAXSDrr = 2299,
  MAXSDrr_Int = 2300,
  MAXSSrm = 2301,
  MAXSSrm_Int = 2302,
  MAXSSrr = 2303,
  MAXSSrr_Int = 2304,
  MFENCE = 2305,
  MINCPDrm = 2306,
  MINCPDrr = 2307,
  MINCPSrm = 2308,
  MINCPSrr = 2309,
  MINCSDrm = 2310,
  MINCSDrr = 2311,
  MINCSSrm = 2312,
  MINCSSrr = 2313,
  MINPDrm = 2314,
  MINPDrr = 2315,
  MINPSrm = 2316,
  MINPSrr = 2317,
  MINSDrm = 2318,
  MINSDrm_Int = 2319,
  MINSDrr = 2320,
  MINSDrr_Int = 2321,
  MINSSrm = 2322,
  MINSSrm_Int = 2323,
  MINSSrr = 2324,
  MINSSrr_Int = 2325,
  MMX_CVTPD2PIrm = 2326,
  MMX_CVTPD2PIrr = 2327,
  MMX_CVTPI2PDrm = 2328,
  MMX_CVTPI2PDrr = 2329,
  MMX_CVTPI2PSrm = 2330,
  MMX_CVTPI2PSrr = 2331,
  MMX_CVTPS2PIrm = 2332,
  MMX_CVTPS2PIrr = 2333,
  MMX_CVTTPD2PIrm = 2334,
  MMX_CVTTPD2PIrr = 2335,
  MMX_CVTTPS2PIrm = 2336,
  MMX_CVTTPS2PIrr = 2337,
  MMX_EMMS = 2338,
  MMX_MASKMOVQ = 2339,
  MMX_MASKMOVQ64 = 2340,
  MMX_MOVD64from64mr = 2341,
  MMX_MOVD64from64rr = 2342,
  MMX_MOVD64grr = 2343,
  MMX_MOVD64mr = 2344,
  MMX_MOVD64rm = 2345,
  MMX_MOVD64rr = 2346,
  MMX_MOVD64to64rm = 2347,
  MMX_MOVD64to64rr = 2348,
  MMX_MOVDQ2Qrr = 2349,
  MMX_MOVFR642Qrr = 2350,
  MMX_MOVNTQmr = 2351,
  MMX_MOVQ2DQrr = 2352,
  MMX_MOVQ2FR64rr = 2353,
  MMX_MOVQ64mr = 2354,
  MMX_MOVQ64rm = 2355,
  MMX_MOVQ64rr = 2356,
  MMX_MOVQ64rr_REV = 2357,
  MMX_PABSBrm = 2358,
  MMX_PABSBrr = 2359,
  MMX_PABSDrm = 2360,
  MMX_PABSDrr = 2361,
  MMX_PABSWrm = 2362,
  MMX_PABSWrr = 2363,
  MMX_PACKSSDWrm = 2364,
  MMX_PACKSSDWrr = 2365,
  MMX_PACKSSWBrm = 2366,
  MMX_PACKSSWBrr = 2367,
  MMX_PACKUSWBrm = 2368,
  MMX_PACKUSWBrr = 2369,
  MMX_PADDBrm = 2370,
  MMX_PADDBrr = 2371,
  MMX_PADDDrm = 2372,
  MMX_PADDDrr = 2373,
  MMX_PADDQrm = 2374,
  MMX_PADDQrr = 2375,
  MMX_PADDSBrm = 2376,
  MMX_PADDSBrr = 2377,
  MMX_PADDSWrm = 2378,
  MMX_PADDSWrr = 2379,
  MMX_PADDUSBrm = 2380,
  MMX_PADDUSBrr = 2381,
  MMX_PADDUSWrm = 2382,
  MMX_PADDUSWrr = 2383,
  MMX_PADDWrm = 2384,
  MMX_PADDWrr = 2385,
  MMX_PALIGNRrmi = 2386,
  MMX_PALIGNRrri = 2387,
  MMX_PANDNrm = 2388,
  MMX_PANDNrr = 2389,
  MMX_PANDrm = 2390,
  MMX_PANDrr = 2391,
  MMX_PAVGBrm = 2392,
  MMX_PAVGBrr = 2393,
  MMX_PAVGWrm = 2394,
  MMX_PAVGWrr = 2395,
  MMX_PCMPEQBrm = 2396,
  MMX_PCMPEQBrr = 2397,
  MMX_PCMPEQDrm = 2398,
  MMX_PCMPEQDrr = 2399,
  MMX_PCMPEQWrm = 2400,
  MMX_PCMPEQWrr = 2401,
  MMX_PCMPGTBrm = 2402,
  MMX_PCMPGTBrr = 2403,
  MMX_PCMPGTDrm = 2404,
  MMX_PCMPGTDrr = 2405,
  MMX_PCMPGTWrm = 2406,
  MMX_PCMPGTWrr = 2407,
  MMX_PEXTRWrri = 2408,
  MMX_PHADDDrm = 2409,
  MMX_PHADDDrr = 2410,
  MMX_PHADDSWrm = 2411,
  MMX_PHADDSWrr = 2412,
  MMX_PHADDWrm = 2413,
  MMX_PHADDWrr = 2414,
  MMX_PHSUBDrm = 2415,
  MMX_PHSUBDrr = 2416,
  MMX_PHSUBSWrm = 2417,
  MMX_PHSUBSWrr = 2418,
  MMX_PHSUBWrm = 2419,
  MMX_PHSUBWrr = 2420,
  MMX_PINSRWrmi = 2421,
  MMX_PINSRWrri = 2422,
  MMX_PMADDUBSWrm = 2423,
  MMX_PMADDUBSWrr = 2424,
  MMX_PMADDWDrm = 2425,
  MMX_PMADDWDrr = 2426,
  MMX_PMAXSWrm = 2427,
  MMX_PMAXSWrr = 2428,
  MMX_PMAXUBrm = 2429,
  MMX_PMAXUBrr = 2430,
  MMX_PMINSWrm = 2431,
  MMX_PMINSWrr = 2432,
  MMX_PMINUBrm = 2433,
  MMX_PMINUBrr = 2434,
  MMX_PMOVMSKBrr = 2435,
  MMX_PMULHRSWrm = 2436,
  MMX_PMULHRSWrr = 2437,
  MMX_PMULHUWrm = 2438,
  MMX_PMULHUWrr = 2439,
  MMX_PMULHWrm = 2440,
  MMX_PMULHWrr = 2441,
  MMX_PMULLWrm = 2442,
  MMX_PMULLWrr = 2443,
  MMX_PMULUDQrm = 2444,
  MMX_PMULUDQrr = 2445,
  MMX_PORrm = 2446,
  MMX_PORrr = 2447,
  MMX_PSADBWrm = 2448,
  MMX_PSADBWrr = 2449,
  MMX_PSHUFBrm = 2450,
  MMX_PSHUFBrr = 2451,
  MMX_PSHUFWmi = 2452,
  MMX_PSHUFWri = 2453,
  MMX_PSIGNBrm = 2454,
  MMX_PSIGNBrr = 2455,
  MMX_PSIGNDrm = 2456,
  MMX_PSIGNDrr = 2457,
  MMX_PSIGNWrm = 2458,
  MMX_PSIGNWrr = 2459,
  MMX_PSLLDri = 2460,
  MMX_PSLLDrm = 2461,
  MMX_PSLLDrr = 2462,
  MMX_PSLLQri = 2463,
  MMX_PSLLQrm = 2464,
  MMX_PSLLQrr = 2465,
  MMX_PSLLWri = 2466,
  MMX_PSLLWrm = 2467,
  MMX_PSLLWrr = 2468,
  MMX_PSRADri = 2469,
  MMX_PSRADrm = 2470,
  MMX_PSRADrr = 2471,
  MMX_PSRAWri = 2472,
  MMX_PSRAWrm = 2473,
  MMX_PSRAWrr = 2474,
  MMX_PSRLDri = 2475,
  MMX_PSRLDrm = 2476,
  MMX_PSRLDrr = 2477,
  MMX_PSRLQri = 2478,
  MMX_PSRLQrm = 2479,
  MMX_PSRLQrr = 2480,
  MMX_PSRLWri = 2481,
  MMX_PSRLWrm = 2482,
  MMX_PSRLWrr = 2483,
  MMX_PSUBBrm = 2484,
  MMX_PSUBBrr = 2485,
  MMX_PSUBDrm = 2486,
  MMX_PSUBDrr = 2487,
  MMX_PSUBQrm = 2488,
  MMX_PSUBQrr = 2489,
  MMX_PSUBSBrm = 2490,
  MMX_PSUBSBrr = 2491,
  MMX_PSUBSWrm = 2492,
  MMX_PSUBSWrr = 2493,
  MMX_PSUBUSBrm = 2494,
  MMX_PSUBUSBrr = 2495,
  MMX_PSUBUSWrm = 2496,
  MMX_PSUBUSWrr = 2497,
  MMX_PSUBWrm = 2498,
  MMX_PSUBWrr = 2499,
  MMX_PUNPCKHBWrm = 2500,
  MMX_PUNPCKHBWrr = 2501,
  MMX_PUNPCKHDQrm = 2502,
  MMX_PUNPCKHDQrr = 2503,
  MMX_PUNPCKHWDrm = 2504,
  MMX_PUNPCKHWDrr = 2505,
  MMX_PUNPCKLBWrm = 2506,
  MMX_PUNPCKLBWrr = 2507,
  MMX_PUNPCKLDQrm = 2508,
  MMX_PUNPCKLDQrr = 2509,
  MMX_PUNPCKLWDrm = 2510,
  MMX_PUNPCKLWDrr = 2511,
  MMX_PXORrm = 2512,
  MMX_PXORrr = 2513,
  MONITOR32rrr = 2514,
  MONITOR64rrr = 2515,
  MONITORX32rrr = 2516,
  MONITORX64rrr = 2517,
  MONTMUL = 2518,
  MOV16ao16 = 2519,
  MOV16ao32 = 2520,
  MOV16ao64 = 2521,
  MOV16mi = 2522,
  MOV16mr = 2523,
  MOV16ms = 2524,
  MOV16o16a = 2525,
  MOV16o32a = 2526,
  MOV16o64a = 2527,
  MOV16ri = 2528,
  MOV16ri_alt = 2529,
  MOV16rm = 2530,
  MOV16rr = 2531,
  MOV16rr_REV = 2532,
  MOV16rs = 2533,
  MOV16sm = 2534,
  MOV16sr = 2535,
  MOV32ao16 = 2536,
  MOV32ao32 = 2537,
  MOV32ao64 = 2538,
  MOV32cr = 2539,
  MOV32dr = 2540,
  MOV32mi = 2541,
  MOV32mr = 2542,
  MOV32o16a = 2543,
  MOV32o32a = 2544,
  MOV32o64a = 2545,
  MOV32rc = 2546,
  MOV32rd = 2547,
  MOV32ri = 2548,
  MOV32ri_alt = 2549,
  MOV32rm = 2550,
  MOV32rr = 2551,
  MOV32rr_REV = 2552,
  MOV32rs = 2553,
  MOV32sr = 2554,
  MOV64ao32 = 2555,
  MOV64ao64 = 2556,
  MOV64cr = 2557,
  MOV64dr = 2558,
  MOV64mi32 = 2559,
  MOV64mr = 2560,
  MOV64o32a = 2561,
  MOV64o64a = 2562,
  MOV64rc = 2563,
  MOV64rd = 2564,
  MOV64ri = 2565,
  MOV64ri32 = 2566,
  MOV64rm = 2567,
  MOV64rr = 2568,
  MOV64rr_REV = 2569,
  MOV64rs = 2570,
  MOV64sr = 2571,
  MOV64toPQIrm = 2572,
  MOV64toPQIrr = 2573,
  MOV64toSDrr = 2574,
  MOV8ao16 = 2575,
  MOV8ao32 = 2576,
  MOV8ao64 = 2577,
  MOV8mi = 2578,
  MOV8mr = 2579,
  MOV8mr_NOREX = 2580,
  MOV8o16a = 2581,
  MOV8o32a = 2582,
  MOV8o64a = 2583,
  MOV8ri = 2584,
  MOV8ri_alt = 2585,
  MOV8rm = 2586,
  MOV8rm_NOREX = 2587,
  MOV8rr = 2588,
  MOV8rr_NOREX = 2589,
  MOV8rr_REV = 2590,
  MOVAPDmr = 2591,
  MOVAPDrm = 2592,
  MOVAPDrr = 2593,
  MOVAPDrr_REV = 2594,
  MOVAPSmr = 2595,
  MOVAPSrm = 2596,
  MOVAPSrr = 2597,
  MOVAPSrr_REV = 2598,
  MOVBE16mr = 2599,
  MOVBE16mr_EVEX = 2600,
  MOVBE16rm = 2601,
  MOVBE16rm_EVEX = 2602,
  MOVBE16rr = 2603,
  MOVBE16rr_REV = 2604,
  MOVBE32mr = 2605,
  MOVBE32mr_EVEX = 2606,
  MOVBE32rm = 2607,
  MOVBE32rm_EVEX = 2608,
  MOVBE32rr = 2609,
  MOVBE32rr_REV = 2610,
  MOVBE64mr = 2611,
  MOVBE64mr_EVEX = 2612,
  MOVBE64rm = 2613,
  MOVBE64rm_EVEX = 2614,
  MOVBE64rr = 2615,
  MOVBE64rr_REV = 2616,
  MOVDDUPrm = 2617,
  MOVDDUPrr = 2618,
  MOVDI2PDIrm = 2619,
  MOVDI2PDIrr = 2620,
  MOVDI2SSrr = 2621,
  MOVDIR64B16 = 2622,
  MOVDIR64B32 = 2623,
  MOVDIR64B32_EVEX = 2624,
  MOVDIR64B64 = 2625,
  MOVDIR64B64_EVEX = 2626,
  MOVDIRI32 = 2627,
  MOVDIRI32_EVEX = 2628,
  MOVDIRI64 = 2629,
  MOVDIRI64_EVEX = 2630,
  MOVDQAmr = 2631,
  MOVDQArm = 2632,
  MOVDQArr = 2633,
  MOVDQArr_REV = 2634,
  MOVDQUmr = 2635,
  MOVDQUrm = 2636,
  MOVDQUrr = 2637,
  MOVDQUrr_REV = 2638,
  MOVHLPSrr = 2639,
  MOVHPDmr = 2640,
  MOVHPDrm = 2641,
  MOVHPSmr = 2642,
  MOVHPSrm = 2643,
  MOVLHPSrr = 2644,
  MOVLPDmr = 2645,
  MOVLPDrm = 2646,
  MOVLPSmr = 2647,
  MOVLPSrm = 2648,
  MOVMSKPDrr = 2649,
  MOVMSKPSrr = 2650,
  MOVNTDQArm = 2651,
  MOVNTDQmr = 2652,
  MOVNTI_64mr = 2653,
  MOVNTImr = 2654,
  MOVNTPDmr = 2655,
  MOVNTPSmr = 2656,
  MOVNTSD = 2657,
  MOVNTSS = 2658,
  MOVPC32r = 2659,
  MOVPDI2DImr = 2660,
  MOVPDI2DIrr = 2661,
  MOVPQI2QImr = 2662,
  MOVPQI2QIrr = 2663,
  MOVPQIto64mr = 2664,
  MOVPQIto64rr = 2665,
  MOVQI2PQIrm = 2666,
  MOVRS16rm = 2667,
  MOVRS16rm_EVEX = 2668,
  MOVRS32rm = 2669,
  MOVRS32rm_EVEX = 2670,
  MOVRS64rm = 2671,
  MOVRS64rm_EVEX = 2672,
  MOVRS8rm = 2673,
  MOVRS8rm_EVEX = 2674,
  MOVSB = 2675,
  MOVSDmr = 2676,
  MOVSDrm = 2677,
  MOVSDrm_alt = 2678,
  MOVSDrr = 2679,
  MOVSDrr_REV = 2680,
  MOVSDto64rr = 2681,
  MOVSHDUPrm = 2682,
  MOVSHDUPrr = 2683,
  MOVSL = 2684,
  MOVSLDUPrm = 2685,
  MOVSLDUPrr = 2686,
  MOVSQ = 2687,
  MOVSS2DIrr = 2688,
  MOVSSmr = 2689,
  MOVSSrm = 2690,
  MOVSSrm_alt = 2691,
  MOVSSrr = 2692,
  MOVSSrr_REV = 2693,
  MOVSW = 2694,
  MOVSX16rm16 = 2695,
  MOVSX16rm32 = 2696,
  MOVSX16rm8 = 2697,
  MOVSX16rr16 = 2698,
  MOVSX16rr32 = 2699,
  MOVSX16rr8 = 2700,
  MOVSX32rm16 = 2701,
  MOVSX32rm32 = 2702,
  MOVSX32rm8 = 2703,
  MOVSX32rm8_NOREX = 2704,
  MOVSX32rr16 = 2705,
  MOVSX32rr32 = 2706,
  MOVSX32rr8 = 2707,
  MOVSX32rr8_NOREX = 2708,
  MOVSX64rm16 = 2709,
  MOVSX64rm32 = 2710,
  MOVSX64rm8 = 2711,
  MOVSX64rr16 = 2712,
  MOVSX64rr32 = 2713,
  MOVSX64rr8 = 2714,
  MOVUPDmr = 2715,
  MOVUPDrm = 2716,
  MOVUPDrr = 2717,
  MOVUPDrr_REV = 2718,
  MOVUPSmr = 2719,
  MOVUPSrm = 2720,
  MOVUPSrr = 2721,
  MOVUPSrr_REV = 2722,
  MOVZPQILo2PQIrr = 2723,
  MOVZX16rm16 = 2724,
  MOVZX16rm8 = 2725,
  MOVZX16rr16 = 2726,
  MOVZX16rr8 = 2727,
  MOVZX32rm16 = 2728,
  MOVZX32rm8 = 2729,
  MOVZX32rm8_NOREX = 2730,
  MOVZX32rr16 = 2731,
  MOVZX32rr8 = 2732,
  MOVZX32rr8_NOREX = 2733,
  MOVZX64rm16 = 2734,
  MOVZX64rm8 = 2735,
  MOVZX64rr16 = 2736,
  MOVZX64rr8 = 2737,
  MPSADBWrmi = 2738,
  MPSADBWrri = 2739,
  MUL16m = 2740,
  MUL16m_EVEX = 2741,
  MUL16m_NF = 2742,
  MUL16r = 2743,
  MUL16r_EVEX = 2744,
  MUL16r_NF = 2745,
  MUL32m = 2746,
  MUL32m_EVEX = 2747,
  MUL32m_NF = 2748,
  MUL32r = 2749,
  MUL32r_EVEX = 2750,
  MUL32r_NF = 2751,
  MUL64m = 2752,
  MUL64m_EVEX = 2753,
  MUL64m_NF = 2754,
  MUL64r = 2755,
  MUL64r_EVEX = 2756,
  MUL64r_NF = 2757,
  MUL8m = 2758,
  MUL8m_EVEX = 2759,
  MUL8m_NF = 2760,
  MUL8r = 2761,
  MUL8r_EVEX = 2762,
  MUL8r_NF = 2763,
  MULPDrm = 2764,
  MULPDrr = 2765,
  MULPSrm = 2766,
  MULPSrr = 2767,
  MULSDrm = 2768,
  MULSDrm_Int = 2769,
  MULSDrr = 2770,
  MULSDrr_Int = 2771,
  MULSSrm = 2772,
  MULSSrm_Int = 2773,
  MULSSrr = 2774,
  MULSSrr_Int = 2775,
  MULX32Hrm = 2776,
  MULX32Hrr = 2777,
  MULX32rm = 2778,
  MULX32rm_EVEX = 2779,
  MULX32rr = 2780,
  MULX32rr_EVEX = 2781,
  MULX64Hrm = 2782,
  MULX64Hrr = 2783,
  MULX64rm = 2784,
  MULX64rm_EVEX = 2785,
  MULX64rr = 2786,
  MULX64rr_EVEX = 2787,
  MUL_F32m = 2788,
  MUL_F64m = 2789,
  MUL_FI16m = 2790,
  MUL_FI32m = 2791,
  MUL_FPrST0 = 2792,
  MUL_FST0r = 2793,
  MUL_Fp32 = 2794,
  MUL_Fp32m = 2795,
  MUL_Fp64 = 2796,
  MUL_Fp64m = 2797,
  MUL_Fp64m32 = 2798,
  MUL_Fp80 = 2799,
  MUL_Fp80m32 = 2800,
  MUL_Fp80m64 = 2801,
  MUL_FpI16m32 = 2802,
  MUL_FpI16m64 = 2803,
  MUL_FpI16m80 = 2804,
  MUL_FpI32m32 = 2805,
  MUL_FpI32m64 = 2806,
  MUL_FpI32m80 = 2807,
  MUL_FrST0 = 2808,
  MWAITXrrr = 2809,
  MWAITrr = 2810,
  NEG16m = 2811,
  NEG16m_EVEX = 2812,
  NEG16m_ND = 2813,
  NEG16m_NF = 2814,
  NEG16m_NF_ND = 2815,
  NEG16r = 2816,
  NEG16r_EVEX = 2817,
  NEG16r_ND = 2818,
  NEG16r_NF = 2819,
  NEG16r_NF_ND = 2820,
  NEG32m = 2821,
  NEG32m_EVEX = 2822,
  NEG32m_ND = 2823,
  NEG32m_NF = 2824,
  NEG32m_NF_ND = 2825,
  NEG32r = 2826,
  NEG32r_EVEX = 2827,
  NEG32r_ND = 2828,
  NEG32r_NF = 2829,
  NEG32r_NF_ND = 2830,
  NEG64m = 2831,
  NEG64m_EVEX = 2832,
  NEG64m_ND = 2833,
  NEG64m_NF = 2834,
  NEG64m_NF_ND = 2835,
  NEG64r = 2836,
  NEG64r_EVEX = 2837,
  NEG64r_ND = 2838,
  NEG64r_NF = 2839,
  NEG64r_NF_ND = 2840,
  NEG8m = 2841,
  NEG8m_EVEX = 2842,
  NEG8m_ND = 2843,
  NEG8m_NF = 2844,
  NEG8m_NF_ND = 2845,
  NEG8r = 2846,
  NEG8r_EVEX = 2847,
  NEG8r_ND = 2848,
  NEG8r_NF = 2849,
  NEG8r_NF_ND = 2850,
  NOOP = 2851,
  NOOPL = 2852,
  NOOPLr = 2853,
  NOOPQ = 2854,
  NOOPQr = 2855,
  NOOPW = 2856,
  NOOPWr = 2857,
  NOT16m = 2858,
  NOT16m_EVEX = 2859,
  NOT16m_ND = 2860,
  NOT16r = 2861,
  NOT16r_EVEX = 2862,
  NOT16r_ND = 2863,
  NOT32m = 2864,
  NOT32m_EVEX = 2865,
  NOT32m_ND = 2866,
  NOT32r = 2867,
  NOT32r_EVEX = 2868,
  NOT32r_ND = 2869,
  NOT64m = 2870,
  NOT64m_EVEX = 2871,
  NOT64m_ND = 2872,
  NOT64r = 2873,
  NOT64r_EVEX = 2874,
  NOT64r_ND = 2875,
  NOT8m = 2876,
  NOT8m_EVEX = 2877,
  NOT8m_ND = 2878,
  NOT8r = 2879,
  NOT8r_EVEX = 2880,
  NOT8r_ND = 2881,
  OR16i16 = 2882,
  OR16mi = 2883,
  OR16mi8 = 2884,
  OR16mi8_EVEX = 2885,
  OR16mi8_ND = 2886,
  OR16mi8_NF = 2887,
  OR16mi8_NF_ND = 2888,
  OR16mi_EVEX = 2889,
  OR16mi_ND = 2890,
  OR16mi_NF = 2891,
  OR16mi_NF_ND = 2892,
  OR16mr = 2893,
  OR16mr_EVEX = 2894,
  OR16mr_ND = 2895,
  OR16mr_NF = 2896,
  OR16mr_NF_ND = 2897,
  OR16ri = 2898,
  OR16ri8 = 2899,
  OR16ri8_EVEX = 2900,
  OR16ri8_ND = 2901,
  OR16ri8_NF = 2902,
  OR16ri8_NF_ND = 2903,
  OR16ri_EVEX = 2904,
  OR16ri_ND = 2905,
  OR16ri_NF = 2906,
  OR16ri_NF_ND = 2907,
  OR16rm = 2908,
  OR16rm_EVEX = 2909,
  OR16rm_ND = 2910,
  OR16rm_NF = 2911,
  OR16rm_NF_ND = 2912,
  OR16rr = 2913,
  OR16rr_EVEX = 2914,
  OR16rr_EVEX_REV = 2915,
  OR16rr_ND = 2916,
  OR16rr_ND_REV = 2917,
  OR16rr_NF = 2918,
  OR16rr_NF_ND = 2919,
  OR16rr_NF_ND_REV = 2920,
  OR16rr_NF_REV = 2921,
  OR16rr_REV = 2922,
  OR32i32 = 2923,
  OR32mi = 2924,
  OR32mi8 = 2925,
  OR32mi8Locked = 2926,
  OR32mi8_EVEX = 2927,
  OR32mi8_ND = 2928,
  OR32mi8_NF = 2929,
  OR32mi8_NF_ND = 2930,
  OR32mi_EVEX = 2931,
  OR32mi_ND = 2932,
  OR32mi_NF = 2933,
  OR32mi_NF_ND = 2934,
  OR32mr = 2935,
  OR32mr_EVEX = 2936,
  OR32mr_ND = 2937,
  OR32mr_NF = 2938,
  OR32mr_NF_ND = 2939,
  OR32ri = 2940,
  OR32ri8 = 2941,
  OR32ri8_EVEX = 2942,
  OR32ri8_ND = 2943,
  OR32ri8_NF = 2944,
  OR32ri8_NF_ND = 2945,
  OR32ri_EVEX = 2946,
  OR32ri_ND = 2947,
  OR32ri_NF = 2948,
  OR32ri_NF_ND = 2949,
  OR32rm = 2950,
  OR32rm_EVEX = 2951,
  OR32rm_ND = 2952,
  OR32rm_NF = 2953,
  OR32rm_NF_ND = 2954,
  OR32rr = 2955,
  OR32rr_EVEX = 2956,
  OR32rr_EVEX_REV = 2957,
  OR32rr_ND = 2958,
  OR32rr_ND_REV = 2959,
  OR32rr_NF = 2960,
  OR32rr_NF_ND = 2961,
  OR32rr_NF_ND_REV = 2962,
  OR32rr_NF_REV = 2963,
  OR32rr_REV = 2964,
  OR64i32 = 2965,
  OR64mi32 = 2966,
  OR64mi32_EVEX = 2967,
  OR64mi32_ND = 2968,
  OR64mi32_NF = 2969,
  OR64mi32_NF_ND = 2970,
  OR64mi8 = 2971,
  OR64mi8_EVEX = 2972,
  OR64mi8_ND = 2973,
  OR64mi8_NF = 2974,
  OR64mi8_NF_ND = 2975,
  OR64mr = 2976,
  OR64mr_EVEX = 2977,
  OR64mr_ND = 2978,
  OR64mr_NF = 2979,
  OR64mr_NF_ND = 2980,
  OR64ri32 = 2981,
  OR64ri32_EVEX = 2982,
  OR64ri32_ND = 2983,
  OR64ri32_NF = 2984,
  OR64ri32_NF_ND = 2985,
  OR64ri8 = 2986,
  OR64ri8_EVEX = 2987,
  OR64ri8_ND = 2988,
  OR64ri8_NF = 2989,
  OR64ri8_NF_ND = 2990,
  OR64rm = 2991,
  OR64rm_EVEX = 2992,
  OR64rm_ND = 2993,
  OR64rm_NF = 2994,
  OR64rm_NF_ND = 2995,
  OR64rr = 2996,
  OR64rr_EVEX = 2997,
  OR64rr_EVEX_REV = 2998,
  OR64rr_ND = 2999,
  OR64rr_ND_REV = 3000,
  OR64rr_NF = 3001,
  OR64rr_NF_ND = 3002,
  OR64rr_NF_ND_REV = 3003,
  OR64rr_NF_REV = 3004,
  OR64rr_REV = 3005,
  OR8i8 = 3006,
  OR8mi = 3007,
  OR8mi8 = 3008,
  OR8mi_EVEX = 3009,
  OR8mi_ND = 3010,
  OR8mi_NF = 3011,
  OR8mi_NF_ND = 3012,
  OR8mr = 3013,
  OR8mr_EVEX = 3014,
  OR8mr_ND = 3015,
  OR8mr_NF = 3016,
  OR8mr_NF_ND = 3017,
  OR8ri = 3018,
  OR8ri8 = 3019,
  OR8ri_EVEX = 3020,
  OR8ri_ND = 3021,
  OR8ri_NF = 3022,
  OR8ri_NF_ND = 3023,
  OR8rm = 3024,
  OR8rm_EVEX = 3025,
  OR8rm_ND = 3026,
  OR8rm_NF = 3027,
  OR8rm_NF_ND = 3028,
  OR8rr = 3029,
  OR8rr_EVEX = 3030,
  OR8rr_EVEX_REV = 3031,
  OR8rr_ND = 3032,
  OR8rr_ND_REV = 3033,
  OR8rr_NF = 3034,
  OR8rr_NF_ND = 3035,
  OR8rr_NF_ND_REV = 3036,
  OR8rr_NF_REV = 3037,
  OR8rr_REV = 3038,
  ORPDrm = 3039,
  ORPDrr = 3040,
  ORPSrm = 3041,
  ORPSrr = 3042,
  OUT16ir = 3043,
  OUT16rr = 3044,
  OUT32ir = 3045,
  OUT32rr = 3046,
  OUT8ir = 3047,
  OUT8rr = 3048,
  OUTSB = 3049,
  OUTSL = 3050,
  OUTSW = 3051,
  PABSBrm = 3052,
  PABSBrr = 3053,
  PABSDrm = 3054,
  PABSDrr = 3055,
  PABSWrm = 3056,
  PABSWrr = 3057,
  PACKSSDWrm = 3058,
  PACKSSDWrr = 3059,
  PACKSSWBrm = 3060,
  PACKSSWBrr = 3061,
  PACKUSDWrm = 3062,
  PACKUSDWrr = 3063,
  PACKUSWBrm = 3064,
  PACKUSWBrr = 3065,
  PADDBrm = 3066,
  PADDBrr = 3067,
  PADDDrm = 3068,
  PADDDrr = 3069,
  PADDQrm = 3070,
  PADDQrr = 3071,
  PADDSBrm = 3072,
  PADDSBrr = 3073,
  PADDSWrm = 3074,
  PADDSWrr = 3075,
  PADDUSBrm = 3076,
  PADDUSBrr = 3077,
  PADDUSWrm = 3078,
  PADDUSWrr = 3079,
  PADDWrm = 3080,
  PADDWrr = 3081,
  PALIGNRrmi = 3082,
  PALIGNRrri = 3083,
  PANDNrm = 3084,
  PANDNrr = 3085,
  PANDrm = 3086,
  PANDrr = 3087,
  PAUSE = 3088,
  PAVGBrm = 3089,
  PAVGBrr = 3090,
  PAVGUSBrm = 3091,
  PAVGUSBrr = 3092,
  PAVGWrm = 3093,
  PAVGWrr = 3094,
  PBLENDVBrm0 = 3095,
  PBLENDVBrr0 = 3096,
  PBLENDWrmi = 3097,
  PBLENDWrri = 3098,
  PBNDKB = 3099,
  PCLMULQDQrmi = 3100,
  PCLMULQDQrri = 3101,
  PCMPEQBrm = 3102,
  PCMPEQBrr = 3103,
  PCMPEQDrm = 3104,
  PCMPEQDrr = 3105,
  PCMPEQQrm = 3106,
  PCMPEQQrr = 3107,
  PCMPEQWrm = 3108,
  PCMPEQWrr = 3109,
  PCMPESTRIrmi = 3110,
  PCMPESTRIrri = 3111,
  PCMPESTRMrmi = 3112,
  PCMPESTRMrri = 3113,
  PCMPGTBrm = 3114,
  PCMPGTBrr = 3115,
  PCMPGTDrm = 3116,
  PCMPGTDrr = 3117,
  PCMPGTQrm = 3118,
  PCMPGTQrr = 3119,
  PCMPGTWrm = 3120,
  PCMPGTWrr = 3121,
  PCMPISTRIrmi = 3122,
  PCMPISTRIrri = 3123,
  PCMPISTRMrmi = 3124,
  PCMPISTRMrri = 3125,
  PCONFIG = 3126,
  PDEP32rm = 3127,
  PDEP32rm_EVEX = 3128,
  PDEP32rr = 3129,
  PDEP32rr_EVEX = 3130,
  PDEP64rm = 3131,
  PDEP64rm_EVEX = 3132,
  PDEP64rr = 3133,
  PDEP64rr_EVEX = 3134,
  PEXT32rm = 3135,
  PEXT32rm_EVEX = 3136,
  PEXT32rr = 3137,
  PEXT32rr_EVEX = 3138,
  PEXT64rm = 3139,
  PEXT64rm_EVEX = 3140,
  PEXT64rr = 3141,
  PEXT64rr_EVEX = 3142,
  PEXTRBmri = 3143,
  PEXTRBrri = 3144,
  PEXTRDmri = 3145,
  PEXTRDrri = 3146,
  PEXTRQmri = 3147,
  PEXTRQrri = 3148,
  PEXTRWmri = 3149,
  PEXTRWrri = 3150,
  PEXTRWrri_REV = 3151,
  PF2IDrm = 3152,
  PF2IDrr = 3153,
  PF2IWrm = 3154,
  PF2IWrr = 3155,
  PFACCrm = 3156,
  PFACCrr = 3157,
  PFADDrm = 3158,
  PFADDrr = 3159,
  PFCMPEQrm = 3160,
  PFCMPEQrr = 3161,
  PFCMPGErm = 3162,
  PFCMPGErr = 3163,
  PFCMPGTrm = 3164,
  PFCMPGTrr = 3165,
  PFMAXrm = 3166,
  PFMAXrr = 3167,
  PFMINrm = 3168,
  PFMINrr = 3169,
  PFMULrm = 3170,
  PFMULrr = 3171,
  PFNACCrm = 3172,
  PFNACCrr = 3173,
  PFPNACCrm = 3174,
  PFPNACCrr = 3175,
  PFRCPIT1rm = 3176,
  PFRCPIT1rr = 3177,
  PFRCPIT2rm = 3178,
  PFRCPIT2rr = 3179,
  PFRCPrm = 3180,
  PFRCPrr = 3181,
  PFRSQIT1rm = 3182,
  PFRSQIT1rr = 3183,
  PFRSQRTrm = 3184,
  PFRSQRTrr = 3185,
  PFSUBRrm = 3186,
  PFSUBRrr = 3187,
  PFSUBrm = 3188,
  PFSUBrr = 3189,
  PHADDDrm = 3190,
  PHADDDrr = 3191,
  PHADDSWrm = 3192,
  PHADDSWrr = 3193,
  PHADDWrm = 3194,
  PHADDWrr = 3195,
  PHMINPOSUWrm = 3196,
  PHMINPOSUWrr = 3197,
  PHSUBDrm = 3198,
  PHSUBDrr = 3199,
  PHSUBSWrm = 3200,
  PHSUBSWrr = 3201,
  PHSUBWrm = 3202,
  PHSUBWrr = 3203,
  PI2FDrm = 3204,
  PI2FDrr = 3205,
  PI2FWrm = 3206,
  PI2FWrr = 3207,
  PINSRBrmi = 3208,
  PINSRBrri = 3209,
  PINSRDrmi = 3210,
  PINSRDrri = 3211,
  PINSRQrmi = 3212,
  PINSRQrri = 3213,
  PINSRWrmi = 3214,
  PINSRWrri = 3215,
  PMADDUBSWrm = 3216,
  PMADDUBSWrr = 3217,
  PMADDWDrm = 3218,
  PMADDWDrr = 3219,
  PMAXSBrm = 3220,
  PMAXSBrr = 3221,
  PMAXSDrm = 3222,
  PMAXSDrr = 3223,
  PMAXSWrm = 3224,
  PMAXSWrr = 3225,
  PMAXUBrm = 3226,
  PMAXUBrr = 3227,
  PMAXUDrm = 3228,
  PMAXUDrr = 3229,
  PMAXUWrm = 3230,
  PMAXUWrr = 3231,
  PMINSBrm = 3232,
  PMINSBrr = 3233,
  PMINSDrm = 3234,
  PMINSDrr = 3235,
  PMINSWrm = 3236,
  PMINSWrr = 3237,
  PMINUBrm = 3238,
  PMINUBrr = 3239,
  PMINUDrm = 3240,
  PMINUDrr = 3241,
  PMINUWrm = 3242,
  PMINUWrr = 3243,
  PMOVMSKBrr = 3244,
  PMOVSXBDrm = 3245,
  PMOVSXBDrr = 3246,
  PMOVSXBQrm = 3247,
  PMOVSXBQrr = 3248,
  PMOVSXBWrm = 3249,
  PMOVSXBWrr = 3250,
  PMOVSXDQrm = 3251,
  PMOVSXDQrr = 3252,
  PMOVSXWDrm = 3253,
  PMOVSXWDrr = 3254,
  PMOVSXWQrm = 3255,
  PMOVSXWQrr = 3256,
  PMOVZXBDrm = 3257,
  PMOVZXBDrr = 3258,
  PMOVZXBQrm = 3259,
  PMOVZXBQrr = 3260,
  PMOVZXBWrm = 3261,
  PMOVZXBWrr = 3262,
  PMOVZXDQrm = 3263,
  PMOVZXDQrr = 3264,
  PMOVZXWDrm = 3265,
  PMOVZXWDrr = 3266,
  PMOVZXWQrm = 3267,
  PMOVZXWQrr = 3268,
  PMULDQrm = 3269,
  PMULDQrr = 3270,
  PMULHRSWrm = 3271,
  PMULHRSWrr = 3272,
  PMULHRWrm = 3273,
  PMULHRWrr = 3274,
  PMULHUWrm = 3275,
  PMULHUWrr = 3276,
  PMULHWrm = 3277,
  PMULHWrr = 3278,
  PMULLDrm = 3279,
  PMULLDrr = 3280,
  PMULLWrm = 3281,
  PMULLWrr = 3282,
  PMULUDQrm = 3283,
  PMULUDQrr = 3284,
  POP16r = 3285,
  POP16rmm = 3286,
  POP16rmr = 3287,
  POP2 = 3288,
  POP2P = 3289,
  POP32r = 3290,
  POP32rmm = 3291,
  POP32rmr = 3292,
  POP64r = 3293,
  POP64rmm = 3294,
  POP64rmr = 3295,
  POPA16 = 3296,
  POPA32 = 3297,
  POPCNT16rm = 3298,
  POPCNT16rm_EVEX = 3299,
  POPCNT16rm_NF = 3300,
  POPCNT16rr = 3301,
  POPCNT16rr_EVEX = 3302,
  POPCNT16rr_NF = 3303,
  POPCNT32rm = 3304,
  POPCNT32rm_EVEX = 3305,
  POPCNT32rm_NF = 3306,
  POPCNT32rr = 3307,
  POPCNT32rr_EVEX = 3308,
  POPCNT32rr_NF = 3309,
  POPCNT64rm = 3310,
  POPCNT64rm_EVEX = 3311,
  POPCNT64rm_NF = 3312,
  POPCNT64rr = 3313,
  POPCNT64rr_EVEX = 3314,
  POPCNT64rr_NF = 3315,
  POPDS16 = 3316,
  POPDS32 = 3317,
  POPES16 = 3318,
  POPES32 = 3319,
  POPF16 = 3320,
  POPF32 = 3321,
  POPF64 = 3322,
  POPFS16 = 3323,
  POPFS32 = 3324,
  POPFS64 = 3325,
  POPGS16 = 3326,
  POPGS32 = 3327,
  POPGS64 = 3328,
  POPP64r = 3329,
  POPSS16 = 3330,
  POPSS32 = 3331,
  PORrm = 3332,
  PORrr = 3333,
  PREFETCH = 3334,
  PREFETCHIT0 = 3335,
  PREFETCHIT1 = 3336,
  PREFETCHNTA = 3337,
  PREFETCHRST2 = 3338,
  PREFETCHT0 = 3339,
  PREFETCHT1 = 3340,
  PREFETCHT2 = 3341,
  PREFETCHW = 3342,
  PREFETCHWT1 = 3343,
  PROBED_ALLOCA_32 = 3344,
  PROBED_ALLOCA_64 = 3345,
  PSADBWrm = 3346,
  PSADBWrr = 3347,
  PSHUFBrm = 3348,
  PSHUFBrr = 3349,
  PSHUFDmi = 3350,
  PSHUFDri = 3351,
  PSHUFHWmi = 3352,
  PSHUFHWri = 3353,
  PSHUFLWmi = 3354,
  PSHUFLWri = 3355,
  PSIGNBrm = 3356,
  PSIGNBrr = 3357,
  PSIGNDrm = 3358,
  PSIGNDrr = 3359,
  PSIGNWrm = 3360,
  PSIGNWrr = 3361,
  PSLLDQri = 3362,
  PSLLDri = 3363,
  PSLLDrm = 3364,
  PSLLDrr = 3365,
  PSLLQri = 3366,
  PSLLQrm = 3367,
  PSLLQrr = 3368,
  PSLLWri = 3369,
  PSLLWrm = 3370,
  PSLLWrr = 3371,
  PSMASH = 3372,
  PSRADri = 3373,
  PSRADrm = 3374,
  PSRADrr = 3375,
  PSRAWri = 3376,
  PSRAWrm = 3377,
  PSRAWrr = 3378,
  PSRLDQri = 3379,
  PSRLDri = 3380,
  PSRLDrm = 3381,
  PSRLDrr = 3382,
  PSRLQri = 3383,
  PSRLQrm = 3384,
  PSRLQrr = 3385,
  PSRLWri = 3386,
  PSRLWrm = 3387,
  PSRLWrr = 3388,
  PSUBBrm = 3389,
  PSUBBrr = 3390,
  PSUBDrm = 3391,
  PSUBDrr = 3392,
  PSUBQrm = 3393,
  PSUBQrr = 3394,
  PSUBSBrm = 3395,
  PSUBSBrr = 3396,
  PSUBSWrm = 3397,
  PSUBSWrr = 3398,
  PSUBUSBrm = 3399,
  PSUBUSBrr = 3400,
  PSUBUSWrm = 3401,
  PSUBUSWrr = 3402,
  PSUBWrm = 3403,
  PSUBWrr = 3404,
  PSWAPDrm = 3405,
  PSWAPDrr = 3406,
  PT2RPNTLVWZ0 = 3407,
  PT2RPNTLVWZ0RS = 3408,
  PT2RPNTLVWZ0RST1 = 3409,
  PT2RPNTLVWZ0T1 = 3410,
  PT2RPNTLVWZ1 = 3411,
  PT2RPNTLVWZ1RS = 3412,
  PT2RPNTLVWZ1RST1 = 3413,
  PT2RPNTLVWZ1T1 = 3414,
  PTCMMIMFP16PS = 3415,
  PTCMMIMFP16PSV = 3416,
  PTCMMRLFP16PS = 3417,
  PTCMMRLFP16PSV = 3418,
  PTCONJTCMMIMFP16PS = 3419,
  PTCONJTCMMIMFP16PSV = 3420,
  PTCONJTFP16 = 3421,
  PTCONJTFP16V = 3422,
  PTCVTROWD2PSrre = 3423,
  PTCVTROWD2PSrreV = 3424,
  PTCVTROWD2PSrri = 3425,
  PTCVTROWD2PSrriV = 3426,
  PTCVTROWPS2BF16Hrre = 3427,
  PTCVTROWPS2BF16HrreV = 3428,
  PTCVTROWPS2BF16Hrri = 3429,
  PTCVTROWPS2BF16HrriV = 3430,
  PTCVTROWPS2BF16Lrre = 3431,
  PTCVTROWPS2BF16LrreV = 3432,
  PTCVTROWPS2BF16Lrri = 3433,
  PTCVTROWPS2BF16LrriV = 3434,
  PTCVTROWPS2PHHrre = 3435,
  PTCVTROWPS2PHHrreV = 3436,
  PTCVTROWPS2PHHrri = 3437,
  PTCVTROWPS2PHHrriV = 3438,
  PTCVTROWPS2PHLrre = 3439,
  PTCVTROWPS2PHLrreV = 3440,
  PTCVTROWPS2PHLrri = 3441,
  PTCVTROWPS2PHLrriV = 3442,
  PTDPBF16PS = 3443,
  PTDPBF8PS = 3444,
  PTDPBF8PSV = 3445,
  PTDPBHF8PS = 3446,
  PTDPBHF8PSV = 3447,
  PTDPBSSD = 3448,
  PTDPBSUD = 3449,
  PTDPBUSD = 3450,
  PTDPBUUD = 3451,
  PTDPFP16PS = 3452,
  PTDPHBF8PS = 3453,
  PTDPHBF8PSV = 3454,
  PTDPHF8PS = 3455,
  PTDPHF8PSV = 3456,
  PTESTrm = 3457,
  PTESTrr = 3458,
  PTILELOADD = 3459,
  PTILELOADDRS = 3460,
  PTILELOADDRST1 = 3461,
  PTILELOADDT1 = 3462,
  PTILEMOVROWrre = 3463,
  PTILEMOVROWrreV = 3464,
  PTILEMOVROWrri = 3465,
  PTILEMOVROWrriV = 3466,
  PTILESTORED = 3467,
  PTILEZERO = 3468,
  PTMMULTF32PS = 3469,
  PTMMULTF32PSV = 3470,
  PTTCMMIMFP16PS = 3471,
  PTTCMMIMFP16PSV = 3472,
  PTTCMMRLFP16PS = 3473,
  PTTCMMRLFP16PSV = 3474,
  PTTDPBF16PS = 3475,
  PTTDPBF16PSV = 3476,
  PTTDPFP16PS = 3477,
  PTTDPFP16PSV = 3478,
  PTTMMULTF32PS = 3479,
  PTTMMULTF32PSV = 3480,
  PTTRANSPOSED = 3481,
  PTTRANSPOSEDV = 3482,
  PTWRITE64m = 3483,
  PTWRITE64r = 3484,
  PTWRITEm = 3485,
  PTWRITEr = 3486,
  PUNPCKHBWrm = 3487,
  PUNPCKHBWrr = 3488,
  PUNPCKHDQrm = 3489,
  PUNPCKHDQrr = 3490,
  PUNPCKHQDQrm = 3491,
  PUNPCKHQDQrr = 3492,
  PUNPCKHWDrm = 3493,
  PUNPCKHWDrr = 3494,
  PUNPCKLBWrm = 3495,
  PUNPCKLBWrr = 3496,
  PUNPCKLDQrm = 3497,
  PUNPCKLDQrr = 3498,
  PUNPCKLQDQrm = 3499,
  PUNPCKLQDQrr = 3500,
  PUNPCKLWDrm = 3501,
  PUNPCKLWDrr = 3502,
  PUSH16i = 3503,
  PUSH16i8 = 3504,
  PUSH16r = 3505,
  PUSH16rmm = 3506,
  PUSH16rmr = 3507,
  PUSH2 = 3508,
  PUSH2P = 3509,
  PUSH32i = 3510,
  PUSH32i8 = 3511,
  PUSH32r = 3512,
  PUSH32rmm = 3513,
  PUSH32rmr = 3514,
  PUSH64i32 = 3515,
  PUSH64i8 = 3516,
  PUSH64r = 3517,
  PUSH64rmm = 3518,
  PUSH64rmr = 3519,
  PUSHA16 = 3520,
  PUSHA32 = 3521,
  PUSHCS16 = 3522,
  PUSHCS32 = 3523,
  PUSHDS16 = 3524,
  PUSHDS32 = 3525,
  PUSHES16 = 3526,
  PUSHES32 = 3527,
  PUSHF16 = 3528,
  PUSHF32 = 3529,
  PUSHF64 = 3530,
  PUSHFS16 = 3531,
  PUSHFS32 = 3532,
  PUSHFS64 = 3533,
  PUSHGS16 = 3534,
  PUSHGS32 = 3535,
  PUSHGS64 = 3536,
  PUSHP64r = 3537,
  PUSHSS16 = 3538,
  PUSHSS32 = 3539,
  PVALIDATE32 = 3540,
  PVALIDATE64 = 3541,
  PXORrm = 3542,
  PXORrr = 3543,
  RCL16m1 = 3544,
  RCL16m1_EVEX = 3545,
  RCL16m1_ND = 3546,
  RCL16mCL = 3547,
  RCL16mCL_EVEX = 3548,
  RCL16mCL_ND = 3549,
  RCL16mi = 3550,
  RCL16mi_EVEX = 3551,
  RCL16mi_ND = 3552,
  RCL16r1 = 3553,
  RCL16r1_EVEX = 3554,
  RCL16r1_ND = 3555,
  RCL16rCL = 3556,
  RCL16rCL_EVEX = 3557,
  RCL16rCL_ND = 3558,
  RCL16ri = 3559,
  RCL16ri_EVEX = 3560,
  RCL16ri_ND = 3561,
  RCL32m1 = 3562,
  RCL32m1_EVEX = 3563,
  RCL32m1_ND = 3564,
  RCL32mCL = 3565,
  RCL32mCL_EVEX = 3566,
  RCL32mCL_ND = 3567,
  RCL32mi = 3568,
  RCL32mi_EVEX = 3569,
  RCL32mi_ND = 3570,
  RCL32r1 = 3571,
  RCL32r1_EVEX = 3572,
  RCL32r1_ND = 3573,
  RCL32rCL = 3574,
  RCL32rCL_EVEX = 3575,
  RCL32rCL_ND = 3576,
  RCL32ri = 3577,
  RCL32ri_EVEX = 3578,
  RCL32ri_ND = 3579,
  RCL64m1 = 3580,
  RCL64m1_EVEX = 3581,
  RCL64m1_ND = 3582,
  RCL64mCL = 3583,
  RCL64mCL_EVEX = 3584,
  RCL64mCL_ND = 3585,
  RCL64mi = 3586,
  RCL64mi_EVEX = 3587,
  RCL64mi_ND = 3588,
  RCL64r1 = 3589,
  RCL64r1_EVEX = 3590,
  RCL64r1_ND = 3591,
  RCL64rCL = 3592,
  RCL64rCL_EVEX = 3593,
  RCL64rCL_ND = 3594,
  RCL64ri = 3595,
  RCL64ri_EVEX = 3596,
  RCL64ri_ND = 3597,
  RCL8m1 = 3598,
  RCL8m1_EVEX = 3599,
  RCL8m1_ND = 3600,
  RCL8mCL = 3601,
  RCL8mCL_EVEX = 3602,
  RCL8mCL_ND = 3603,
  RCL8mi = 3604,
  RCL8mi_EVEX = 3605,
  RCL8mi_ND = 3606,
  RCL8r1 = 3607,
  RCL8r1_EVEX = 3608,
  RCL8r1_ND = 3609,
  RCL8rCL = 3610,
  RCL8rCL_EVEX = 3611,
  RCL8rCL_ND = 3612,
  RCL8ri = 3613,
  RCL8ri_EVEX = 3614,
  RCL8ri_ND = 3615,
  RCPPSm = 3616,
  RCPPSr = 3617,
  RCPSSm = 3618,
  RCPSSm_Int = 3619,
  RCPSSr = 3620,
  RCPSSr_Int = 3621,
  RCR16m1 = 3622,
  RCR16m1_EVEX = 3623,
  RCR16m1_ND = 3624,
  RCR16mCL = 3625,
  RCR16mCL_EVEX = 3626,
  RCR16mCL_ND = 3627,
  RCR16mi = 3628,
  RCR16mi_EVEX = 3629,
  RCR16mi_ND = 3630,
  RCR16r1 = 3631,
  RCR16r1_EVEX = 3632,
  RCR16r1_ND = 3633,
  RCR16rCL = 3634,
  RCR16rCL_EVEX = 3635,
  RCR16rCL_ND = 3636,
  RCR16ri = 3637,
  RCR16ri_EVEX = 3638,
  RCR16ri_ND = 3639,
  RCR32m1 = 3640,
  RCR32m1_EVEX = 3641,
  RCR32m1_ND = 3642,
  RCR32mCL = 3643,
  RCR32mCL_EVEX = 3644,
  RCR32mCL_ND = 3645,
  RCR32mi = 3646,
  RCR32mi_EVEX = 3647,
  RCR32mi_ND = 3648,
  RCR32r1 = 3649,
  RCR32r1_EVEX = 3650,
  RCR32r1_ND = 3651,
  RCR32rCL = 3652,
  RCR32rCL_EVEX = 3653,
  RCR32rCL_ND = 3654,
  RCR32ri = 3655,
  RCR32ri_EVEX = 3656,
  RCR32ri_ND = 3657,
  RCR64m1 = 3658,
  RCR64m1_EVEX = 3659,
  RCR64m1_ND = 3660,
  RCR64mCL = 3661,
  RCR64mCL_EVEX = 3662,
  RCR64mCL_ND = 3663,
  RCR64mi = 3664,
  RCR64mi_EVEX = 3665,
  RCR64mi_ND = 3666,
  RCR64r1 = 3667,
  RCR64r1_EVEX = 3668,
  RCR64r1_ND = 3669,
  RCR64rCL = 3670,
  RCR64rCL_EVEX = 3671,
  RCR64rCL_ND = 3672,
  RCR64ri = 3673,
  RCR64ri_EVEX = 3674,
  RCR64ri_ND = 3675,
  RCR8m1 = 3676,
  RCR8m1_EVEX = 3677,
  RCR8m1_ND = 3678,
  RCR8mCL = 3679,
  RCR8mCL_EVEX = 3680,
  RCR8mCL_ND = 3681,
  RCR8mi = 3682,
  RCR8mi_EVEX = 3683,
  RCR8mi_ND = 3684,
  RCR8r1 = 3685,
  RCR8r1_EVEX = 3686,
  RCR8r1_ND = 3687,
  RCR8rCL = 3688,
  RCR8rCL_EVEX = 3689,
  RCR8rCL_ND = 3690,
  RCR8ri = 3691,
  RCR8ri_EVEX = 3692,
  RCR8ri_ND = 3693,
  RDFSBASE = 3694,
  RDFSBASE64 = 3695,
  RDGSBASE = 3696,
  RDGSBASE64 = 3697,
  RDMSR = 3698,
  RDMSRLIST = 3699,
  RDMSRri = 3700,
  RDMSRri_EVEX = 3701,
  RDPID32 = 3702,
  RDPID64 = 3703,
  RDPKRUr = 3704,
  RDPMC = 3705,
  RDPRU = 3706,
  RDRAND16r = 3707,
  RDRAND32r = 3708,
  RDRAND64r = 3709,
  RDSEED16r = 3710,
  RDSEED32r = 3711,
  RDSEED64r = 3712,
  RDSSPD = 3713,
  RDSSPQ = 3714,
  RDTSC = 3715,
  RDTSCP = 3716,
  REPNE_PREFIX = 3717,
  REP_MOVSB_32 = 3718,
  REP_MOVSB_64 = 3719,
  REP_MOVSD_32 = 3720,
  REP_MOVSD_64 = 3721,
  REP_MOVSQ_32 = 3722,
  REP_MOVSQ_64 = 3723,
  REP_MOVSW_32 = 3724,
  REP_MOVSW_64 = 3725,
  REP_PREFIX = 3726,
  REP_STOSB_32 = 3727,
  REP_STOSB_64 = 3728,
  REP_STOSD_32 = 3729,
  REP_STOSD_64 = 3730,
  REP_STOSQ_32 = 3731,
  REP_STOSQ_64 = 3732,
  REP_STOSW_32 = 3733,
  REP_STOSW_64 = 3734,
  RET = 3735,
  RET16 = 3736,
  RET32 = 3737,
  RET64 = 3738,
  RETI16 = 3739,
  RETI32 = 3740,
  RETI64 = 3741,
  REX64_PREFIX = 3742,
  RMPADJUST = 3743,
  RMPQUERY = 3744,
  RMPUPDATE = 3745,
  ROL16m1 = 3746,
  ROL16m1_EVEX = 3747,
  ROL16m1_ND = 3748,
  ROL16m1_NF = 3749,
  ROL16m1_NF_ND = 3750,
  ROL16mCL = 3751,
  ROL16mCL_EVEX = 3752,
  ROL16mCL_ND = 3753,
  ROL16mCL_NF = 3754,
  ROL16mCL_NF_ND = 3755,
  ROL16mi = 3756,
  ROL16mi_EVEX = 3757,
  ROL16mi_ND = 3758,
  ROL16mi_NF = 3759,
  ROL16mi_NF_ND = 3760,
  ROL16r1 = 3761,
  ROL16r1_EVEX = 3762,
  ROL16r1_ND = 3763,
  ROL16r1_NF = 3764,
  ROL16r1_NF_ND = 3765,
  ROL16rCL = 3766,
  ROL16rCL_EVEX = 3767,
  ROL16rCL_ND = 3768,
  ROL16rCL_NF = 3769,
  ROL16rCL_NF_ND = 3770,
  ROL16ri = 3771,
  ROL16ri_EVEX = 3772,
  ROL16ri_ND = 3773,
  ROL16ri_NF = 3774,
  ROL16ri_NF_ND = 3775,
  ROL32m1 = 3776,
  ROL32m1_EVEX = 3777,
  ROL32m1_ND = 3778,
  ROL32m1_NF = 3779,
  ROL32m1_NF_ND = 3780,
  ROL32mCL = 3781,
  ROL32mCL_EVEX = 3782,
  ROL32mCL_ND = 3783,
  ROL32mCL_NF = 3784,
  ROL32mCL_NF_ND = 3785,
  ROL32mi = 3786,
  ROL32mi_EVEX = 3787,
  ROL32mi_ND = 3788,
  ROL32mi_NF = 3789,
  ROL32mi_NF_ND = 3790,
  ROL32r1 = 3791,
  ROL32r1_EVEX = 3792,
  ROL32r1_ND = 3793,
  ROL32r1_NF = 3794,
  ROL32r1_NF_ND = 3795,
  ROL32rCL = 3796,
  ROL32rCL_EVEX = 3797,
  ROL32rCL_ND = 3798,
  ROL32rCL_NF = 3799,
  ROL32rCL_NF_ND = 3800,
  ROL32ri = 3801,
  ROL32ri_EVEX = 3802,
  ROL32ri_ND = 3803,
  ROL32ri_NF = 3804,
  ROL32ri_NF_ND = 3805,
  ROL64m1 = 3806,
  ROL64m1_EVEX = 3807,
  ROL64m1_ND = 3808,
  ROL64m1_NF = 3809,
  ROL64m1_NF_ND = 3810,
  ROL64mCL = 3811,
  ROL64mCL_EVEX = 3812,
  ROL64mCL_ND = 3813,
  ROL64mCL_NF = 3814,
  ROL64mCL_NF_ND = 3815,
  ROL64mi = 3816,
  ROL64mi_EVEX = 3817,
  ROL64mi_ND = 3818,
  ROL64mi_NF = 3819,
  ROL64mi_NF_ND = 3820,
  ROL64r1 = 3821,
  ROL64r1_EVEX = 3822,
  ROL64r1_ND = 3823,
  ROL64r1_NF = 3824,
  ROL64r1_NF_ND = 3825,
  ROL64rCL = 3826,
  ROL64rCL_EVEX = 3827,
  ROL64rCL_ND = 3828,
  ROL64rCL_NF = 3829,
  ROL64rCL_NF_ND = 3830,
  ROL64ri = 3831,
  ROL64ri_EVEX = 3832,
  ROL64ri_ND = 3833,
  ROL64ri_NF = 3834,
  ROL64ri_NF_ND = 3835,
  ROL8m1 = 3836,
  ROL8m1_EVEX = 3837,
  ROL8m1_ND = 3838,
  ROL8m1_NF = 3839,
  ROL8m1_NF_ND = 3840,
  ROL8mCL = 3841,
  ROL8mCL_EVEX = 3842,
  ROL8mCL_ND = 3843,
  ROL8mCL_NF = 3844,
  ROL8mCL_NF_ND = 3845,
  ROL8mi = 3846,
  ROL8mi_EVEX = 3847,
  ROL8mi_ND = 3848,
  ROL8mi_NF = 3849,
  ROL8mi_NF_ND = 3850,
  ROL8r1 = 3851,
  ROL8r1_EVEX = 3852,
  ROL8r1_ND = 3853,
  ROL8r1_NF = 3854,
  ROL8r1_NF_ND = 3855,
  ROL8rCL = 3856,
  ROL8rCL_EVEX = 3857,
  ROL8rCL_ND = 3858,
  ROL8rCL_NF = 3859,
  ROL8rCL_NF_ND = 3860,
  ROL8ri = 3861,
  ROL8ri_EVEX = 3862,
  ROL8ri_ND = 3863,
  ROL8ri_NF = 3864,
  ROL8ri_NF_ND = 3865,
  ROR16m1 = 3866,
  ROR16m1_EVEX = 3867,
  ROR16m1_ND = 3868,
  ROR16m1_NF = 3869,
  ROR16m1_NF_ND = 3870,
  ROR16mCL = 3871,
  ROR16mCL_EVEX = 3872,
  ROR16mCL_ND = 3873,
  ROR16mCL_NF = 3874,
  ROR16mCL_NF_ND = 3875,
  ROR16mi = 3876,
  ROR16mi_EVEX = 3877,
  ROR16mi_ND = 3878,
  ROR16mi_NF = 3879,
  ROR16mi_NF_ND = 3880,
  ROR16r1 = 3881,
  ROR16r1_EVEX = 3882,
  ROR16r1_ND = 3883,
  ROR16r1_NF = 3884,
  ROR16r1_NF_ND = 3885,
  ROR16rCL = 3886,
  ROR16rCL_EVEX = 3887,
  ROR16rCL_ND = 3888,
  ROR16rCL_NF = 3889,
  ROR16rCL_NF_ND = 3890,
  ROR16ri = 3891,
  ROR16ri_EVEX = 3892,
  ROR16ri_ND = 3893,
  ROR16ri_NF = 3894,
  ROR16ri_NF_ND = 3895,
  ROR32m1 = 3896,
  ROR32m1_EVEX = 3897,
  ROR32m1_ND = 3898,
  ROR32m1_NF = 3899,
  ROR32m1_NF_ND = 3900,
  ROR32mCL = 3901,
  ROR32mCL_EVEX = 3902,
  ROR32mCL_ND = 3903,
  ROR32mCL_NF = 3904,
  ROR32mCL_NF_ND = 3905,
  ROR32mi = 3906,
  ROR32mi_EVEX = 3907,
  ROR32mi_ND = 3908,
  ROR32mi_NF = 3909,
  ROR32mi_NF_ND = 3910,
  ROR32r1 = 3911,
  ROR32r1_EVEX = 3912,
  ROR32r1_ND = 3913,
  ROR32r1_NF = 3914,
  ROR32r1_NF_ND = 3915,
  ROR32rCL = 3916,
  ROR32rCL_EVEX = 3917,
  ROR32rCL_ND = 3918,
  ROR32rCL_NF = 3919,
  ROR32rCL_NF_ND = 3920,
  ROR32ri = 3921,
  ROR32ri_EVEX = 3922,
  ROR32ri_ND = 3923,
  ROR32ri_NF = 3924,
  ROR32ri_NF_ND = 3925,
  ROR64m1 = 3926,
  ROR64m1_EVEX = 3927,
  ROR64m1_ND = 3928,
  ROR64m1_NF = 3929,
  ROR64m1_NF_ND = 3930,
  ROR64mCL = 3931,
  ROR64mCL_EVEX = 3932,
  ROR64mCL_ND = 3933,
  ROR64mCL_NF = 3934,
  ROR64mCL_NF_ND = 3935,
  ROR64mi = 3936,
  ROR64mi_EVEX = 3937,
  ROR64mi_ND = 3938,
  ROR64mi_NF = 3939,
  ROR64mi_NF_ND = 3940,
  ROR64r1 = 3941,
  ROR64r1_EVEX = 3942,
  ROR64r1_ND = 3943,
  ROR64r1_NF = 3944,
  ROR64r1_NF_ND = 3945,
  ROR64rCL = 3946,
  ROR64rCL_EVEX = 3947,
  ROR64rCL_ND = 3948,
  ROR64rCL_NF = 3949,
  ROR64rCL_NF_ND = 3950,
  ROR64ri = 3951,
  ROR64ri_EVEX = 3952,
  ROR64ri_ND = 3953,
  ROR64ri_NF = 3954,
  ROR64ri_NF_ND = 3955,
  ROR8m1 = 3956,
  ROR8m1_EVEX = 3957,
  ROR8m1_ND = 3958,
  ROR8m1_NF = 3959,
  ROR8m1_NF_ND = 3960,
  ROR8mCL = 3961,
  ROR8mCL_EVEX = 3962,
  ROR8mCL_ND = 3963,
  ROR8mCL_NF = 3964,
  ROR8mCL_NF_ND = 3965,
  ROR8mi = 3966,
  ROR8mi_EVEX = 3967,
  ROR8mi_ND = 3968,
  ROR8mi_NF = 3969,
  ROR8mi_NF_ND = 3970,
  ROR8r1 = 3971,
  ROR8r1_EVEX = 3972,
  ROR8r1_ND = 3973,
  ROR8r1_NF = 3974,
  ROR8r1_NF_ND = 3975,
  ROR8rCL = 3976,
  ROR8rCL_EVEX = 3977,
  ROR8rCL_ND = 3978,
  ROR8rCL_NF = 3979,
  ROR8rCL_NF_ND = 3980,
  ROR8ri = 3981,
  ROR8ri_EVEX = 3982,
  ROR8ri_ND = 3983,
  ROR8ri_NF = 3984,
  ROR8ri_NF_ND = 3985,
  RORX32mi = 3986,
  RORX32mi_EVEX = 3987,
  RORX32ri = 3988,
  RORX32ri_EVEX = 3989,
  RORX64mi = 3990,
  RORX64mi_EVEX = 3991,
  RORX64ri = 3992,
  RORX64ri_EVEX = 3993,
  ROUNDPDmi = 3994,
  ROUNDPDri = 3995,
  ROUNDPSmi = 3996,
  ROUNDPSri = 3997,
  ROUNDSDmi = 3998,
  ROUNDSDmi_Int = 3999,
  ROUNDSDri = 4000,
  ROUNDSDri_Int = 4001,
  ROUNDSSmi = 4002,
  ROUNDSSmi_Int = 4003,
  ROUNDSSri = 4004,
  ROUNDSSri_Int = 4005,
  RSM = 4006,
  RSQRTPSm = 4007,
  RSQRTPSr = 4008,
  RSQRTSSm = 4009,
  RSQRTSSm_Int = 4010,
  RSQRTSSr = 4011,
  RSQRTSSr_Int = 4012,
  RSTORSSP = 4013,
  SAHF = 4014,
  SALC = 4015,
  SAR16m1 = 4016,
  SAR16m1_EVEX = 4017,
  SAR16m1_ND = 4018,
  SAR16m1_NF = 4019,
  SAR16m1_NF_ND = 4020,
  SAR16mCL = 4021,
  SAR16mCL_EVEX = 4022,
  SAR16mCL_ND = 4023,
  SAR16mCL_NF = 4024,
  SAR16mCL_NF_ND = 4025,
  SAR16mi = 4026,
  SAR16mi_EVEX = 4027,
  SAR16mi_ND = 4028,
  SAR16mi_NF = 4029,
  SAR16mi_NF_ND = 4030,
  SAR16r1 = 4031,
  SAR16r1_EVEX = 4032,
  SAR16r1_ND = 4033,
  SAR16r1_NF = 4034,
  SAR16r1_NF_ND = 4035,
  SAR16rCL = 4036,
  SAR16rCL_EVEX = 4037,
  SAR16rCL_ND = 4038,
  SAR16rCL_NF = 4039,
  SAR16rCL_NF_ND = 4040,
  SAR16ri = 4041,
  SAR16ri_EVEX = 4042,
  SAR16ri_ND = 4043,
  SAR16ri_NF = 4044,
  SAR16ri_NF_ND = 4045,
  SAR32m1 = 4046,
  SAR32m1_EVEX = 4047,
  SAR32m1_ND = 4048,
  SAR32m1_NF = 4049,
  SAR32m1_NF_ND = 4050,
  SAR32mCL = 4051,
  SAR32mCL_EVEX = 4052,
  SAR32mCL_ND = 4053,
  SAR32mCL_NF = 4054,
  SAR32mCL_NF_ND = 4055,
  SAR32mi = 4056,
  SAR32mi_EVEX = 4057,
  SAR32mi_ND = 4058,
  SAR32mi_NF = 4059,
  SAR32mi_NF_ND = 4060,
  SAR32r1 = 4061,
  SAR32r1_EVEX = 4062,
  SAR32r1_ND = 4063,
  SAR32r1_NF = 4064,
  SAR32r1_NF_ND = 4065,
  SAR32rCL = 4066,
  SAR32rCL_EVEX = 4067,
  SAR32rCL_ND = 4068,
  SAR32rCL_NF = 4069,
  SAR32rCL_NF_ND = 4070,
  SAR32ri = 4071,
  SAR32ri_EVEX = 4072,
  SAR32ri_ND = 4073,
  SAR32ri_NF = 4074,
  SAR32ri_NF_ND = 4075,
  SAR64m1 = 4076,
  SAR64m1_EVEX = 4077,
  SAR64m1_ND = 4078,
  SAR64m1_NF = 4079,
  SAR64m1_NF_ND = 4080,
  SAR64mCL = 4081,
  SAR64mCL_EVEX = 4082,
  SAR64mCL_ND = 4083,
  SAR64mCL_NF = 4084,
  SAR64mCL_NF_ND = 4085,
  SAR64mi = 4086,
  SAR64mi_EVEX = 4087,
  SAR64mi_ND = 4088,
  SAR64mi_NF = 4089,
  SAR64mi_NF_ND = 4090,
  SAR64r1 = 4091,
  SAR64r1_EVEX = 4092,
  SAR64r1_ND = 4093,
  SAR64r1_NF = 4094,
  SAR64r1_NF_ND = 4095,
  SAR64rCL = 4096,
  SAR64rCL_EVEX = 4097,
  SAR64rCL_ND = 4098,
  SAR64rCL_NF = 4099,
  SAR64rCL_NF_ND = 4100,
  SAR64ri = 4101,
  SAR64ri_EVEX = 4102,
  SAR64ri_ND = 4103,
  SAR64ri_NF = 4104,
  SAR64ri_NF_ND = 4105,
  SAR8m1 = 4106,
  SAR8m1_EVEX = 4107,
  SAR8m1_ND = 4108,
  SAR8m1_NF = 4109,
  SAR8m1_NF_ND = 4110,
  SAR8mCL = 4111,
  SAR8mCL_EVEX = 4112,
  SAR8mCL_ND = 4113,
  SAR8mCL_NF = 4114,
  SAR8mCL_NF_ND = 4115,
  SAR8mi = 4116,
  SAR8mi_EVEX = 4117,
  SAR8mi_ND = 4118,
  SAR8mi_NF = 4119,
  SAR8mi_NF_ND = 4120,
  SAR8r1 = 4121,
  SAR8r1_EVEX = 4122,
  SAR8r1_ND = 4123,
  SAR8r1_NF = 4124,
  SAR8r1_NF_ND = 4125,
  SAR8rCL = 4126,
  SAR8rCL_EVEX = 4127,
  SAR8rCL_ND = 4128,
  SAR8rCL_NF = 4129,
  SAR8rCL_NF_ND = 4130,
  SAR8ri = 4131,
  SAR8ri_EVEX = 4132,
  SAR8ri_ND = 4133,
  SAR8ri_NF = 4134,
  SAR8ri_NF_ND = 4135,
  SARX32rm = 4136,
  SARX32rm_EVEX = 4137,
  SARX32rr = 4138,
  SARX32rr_EVEX = 4139,
  SARX64rm = 4140,
  SARX64rm_EVEX = 4141,
  SARX64rr = 4142,
  SARX64rr_EVEX = 4143,
  SAVEPREVSSP = 4144,
  SBB16i16 = 4145,
  SBB16mi = 4146,
  SBB16mi8 = 4147,
  SBB16mi8_EVEX = 4148,
  SBB16mi8_ND = 4149,
  SBB16mi_EVEX = 4150,
  SBB16mi_ND = 4151,
  SBB16mr = 4152,
  SBB16mr_EVEX = 4153,
  SBB16mr_ND = 4154,
  SBB16ri = 4155,
  SBB16ri8 = 4156,
  SBB16ri8_EVEX = 4157,
  SBB16ri8_ND = 4158,
  SBB16ri_EVEX = 4159,
  SBB16ri_ND = 4160,
  SBB16rm = 4161,
  SBB16rm_EVEX = 4162,
  SBB16rm_ND = 4163,
  SBB16rr = 4164,
  SBB16rr_EVEX = 4165,
  SBB16rr_EVEX_REV = 4166,
  SBB16rr_ND = 4167,
  SBB16rr_ND_REV = 4168,
  SBB16rr_REV = 4169,
  SBB32i32 = 4170,
  SBB32mi = 4171,
  SBB32mi8 = 4172,
  SBB32mi8_EVEX = 4173,
  SBB32mi8_ND = 4174,
  SBB32mi_EVEX = 4175,
  SBB32mi_ND = 4176,
  SBB32mr = 4177,
  SBB32mr_EVEX = 4178,
  SBB32mr_ND = 4179,
  SBB32ri = 4180,
  SBB32ri8 = 4181,
  SBB32ri8_EVEX = 4182,
  SBB32ri8_ND = 4183,
  SBB32ri_EVEX = 4184,
  SBB32ri_ND = 4185,
  SBB32rm = 4186,
  SBB32rm_EVEX = 4187,
  SBB32rm_ND = 4188,
  SBB32rr = 4189,
  SBB32rr_EVEX = 4190,
  SBB32rr_EVEX_REV = 4191,
  SBB32rr_ND = 4192,
  SBB32rr_ND_REV = 4193,
  SBB32rr_REV = 4194,
  SBB64i32 = 4195,
  SBB64mi32 = 4196,
  SBB64mi32_EVEX = 4197,
  SBB64mi32_ND = 4198,
  SBB64mi8 = 4199,
  SBB64mi8_EVEX = 4200,
  SBB64mi8_ND = 4201,
  SBB64mr = 4202,
  SBB64mr_EVEX = 4203,
  SBB64mr_ND = 4204,
  SBB64ri32 = 4205,
  SBB64ri32_EVEX = 4206,
  SBB64ri32_ND = 4207,
  SBB64ri8 = 4208,
  SBB64ri8_EVEX = 4209,
  SBB64ri8_ND = 4210,
  SBB64rm = 4211,
  SBB64rm_EVEX = 4212,
  SBB64rm_ND = 4213,
  SBB64rr = 4214,
  SBB64rr_EVEX = 4215,
  SBB64rr_EVEX_REV = 4216,
  SBB64rr_ND = 4217,
  SBB64rr_ND_REV = 4218,
  SBB64rr_REV = 4219,
  SBB8i8 = 4220,
  SBB8mi = 4221,
  SBB8mi8 = 4222,
  SBB8mi_EVEX = 4223,
  SBB8mi_ND = 4224,
  SBB8mr = 4225,
  SBB8mr_EVEX = 4226,
  SBB8mr_ND = 4227,
  SBB8ri = 4228,
  SBB8ri8 = 4229,
  SBB8ri_EVEX = 4230,
  SBB8ri_ND = 4231,
  SBB8rm = 4232,
  SBB8rm_EVEX = 4233,
  SBB8rm_ND = 4234,
  SBB8rr = 4235,
  SBB8rr_EVEX = 4236,
  SBB8rr_EVEX_REV = 4237,
  SBB8rr_ND = 4238,
  SBB8rr_ND_REV = 4239,
  SBB8rr_REV = 4240,
  SCASB = 4241,
  SCASL = 4242,
  SCASQ = 4243,
  SCASW = 4244,
  SEAMCALL = 4245,
  SEAMOPS = 4246,
  SEAMRET = 4247,
  SEG_ALLOCA_32 = 4248,
  SEG_ALLOCA_64 = 4249,
  SENDUIPI = 4250,
  SERIALIZE = 4251,
  SETCCm = 4252,
  SETCCm_EVEX = 4253,
  SETCCr = 4254,
  SETCCr_EVEX = 4255,
  SETSSBSY = 4256,
  SETZUCCm = 4257,
  SETZUCCr = 4258,
  SFENCE = 4259,
  SGDT16m = 4260,
  SGDT32m = 4261,
  SGDT64m = 4262,
  SHA1MSG1rm = 4263,
  SHA1MSG1rr = 4264,
  SHA1MSG2rm = 4265,
  SHA1MSG2rr = 4266,
  SHA1NEXTErm = 4267,
  SHA1NEXTErr = 4268,
  SHA1RNDS4rmi = 4269,
  SHA1RNDS4rri = 4270,
  SHA256MSG1rm = 4271,
  SHA256MSG1rr = 4272,
  SHA256MSG2rm = 4273,
  SHA256MSG2rr = 4274,
  SHA256RNDS2rm = 4275,
  SHA256RNDS2rr = 4276,
  SHL16m1 = 4277,
  SHL16m1_EVEX = 4278,
  SHL16m1_ND = 4279,
  SHL16m1_NF = 4280,
  SHL16m1_NF_ND = 4281,
  SHL16mCL = 4282,
  SHL16mCL_EVEX = 4283,
  SHL16mCL_ND = 4284,
  SHL16mCL_NF = 4285,
  SHL16mCL_NF_ND = 4286,
  SHL16mi = 4287,
  SHL16mi_EVEX = 4288,
  SHL16mi_ND = 4289,
  SHL16mi_NF = 4290,
  SHL16mi_NF_ND = 4291,
  SHL16r1 = 4292,
  SHL16r1_EVEX = 4293,
  SHL16r1_ND = 4294,
  SHL16r1_NF = 4295,
  SHL16r1_NF_ND = 4296,
  SHL16rCL = 4297,
  SHL16rCL_EVEX = 4298,
  SHL16rCL_ND = 4299,
  SHL16rCL_NF = 4300,
  SHL16rCL_NF_ND = 4301,
  SHL16ri = 4302,
  SHL16ri_EVEX = 4303,
  SHL16ri_ND = 4304,
  SHL16ri_NF = 4305,
  SHL16ri_NF_ND = 4306,
  SHL32m1 = 4307,
  SHL32m1_EVEX = 4308,
  SHL32m1_ND = 4309,
  SHL32m1_NF = 4310,
  SHL32m1_NF_ND = 4311,
  SHL32mCL = 4312,
  SHL32mCL_EVEX = 4313,
  SHL32mCL_ND = 4314,
  SHL32mCL_NF = 4315,
  SHL32mCL_NF_ND = 4316,
  SHL32mi = 4317,
  SHL32mi_EVEX = 4318,
  SHL32mi_ND = 4319,
  SHL32mi_NF = 4320,
  SHL32mi_NF_ND = 4321,
  SHL32r1 = 4322,
  SHL32r1_EVEX = 4323,
  SHL32r1_ND = 4324,
  SHL32r1_NF = 4325,
  SHL32r1_NF_ND = 4326,
  SHL32rCL = 4327,
  SHL32rCL_EVEX = 4328,
  SHL32rCL_ND = 4329,
  SHL32rCL_NF = 4330,
  SHL32rCL_NF_ND = 4331,
  SHL32ri = 4332,
  SHL32ri_EVEX = 4333,
  SHL32ri_ND = 4334,
  SHL32ri_NF = 4335,
  SHL32ri_NF_ND = 4336,
  SHL64m1 = 4337,
  SHL64m1_EVEX = 4338,
  SHL64m1_ND = 4339,
  SHL64m1_NF = 4340,
  SHL64m1_NF_ND = 4341,
  SHL64mCL = 4342,
  SHL64mCL_EVEX = 4343,
  SHL64mCL_ND = 4344,
  SHL64mCL_NF = 4345,
  SHL64mCL_NF_ND = 4346,
  SHL64mi = 4347,
  SHL64mi_EVEX = 4348,
  SHL64mi_ND = 4349,
  SHL64mi_NF = 4350,
  SHL64mi_NF_ND = 4351,
  SHL64r1 = 4352,
  SHL64r1_EVEX = 4353,
  SHL64r1_ND = 4354,
  SHL64r1_NF = 4355,
  SHL64r1_NF_ND = 4356,
  SHL64rCL = 4357,
  SHL64rCL_EVEX = 4358,
  SHL64rCL_ND = 4359,
  SHL64rCL_NF = 4360,
  SHL64rCL_NF_ND = 4361,
  SHL64ri = 4362,
  SHL64ri_EVEX = 4363,
  SHL64ri_ND = 4364,
  SHL64ri_NF = 4365,
  SHL64ri_NF_ND = 4366,
  SHL8m1 = 4367,
  SHL8m1_EVEX = 4368,
  SHL8m1_ND = 4369,
  SHL8m1_NF = 4370,
  SHL8m1_NF_ND = 4371,
  SHL8mCL = 4372,
  SHL8mCL_EVEX = 4373,
  SHL8mCL_ND = 4374,
  SHL8mCL_NF = 4375,
  SHL8mCL_NF_ND = 4376,
  SHL8mi = 4377,
  SHL8mi_EVEX = 4378,
  SHL8mi_ND = 4379,
  SHL8mi_NF = 4380,
  SHL8mi_NF_ND = 4381,
  SHL8r1 = 4382,
  SHL8r1_EVEX = 4383,
  SHL8r1_ND = 4384,
  SHL8r1_NF = 4385,
  SHL8r1_NF_ND = 4386,
  SHL8rCL = 4387,
  SHL8rCL_EVEX = 4388,
  SHL8rCL_ND = 4389,
  SHL8rCL_NF = 4390,
  SHL8rCL_NF_ND = 4391,
  SHL8ri = 4392,
  SHL8ri_EVEX = 4393,
  SHL8ri_ND = 4394,
  SHL8ri_NF = 4395,
  SHL8ri_NF_ND = 4396,
  SHLD16mrCL = 4397,
  SHLD16mrCL_EVEX = 4398,
  SHLD16mrCL_ND = 4399,
  SHLD16mrCL_NF = 4400,
  SHLD16mrCL_NF_ND = 4401,
  SHLD16mri8 = 4402,
  SHLD16mri8_EVEX = 4403,
  SHLD16mri8_ND = 4404,
  SHLD16mri8_NF = 4405,
  SHLD16mri8_NF_ND = 4406,
  SHLD16rrCL = 4407,
  SHLD16rrCL_EVEX = 4408,
  SHLD16rrCL_ND = 4409,
  SHLD16rrCL_NF = 4410,
  SHLD16rrCL_NF_ND = 4411,
  SHLD16rri8 = 4412,
  SHLD16rri8_EVEX = 4413,
  SHLD16rri8_ND = 4414,
  SHLD16rri8_NF = 4415,
  SHLD16rri8_NF_ND = 4416,
  SHLD32mrCL = 4417,
  SHLD32mrCL_EVEX = 4418,
  SHLD32mrCL_ND = 4419,
  SHLD32mrCL_NF = 4420,
  SHLD32mrCL_NF_ND = 4421,
  SHLD32mri8 = 4422,
  SHLD32mri8_EVEX = 4423,
  SHLD32mri8_ND = 4424,
  SHLD32mri8_NF = 4425,
  SHLD32mri8_NF_ND = 4426,
  SHLD32rrCL = 4427,
  SHLD32rrCL_EVEX = 4428,
  SHLD32rrCL_ND = 4429,
  SHLD32rrCL_NF = 4430,
  SHLD32rrCL_NF_ND = 4431,
  SHLD32rri8 = 4432,
  SHLD32rri8_EVEX = 4433,
  SHLD32rri8_ND = 4434,
  SHLD32rri8_NF = 4435,
  SHLD32rri8_NF_ND = 4436,
  SHLD64mrCL = 4437,
  SHLD64mrCL_EVEX = 4438,
  SHLD64mrCL_ND = 4439,
  SHLD64mrCL_NF = 4440,
  SHLD64mrCL_NF_ND = 4441,
  SHLD64mri8 = 4442,
  SHLD64mri8_EVEX = 4443,
  SHLD64mri8_ND = 4444,
  SHLD64mri8_NF = 4445,
  SHLD64mri8_NF_ND = 4446,
  SHLD64rrCL = 4447,
  SHLD64rrCL_EVEX = 4448,
  SHLD64rrCL_ND = 4449,
  SHLD64rrCL_NF = 4450,
  SHLD64rrCL_NF_ND = 4451,
  SHLD64rri8 = 4452,
  SHLD64rri8_EVEX = 4453,
  SHLD64rri8_ND = 4454,
  SHLD64rri8_NF = 4455,
  SHLD64rri8_NF_ND = 4456,
  SHLX32rm = 4457,
  SHLX32rm_EVEX = 4458,
  SHLX32rr = 4459,
  SHLX32rr_EVEX = 4460,
  SHLX64rm = 4461,
  SHLX64rm_EVEX = 4462,
  SHLX64rr = 4463,
  SHLX64rr_EVEX = 4464,
  SHR16m1 = 4465,
  SHR16m1_EVEX = 4466,
  SHR16m1_ND = 4467,
  SHR16m1_NF = 4468,
  SHR16m1_NF_ND = 4469,
  SHR16mCL = 4470,
  SHR16mCL_EVEX = 4471,
  SHR16mCL_ND = 4472,
  SHR16mCL_NF = 4473,
  SHR16mCL_NF_ND = 4474,
  SHR16mi = 4475,
  SHR16mi_EVEX = 4476,
  SHR16mi_ND = 4477,
  SHR16mi_NF = 4478,
  SHR16mi_NF_ND = 4479,
  SHR16r1 = 4480,
  SHR16r1_EVEX = 4481,
  SHR16r1_ND = 4482,
  SHR16r1_NF = 4483,
  SHR16r1_NF_ND = 4484,
  SHR16rCL = 4485,
  SHR16rCL_EVEX = 4486,
  SHR16rCL_ND = 4487,
  SHR16rCL_NF = 4488,
  SHR16rCL_NF_ND = 4489,
  SHR16ri = 4490,
  SHR16ri_EVEX = 4491,
  SHR16ri_ND = 4492,
  SHR16ri_NF = 4493,
  SHR16ri_NF_ND = 4494,
  SHR32m1 = 4495,
  SHR32m1_EVEX = 4496,
  SHR32m1_ND = 4497,
  SHR32m1_NF = 4498,
  SHR32m1_NF_ND = 4499,
  SHR32mCL = 4500,
  SHR32mCL_EVEX = 4501,
  SHR32mCL_ND = 4502,
  SHR32mCL_NF = 4503,
  SHR32mCL_NF_ND = 4504,
  SHR32mi = 4505,
  SHR32mi_EVEX = 4506,
  SHR32mi_ND = 4507,
  SHR32mi_NF = 4508,
  SHR32mi_NF_ND = 4509,
  SHR32r1 = 4510,
  SHR32r1_EVEX = 4511,
  SHR32r1_ND = 4512,
  SHR32r1_NF = 4513,
  SHR32r1_NF_ND = 4514,
  SHR32rCL = 4515,
  SHR32rCL_EVEX = 4516,
  SHR32rCL_ND = 4517,
  SHR32rCL_NF = 4518,
  SHR32rCL_NF_ND = 4519,
  SHR32ri = 4520,
  SHR32ri_EVEX = 4521,
  SHR32ri_ND = 4522,
  SHR32ri_NF = 4523,
  SHR32ri_NF_ND = 4524,
  SHR64m1 = 4525,
  SHR64m1_EVEX = 4526,
  SHR64m1_ND = 4527,
  SHR64m1_NF = 4528,
  SHR64m1_NF_ND = 4529,
  SHR64mCL = 4530,
  SHR64mCL_EVEX = 4531,
  SHR64mCL_ND = 4532,
  SHR64mCL_NF = 4533,
  SHR64mCL_NF_ND = 4534,
  SHR64mi = 4535,
  SHR64mi_EVEX = 4536,
  SHR64mi_ND = 4537,
  SHR64mi_NF = 4538,
  SHR64mi_NF_ND = 4539,
  SHR64r1 = 4540,
  SHR64r1_EVEX = 4541,
  SHR64r1_ND = 4542,
  SHR64r1_NF = 4543,
  SHR64r1_NF_ND = 4544,
  SHR64rCL = 4545,
  SHR64rCL_EVEX = 4546,
  SHR64rCL_ND = 4547,
  SHR64rCL_NF = 4548,
  SHR64rCL_NF_ND = 4549,
  SHR64ri = 4550,
  SHR64ri_EVEX = 4551,
  SHR64ri_ND = 4552,
  SHR64ri_NF = 4553,
  SHR64ri_NF_ND = 4554,
  SHR8m1 = 4555,
  SHR8m1_EVEX = 4556,
  SHR8m1_ND = 4557,
  SHR8m1_NF = 4558,
  SHR8m1_NF_ND = 4559,
  SHR8mCL = 4560,
  SHR8mCL_EVEX = 4561,
  SHR8mCL_ND = 4562,
  SHR8mCL_NF = 4563,
  SHR8mCL_NF_ND = 4564,
  SHR8mi = 4565,
  SHR8mi_EVEX = 4566,
  SHR8mi_ND = 4567,
  SHR8mi_NF = 4568,
  SHR8mi_NF_ND = 4569,
  SHR8r1 = 4570,
  SHR8r1_EVEX = 4571,
  SHR8r1_ND = 4572,
  SHR8r1_NF = 4573,
  SHR8r1_NF_ND = 4574,
  SHR8rCL = 4575,
  SHR8rCL_EVEX = 4576,
  SHR8rCL_ND = 4577,
  SHR8rCL_NF = 4578,
  SHR8rCL_NF_ND = 4579,
  SHR8ri = 4580,
  SHR8ri_EVEX = 4581,
  SHR8ri_ND = 4582,
  SHR8ri_NF = 4583,
  SHR8ri_NF_ND = 4584,
  SHRD16mrCL = 4585,
  SHRD16mrCL_EVEX = 4586,
  SHRD16mrCL_ND = 4587,
  SHRD16mrCL_NF = 4588,
  SHRD16mrCL_NF_ND = 4589,
  SHRD16mri8 = 4590,
  SHRD16mri8_EVEX = 4591,
  SHRD16mri8_ND = 4592,
  SHRD16mri8_NF = 4593,
  SHRD16mri8_NF_ND = 4594,
  SHRD16rrCL = 4595,
  SHRD16rrCL_EVEX = 4596,
  SHRD16rrCL_ND = 4597,
  SHRD16rrCL_NF = 4598,
  SHRD16rrCL_NF_ND = 4599,
  SHRD16rri8 = 4600,
  SHRD16rri8_EVEX = 4601,
  SHRD16rri8_ND = 4602,
  SHRD16rri8_NF = 4603,
  SHRD16rri8_NF_ND = 4604,
  SHRD32mrCL = 4605,
  SHRD32mrCL_EVEX = 4606,
  SHRD32mrCL_ND = 4607,
  SHRD32mrCL_NF = 4608,
  SHRD32mrCL_NF_ND = 4609,
  SHRD32mri8 = 4610,
  SHRD32mri8_EVEX = 4611,
  SHRD32mri8_ND = 4612,
  SHRD32mri8_NF = 4613,
  SHRD32mri8_NF_ND = 4614,
  SHRD32rrCL = 4615,
  SHRD32rrCL_EVEX = 4616,
  SHRD32rrCL_ND = 4617,
  SHRD32rrCL_NF = 4618,
  SHRD32rrCL_NF_ND = 4619,
  SHRD32rri8 = 4620,
  SHRD32rri8_EVEX = 4621,
  SHRD32rri8_ND = 4622,
  SHRD32rri8_NF = 4623,
  SHRD32rri8_NF_ND = 4624,
  SHRD64mrCL = 4625,
  SHRD64mrCL_EVEX = 4626,
  SHRD64mrCL_ND = 4627,
  SHRD64mrCL_NF = 4628,
  SHRD64mrCL_NF_ND = 4629,
  SHRD64mri8 = 4630,
  SHRD64mri8_EVEX = 4631,
  SHRD64mri8_ND = 4632,
  SHRD64mri8_NF = 4633,
  SHRD64mri8_NF_ND = 4634,
  SHRD64rrCL = 4635,
  SHRD64rrCL_EVEX = 4636,
  SHRD64rrCL_ND = 4637,
  SHRD64rrCL_NF = 4638,
  SHRD64rrCL_NF_ND = 4639,
  SHRD64rri8 = 4640,
  SHRD64rri8_EVEX = 4641,
  SHRD64rri8_ND = 4642,
  SHRD64rri8_NF = 4643,
  SHRD64rri8_NF_ND = 4644,
  SHRX32rm = 4645,
  SHRX32rm_EVEX = 4646,
  SHRX32rr = 4647,
  SHRX32rr_EVEX = 4648,
  SHRX64rm = 4649,
  SHRX64rm_EVEX = 4650,
  SHRX64rr = 4651,
  SHRX64rr_EVEX = 4652,
  SHUFPDrmi = 4653,
  SHUFPDrri = 4654,
  SHUFPSrmi = 4655,
  SHUFPSrri = 4656,
  SIDT16m = 4657,
  SIDT32m = 4658,
  SIDT64m = 4659,
  SKINIT = 4660,
  SLDT16m = 4661,
  SLDT16r = 4662,
  SLDT32r = 4663,
  SLDT64r = 4664,
  SLWPCB = 4665,
  SLWPCB64 = 4666,
  SMSW16m = 4667,
  SMSW16r = 4668,
  SMSW32r = 4669,
  SMSW64r = 4670,
  SQRTPDm = 4671,
  SQRTPDr = 4672,
  SQRTPSm = 4673,
  SQRTPSr = 4674,
  SQRTSDm = 4675,
  SQRTSDm_Int = 4676,
  SQRTSDr = 4677,
  SQRTSDr_Int = 4678,
  SQRTSSm = 4679,
  SQRTSSm_Int = 4680,
  SQRTSSr = 4681,
  SQRTSSr_Int = 4682,
  SQRT_F = 4683,
  SQRT_Fp32 = 4684,
  SQRT_Fp64 = 4685,
  SQRT_Fp80 = 4686,
  SS_PREFIX = 4687,
  STAC = 4688,
  STACKALLOC_W_PROBING = 4689,
  STC = 4690,
  STD = 4691,
  STGI = 4692,
  STI = 4693,
  STMXCSR = 4694,
  STOSB = 4695,
  STOSL = 4696,
  STOSQ = 4697,
  STOSW = 4698,
  STR16r = 4699,
  STR32r = 4700,
  STR64r = 4701,
  STRm = 4702,
  STTILECFG = 4703,
  STTILECFG_EVEX = 4704,
  STUI = 4705,
  ST_F32m = 4706,
  ST_F64m = 4707,
  ST_FP32m = 4708,
  ST_FP64m = 4709,
  ST_FP80m = 4710,
  ST_FPrr = 4711,
  ST_Fp32m = 4712,
  ST_Fp64m = 4713,
  ST_Fp64m32 = 4714,
  ST_Fp80m32 = 4715,
  ST_Fp80m64 = 4716,
  ST_FpP32m = 4717,
  ST_FpP64m = 4718,
  ST_FpP64m32 = 4719,
  ST_FpP80m = 4720,
  ST_FpP80m32 = 4721,
  ST_FpP80m64 = 4722,
  ST_Frr = 4723,
  SUB16i16 = 4724,
  SUB16mi = 4725,
  SUB16mi8 = 4726,
  SUB16mi8_EVEX = 4727,
  SUB16mi8_ND = 4728,
  SUB16mi8_NF = 4729,
  SUB16mi8_NF_ND = 4730,
  SUB16mi_EVEX = 4731,
  SUB16mi_ND = 4732,
  SUB16mi_NF = 4733,
  SUB16mi_NF_ND = 4734,
  SUB16mr = 4735,
  SUB16mr_EVEX = 4736,
  SUB16mr_ND = 4737,
  SUB16mr_NF = 4738,
  SUB16mr_NF_ND = 4739,
  SUB16ri = 4740,
  SUB16ri8 = 4741,
  SUB16ri8_EVEX = 4742,
  SUB16ri8_ND = 4743,
  SUB16ri8_NF = 4744,
  SUB16ri8_NF_ND = 4745,
  SUB16ri_EVEX = 4746,
  SUB16ri_ND = 4747,
  SUB16ri_NF = 4748,
  SUB16ri_NF_ND = 4749,
  SUB16rm = 4750,
  SUB16rm_EVEX = 4751,
  SUB16rm_ND = 4752,
  SUB16rm_NF = 4753,
  SUB16rm_NF_ND = 4754,
  SUB16rr = 4755,
  SUB16rr_EVEX = 4756,
  SUB16rr_EVEX_REV = 4757,
  SUB16rr_ND = 4758,
  SUB16rr_ND_REV = 4759,
  SUB16rr_NF = 4760,
  SUB16rr_NF_ND = 4761,
  SUB16rr_NF_ND_REV = 4762,
  SUB16rr_NF_REV = 4763,
  SUB16rr_REV = 4764,
  SUB32i32 = 4765,
  SUB32mi = 4766,
  SUB32mi8 = 4767,
  SUB32mi8_EVEX = 4768,
  SUB32mi8_ND = 4769,
  SUB32mi8_NF = 4770,
  SUB32mi8_NF_ND = 4771,
  SUB32mi_EVEX = 4772,
  SUB32mi_ND = 4773,
  SUB32mi_NF = 4774,
  SUB32mi_NF_ND = 4775,
  SUB32mr = 4776,
  SUB32mr_EVEX = 4777,
  SUB32mr_ND = 4778,
  SUB32mr_NF = 4779,
  SUB32mr_NF_ND = 4780,
  SUB32ri = 4781,
  SUB32ri8 = 4782,
  SUB32ri8_EVEX = 4783,
  SUB32ri8_ND = 4784,
  SUB32ri8_NF = 4785,
  SUB32ri8_NF_ND = 4786,
  SUB32ri_EVEX = 4787,
  SUB32ri_ND = 4788,
  SUB32ri_NF = 4789,
  SUB32ri_NF_ND = 4790,
  SUB32rm = 4791,
  SUB32rm_EVEX = 4792,
  SUB32rm_ND = 4793,
  SUB32rm_NF = 4794,
  SUB32rm_NF_ND = 4795,
  SUB32rr = 4796,
  SUB32rr_EVEX = 4797,
  SUB32rr_EVEX_REV = 4798,
  SUB32rr_ND = 4799,
  SUB32rr_ND_REV = 4800,
  SUB32rr_NF = 4801,
  SUB32rr_NF_ND = 4802,
  SUB32rr_NF_ND_REV = 4803,
  SUB32rr_NF_REV = 4804,
  SUB32rr_REV = 4805,
  SUB64i32 = 4806,
  SUB64mi32 = 4807,
  SUB64mi32_EVEX = 4808,
  SUB64mi32_ND = 4809,
  SUB64mi32_NF = 4810,
  SUB64mi32_NF_ND = 4811,
  SUB64mi8 = 4812,
  SUB64mi8_EVEX = 4813,
  SUB64mi8_ND = 4814,
  SUB64mi8_NF = 4815,
  SUB64mi8_NF_ND = 4816,
  SUB64mr = 4817,
  SUB64mr_EVEX = 4818,
  SUB64mr_ND = 4819,
  SUB64mr_NF = 4820,
  SUB64mr_NF_ND = 4821,
  SUB64ri32 = 4822,
  SUB64ri32_EVEX = 4823,
  SUB64ri32_ND = 4824,
  SUB64ri32_NF = 4825,
  SUB64ri32_NF_ND = 4826,
  SUB64ri8 = 4827,
  SUB64ri8_EVEX = 4828,
  SUB64ri8_ND = 4829,
  SUB64ri8_NF = 4830,
  SUB64ri8_NF_ND = 4831,
  SUB64rm = 4832,
  SUB64rm_EVEX = 4833,
  SUB64rm_ND = 4834,
  SUB64rm_NF = 4835,
  SUB64rm_NF_ND = 4836,
  SUB64rr = 4837,
  SUB64rr_EVEX = 4838,
  SUB64rr_EVEX_REV = 4839,
  SUB64rr_ND = 4840,
  SUB64rr_ND_REV = 4841,
  SUB64rr_NF = 4842,
  SUB64rr_NF_ND = 4843,
  SUB64rr_NF_ND_REV = 4844,
  SUB64rr_NF_REV = 4845,
  SUB64rr_REV = 4846,
  SUB8i8 = 4847,
  SUB8mi = 4848,
  SUB8mi8 = 4849,
  SUB8mi_EVEX = 4850,
  SUB8mi_ND = 4851,
  SUB8mi_NF = 4852,
  SUB8mi_NF_ND = 4853,
  SUB8mr = 4854,
  SUB8mr_EVEX = 4855,
  SUB8mr_ND = 4856,
  SUB8mr_NF = 4857,
  SUB8mr_NF_ND = 4858,
  SUB8ri = 4859,
  SUB8ri8 = 4860,
  SUB8ri_EVEX = 4861,
  SUB8ri_ND = 4862,
  SUB8ri_NF = 4863,
  SUB8ri_NF_ND = 4864,
  SUB8rm = 4865,
  SUB8rm_EVEX = 4866,
  SUB8rm_ND = 4867,
  SUB8rm_NF = 4868,
  SUB8rm_NF_ND = 4869,
  SUB8rr = 4870,
  SUB8rr_EVEX = 4871,
  SUB8rr_EVEX_REV = 4872,
  SUB8rr_ND = 4873,
  SUB8rr_ND_REV = 4874,
  SUB8rr_NF = 4875,
  SUB8rr_NF_ND = 4876,
  SUB8rr_NF_ND_REV = 4877,
  SUB8rr_NF_REV = 4878,
  SUB8rr_REV = 4879,
  SUBPDrm = 4880,
  SUBPDrr = 4881,
  SUBPSrm = 4882,
  SUBPSrr = 4883,
  SUBR_F32m = 4884,
  SUBR_F64m = 4885,
  SUBR_FI16m = 4886,
  SUBR_FI32m = 4887,
  SUBR_FPrST0 = 4888,
  SUBR_FST0r = 4889,
  SUBR_Fp32m = 4890,
  SUBR_Fp64m = 4891,
  SUBR_Fp64m32 = 4892,
  SUBR_Fp80m32 = 4893,
  SUBR_Fp80m64 = 4894,
  SUBR_FpI16m32 = 4895,
  SUBR_FpI16m64 = 4896,
  SUBR_FpI16m80 = 4897,
  SUBR_FpI32m32 = 4898,
  SUBR_FpI32m64 = 4899,
  SUBR_FpI32m80 = 4900,
  SUBR_FrST0 = 4901,
  SUBSDrm = 4902,
  SUBSDrm_Int = 4903,
  SUBSDrr = 4904,
  SUBSDrr_Int = 4905,
  SUBSSrm = 4906,
  SUBSSrm_Int = 4907,
  SUBSSrr = 4908,
  SUBSSrr_Int = 4909,
  SUB_F32m = 4910,
  SUB_F64m = 4911,
  SUB_FI16m = 4912,
  SUB_FI32m = 4913,
  SUB_FPrST0 = 4914,
  SUB_FST0r = 4915,
  SUB_Fp32 = 4916,
  SUB_Fp32m = 4917,
  SUB_Fp64 = 4918,
  SUB_Fp64m = 4919,
  SUB_Fp64m32 = 4920,
  SUB_Fp80 = 4921,
  SUB_Fp80m32 = 4922,
  SUB_Fp80m64 = 4923,
  SUB_FpI16m32 = 4924,
  SUB_FpI16m64 = 4925,
  SUB_FpI16m80 = 4926,
  SUB_FpI32m32 = 4927,
  SUB_FpI32m64 = 4928,
  SUB_FpI32m80 = 4929,
  SUB_FrST0 = 4930,
  SWAPGS = 4931,
  SYSCALL = 4932,
  SYSENTER = 4933,
  SYSEXIT = 4934,
  SYSEXIT64 = 4935,
  SYSRET = 4936,
  SYSRET64 = 4937,
  T1MSKC32rm = 4938,
  T1MSKC32rr = 4939,
  T1MSKC64rm = 4940,
  T1MSKC64rr = 4941,
  T2RPNTLVWZ0 = 4942,
  T2RPNTLVWZ0RS = 4943,
  T2RPNTLVWZ0RST1 = 4944,
  T2RPNTLVWZ0RST1_EVEX = 4945,
  T2RPNTLVWZ0RS_EVEX = 4946,
  T2RPNTLVWZ0T1 = 4947,
  T2RPNTLVWZ0T1_EVEX = 4948,
  T2RPNTLVWZ0_EVEX = 4949,
  T2RPNTLVWZ1 = 4950,
  T2RPNTLVWZ1RS = 4951,
  T2RPNTLVWZ1RST1 = 4952,
  T2RPNTLVWZ1RST1_EVEX = 4953,
  T2RPNTLVWZ1RS_EVEX = 4954,
  T2RPNTLVWZ1T1 = 4955,
  T2RPNTLVWZ1T1_EVEX = 4956,
  T2RPNTLVWZ1_EVEX = 4957,
  TAILJMPd = 4958,
  TAILJMPd64 = 4959,
  TAILJMPd64_CC = 4960,
  TAILJMPd_CC = 4961,
  TAILJMPm = 4962,
  TAILJMPm64 = 4963,
  TAILJMPm64_REX = 4964,
  TAILJMPr = 4965,
  TAILJMPr64 = 4966,
  TAILJMPr64_REX = 4967,
  TCMMIMFP16PS = 4968,
  TCMMRLFP16PS = 4969,
  TCONJTCMMIMFP16PS = 4970,
  TCONJTFP16 = 4971,
  TCRETURNdi = 4972,
  TCRETURNdi64 = 4973,
  TCRETURNdi64cc = 4974,
  TCRETURNdicc = 4975,
  TCRETURNmi = 4976,
  TCRETURNmi64 = 4977,
  TCRETURNri = 4978,
  TCRETURNri64 = 4979,
  TCVTROWD2PSrre = 4980,
  TCVTROWD2PSrri = 4981,
  TCVTROWPS2BF16Hrre = 4982,
  TCVTROWPS2BF16Hrri = 4983,
  TCVTROWPS2BF16Lrre = 4984,
  TCVTROWPS2BF16Lrri = 4985,
  TCVTROWPS2PHHrre = 4986,
  TCVTROWPS2PHHrri = 4987,
  TCVTROWPS2PHLrre = 4988,
  TCVTROWPS2PHLrri = 4989,
  TDCALL = 4990,
  TDPBF16PS = 4991,
  TDPBF8PS = 4992,
  TDPBHF8PS = 4993,
  TDPBSSD = 4994,
  TDPBSUD = 4995,
  TDPBUSD = 4996,
  TDPBUUD = 4997,
  TDPFP16PS = 4998,
  TDPHBF8PS = 4999,
  TDPHF8PS = 5000,
  TEST16i16 = 5001,
  TEST16mi = 5002,
  TEST16mr = 5003,
  TEST16ri = 5004,
  TEST16rr = 5005,
  TEST32i32 = 5006,
  TEST32mi = 5007,
  TEST32mr = 5008,
  TEST32ri = 5009,
  TEST32rr = 5010,
  TEST64i32 = 5011,
  TEST64mi32 = 5012,
  TEST64mr = 5013,
  TEST64ri32 = 5014,
  TEST64rr = 5015,
  TEST8i8 = 5016,
  TEST8mi = 5017,
  TEST8mr = 5018,
  TEST8ri = 5019,
  TEST8rr = 5020,
  TESTUI = 5021,
  TILELOADD = 5022,
  TILELOADDRS = 5023,
  TILELOADDRST1 = 5024,
  TILELOADDRST1_EVEX = 5025,
  TILELOADDRS_EVEX = 5026,
  TILELOADDT1 = 5027,
  TILELOADDT1_EVEX = 5028,
  TILELOADD_EVEX = 5029,
  TILEMOVROWrre = 5030,
  TILEMOVROWrri = 5031,
  TILERELEASE = 5032,
  TILESTORED = 5033,
  TILESTORED_EVEX = 5034,
  TILEZERO = 5035,
  TLBSYNC = 5036,
  TLSCall_32 = 5037,
  TLSCall_64 = 5038,
  TLS_addr32 = 5039,
  TLS_addr64 = 5040,
  TLS_addrX32 = 5041,
  TLS_base_addr32 = 5042,
  TLS_base_addr64 = 5043,
  TLS_base_addrX32 = 5044,
  TLS_desc32 = 5045,
  TLS_desc64 = 5046,
  TMMULTF32PS = 5047,
  TPAUSE = 5048,
  TRAP = 5049,
  TST_F = 5050,
  TST_Fp32 = 5051,
  TST_Fp64 = 5052,
  TST_Fp80 = 5053,
  TTCMMIMFP16PS = 5054,
  TTCMMRLFP16PS = 5055,
  TTDPBF16PS = 5056,
  TTDPFP16PS = 5057,
  TTMMULTF32PS = 5058,
  TTRANSPOSED = 5059,
  TZCNT16rm = 5060,
  TZCNT16rm_EVEX = 5061,
  TZCNT16rm_NF = 5062,
  TZCNT16rr = 5063,
  TZCNT16rr_EVEX = 5064,
  TZCNT16rr_NF = 5065,
  TZCNT32rm = 5066,
  TZCNT32rm_EVEX = 5067,
  TZCNT32rm_NF = 5068,
  TZCNT32rr = 5069,
  TZCNT32rr_EVEX = 5070,
  TZCNT32rr_NF = 5071,
  TZCNT64rm = 5072,
  TZCNT64rm_EVEX = 5073,
  TZCNT64rm_NF = 5074,
  TZCNT64rr = 5075,
  TZCNT64rr_EVEX = 5076,
  TZCNT64rr_NF = 5077,
  TZMSK32rm = 5078,
  TZMSK32rr = 5079,
  TZMSK64rm = 5080,
  TZMSK64rr = 5081,
  UBSAN_UD1 = 5082,
  UCOMISDrm = 5083,
  UCOMISDrm_Int = 5084,
  UCOMISDrr = 5085,
  UCOMISDrr_Int = 5086,
  UCOMISSrm = 5087,
  UCOMISSrm_Int = 5088,
  UCOMISSrr = 5089,
  UCOMISSrr_Int = 5090,
  UCOM_FIPr = 5091,
  UCOM_FIr = 5092,
  UCOM_FPPr = 5093,
  UCOM_FPr = 5094,
  UCOM_FpIr32 = 5095,
  UCOM_FpIr64 = 5096,
  UCOM_FpIr80 = 5097,
  UCOM_Fpr32 = 5098,
  UCOM_Fpr64 = 5099,
  UCOM_Fpr80 = 5100,
  UCOM_Fr = 5101,
  UD1Lm = 5102,
  UD1Lr = 5103,
  UD1Qm = 5104,
  UD1Qr = 5105,
  UD1Wm = 5106,
  UD1Wr = 5107,
  UIRET = 5108,
  UMONITOR16 = 5109,
  UMONITOR32 = 5110,
  UMONITOR64 = 5111,
  UMWAIT = 5112,
  UNPCKHPDrm = 5113,
  UNPCKHPDrr = 5114,
  UNPCKHPSrm = 5115,
  UNPCKHPSrr = 5116,
  UNPCKLPDrm = 5117,
  UNPCKLPDrr = 5118,
  UNPCKLPSrm = 5119,
  UNPCKLPSrr = 5120,
  URDMSRri = 5121,
  URDMSRri_EVEX = 5122,
  URDMSRrr = 5123,
  URDMSRrr_EVEX = 5124,
  UWRMSRir = 5125,
  UWRMSRir_EVEX = 5126,
  UWRMSRrr = 5127,
  UWRMSRrr_EVEX = 5128,
  V4FMADDPSrm = 5129,
  V4FMADDPSrmk = 5130,
  V4FMADDPSrmkz = 5131,
  V4FMADDSSrm = 5132,
  V4FMADDSSrmk = 5133,
  V4FMADDSSrmkz = 5134,
  V4FNMADDPSrm = 5135,
  V4FNMADDPSrmk = 5136,
  V4FNMADDPSrmkz = 5137,
  V4FNMADDSSrm = 5138,
  V4FNMADDSSrmk = 5139,
  V4FNMADDSSrmkz = 5140,
  VAARG_64 = 5141,
  VAARG_X32 = 5142,
  VADDBF16Z128rm = 5143,
  VADDBF16Z128rmb = 5144,
  VADDBF16Z128rmbk = 5145,
  VADDBF16Z128rmbkz = 5146,
  VADDBF16Z128rmk = 5147,
  VADDBF16Z128rmkz = 5148,
  VADDBF16Z128rr = 5149,
  VADDBF16Z128rrk = 5150,
  VADDBF16Z128rrkz = 5151,
  VADDBF16Z256rm = 5152,
  VADDBF16Z256rmb = 5153,
  VADDBF16Z256rmbk = 5154,
  VADDBF16Z256rmbkz = 5155,
  VADDBF16Z256rmk = 5156,
  VADDBF16Z256rmkz = 5157,
  VADDBF16Z256rr = 5158,
  VADDBF16Z256rrk = 5159,
  VADDBF16Z256rrkz = 5160,
  VADDBF16Zrm = 5161,
  VADDBF16Zrmb = 5162,
  VADDBF16Zrmbk = 5163,
  VADDBF16Zrmbkz = 5164,
  VADDBF16Zrmk = 5165,
  VADDBF16Zrmkz = 5166,
  VADDBF16Zrr = 5167,
  VADDBF16Zrrk = 5168,
  VADDBF16Zrrkz = 5169,
  VADDPDYrm = 5170,
  VADDPDYrr = 5171,
  VADDPDZ128rm = 5172,
  VADDPDZ128rmb = 5173,
  VADDPDZ128rmbk = 5174,
  VADDPDZ128rmbkz = 5175,
  VADDPDZ128rmk = 5176,
  VADDPDZ128rmkz = 5177,
  VADDPDZ128rr = 5178,
  VADDPDZ128rrk = 5179,
  VADDPDZ128rrkz = 5180,
  VADDPDZ256rm = 5181,
  VADDPDZ256rmb = 5182,
  VADDPDZ256rmbk = 5183,
  VADDPDZ256rmbkz = 5184,
  VADDPDZ256rmk = 5185,
  VADDPDZ256rmkz = 5186,
  VADDPDZ256rr = 5187,
  VADDPDZ256rrb = 5188,
  VADDPDZ256rrbk = 5189,
  VADDPDZ256rrbkz = 5190,
  VADDPDZ256rrk = 5191,
  VADDPDZ256rrkz = 5192,
  VADDPDZrm = 5193,
  VADDPDZrmb = 5194,
  VADDPDZrmbk = 5195,
  VADDPDZrmbkz = 5196,
  VADDPDZrmk = 5197,
  VADDPDZrmkz = 5198,
  VADDPDZrr = 5199,
  VADDPDZrrb = 5200,
  VADDPDZrrbk = 5201,
  VADDPDZrrbkz = 5202,
  VADDPDZrrk = 5203,
  VADDPDZrrkz = 5204,
  VADDPDrm = 5205,
  VADDPDrr = 5206,
  VADDPHZ128rm = 5207,
  VADDPHZ128rmb = 5208,
  VADDPHZ128rmbk = 5209,
  VADDPHZ128rmbkz = 5210,
  VADDPHZ128rmk = 5211,
  VADDPHZ128rmkz = 5212,
  VADDPHZ128rr = 5213,
  VADDPHZ128rrk = 5214,
  VADDPHZ128rrkz = 5215,
  VADDPHZ256rm = 5216,
  VADDPHZ256rmb = 5217,
  VADDPHZ256rmbk = 5218,
  VADDPHZ256rmbkz = 5219,
  VADDPHZ256rmk = 5220,
  VADDPHZ256rmkz = 5221,
  VADDPHZ256rr = 5222,
  VADDPHZ256rrb = 5223,
  VADDPHZ256rrbk = 5224,
  VADDPHZ256rrbkz = 5225,
  VADDPHZ256rrk = 5226,
  VADDPHZ256rrkz = 5227,
  VADDPHZrm = 5228,
  VADDPHZrmb = 5229,
  VADDPHZrmbk = 5230,
  VADDPHZrmbkz = 5231,
  VADDPHZrmk = 5232,
  VADDPHZrmkz = 5233,
  VADDPHZrr = 5234,
  VADDPHZrrb = 5235,
  VADDPHZrrbk = 5236,
  VADDPHZrrbkz = 5237,
  VADDPHZrrk = 5238,
  VADDPHZrrkz = 5239,
  VADDPSYrm = 5240,
  VADDPSYrr = 5241,
  VADDPSZ128rm = 5242,
  VADDPSZ128rmb = 5243,
  VADDPSZ128rmbk = 5244,
  VADDPSZ128rmbkz = 5245,
  VADDPSZ128rmk = 5246,
  VADDPSZ128rmkz = 5247,
  VADDPSZ128rr = 5248,
  VADDPSZ128rrk = 5249,
  VADDPSZ128rrkz = 5250,
  VADDPSZ256rm = 5251,
  VADDPSZ256rmb = 5252,
  VADDPSZ256rmbk = 5253,
  VADDPSZ256rmbkz = 5254,
  VADDPSZ256rmk = 5255,
  VADDPSZ256rmkz = 5256,
  VADDPSZ256rr = 5257,
  VADDPSZ256rrb = 5258,
  VADDPSZ256rrbk = 5259,
  VADDPSZ256rrbkz = 5260,
  VADDPSZ256rrk = 5261,
  VADDPSZ256rrkz = 5262,
  VADDPSZrm = 5263,
  VADDPSZrmb = 5264,
  VADDPSZrmbk = 5265,
  VADDPSZrmbkz = 5266,
  VADDPSZrmk = 5267,
  VADDPSZrmkz = 5268,
  VADDPSZrr = 5269,
  VADDPSZrrb = 5270,
  VADDPSZrrbk = 5271,
  VADDPSZrrbkz = 5272,
  VADDPSZrrk = 5273,
  VADDPSZrrkz = 5274,
  VADDPSrm = 5275,
  VADDPSrr = 5276,
  VADDSDZrm = 5277,
  VADDSDZrm_Int = 5278,
  VADDSDZrmk_Int = 5279,
  VADDSDZrmkz_Int = 5280,
  VADDSDZrr = 5281,
  VADDSDZrr_Int = 5282,
  VADDSDZrrb_Int = 5283,
  VADDSDZrrbk_Int = 5284,
  VADDSDZrrbkz_Int = 5285,
  VADDSDZrrk_Int = 5286,
  VADDSDZrrkz_Int = 5287,
  VADDSDrm = 5288,
  VADDSDrm_Int = 5289,
  VADDSDrr = 5290,
  VADDSDrr_Int = 5291,
  VADDSHZrm = 5292,
  VADDSHZrm_Int = 5293,
  VADDSHZrmk_Int = 5294,
  VADDSHZrmkz_Int = 5295,
  VADDSHZrr = 5296,
  VADDSHZrr_Int = 5297,
  VADDSHZrrb_Int = 5298,
  VADDSHZrrbk_Int = 5299,
  VADDSHZrrbkz_Int = 5300,
  VADDSHZrrk_Int = 5301,
  VADDSHZrrkz_Int = 5302,
  VADDSSZrm = 5303,
  VADDSSZrm_Int = 5304,
  VADDSSZrmk_Int = 5305,
  VADDSSZrmkz_Int = 5306,
  VADDSSZrr = 5307,
  VADDSSZrr_Int = 5308,
  VADDSSZrrb_Int = 5309,
  VADDSSZrrbk_Int = 5310,
  VADDSSZrrbkz_Int = 5311,
  VADDSSZrrk_Int = 5312,
  VADDSSZrrkz_Int = 5313,
  VADDSSrm = 5314,
  VADDSSrm_Int = 5315,
  VADDSSrr = 5316,
  VADDSSrr_Int = 5317,
  VADDSUBPDYrm = 5318,
  VADDSUBPDYrr = 5319,
  VADDSUBPDrm = 5320,
  VADDSUBPDrr = 5321,
  VADDSUBPSYrm = 5322,
  VADDSUBPSYrr = 5323,
  VADDSUBPSrm = 5324,
  VADDSUBPSrr = 5325,
  VAESDECLASTYrm = 5326,
  VAESDECLASTYrr = 5327,
  VAESDECLASTZ128rm = 5328,
  VAESDECLASTZ128rr = 5329,
  VAESDECLASTZ256rm = 5330,
  VAESDECLASTZ256rr = 5331,
  VAESDECLASTZrm = 5332,
  VAESDECLASTZrr = 5333,
  VAESDECLASTrm = 5334,
  VAESDECLASTrr = 5335,
  VAESDECYrm = 5336,
  VAESDECYrr = 5337,
  VAESDECZ128rm = 5338,
  VAESDECZ128rr = 5339,
  VAESDECZ256rm = 5340,
  VAESDECZ256rr = 5341,
  VAESDECZrm = 5342,
  VAESDECZrr = 5343,
  VAESDECrm = 5344,
  VAESDECrr = 5345,
  VAESENCLASTYrm = 5346,
  VAESENCLASTYrr = 5347,
  VAESENCLASTZ128rm = 5348,
  VAESENCLASTZ128rr = 5349,
  VAESENCLASTZ256rm = 5350,
  VAESENCLASTZ256rr = 5351,
  VAESENCLASTZrm = 5352,
  VAESENCLASTZrr = 5353,
  VAESENCLASTrm = 5354,
  VAESENCLASTrr = 5355,
  VAESENCYrm = 5356,
  VAESENCYrr = 5357,
  VAESENCZ128rm = 5358,
  VAESENCZ128rr = 5359,
  VAESENCZ256rm = 5360,
  VAESENCZ256rr = 5361,
  VAESENCZrm = 5362,
  VAESENCZrr = 5363,
  VAESENCrm = 5364,
  VAESENCrr = 5365,
  VAESIMCrm = 5366,
  VAESIMCrr = 5367,
  VAESKEYGENASSIST128rm = 5368,
  VAESKEYGENASSIST128rr = 5369,
  VALIGNDZ128rmbi = 5370,
  VALIGNDZ128rmbik = 5371,
  VALIGNDZ128rmbikz = 5372,
  VALIGNDZ128rmi = 5373,
  VALIGNDZ128rmik = 5374,
  VALIGNDZ128rmikz = 5375,
  VALIGNDZ128rri = 5376,
  VALIGNDZ128rrik = 5377,
  VALIGNDZ128rrikz = 5378,
  VALIGNDZ256rmbi = 5379,
  VALIGNDZ256rmbik = 5380,
  VALIGNDZ256rmbikz = 5381,
  VALIGNDZ256rmi = 5382,
  VALIGNDZ256rmik = 5383,
  VALIGNDZ256rmikz = 5384,
  VALIGNDZ256rri = 5385,
  VALIGNDZ256rrik = 5386,
  VALIGNDZ256rrikz = 5387,
  VALIGNDZrmbi = 5388,
  VALIGNDZrmbik = 5389,
  VALIGNDZrmbikz = 5390,
  VALIGNDZrmi = 5391,
  VALIGNDZrmik = 5392,
  VALIGNDZrmikz = 5393,
  VALIGNDZrri = 5394,
  VALIGNDZrrik = 5395,
  VALIGNDZrrikz = 5396,
  VALIGNQZ128rmbi = 5397,
  VALIGNQZ128rmbik = 5398,
  VALIGNQZ128rmbikz = 5399,
  VALIGNQZ128rmi = 5400,
  VALIGNQZ128rmik = 5401,
  VALIGNQZ128rmikz = 5402,
  VALIGNQZ128rri = 5403,
  VALIGNQZ128rrik = 5404,
  VALIGNQZ128rrikz = 5405,
  VALIGNQZ256rmbi = 5406,
  VALIGNQZ256rmbik = 5407,
  VALIGNQZ256rmbikz = 5408,
  VALIGNQZ256rmi = 5409,
  VALIGNQZ256rmik = 5410,
  VALIGNQZ256rmikz = 5411,
  VALIGNQZ256rri = 5412,
  VALIGNQZ256rrik = 5413,
  VALIGNQZ256rrikz = 5414,
  VALIGNQZrmbi = 5415,
  VALIGNQZrmbik = 5416,
  VALIGNQZrmbikz = 5417,
  VALIGNQZrmi = 5418,
  VALIGNQZrmik = 5419,
  VALIGNQZrmikz = 5420,
  VALIGNQZrri = 5421,
  VALIGNQZrrik = 5422,
  VALIGNQZrrikz = 5423,
  VANDNPDYrm = 5424,
  VANDNPDYrr = 5425,
  VANDNPDZ128rm = 5426,
  VANDNPDZ128rmb = 5427,
  VANDNPDZ128rmbk = 5428,
  VANDNPDZ128rmbkz = 5429,
  VANDNPDZ128rmk = 5430,
  VANDNPDZ128rmkz = 5431,
  VANDNPDZ128rr = 5432,
  VANDNPDZ128rrk = 5433,
  VANDNPDZ128rrkz = 5434,
  VANDNPDZ256rm = 5435,
  VANDNPDZ256rmb = 5436,
  VANDNPDZ256rmbk = 5437,
  VANDNPDZ256rmbkz = 5438,
  VANDNPDZ256rmk = 5439,
  VANDNPDZ256rmkz = 5440,
  VANDNPDZ256rr = 5441,
  VANDNPDZ256rrk = 5442,
  VANDNPDZ256rrkz = 5443,
  VANDNPDZrm = 5444,
  VANDNPDZrmb = 5445,
  VANDNPDZrmbk = 5446,
  VANDNPDZrmbkz = 5447,
  VANDNPDZrmk = 5448,
  VANDNPDZrmkz = 5449,
  VANDNPDZrr = 5450,
  VANDNPDZrrk = 5451,
  VANDNPDZrrkz = 5452,
  VANDNPDrm = 5453,
  VANDNPDrr = 5454,
  VANDNPSYrm = 5455,
  VANDNPSYrr = 5456,
  VANDNPSZ128rm = 5457,
  VANDNPSZ128rmb = 5458,
  VANDNPSZ128rmbk = 5459,
  VANDNPSZ128rmbkz = 5460,
  VANDNPSZ128rmk = 5461,
  VANDNPSZ128rmkz = 5462,
  VANDNPSZ128rr = 5463,
  VANDNPSZ128rrk = 5464,
  VANDNPSZ128rrkz = 5465,
  VANDNPSZ256rm = 5466,
  VANDNPSZ256rmb = 5467,
  VANDNPSZ256rmbk = 5468,
  VANDNPSZ256rmbkz = 5469,
  VANDNPSZ256rmk = 5470,
  VANDNPSZ256rmkz = 5471,
  VANDNPSZ256rr = 5472,
  VANDNPSZ256rrk = 5473,
  VANDNPSZ256rrkz = 5474,
  VANDNPSZrm = 5475,
  VANDNPSZrmb = 5476,
  VANDNPSZrmbk = 5477,
  VANDNPSZrmbkz = 5478,
  VANDNPSZrmk = 5479,
  VANDNPSZrmkz = 5480,
  VANDNPSZrr = 5481,
  VANDNPSZrrk = 5482,
  VANDNPSZrrkz = 5483,
  VANDNPSrm = 5484,
  VANDNPSrr = 5485,
  VANDPDYrm = 5486,
  VANDPDYrr = 5487,
  VANDPDZ128rm = 5488,
  VANDPDZ128rmb = 5489,
  VANDPDZ128rmbk = 5490,
  VANDPDZ128rmbkz = 5491,
  VANDPDZ128rmk = 5492,
  VANDPDZ128rmkz = 5493,
  VANDPDZ128rr = 5494,
  VANDPDZ128rrk = 5495,
  VANDPDZ128rrkz = 5496,
  VANDPDZ256rm = 5497,
  VANDPDZ256rmb = 5498,
  VANDPDZ256rmbk = 5499,
  VANDPDZ256rmbkz = 5500,
  VANDPDZ256rmk = 5501,
  VANDPDZ256rmkz = 5502,
  VANDPDZ256rr = 5503,
  VANDPDZ256rrk = 5504,
  VANDPDZ256rrkz = 5505,
  VANDPDZrm = 5506,
  VANDPDZrmb = 5507,
  VANDPDZrmbk = 5508,
  VANDPDZrmbkz = 5509,
  VANDPDZrmk = 5510,
  VANDPDZrmkz = 5511,
  VANDPDZrr = 5512,
  VANDPDZrrk = 5513,
  VANDPDZrrkz = 5514,
  VANDPDrm = 5515,
  VANDPDrr = 5516,
  VANDPSYrm = 5517,
  VANDPSYrr = 5518,
  VANDPSZ128rm = 5519,
  VANDPSZ128rmb = 5520,
  VANDPSZ128rmbk = 5521,
  VANDPSZ128rmbkz = 5522,
  VANDPSZ128rmk = 5523,
  VANDPSZ128rmkz = 5524,
  VANDPSZ128rr = 5525,
  VANDPSZ128rrk = 5526,
  VANDPSZ128rrkz = 5527,
  VANDPSZ256rm = 5528,
  VANDPSZ256rmb = 5529,
  VANDPSZ256rmbk = 5530,
  VANDPSZ256rmbkz = 5531,
  VANDPSZ256rmk = 5532,
  VANDPSZ256rmkz = 5533,
  VANDPSZ256rr = 5534,
  VANDPSZ256rrk = 5535,
  VANDPSZ256rrkz = 5536,
  VANDPSZrm = 5537,
  VANDPSZrmb = 5538,
  VANDPSZrmbk = 5539,
  VANDPSZrmbkz = 5540,
  VANDPSZrmk = 5541,
  VANDPSZrmkz = 5542,
  VANDPSZrr = 5543,
  VANDPSZrrk = 5544,
  VANDPSZrrkz = 5545,
  VANDPSrm = 5546,
  VANDPSrr = 5547,
  VASTART_SAVE_XMM_REGS = 5548,
  VBCSTNEBF162PSYrm = 5549,
  VBCSTNEBF162PSrm = 5550,
  VBCSTNESH2PSYrm = 5551,
  VBCSTNESH2PSrm = 5552,
  VBLENDMPDZ128rm = 5553,
  VBLENDMPDZ128rmb = 5554,
  VBLENDMPDZ128rmbk = 5555,
  VBLENDMPDZ128rmbkz = 5556,
  VBLENDMPDZ128rmk = 5557,
  VBLENDMPDZ128rmkz = 5558,
  VBLENDMPDZ128rr = 5559,
  VBLENDMPDZ128rrk = 5560,
  VBLENDMPDZ128rrkz = 5561,
  VBLENDMPDZ256rm = 5562,
  VBLENDMPDZ256rmb = 5563,
  VBLENDMPDZ256rmbk = 5564,
  VBLENDMPDZ256rmbkz = 5565,
  VBLENDMPDZ256rmk = 5566,
  VBLENDMPDZ256rmkz = 5567,
  VBLENDMPDZ256rr = 5568,
  VBLENDMPDZ256rrk = 5569,
  VBLENDMPDZ256rrkz = 5570,
  VBLENDMPDZrm = 5571,
  VBLENDMPDZrmb = 5572,
  VBLENDMPDZrmbk = 5573,
  VBLENDMPDZrmbkz = 5574,
  VBLENDMPDZrmk = 5575,
  VBLENDMPDZrmkz = 5576,
  VBLENDMPDZrr = 5577,
  VBLENDMPDZrrk = 5578,
  VBLENDMPDZrrkz = 5579,
  VBLENDMPSZ128rm = 5580,
  VBLENDMPSZ128rmb = 5581,
  VBLENDMPSZ128rmbk = 5582,
  VBLENDMPSZ128rmbkz = 5583,
  VBLENDMPSZ128rmk = 5584,
  VBLENDMPSZ128rmkz = 5585,
  VBLENDMPSZ128rr = 5586,
  VBLENDMPSZ128rrk = 5587,
  VBLENDMPSZ128rrkz = 5588,
  VBLENDMPSZ256rm = 5589,
  VBLENDMPSZ256rmb = 5590,
  VBLENDMPSZ256rmbk = 5591,
  VBLENDMPSZ256rmbkz = 5592,
  VBLENDMPSZ256rmk = 5593,
  VBLENDMPSZ256rmkz = 5594,
  VBLENDMPSZ256rr = 5595,
  VBLENDMPSZ256rrk = 5596,
  VBLENDMPSZ256rrkz = 5597,
  VBLENDMPSZrm = 5598,
  VBLENDMPSZrmb = 5599,
  VBLENDMPSZrmbk = 5600,
  VBLENDMPSZrmbkz = 5601,
  VBLENDMPSZrmk = 5602,
  VBLENDMPSZrmkz = 5603,
  VBLENDMPSZrr = 5604,
  VBLENDMPSZrrk = 5605,
  VBLENDMPSZrrkz = 5606,
  VBLENDPDYrmi = 5607,
  VBLENDPDYrri = 5608,
  VBLENDPDrmi = 5609,
  VBLENDPDrri = 5610,
  VBLENDPSYrmi = 5611,
  VBLENDPSYrri = 5612,
  VBLENDPSrmi = 5613,
  VBLENDPSrri = 5614,
  VBLENDVPDYrmr = 5615,
  VBLENDVPDYrrr = 5616,
  VBLENDVPDrmr = 5617,
  VBLENDVPDrrr = 5618,
  VBLENDVPSYrmr = 5619,
  VBLENDVPSYrrr = 5620,
  VBLENDVPSrmr = 5621,
  VBLENDVPSrrr = 5622,
  VBROADCASTF128rm = 5623,
  VBROADCASTF32X2Z256rm = 5624,
  VBROADCASTF32X2Z256rmk = 5625,
  VBROADCASTF32X2Z256rmkz = 5626,
  VBROADCASTF32X2Z256rr = 5627,
  VBROADCASTF32X2Z256rrk = 5628,
  VBROADCASTF32X2Z256rrkz = 5629,
  VBROADCASTF32X2Zrm = 5630,
  VBROADCASTF32X2Zrmk = 5631,
  VBROADCASTF32X2Zrmkz = 5632,
  VBROADCASTF32X2Zrr = 5633,
  VBROADCASTF32X2Zrrk = 5634,
  VBROADCASTF32X2Zrrkz = 5635,
  VBROADCASTF32X4Z256rm = 5636,
  VBROADCASTF32X4Z256rmk = 5637,
  VBROADCASTF32X4Z256rmkz = 5638,
  VBROADCASTF32X4Zrm = 5639,
  VBROADCASTF32X4Zrmk = 5640,
  VBROADCASTF32X4Zrmkz = 5641,
  VBROADCASTF32X8Zrm = 5642,
  VBROADCASTF32X8Zrmk = 5643,
  VBROADCASTF32X8Zrmkz = 5644,
  VBROADCASTF64X2Z256rm = 5645,
  VBROADCASTF64X2Z256rmk = 5646,
  VBROADCASTF64X2Z256rmkz = 5647,
  VBROADCASTF64X2Zrm = 5648,
  VBROADCASTF64X2Zrmk = 5649,
  VBROADCASTF64X2Zrmkz = 5650,
  VBROADCASTF64X4Zrm = 5651,
  VBROADCASTF64X4Zrmk = 5652,
  VBROADCASTF64X4Zrmkz = 5653,
  VBROADCASTI128rm = 5654,
  VBROADCASTI32X2Z128rm = 5655,
  VBROADCASTI32X2Z128rmk = 5656,
  VBROADCASTI32X2Z128rmkz = 5657,
  VBROADCASTI32X2Z128rr = 5658,
  VBROADCASTI32X2Z128rrk = 5659,
  VBROADCASTI32X2Z128rrkz = 5660,
  VBROADCASTI32X2Z256rm = 5661,
  VBROADCASTI32X2Z256rmk = 5662,
  VBROADCASTI32X2Z256rmkz = 5663,
  VBROADCASTI32X2Z256rr = 5664,
  VBROADCASTI32X2Z256rrk = 5665,
  VBROADCASTI32X2Z256rrkz = 5666,
  VBROADCASTI32X2Zrm = 5667,
  VBROADCASTI32X2Zrmk = 5668,
  VBROADCASTI32X2Zrmkz = 5669,
  VBROADCASTI32X2Zrr = 5670,
  VBROADCASTI32X2Zrrk = 5671,
  VBROADCASTI32X2Zrrkz = 5672,
  VBROADCASTI32X4Z256rm = 5673,
  VBROADCASTI32X4Z256rmk = 5674,
  VBROADCASTI32X4Z256rmkz = 5675,
  VBROADCASTI32X4Zrm = 5676,
  VBROADCASTI32X4Zrmk = 5677,
  VBROADCASTI32X4Zrmkz = 5678,
  VBROADCASTI32X8Zrm = 5679,
  VBROADCASTI32X8Zrmk = 5680,
  VBROADCASTI32X8Zrmkz = 5681,
  VBROADCASTI64X2Z256rm = 5682,
  VBROADCASTI64X2Z256rmk = 5683,
  VBROADCASTI64X2Z256rmkz = 5684,
  VBROADCASTI64X2Zrm = 5685,
  VBROADCASTI64X2Zrmk = 5686,
  VBROADCASTI64X2Zrmkz = 5687,
  VBROADCASTI64X4Zrm = 5688,
  VBROADCASTI64X4Zrmk = 5689,
  VBROADCASTI64X4Zrmkz = 5690,
  VBROADCASTSDYrm = 5691,
  VBROADCASTSDYrr = 5692,
  VBROADCASTSDZ256rm = 5693,
  VBROADCASTSDZ256rmk = 5694,
  VBROADCASTSDZ256rmkz = 5695,
  VBROADCASTSDZ256rr = 5696,
  VBROADCASTSDZ256rrk = 5697,
  VBROADCASTSDZ256rrkz = 5698,
  VBROADCASTSDZrm = 5699,
  VBROADCASTSDZrmk = 5700,
  VBROADCASTSDZrmkz = 5701,
  VBROADCASTSDZrr = 5702,
  VBROADCASTSDZrrk = 5703,
  VBROADCASTSDZrrkz = 5704,
  VBROADCASTSSYrm = 5705,
  VBROADCASTSSYrr = 5706,
  VBROADCASTSSZ128rm = 5707,
  VBROADCASTSSZ128rmk = 5708,
  VBROADCASTSSZ128rmkz = 5709,
  VBROADCASTSSZ128rr = 5710,
  VBROADCASTSSZ128rrk = 5711,
  VBROADCASTSSZ128rrkz = 5712,
  VBROADCASTSSZ256rm = 5713,
  VBROADCASTSSZ256rmk = 5714,
  VBROADCASTSSZ256rmkz = 5715,
  VBROADCASTSSZ256rr = 5716,
  VBROADCASTSSZ256rrk = 5717,
  VBROADCASTSSZ256rrkz = 5718,
  VBROADCASTSSZrm = 5719,
  VBROADCASTSSZrmk = 5720,
  VBROADCASTSSZrmkz = 5721,
  VBROADCASTSSZrr = 5722,
  VBROADCASTSSZrrk = 5723,
  VBROADCASTSSZrrkz = 5724,
  VBROADCASTSSrm = 5725,
  VBROADCASTSSrr = 5726,
  VCMPBF16Z128rmbi = 5727,
  VCMPBF16Z128rmbik = 5728,
  VCMPBF16Z128rmi = 5729,
  VCMPBF16Z128rmik = 5730,
  VCMPBF16Z128rri = 5731,
  VCMPBF16Z128rrik = 5732,
  VCMPBF16Z256rmbi = 5733,
  VCMPBF16Z256rmbik = 5734,
  VCMPBF16Z256rmi = 5735,
  VCMPBF16Z256rmik = 5736,
  VCMPBF16Z256rri = 5737,
  VCMPBF16Z256rrik = 5738,
  VCMPBF16Zrmbi = 5739,
  VCMPBF16Zrmbik = 5740,
  VCMPBF16Zrmi = 5741,
  VCMPBF16Zrmik = 5742,
  VCMPBF16Zrri = 5743,
  VCMPBF16Zrrik = 5744,
  VCMPPDYrmi = 5745,
  VCMPPDYrri = 5746,
  VCMPPDZ128rmbi = 5747,
  VCMPPDZ128rmbik = 5748,
  VCMPPDZ128rmi = 5749,
  VCMPPDZ128rmik = 5750,
  VCMPPDZ128rri = 5751,
  VCMPPDZ128rrik = 5752,
  VCMPPDZ256rmbi = 5753,
  VCMPPDZ256rmbik = 5754,
  VCMPPDZ256rmi = 5755,
  VCMPPDZ256rmik = 5756,
  VCMPPDZ256rri = 5757,
  VCMPPDZ256rrib = 5758,
  VCMPPDZ256rribk = 5759,
  VCMPPDZ256rrik = 5760,
  VCMPPDZrmbi = 5761,
  VCMPPDZrmbik = 5762,
  VCMPPDZrmi = 5763,
  VCMPPDZrmik = 5764,
  VCMPPDZrri = 5765,
  VCMPPDZrrib = 5766,
  VCMPPDZrribk = 5767,
  VCMPPDZrrik = 5768,
  VCMPPDrmi = 5769,
  VCMPPDrri = 5770,
  VCMPPHZ128rmbi = 5771,
  VCMPPHZ128rmbik = 5772,
  VCMPPHZ128rmi = 5773,
  VCMPPHZ128rmik = 5774,
  VCMPPHZ128rri = 5775,
  VCMPPHZ128rrik = 5776,
  VCMPPHZ256rmbi = 5777,
  VCMPPHZ256rmbik = 5778,
  VCMPPHZ256rmi = 5779,
  VCMPPHZ256rmik = 5780,
  VCMPPHZ256rri = 5781,
  VCMPPHZ256rrib = 5782,
  VCMPPHZ256rribk = 5783,
  VCMPPHZ256rrik = 5784,
  VCMPPHZrmbi = 5785,
  VCMPPHZrmbik = 5786,
  VCMPPHZrmi = 5787,
  VCMPPHZrmik = 5788,
  VCMPPHZrri = 5789,
  VCMPPHZrrib = 5790,
  VCMPPHZrribk = 5791,
  VCMPPHZrrik = 5792,
  VCMPPSYrmi = 5793,
  VCMPPSYrri = 5794,
  VCMPPSZ128rmbi = 5795,
  VCMPPSZ128rmbik = 5796,
  VCMPPSZ128rmi = 5797,
  VCMPPSZ128rmik = 5798,
  VCMPPSZ128rri = 5799,
  VCMPPSZ128rrik = 5800,
  VCMPPSZ256rmbi = 5801,
  VCMPPSZ256rmbik = 5802,
  VCMPPSZ256rmi = 5803,
  VCMPPSZ256rmik = 5804,
  VCMPPSZ256rri = 5805,
  VCMPPSZ256rrib = 5806,
  VCMPPSZ256rribk = 5807,
  VCMPPSZ256rrik = 5808,
  VCMPPSZrmbi = 5809,
  VCMPPSZrmbik = 5810,
  VCMPPSZrmi = 5811,
  VCMPPSZrmik = 5812,
  VCMPPSZrri = 5813,
  VCMPPSZrrib = 5814,
  VCMPPSZrribk = 5815,
  VCMPPSZrrik = 5816,
  VCMPPSrmi = 5817,
  VCMPPSrri = 5818,
  VCMPSDZrmi = 5819,
  VCMPSDZrmi_Int = 5820,
  VCMPSDZrmik_Int = 5821,
  VCMPSDZrri = 5822,
  VCMPSDZrri_Int = 5823,
  VCMPSDZrrib_Int = 5824,
  VCMPSDZrribk_Int = 5825,
  VCMPSDZrrik_Int = 5826,
  VCMPSDrmi = 5827,
  VCMPSDrmi_Int = 5828,
  VCMPSDrri = 5829,
  VCMPSDrri_Int = 5830,
  VCMPSHZrmi = 5831,
  VCMPSHZrmi_Int = 5832,
  VCMPSHZrmik_Int = 5833,
  VCMPSHZrri = 5834,
  VCMPSHZrri_Int = 5835,
  VCMPSHZrrib_Int = 5836,
  VCMPSHZrribk_Int = 5837,
  VCMPSHZrrik_Int = 5838,
  VCMPSSZrmi = 5839,
  VCMPSSZrmi_Int = 5840,
  VCMPSSZrmik_Int = 5841,
  VCMPSSZrri = 5842,
  VCMPSSZrri_Int = 5843,
  VCMPSSZrrib_Int = 5844,
  VCMPSSZrribk_Int = 5845,
  VCMPSSZrrik_Int = 5846,
  VCMPSSrmi = 5847,
  VCMPSSrmi_Int = 5848,
  VCMPSSrri = 5849,
  VCMPSSrri_Int = 5850,
  VCOMISBF16Zrm = 5851,
  VCOMISBF16Zrm_Int = 5852,
  VCOMISBF16Zrr = 5853,
  VCOMISBF16Zrr_Int = 5854,
  VCOMISDZrm = 5855,
  VCOMISDZrm_Int = 5856,
  VCOMISDZrr = 5857,
  VCOMISDZrr_Int = 5858,
  VCOMISDZrrb = 5859,
  VCOMISDrm = 5860,
  VCOMISDrm_Int = 5861,
  VCOMISDrr = 5862,
  VCOMISDrr_Int = 5863,
  VCOMISHZrm = 5864,
  VCOMISHZrm_Int = 5865,
  VCOMISHZrr = 5866,
  VCOMISHZrr_Int = 5867,
  VCOMISHZrrb = 5868,
  VCOMISSZrm = 5869,
  VCOMISSZrm_Int = 5870,
  VCOMISSZrr = 5871,
  VCOMISSZrr_Int = 5872,
  VCOMISSZrrb = 5873,
  VCOMISSrm = 5874,
  VCOMISSrm_Int = 5875,
  VCOMISSrr = 5876,
  VCOMISSrr_Int = 5877,
  VCOMPRESSPDZ128mr = 5878,
  VCOMPRESSPDZ128mrk = 5879,
  VCOMPRESSPDZ128rr = 5880,
  VCOMPRESSPDZ128rrk = 5881,
  VCOMPRESSPDZ128rrkz = 5882,
  VCOMPRESSPDZ256mr = 5883,
  VCOMPRESSPDZ256mrk = 5884,
  VCOMPRESSPDZ256rr = 5885,
  VCOMPRESSPDZ256rrk = 5886,
  VCOMPRESSPDZ256rrkz = 5887,
  VCOMPRESSPDZmr = 5888,
  VCOMPRESSPDZmrk = 5889,
  VCOMPRESSPDZrr = 5890,
  VCOMPRESSPDZrrk = 5891,
  VCOMPRESSPDZrrkz = 5892,
  VCOMPRESSPSZ128mr = 5893,
  VCOMPRESSPSZ128mrk = 5894,
  VCOMPRESSPSZ128rr = 5895,
  VCOMPRESSPSZ128rrk = 5896,
  VCOMPRESSPSZ128rrkz = 5897,
  VCOMPRESSPSZ256mr = 5898,
  VCOMPRESSPSZ256mrk = 5899,
  VCOMPRESSPSZ256rr = 5900,
  VCOMPRESSPSZ256rrk = 5901,
  VCOMPRESSPSZ256rrkz = 5902,
  VCOMPRESSPSZmr = 5903,
  VCOMPRESSPSZmrk = 5904,
  VCOMPRESSPSZrr = 5905,
  VCOMPRESSPSZrrk = 5906,
  VCOMPRESSPSZrrkz = 5907,
  VCOMXSDZrm_Int = 5908,
  VCOMXSDZrr_Int = 5909,
  VCOMXSDZrrb_Int = 5910,
  VCOMXSHZrm_Int = 5911,
  VCOMXSHZrr_Int = 5912,
  VCOMXSHZrrb_Int = 5913,
  VCOMXSSZrm_Int = 5914,
  VCOMXSSZrr_Int = 5915,
  VCOMXSSZrrb_Int = 5916,
  VCVT2PH2BF8SZ128rm = 5917,
  VCVT2PH2BF8SZ128rmb = 5918,
  VCVT2PH2BF8SZ128rmbk = 5919,
  VCVT2PH2BF8SZ128rmbkz = 5920,
  VCVT2PH2BF8SZ128rmk = 5921,
  VCVT2PH2BF8SZ128rmkz = 5922,
  VCVT2PH2BF8SZ128rr = 5923,
  VCVT2PH2BF8SZ128rrk = 5924,
  VCVT2PH2BF8SZ128rrkz = 5925,
  VCVT2PH2BF8SZ256rm = 5926,
  VCVT2PH2BF8SZ256rmb = 5927,
  VCVT2PH2BF8SZ256rmbk = 5928,
  VCVT2PH2BF8SZ256rmbkz = 5929,
  VCVT2PH2BF8SZ256rmk = 5930,
  VCVT2PH2BF8SZ256rmkz = 5931,
  VCVT2PH2BF8SZ256rr = 5932,
  VCVT2PH2BF8SZ256rrk = 5933,
  VCVT2PH2BF8SZ256rrkz = 5934,
  VCVT2PH2BF8SZrm = 5935,
  VCVT2PH2BF8SZrmb = 5936,
  VCVT2PH2BF8SZrmbk = 5937,
  VCVT2PH2BF8SZrmbkz = 5938,
  VCVT2PH2BF8SZrmk = 5939,
  VCVT2PH2BF8SZrmkz = 5940,
  VCVT2PH2BF8SZrr = 5941,
  VCVT2PH2BF8SZrrk = 5942,
  VCVT2PH2BF8SZrrkz = 5943,
  VCVT2PH2BF8Z128rm = 5944,
  VCVT2PH2BF8Z128rmb = 5945,
  VCVT2PH2BF8Z128rmbk = 5946,
  VCVT2PH2BF8Z128rmbkz = 5947,
  VCVT2PH2BF8Z128rmk = 5948,
  VCVT2PH2BF8Z128rmkz = 5949,
  VCVT2PH2BF8Z128rr = 5950,
  VCVT2PH2BF8Z128rrk = 5951,
  VCVT2PH2BF8Z128rrkz = 5952,
  VCVT2PH2BF8Z256rm = 5953,
  VCVT2PH2BF8Z256rmb = 5954,
  VCVT2PH2BF8Z256rmbk = 5955,
  VCVT2PH2BF8Z256rmbkz = 5956,
  VCVT2PH2BF8Z256rmk = 5957,
  VCVT2PH2BF8Z256rmkz = 5958,
  VCVT2PH2BF8Z256rr = 5959,
  VCVT2PH2BF8Z256rrk = 5960,
  VCVT2PH2BF8Z256rrkz = 5961,
  VCVT2PH2BF8Zrm = 5962,
  VCVT2PH2BF8Zrmb = 5963,
  VCVT2PH2BF8Zrmbk = 5964,
  VCVT2PH2BF8Zrmbkz = 5965,
  VCVT2PH2BF8Zrmk = 5966,
  VCVT2PH2BF8Zrmkz = 5967,
  VCVT2PH2BF8Zrr = 5968,
  VCVT2PH2BF8Zrrk = 5969,
  VCVT2PH2BF8Zrrkz = 5970,
  VCVT2PH2HF8SZ128rm = 5971,
  VCVT2PH2HF8SZ128rmb = 5972,
  VCVT2PH2HF8SZ128rmbk = 5973,
  VCVT2PH2HF8SZ128rmbkz = 5974,
  VCVT2PH2HF8SZ128rmk = 5975,
  VCVT2PH2HF8SZ128rmkz = 5976,
  VCVT2PH2HF8SZ128rr = 5977,
  VCVT2PH2HF8SZ128rrk = 5978,
  VCVT2PH2HF8SZ128rrkz = 5979,
  VCVT2PH2HF8SZ256rm = 5980,
  VCVT2PH2HF8SZ256rmb = 5981,
  VCVT2PH2HF8SZ256rmbk = 5982,
  VCVT2PH2HF8SZ256rmbkz = 5983,
  VCVT2PH2HF8SZ256rmk = 5984,
  VCVT2PH2HF8SZ256rmkz = 5985,
  VCVT2PH2HF8SZ256rr = 5986,
  VCVT2PH2HF8SZ256rrk = 5987,
  VCVT2PH2HF8SZ256rrkz = 5988,
  VCVT2PH2HF8SZrm = 5989,
  VCVT2PH2HF8SZrmb = 5990,
  VCVT2PH2HF8SZrmbk = 5991,
  VCVT2PH2HF8SZrmbkz = 5992,
  VCVT2PH2HF8SZrmk = 5993,
  VCVT2PH2HF8SZrmkz = 5994,
  VCVT2PH2HF8SZrr = 5995,
  VCVT2PH2HF8SZrrk = 5996,
  VCVT2PH2HF8SZrrkz = 5997,
  VCVT2PH2HF8Z128rm = 5998,
  VCVT2PH2HF8Z128rmb = 5999,
  VCVT2PH2HF8Z128rmbk = 6000,
  VCVT2PH2HF8Z128rmbkz = 6001,
  VCVT2PH2HF8Z128rmk = 6002,
  VCVT2PH2HF8Z128rmkz = 6003,
  VCVT2PH2HF8Z128rr = 6004,
  VCVT2PH2HF8Z128rrk = 6005,
  VCVT2PH2HF8Z128rrkz = 6006,
  VCVT2PH2HF8Z256rm = 6007,
  VCVT2PH2HF8Z256rmb = 6008,
  VCVT2PH2HF8Z256rmbk = 6009,
  VCVT2PH2HF8Z256rmbkz = 6010,
  VCVT2PH2HF8Z256rmk = 6011,
  VCVT2PH2HF8Z256rmkz = 6012,
  VCVT2PH2HF8Z256rr = 6013,
  VCVT2PH2HF8Z256rrk = 6014,
  VCVT2PH2HF8Z256rrkz = 6015,
  VCVT2PH2HF8Zrm = 6016,
  VCVT2PH2HF8Zrmb = 6017,
  VCVT2PH2HF8Zrmbk = 6018,
  VCVT2PH2HF8Zrmbkz = 6019,
  VCVT2PH2HF8Zrmk = 6020,
  VCVT2PH2HF8Zrmkz = 6021,
  VCVT2PH2HF8Zrr = 6022,
  VCVT2PH2HF8Zrrk = 6023,
  VCVT2PH2HF8Zrrkz = 6024,
  VCVT2PS2PHXZ128rm = 6025,
  VCVT2PS2PHXZ128rmb = 6026,
  VCVT2PS2PHXZ128rmbk = 6027,
  VCVT2PS2PHXZ128rmbkz = 6028,
  VCVT2PS2PHXZ128rmk = 6029,
  VCVT2PS2PHXZ128rmkz = 6030,
  VCVT2PS2PHXZ128rr = 6031,
  VCVT2PS2PHXZ128rrk = 6032,
  VCVT2PS2PHXZ128rrkz = 6033,
  VCVT2PS2PHXZ256rm = 6034,
  VCVT2PS2PHXZ256rmb = 6035,
  VCVT2PS2PHXZ256rmbk = 6036,
  VCVT2PS2PHXZ256rmbkz = 6037,
  VCVT2PS2PHXZ256rmk = 6038,
  VCVT2PS2PHXZ256rmkz = 6039,
  VCVT2PS2PHXZ256rr = 6040,
  VCVT2PS2PHXZ256rrb = 6041,
  VCVT2PS2PHXZ256rrbk = 6042,
  VCVT2PS2PHXZ256rrbkz = 6043,
  VCVT2PS2PHXZ256rrk = 6044,
  VCVT2PS2PHXZ256rrkz = 6045,
  VCVT2PS2PHXZrm = 6046,
  VCVT2PS2PHXZrmb = 6047,
  VCVT2PS2PHXZrmbk = 6048,
  VCVT2PS2PHXZrmbkz = 6049,
  VCVT2PS2PHXZrmk = 6050,
  VCVT2PS2PHXZrmkz = 6051,
  VCVT2PS2PHXZrr = 6052,
  VCVT2PS2PHXZrrb = 6053,
  VCVT2PS2PHXZrrbk = 6054,
  VCVT2PS2PHXZrrbkz = 6055,
  VCVT2PS2PHXZrrk = 6056,
  VCVT2PS2PHXZrrkz = 6057,
  VCVTBF162IBSZ128rm = 6058,
  VCVTBF162IBSZ128rmb = 6059,
  VCVTBF162IBSZ128rmbk = 6060,
  VCVTBF162IBSZ128rmbkz = 6061,
  VCVTBF162IBSZ128rmk = 6062,
  VCVTBF162IBSZ128rmkz = 6063,
  VCVTBF162IBSZ128rr = 6064,
  VCVTBF162IBSZ128rrk = 6065,
  VCVTBF162IBSZ128rrkz = 6066,
  VCVTBF162IBSZ256rm = 6067,
  VCVTBF162IBSZ256rmb = 6068,
  VCVTBF162IBSZ256rmbk = 6069,
  VCVTBF162IBSZ256rmbkz = 6070,
  VCVTBF162IBSZ256rmk = 6071,
  VCVTBF162IBSZ256rmkz = 6072,
  VCVTBF162IBSZ256rr = 6073,
  VCVTBF162IBSZ256rrk = 6074,
  VCVTBF162IBSZ256rrkz = 6075,
  VCVTBF162IBSZrm = 6076,
  VCVTBF162IBSZrmb = 6077,
  VCVTBF162IBSZrmbk = 6078,
  VCVTBF162IBSZrmbkz = 6079,
  VCVTBF162IBSZrmk = 6080,
  VCVTBF162IBSZrmkz = 6081,
  VCVTBF162IBSZrr = 6082,
  VCVTBF162IBSZrrk = 6083,
  VCVTBF162IBSZrrkz = 6084,
  VCVTBF162IUBSZ128rm = 6085,
  VCVTBF162IUBSZ128rmb = 6086,
  VCVTBF162IUBSZ128rmbk = 6087,
  VCVTBF162IUBSZ128rmbkz = 6088,
  VCVTBF162IUBSZ128rmk = 6089,
  VCVTBF162IUBSZ128rmkz = 6090,
  VCVTBF162IUBSZ128rr = 6091,
  VCVTBF162IUBSZ128rrk = 6092,
  VCVTBF162IUBSZ128rrkz = 6093,
  VCVTBF162IUBSZ256rm = 6094,
  VCVTBF162IUBSZ256rmb = 6095,
  VCVTBF162IUBSZ256rmbk = 6096,
  VCVTBF162IUBSZ256rmbkz = 6097,
  VCVTBF162IUBSZ256rmk = 6098,
  VCVTBF162IUBSZ256rmkz = 6099,
  VCVTBF162IUBSZ256rr = 6100,
  VCVTBF162IUBSZ256rrk = 6101,
  VCVTBF162IUBSZ256rrkz = 6102,
  VCVTBF162IUBSZrm = 6103,
  VCVTBF162IUBSZrmb = 6104,
  VCVTBF162IUBSZrmbk = 6105,
  VCVTBF162IUBSZrmbkz = 6106,
  VCVTBF162IUBSZrmk = 6107,
  VCVTBF162IUBSZrmkz = 6108,
  VCVTBF162IUBSZrr = 6109,
  VCVTBF162IUBSZrrk = 6110,
  VCVTBF162IUBSZrrkz = 6111,
  VCVTBIASPH2BF8SZ128rm = 6112,
  VCVTBIASPH2BF8SZ128rmb = 6113,
  VCVTBIASPH2BF8SZ128rmbk = 6114,
  VCVTBIASPH2BF8SZ128rmbkz = 6115,
  VCVTBIASPH2BF8SZ128rmk = 6116,
  VCVTBIASPH2BF8SZ128rmkz = 6117,
  VCVTBIASPH2BF8SZ128rr = 6118,
  VCVTBIASPH2BF8SZ128rrk = 6119,
  VCVTBIASPH2BF8SZ128rrkz = 6120,
  VCVTBIASPH2BF8SZ256rm = 6121,
  VCVTBIASPH2BF8SZ256rmb = 6122,
  VCVTBIASPH2BF8SZ256rmbk = 6123,
  VCVTBIASPH2BF8SZ256rmbkz = 6124,
  VCVTBIASPH2BF8SZ256rmk = 6125,
  VCVTBIASPH2BF8SZ256rmkz = 6126,
  VCVTBIASPH2BF8SZ256rr = 6127,
  VCVTBIASPH2BF8SZ256rrk = 6128,
  VCVTBIASPH2BF8SZ256rrkz = 6129,
  VCVTBIASPH2BF8SZrm = 6130,
  VCVTBIASPH2BF8SZrmb = 6131,
  VCVTBIASPH2BF8SZrmbk = 6132,
  VCVTBIASPH2BF8SZrmbkz = 6133,
  VCVTBIASPH2BF8SZrmk = 6134,
  VCVTBIASPH2BF8SZrmkz = 6135,
  VCVTBIASPH2BF8SZrr = 6136,
  VCVTBIASPH2BF8SZrrk = 6137,
  VCVTBIASPH2BF8SZrrkz = 6138,
  VCVTBIASPH2BF8Z128rm = 6139,
  VCVTBIASPH2BF8Z128rmb = 6140,
  VCVTBIASPH2BF8Z128rmbk = 6141,
  VCVTBIASPH2BF8Z128rmbkz = 6142,
  VCVTBIASPH2BF8Z128rmk = 6143,
  VCVTBIASPH2BF8Z128rmkz = 6144,
  VCVTBIASPH2BF8Z128rr = 6145,
  VCVTBIASPH2BF8Z128rrk = 6146,
  VCVTBIASPH2BF8Z128rrkz = 6147,
  VCVTBIASPH2BF8Z256rm = 6148,
  VCVTBIASPH2BF8Z256rmb = 6149,
  VCVTBIASPH2BF8Z256rmbk = 6150,
  VCVTBIASPH2BF8Z256rmbkz = 6151,
  VCVTBIASPH2BF8Z256rmk = 6152,
  VCVTBIASPH2BF8Z256rmkz = 6153,
  VCVTBIASPH2BF8Z256rr = 6154,
  VCVTBIASPH2BF8Z256rrk = 6155,
  VCVTBIASPH2BF8Z256rrkz = 6156,
  VCVTBIASPH2BF8Zrm = 6157,
  VCVTBIASPH2BF8Zrmb = 6158,
  VCVTBIASPH2BF8Zrmbk = 6159,
  VCVTBIASPH2BF8Zrmbkz = 6160,
  VCVTBIASPH2BF8Zrmk = 6161,
  VCVTBIASPH2BF8Zrmkz = 6162,
  VCVTBIASPH2BF8Zrr = 6163,
  VCVTBIASPH2BF8Zrrk = 6164,
  VCVTBIASPH2BF8Zrrkz = 6165,
  VCVTBIASPH2HF8SZ128rm = 6166,
  VCVTBIASPH2HF8SZ128rmb = 6167,
  VCVTBIASPH2HF8SZ128rmbk = 6168,
  VCVTBIASPH2HF8SZ128rmbkz = 6169,
  VCVTBIASPH2HF8SZ128rmk = 6170,
  VCVTBIASPH2HF8SZ128rmkz = 6171,
  VCVTBIASPH2HF8SZ128rr = 6172,
  VCVTBIASPH2HF8SZ128rrk = 6173,
  VCVTBIASPH2HF8SZ128rrkz = 6174,
  VCVTBIASPH2HF8SZ256rm = 6175,
  VCVTBIASPH2HF8SZ256rmb = 6176,
  VCVTBIASPH2HF8SZ256rmbk = 6177,
  VCVTBIASPH2HF8SZ256rmbkz = 6178,
  VCVTBIASPH2HF8SZ256rmk = 6179,
  VCVTBIASPH2HF8SZ256rmkz = 6180,
  VCVTBIASPH2HF8SZ256rr = 6181,
  VCVTBIASPH2HF8SZ256rrk = 6182,
  VCVTBIASPH2HF8SZ256rrkz = 6183,
  VCVTBIASPH2HF8SZrm = 6184,
  VCVTBIASPH2HF8SZrmb = 6185,
  VCVTBIASPH2HF8SZrmbk = 6186,
  VCVTBIASPH2HF8SZrmbkz = 6187,
  VCVTBIASPH2HF8SZrmk = 6188,
  VCVTBIASPH2HF8SZrmkz = 6189,
  VCVTBIASPH2HF8SZrr = 6190,
  VCVTBIASPH2HF8SZrrk = 6191,
  VCVTBIASPH2HF8SZrrkz = 6192,
  VCVTBIASPH2HF8Z128rm = 6193,
  VCVTBIASPH2HF8Z128rmb = 6194,
  VCVTBIASPH2HF8Z128rmbk = 6195,
  VCVTBIASPH2HF8Z128rmbkz = 6196,
  VCVTBIASPH2HF8Z128rmk = 6197,
  VCVTBIASPH2HF8Z128rmkz = 6198,
  VCVTBIASPH2HF8Z128rr = 6199,
  VCVTBIASPH2HF8Z128rrk = 6200,
  VCVTBIASPH2HF8Z128rrkz = 6201,
  VCVTBIASPH2HF8Z256rm = 6202,
  VCVTBIASPH2HF8Z256rmb = 6203,
  VCVTBIASPH2HF8Z256rmbk = 6204,
  VCVTBIASPH2HF8Z256rmbkz = 6205,
  VCVTBIASPH2HF8Z256rmk = 6206,
  VCVTBIASPH2HF8Z256rmkz = 6207,
  VCVTBIASPH2HF8Z256rr = 6208,
  VCVTBIASPH2HF8Z256rrk = 6209,
  VCVTBIASPH2HF8Z256rrkz = 6210,
  VCVTBIASPH2HF8Zrm = 6211,
  VCVTBIASPH2HF8Zrmb = 6212,
  VCVTBIASPH2HF8Zrmbk = 6213,
  VCVTBIASPH2HF8Zrmbkz = 6214,
  VCVTBIASPH2HF8Zrmk = 6215,
  VCVTBIASPH2HF8Zrmkz = 6216,
  VCVTBIASPH2HF8Zrr = 6217,
  VCVTBIASPH2HF8Zrrk = 6218,
  VCVTBIASPH2HF8Zrrkz = 6219,
  VCVTDQ2PDYrm = 6220,
  VCVTDQ2PDYrr = 6221,
  VCVTDQ2PDZ128rm = 6222,
  VCVTDQ2PDZ128rmb = 6223,
  VCVTDQ2PDZ128rmbk = 6224,
  VCVTDQ2PDZ128rmbkz = 6225,
  VCVTDQ2PDZ128rmk = 6226,
  VCVTDQ2PDZ128rmkz = 6227,
  VCVTDQ2PDZ128rr = 6228,
  VCVTDQ2PDZ128rrk = 6229,
  VCVTDQ2PDZ128rrkz = 6230,
  VCVTDQ2PDZ256rm = 6231,
  VCVTDQ2PDZ256rmb = 6232,
  VCVTDQ2PDZ256rmbk = 6233,
  VCVTDQ2PDZ256rmbkz = 6234,
  VCVTDQ2PDZ256rmk = 6235,
  VCVTDQ2PDZ256rmkz = 6236,
  VCVTDQ2PDZ256rr = 6237,
  VCVTDQ2PDZ256rrk = 6238,
  VCVTDQ2PDZ256rrkz = 6239,
  VCVTDQ2PDZrm = 6240,
  VCVTDQ2PDZrmb = 6241,
  VCVTDQ2PDZrmbk = 6242,
  VCVTDQ2PDZrmbkz = 6243,
  VCVTDQ2PDZrmk = 6244,
  VCVTDQ2PDZrmkz = 6245,
  VCVTDQ2PDZrr = 6246,
  VCVTDQ2PDZrrk = 6247,
  VCVTDQ2PDZrrkz = 6248,
  VCVTDQ2PDrm = 6249,
  VCVTDQ2PDrr = 6250,
  VCVTDQ2PHZ128rm = 6251,
  VCVTDQ2PHZ128rmb = 6252,
  VCVTDQ2PHZ128rmbk = 6253,
  VCVTDQ2PHZ128rmbkz = 6254,
  VCVTDQ2PHZ128rmk = 6255,
  VCVTDQ2PHZ128rmkz = 6256,
  VCVTDQ2PHZ128rr = 6257,
  VCVTDQ2PHZ128rrk = 6258,
  VCVTDQ2PHZ128rrkz = 6259,
  VCVTDQ2PHZ256rm = 6260,
  VCVTDQ2PHZ256rmb = 6261,
  VCVTDQ2PHZ256rmbk = 6262,
  VCVTDQ2PHZ256rmbkz = 6263,
  VCVTDQ2PHZ256rmk = 6264,
  VCVTDQ2PHZ256rmkz = 6265,
  VCVTDQ2PHZ256rr = 6266,
  VCVTDQ2PHZ256rrb = 6267,
  VCVTDQ2PHZ256rrbk = 6268,
  VCVTDQ2PHZ256rrbkz = 6269,
  VCVTDQ2PHZ256rrk = 6270,
  VCVTDQ2PHZ256rrkz = 6271,
  VCVTDQ2PHZrm = 6272,
  VCVTDQ2PHZrmb = 6273,
  VCVTDQ2PHZrmbk = 6274,
  VCVTDQ2PHZrmbkz = 6275,
  VCVTDQ2PHZrmk = 6276,
  VCVTDQ2PHZrmkz = 6277,
  VCVTDQ2PHZrr = 6278,
  VCVTDQ2PHZrrb = 6279,
  VCVTDQ2PHZrrbk = 6280,
  VCVTDQ2PHZrrbkz = 6281,
  VCVTDQ2PHZrrk = 6282,
  VCVTDQ2PHZrrkz = 6283,
  VCVTDQ2PSYrm = 6284,
  VCVTDQ2PSYrr = 6285,
  VCVTDQ2PSZ128rm = 6286,
  VCVTDQ2PSZ128rmb = 6287,
  VCVTDQ2PSZ128rmbk = 6288,
  VCVTDQ2PSZ128rmbkz = 6289,
  VCVTDQ2PSZ128rmk = 6290,
  VCVTDQ2PSZ128rmkz = 6291,
  VCVTDQ2PSZ128rr = 6292,
  VCVTDQ2PSZ128rrk = 6293,
  VCVTDQ2PSZ128rrkz = 6294,
  VCVTDQ2PSZ256rm = 6295,
  VCVTDQ2PSZ256rmb = 6296,
  VCVTDQ2PSZ256rmbk = 6297,
  VCVTDQ2PSZ256rmbkz = 6298,
  VCVTDQ2PSZ256rmk = 6299,
  VCVTDQ2PSZ256rmkz = 6300,
  VCVTDQ2PSZ256rr = 6301,
  VCVTDQ2PSZ256rrb = 6302,
  VCVTDQ2PSZ256rrbk = 6303,
  VCVTDQ2PSZ256rrbkz = 6304,
  VCVTDQ2PSZ256rrk = 6305,
  VCVTDQ2PSZ256rrkz = 6306,
  VCVTDQ2PSZrm = 6307,
  VCVTDQ2PSZrmb = 6308,
  VCVTDQ2PSZrmbk = 6309,
  VCVTDQ2PSZrmbkz = 6310,
  VCVTDQ2PSZrmk = 6311,
  VCVTDQ2PSZrmkz = 6312,
  VCVTDQ2PSZrr = 6313,
  VCVTDQ2PSZrrb = 6314,
  VCVTDQ2PSZrrbk = 6315,
  VCVTDQ2PSZrrbkz = 6316,
  VCVTDQ2PSZrrk = 6317,
  VCVTDQ2PSZrrkz = 6318,
  VCVTDQ2PSrm = 6319,
  VCVTDQ2PSrr = 6320,
  VCVTHF82PHZ128rm = 6321,
  VCVTHF82PHZ128rmk = 6322,
  VCVTHF82PHZ128rmkz = 6323,
  VCVTHF82PHZ128rr = 6324,
  VCVTHF82PHZ128rrk = 6325,
  VCVTHF82PHZ128rrkz = 6326,
  VCVTHF82PHZ256rm = 6327,
  VCVTHF82PHZ256rmk = 6328,
  VCVTHF82PHZ256rmkz = 6329,
  VCVTHF82PHZ256rr = 6330,
  VCVTHF82PHZ256rrk = 6331,
  VCVTHF82PHZ256rrkz = 6332,
  VCVTHF82PHZrm = 6333,
  VCVTHF82PHZrmk = 6334,
  VCVTHF82PHZrmkz = 6335,
  VCVTHF82PHZrr = 6336,
  VCVTHF82PHZrrk = 6337,
  VCVTHF82PHZrrkz = 6338,
  VCVTNE2PS2BF16Z128rm = 6339,
  VCVTNE2PS2BF16Z128rmb = 6340,
  VCVTNE2PS2BF16Z128rmbk = 6341,
  VCVTNE2PS2BF16Z128rmbkz = 6342,
  VCVTNE2PS2BF16Z128rmk = 6343,
  VCVTNE2PS2BF16Z128rmkz = 6344,
  VCVTNE2PS2BF16Z128rr = 6345,
  VCVTNE2PS2BF16Z128rrk = 6346,
  VCVTNE2PS2BF16Z128rrkz = 6347,
  VCVTNE2PS2BF16Z256rm = 6348,
  VCVTNE2PS2BF16Z256rmb = 6349,
  VCVTNE2PS2BF16Z256rmbk = 6350,
  VCVTNE2PS2BF16Z256rmbkz = 6351,
  VCVTNE2PS2BF16Z256rmk = 6352,
  VCVTNE2PS2BF16Z256rmkz = 6353,
  VCVTNE2PS2BF16Z256rr = 6354,
  VCVTNE2PS2BF16Z256rrk = 6355,
  VCVTNE2PS2BF16Z256rrkz = 6356,
  VCVTNE2PS2BF16Zrm = 6357,
  VCVTNE2PS2BF16Zrmb = 6358,
  VCVTNE2PS2BF16Zrmbk = 6359,
  VCVTNE2PS2BF16Zrmbkz = 6360,
  VCVTNE2PS2BF16Zrmk = 6361,
  VCVTNE2PS2BF16Zrmkz = 6362,
  VCVTNE2PS2BF16Zrr = 6363,
  VCVTNE2PS2BF16Zrrk = 6364,
  VCVTNE2PS2BF16Zrrkz = 6365,
  VCVTNEEBF162PSYrm = 6366,
  VCVTNEEBF162PSrm = 6367,
  VCVTNEEPH2PSYrm = 6368,
  VCVTNEEPH2PSrm = 6369,
  VCVTNEOBF162PSYrm = 6370,
  VCVTNEOBF162PSrm = 6371,
  VCVTNEOPH2PSYrm = 6372,
  VCVTNEOPH2PSrm = 6373,
  VCVTNEPS2BF16Yrm = 6374,
  VCVTNEPS2BF16Yrr = 6375,
  VCVTNEPS2BF16Z128rm = 6376,
  VCVTNEPS2BF16Z128rmb = 6377,
  VCVTNEPS2BF16Z128rmbk = 6378,
  VCVTNEPS2BF16Z128rmbkz = 6379,
  VCVTNEPS2BF16Z128rmk = 6380,
  VCVTNEPS2BF16Z128rmkz = 6381,
  VCVTNEPS2BF16Z128rr = 6382,
  VCVTNEPS2BF16Z128rrk = 6383,
  VCVTNEPS2BF16Z128rrkz = 6384,
  VCVTNEPS2BF16Z256rm = 6385,
  VCVTNEPS2BF16Z256rmb = 6386,
  VCVTNEPS2BF16Z256rmbk = 6387,
  VCVTNEPS2BF16Z256rmbkz = 6388,
  VCVTNEPS2BF16Z256rmk = 6389,
  VCVTNEPS2BF16Z256rmkz = 6390,
  VCVTNEPS2BF16Z256rr = 6391,
  VCVTNEPS2BF16Z256rrk = 6392,
  VCVTNEPS2BF16Z256rrkz = 6393,
  VCVTNEPS2BF16Zrm = 6394,
  VCVTNEPS2BF16Zrmb = 6395,
  VCVTNEPS2BF16Zrmbk = 6396,
  VCVTNEPS2BF16Zrmbkz = 6397,
  VCVTNEPS2BF16Zrmk = 6398,
  VCVTNEPS2BF16Zrmkz = 6399,
  VCVTNEPS2BF16Zrr = 6400,
  VCVTNEPS2BF16Zrrk = 6401,
  VCVTNEPS2BF16Zrrkz = 6402,
  VCVTNEPS2BF16rm = 6403,
  VCVTNEPS2BF16rr = 6404,
  VCVTPD2DQYrm = 6405,
  VCVTPD2DQYrr = 6406,
  VCVTPD2DQZ128rm = 6407,
  VCVTPD2DQZ128rmb = 6408,
  VCVTPD2DQZ128rmbk = 6409,
  VCVTPD2DQZ128rmbkz = 6410,
  VCVTPD2DQZ128rmk = 6411,
  VCVTPD2DQZ128rmkz = 6412,
  VCVTPD2DQZ128rr = 6413,
  VCVTPD2DQZ128rrk = 6414,
  VCVTPD2DQZ128rrkz = 6415,
  VCVTPD2DQZ256rm = 6416,
  VCVTPD2DQZ256rmb = 6417,
  VCVTPD2DQZ256rmbk = 6418,
  VCVTPD2DQZ256rmbkz = 6419,
  VCVTPD2DQZ256rmk = 6420,
  VCVTPD2DQZ256rmkz = 6421,
  VCVTPD2DQZ256rr = 6422,
  VCVTPD2DQZ256rrb = 6423,
  VCVTPD2DQZ256rrbk = 6424,
  VCVTPD2DQZ256rrbkz = 6425,
  VCVTPD2DQZ256rrk = 6426,
  VCVTPD2DQZ256rrkz = 6427,
  VCVTPD2DQZrm = 6428,
  VCVTPD2DQZrmb = 6429,
  VCVTPD2DQZrmbk = 6430,
  VCVTPD2DQZrmbkz = 6431,
  VCVTPD2DQZrmk = 6432,
  VCVTPD2DQZrmkz = 6433,
  VCVTPD2DQZrr = 6434,
  VCVTPD2DQZrrb = 6435,
  VCVTPD2DQZrrbk = 6436,
  VCVTPD2DQZrrbkz = 6437,
  VCVTPD2DQZrrk = 6438,
  VCVTPD2DQZrrkz = 6439,
  VCVTPD2DQrm = 6440,
  VCVTPD2DQrr = 6441,
  VCVTPD2PHZ128rm = 6442,
  VCVTPD2PHZ128rmb = 6443,
  VCVTPD2PHZ128rmbk = 6444,
  VCVTPD2PHZ128rmbkz = 6445,
  VCVTPD2PHZ128rmk = 6446,
  VCVTPD2PHZ128rmkz = 6447,
  VCVTPD2PHZ128rr = 6448,
  VCVTPD2PHZ128rrk = 6449,
  VCVTPD2PHZ128rrkz = 6450,
  VCVTPD2PHZ256rm = 6451,
  VCVTPD2PHZ256rmb = 6452,
  VCVTPD2PHZ256rmbk = 6453,
  VCVTPD2PHZ256rmbkz = 6454,
  VCVTPD2PHZ256rmk = 6455,
  VCVTPD2PHZ256rmkz = 6456,
  VCVTPD2PHZ256rr = 6457,
  VCVTPD2PHZ256rrb = 6458,
  VCVTPD2PHZ256rrbk = 6459,
  VCVTPD2PHZ256rrbkz = 6460,
  VCVTPD2PHZ256rrk = 6461,
  VCVTPD2PHZ256rrkz = 6462,
  VCVTPD2PHZrm = 6463,
  VCVTPD2PHZrmb = 6464,
  VCVTPD2PHZrmbk = 6465,
  VCVTPD2PHZrmbkz = 6466,
  VCVTPD2PHZrmk = 6467,
  VCVTPD2PHZrmkz = 6468,
  VCVTPD2PHZrr = 6469,
  VCVTPD2PHZrrb = 6470,
  VCVTPD2PHZrrbk = 6471,
  VCVTPD2PHZrrbkz = 6472,
  VCVTPD2PHZrrk = 6473,
  VCVTPD2PHZrrkz = 6474,
  VCVTPD2PSYrm = 6475,
  VCVTPD2PSYrr = 6476,
  VCVTPD2PSZ128rm = 6477,
  VCVTPD2PSZ128rmb = 6478,
  VCVTPD2PSZ128rmbk = 6479,
  VCVTPD2PSZ128rmbkz = 6480,
  VCVTPD2PSZ128rmk = 6481,
  VCVTPD2PSZ128rmkz = 6482,
  VCVTPD2PSZ128rr = 6483,
  VCVTPD2PSZ128rrk = 6484,
  VCVTPD2PSZ128rrkz = 6485,
  VCVTPD2PSZ256rm = 6486,
  VCVTPD2PSZ256rmb = 6487,
  VCVTPD2PSZ256rmbk = 6488,
  VCVTPD2PSZ256rmbkz = 6489,
  VCVTPD2PSZ256rmk = 6490,
  VCVTPD2PSZ256rmkz = 6491,
  VCVTPD2PSZ256rr = 6492,
  VCVTPD2PSZ256rrb = 6493,
  VCVTPD2PSZ256rrbk = 6494,
  VCVTPD2PSZ256rrbkz = 6495,
  VCVTPD2PSZ256rrk = 6496,
  VCVTPD2PSZ256rrkz = 6497,
  VCVTPD2PSZrm = 6498,
  VCVTPD2PSZrmb = 6499,
  VCVTPD2PSZrmbk = 6500,
  VCVTPD2PSZrmbkz = 6501,
  VCVTPD2PSZrmk = 6502,
  VCVTPD2PSZrmkz = 6503,
  VCVTPD2PSZrr = 6504,
  VCVTPD2PSZrrb = 6505,
  VCVTPD2PSZrrbk = 6506,
  VCVTPD2PSZrrbkz = 6507,
  VCVTPD2PSZrrk = 6508,
  VCVTPD2PSZrrkz = 6509,
  VCVTPD2PSrm = 6510,
  VCVTPD2PSrr = 6511,
  VCVTPD2QQZ128rm = 6512,
  VCVTPD2QQZ128rmb = 6513,
  VCVTPD2QQZ128rmbk = 6514,
  VCVTPD2QQZ128rmbkz = 6515,
  VCVTPD2QQZ128rmk = 6516,
  VCVTPD2QQZ128rmkz = 6517,
  VCVTPD2QQZ128rr = 6518,
  VCVTPD2QQZ128rrk = 6519,
  VCVTPD2QQZ128rrkz = 6520,
  VCVTPD2QQZ256rm = 6521,
  VCVTPD2QQZ256rmb = 6522,
  VCVTPD2QQZ256rmbk = 6523,
  VCVTPD2QQZ256rmbkz = 6524,
  VCVTPD2QQZ256rmk = 6525,
  VCVTPD2QQZ256rmkz = 6526,
  VCVTPD2QQZ256rr = 6527,
  VCVTPD2QQZ256rrb = 6528,
  VCVTPD2QQZ256rrbk = 6529,
  VCVTPD2QQZ256rrbkz = 6530,
  VCVTPD2QQZ256rrk = 6531,
  VCVTPD2QQZ256rrkz = 6532,
  VCVTPD2QQZrm = 6533,
  VCVTPD2QQZrmb = 6534,
  VCVTPD2QQZrmbk = 6535,
  VCVTPD2QQZrmbkz = 6536,
  VCVTPD2QQZrmk = 6537,
  VCVTPD2QQZrmkz = 6538,
  VCVTPD2QQZrr = 6539,
  VCVTPD2QQZrrb = 6540,
  VCVTPD2QQZrrbk = 6541,
  VCVTPD2QQZrrbkz = 6542,
  VCVTPD2QQZrrk = 6543,
  VCVTPD2QQZrrkz = 6544,
  VCVTPD2UDQZ128rm = 6545,
  VCVTPD2UDQZ128rmb = 6546,
  VCVTPD2UDQZ128rmbk = 6547,
  VCVTPD2UDQZ128rmbkz = 6548,
  VCVTPD2UDQZ128rmk = 6549,
  VCVTPD2UDQZ128rmkz = 6550,
  VCVTPD2UDQZ128rr = 6551,
  VCVTPD2UDQZ128rrk = 6552,
  VCVTPD2UDQZ128rrkz = 6553,
  VCVTPD2UDQZ256rm = 6554,
  VCVTPD2UDQZ256rmb = 6555,
  VCVTPD2UDQZ256rmbk = 6556,
  VCVTPD2UDQZ256rmbkz = 6557,
  VCVTPD2UDQZ256rmk = 6558,
  VCVTPD2UDQZ256rmkz = 6559,
  VCVTPD2UDQZ256rr = 6560,
  VCVTPD2UDQZ256rrb = 6561,
  VCVTPD2UDQZ256rrbk = 6562,
  VCVTPD2UDQZ256rrbkz = 6563,
  VCVTPD2UDQZ256rrk = 6564,
  VCVTPD2UDQZ256rrkz = 6565,
  VCVTPD2UDQZrm = 6566,
  VCVTPD2UDQZrmb = 6567,
  VCVTPD2UDQZrmbk = 6568,
  VCVTPD2UDQZrmbkz = 6569,
  VCVTPD2UDQZrmk = 6570,
  VCVTPD2UDQZrmkz = 6571,
  VCVTPD2UDQZrr = 6572,
  VCVTPD2UDQZrrb = 6573,
  VCVTPD2UDQZrrbk = 6574,
  VCVTPD2UDQZrrbkz = 6575,
  VCVTPD2UDQZrrk = 6576,
  VCVTPD2UDQZrrkz = 6577,
  VCVTPD2UQQZ128rm = 6578,
  VCVTPD2UQQZ128rmb = 6579,
  VCVTPD2UQQZ128rmbk = 6580,
  VCVTPD2UQQZ128rmbkz = 6581,
  VCVTPD2UQQZ128rmk = 6582,
  VCVTPD2UQQZ128rmkz = 6583,
  VCVTPD2UQQZ128rr = 6584,
  VCVTPD2UQQZ128rrk = 6585,
  VCVTPD2UQQZ128rrkz = 6586,
  VCVTPD2UQQZ256rm = 6587,
  VCVTPD2UQQZ256rmb = 6588,
  VCVTPD2UQQZ256rmbk = 6589,
  VCVTPD2UQQZ256rmbkz = 6590,
  VCVTPD2UQQZ256rmk = 6591,
  VCVTPD2UQQZ256rmkz = 6592,
  VCVTPD2UQQZ256rr = 6593,
  VCVTPD2UQQZ256rrb = 6594,
  VCVTPD2UQQZ256rrbk = 6595,
  VCVTPD2UQQZ256rrbkz = 6596,
  VCVTPD2UQQZ256rrk = 6597,
  VCVTPD2UQQZ256rrkz = 6598,
  VCVTPD2UQQZrm = 6599,
  VCVTPD2UQQZrmb = 6600,
  VCVTPD2UQQZrmbk = 6601,
  VCVTPD2UQQZrmbkz = 6602,
  VCVTPD2UQQZrmk = 6603,
  VCVTPD2UQQZrmkz = 6604,
  VCVTPD2UQQZrr = 6605,
  VCVTPD2UQQZrrb = 6606,
  VCVTPD2UQQZrrbk = 6607,
  VCVTPD2UQQZrrbkz = 6608,
  VCVTPD2UQQZrrk = 6609,
  VCVTPD2UQQZrrkz = 6610,
  VCVTPH2BF8SZ128rm = 6611,
  VCVTPH2BF8SZ128rmb = 6612,
  VCVTPH2BF8SZ128rmbk = 6613,
  VCVTPH2BF8SZ128rmbkz = 6614,
  VCVTPH2BF8SZ128rmk = 6615,
  VCVTPH2BF8SZ128rmkz = 6616,
  VCVTPH2BF8SZ128rr = 6617,
  VCVTPH2BF8SZ128rrk = 6618,
  VCVTPH2BF8SZ128rrkz = 6619,
  VCVTPH2BF8SZ256rm = 6620,
  VCVTPH2BF8SZ256rmb = 6621,
  VCVTPH2BF8SZ256rmbk = 6622,
  VCVTPH2BF8SZ256rmbkz = 6623,
  VCVTPH2BF8SZ256rmk = 6624,
  VCVTPH2BF8SZ256rmkz = 6625,
  VCVTPH2BF8SZ256rr = 6626,
  VCVTPH2BF8SZ256rrk = 6627,
  VCVTPH2BF8SZ256rrkz = 6628,
  VCVTPH2BF8SZrm = 6629,
  VCVTPH2BF8SZrmb = 6630,
  VCVTPH2BF8SZrmbk = 6631,
  VCVTPH2BF8SZrmbkz = 6632,
  VCVTPH2BF8SZrmk = 6633,
  VCVTPH2BF8SZrmkz = 6634,
  VCVTPH2BF8SZrr = 6635,
  VCVTPH2BF8SZrrk = 6636,
  VCVTPH2BF8SZrrkz = 6637,
  VCVTPH2BF8Z128rm = 6638,
  VCVTPH2BF8Z128rmb = 6639,
  VCVTPH2BF8Z128rmbk = 6640,
  VCVTPH2BF8Z128rmbkz = 6641,
  VCVTPH2BF8Z128rmk = 6642,
  VCVTPH2BF8Z128rmkz = 6643,
  VCVTPH2BF8Z128rr = 6644,
  VCVTPH2BF8Z128rrk = 6645,
  VCVTPH2BF8Z128rrkz = 6646,
  VCVTPH2BF8Z256rm = 6647,
  VCVTPH2BF8Z256rmb = 6648,
  VCVTPH2BF8Z256rmbk = 6649,
  VCVTPH2BF8Z256rmbkz = 6650,
  VCVTPH2BF8Z256rmk = 6651,
  VCVTPH2BF8Z256rmkz = 6652,
  VCVTPH2BF8Z256rr = 6653,
  VCVTPH2BF8Z256rrk = 6654,
  VCVTPH2BF8Z256rrkz = 6655,
  VCVTPH2BF8Zrm = 6656,
  VCVTPH2BF8Zrmb = 6657,
  VCVTPH2BF8Zrmbk = 6658,
  VCVTPH2BF8Zrmbkz = 6659,
  VCVTPH2BF8Zrmk = 6660,
  VCVTPH2BF8Zrmkz = 6661,
  VCVTPH2BF8Zrr = 6662,
  VCVTPH2BF8Zrrk = 6663,
  VCVTPH2BF8Zrrkz = 6664,
  VCVTPH2DQZ128rm = 6665,
  VCVTPH2DQZ128rmb = 6666,
  VCVTPH2DQZ128rmbk = 6667,
  VCVTPH2DQZ128rmbkz = 6668,
  VCVTPH2DQZ128rmk = 6669,
  VCVTPH2DQZ128rmkz = 6670,
  VCVTPH2DQZ128rr = 6671,
  VCVTPH2DQZ128rrk = 6672,
  VCVTPH2DQZ128rrkz = 6673,
  VCVTPH2DQZ256rm = 6674,
  VCVTPH2DQZ256rmb = 6675,
  VCVTPH2DQZ256rmbk = 6676,
  VCVTPH2DQZ256rmbkz = 6677,
  VCVTPH2DQZ256rmk = 6678,
  VCVTPH2DQZ256rmkz = 6679,
  VCVTPH2DQZ256rr = 6680,
  VCVTPH2DQZ256rrb = 6681,
  VCVTPH2DQZ256rrbk = 6682,
  VCVTPH2DQZ256rrbkz = 6683,
  VCVTPH2DQZ256rrk = 6684,
  VCVTPH2DQZ256rrkz = 6685,
  VCVTPH2DQZrm = 6686,
  VCVTPH2DQZrmb = 6687,
  VCVTPH2DQZrmbk = 6688,
  VCVTPH2DQZrmbkz = 6689,
  VCVTPH2DQZrmk = 6690,
  VCVTPH2DQZrmkz = 6691,
  VCVTPH2DQZrr = 6692,
  VCVTPH2DQZrrb = 6693,
  VCVTPH2DQZrrbk = 6694,
  VCVTPH2DQZrrbkz = 6695,
  VCVTPH2DQZrrk = 6696,
  VCVTPH2DQZrrkz = 6697,
  VCVTPH2HF8SZ128rm = 6698,
  VCVTPH2HF8SZ128rmb = 6699,
  VCVTPH2HF8SZ128rmbk = 6700,
  VCVTPH2HF8SZ128rmbkz = 6701,
  VCVTPH2HF8SZ128rmk = 6702,
  VCVTPH2HF8SZ128rmkz = 6703,
  VCVTPH2HF8SZ128rr = 6704,
  VCVTPH2HF8SZ128rrk = 6705,
  VCVTPH2HF8SZ128rrkz = 6706,
  VCVTPH2HF8SZ256rm = 6707,
  VCVTPH2HF8SZ256rmb = 6708,
  VCVTPH2HF8SZ256rmbk = 6709,
  VCVTPH2HF8SZ256rmbkz = 6710,
  VCVTPH2HF8SZ256rmk = 6711,
  VCVTPH2HF8SZ256rmkz = 6712,
  VCVTPH2HF8SZ256rr = 6713,
  VCVTPH2HF8SZ256rrk = 6714,
  VCVTPH2HF8SZ256rrkz = 6715,
  VCVTPH2HF8SZrm = 6716,
  VCVTPH2HF8SZrmb = 6717,
  VCVTPH2HF8SZrmbk = 6718,
  VCVTPH2HF8SZrmbkz = 6719,
  VCVTPH2HF8SZrmk = 6720,
  VCVTPH2HF8SZrmkz = 6721,
  VCVTPH2HF8SZrr = 6722,
  VCVTPH2HF8SZrrk = 6723,
  VCVTPH2HF8SZrrkz = 6724,
  VCVTPH2HF8Z128rm = 6725,
  VCVTPH2HF8Z128rmb = 6726,
  VCVTPH2HF8Z128rmbk = 6727,
  VCVTPH2HF8Z128rmbkz = 6728,
  VCVTPH2HF8Z128rmk = 6729,
  VCVTPH2HF8Z128rmkz = 6730,
  VCVTPH2HF8Z128rr = 6731,
  VCVTPH2HF8Z128rrk = 6732,
  VCVTPH2HF8Z128rrkz = 6733,
  VCVTPH2HF8Z256rm = 6734,
  VCVTPH2HF8Z256rmb = 6735,
  VCVTPH2HF8Z256rmbk = 6736,
  VCVTPH2HF8Z256rmbkz = 6737,
  VCVTPH2HF8Z256rmk = 6738,
  VCVTPH2HF8Z256rmkz = 6739,
  VCVTPH2HF8Z256rr = 6740,
  VCVTPH2HF8Z256rrk = 6741,
  VCVTPH2HF8Z256rrkz = 6742,
  VCVTPH2HF8Zrm = 6743,
  VCVTPH2HF8Zrmb = 6744,
  VCVTPH2HF8Zrmbk = 6745,
  VCVTPH2HF8Zrmbkz = 6746,
  VCVTPH2HF8Zrmk = 6747,
  VCVTPH2HF8Zrmkz = 6748,
  VCVTPH2HF8Zrr = 6749,
  VCVTPH2HF8Zrrk = 6750,
  VCVTPH2HF8Zrrkz = 6751,
  VCVTPH2IBSZ128rm = 6752,
  VCVTPH2IBSZ128rmb = 6753,
  VCVTPH2IBSZ128rmbk = 6754,
  VCVTPH2IBSZ128rmbkz = 6755,
  VCVTPH2IBSZ128rmk = 6756,
  VCVTPH2IBSZ128rmkz = 6757,
  VCVTPH2IBSZ128rr = 6758,
  VCVTPH2IBSZ128rrk = 6759,
  VCVTPH2IBSZ128rrkz = 6760,
  VCVTPH2IBSZ256rm = 6761,
  VCVTPH2IBSZ256rmb = 6762,
  VCVTPH2IBSZ256rmbk = 6763,
  VCVTPH2IBSZ256rmbkz = 6764,
  VCVTPH2IBSZ256rmk = 6765,
  VCVTPH2IBSZ256rmkz = 6766,
  VCVTPH2IBSZ256rr = 6767,
  VCVTPH2IBSZ256rrb = 6768,
  VCVTPH2IBSZ256rrbk = 6769,
  VCVTPH2IBSZ256rrbkz = 6770,
  VCVTPH2IBSZ256rrk = 6771,
  VCVTPH2IBSZ256rrkz = 6772,
  VCVTPH2IBSZrm = 6773,
  VCVTPH2IBSZrmb = 6774,
  VCVTPH2IBSZrmbk = 6775,
  VCVTPH2IBSZrmbkz = 6776,
  VCVTPH2IBSZrmk = 6777,
  VCVTPH2IBSZrmkz = 6778,
  VCVTPH2IBSZrr = 6779,
  VCVTPH2IBSZrrb = 6780,
  VCVTPH2IBSZrrbk = 6781,
  VCVTPH2IBSZrrbkz = 6782,
  VCVTPH2IBSZrrk = 6783,
  VCVTPH2IBSZrrkz = 6784,
  VCVTPH2IUBSZ128rm = 6785,
  VCVTPH2IUBSZ128rmb = 6786,
  VCVTPH2IUBSZ128rmbk = 6787,
  VCVTPH2IUBSZ128rmbkz = 6788,
  VCVTPH2IUBSZ128rmk = 6789,
  VCVTPH2IUBSZ128rmkz = 6790,
  VCVTPH2IUBSZ128rr = 6791,
  VCVTPH2IUBSZ128rrk = 6792,
  VCVTPH2IUBSZ128rrkz = 6793,
  VCVTPH2IUBSZ256rm = 6794,
  VCVTPH2IUBSZ256rmb = 6795,
  VCVTPH2IUBSZ256rmbk = 6796,
  VCVTPH2IUBSZ256rmbkz = 6797,
  VCVTPH2IUBSZ256rmk = 6798,
  VCVTPH2IUBSZ256rmkz = 6799,
  VCVTPH2IUBSZ256rr = 6800,
  VCVTPH2IUBSZ256rrb = 6801,
  VCVTPH2IUBSZ256rrbk = 6802,
  VCVTPH2IUBSZ256rrbkz = 6803,
  VCVTPH2IUBSZ256rrk = 6804,
  VCVTPH2IUBSZ256rrkz = 6805,
  VCVTPH2IUBSZrm = 6806,
  VCVTPH2IUBSZrmb = 6807,
  VCVTPH2IUBSZrmbk = 6808,
  VCVTPH2IUBSZrmbkz = 6809,
  VCVTPH2IUBSZrmk = 6810,
  VCVTPH2IUBSZrmkz = 6811,
  VCVTPH2IUBSZrr = 6812,
  VCVTPH2IUBSZrrb = 6813,
  VCVTPH2IUBSZrrbk = 6814,
  VCVTPH2IUBSZrrbkz = 6815,
  VCVTPH2IUBSZrrk = 6816,
  VCVTPH2IUBSZrrkz = 6817,
  VCVTPH2PDZ128rm = 6818,
  VCVTPH2PDZ128rmb = 6819,
  VCVTPH2PDZ128rmbk = 6820,
  VCVTPH2PDZ128rmbkz = 6821,
  VCVTPH2PDZ128rmk = 6822,
  VCVTPH2PDZ128rmkz = 6823,
  VCVTPH2PDZ128rr = 6824,
  VCVTPH2PDZ128rrk = 6825,
  VCVTPH2PDZ128rrkz = 6826,
  VCVTPH2PDZ256rm = 6827,
  VCVTPH2PDZ256rmb = 6828,
  VCVTPH2PDZ256rmbk = 6829,
  VCVTPH2PDZ256rmbkz = 6830,
  VCVTPH2PDZ256rmk = 6831,
  VCVTPH2PDZ256rmkz = 6832,
  VCVTPH2PDZ256rr = 6833,
  VCVTPH2PDZ256rrb = 6834,
  VCVTPH2PDZ256rrbk = 6835,
  VCVTPH2PDZ256rrbkz = 6836,
  VCVTPH2PDZ256rrk = 6837,
  VCVTPH2PDZ256rrkz = 6838,
  VCVTPH2PDZrm = 6839,
  VCVTPH2PDZrmb = 6840,
  VCVTPH2PDZrmbk = 6841,
  VCVTPH2PDZrmbkz = 6842,
  VCVTPH2PDZrmk = 6843,
  VCVTPH2PDZrmkz = 6844,
  VCVTPH2PDZrr = 6845,
  VCVTPH2PDZrrb = 6846,
  VCVTPH2PDZrrbk = 6847,
  VCVTPH2PDZrrbkz = 6848,
  VCVTPH2PDZrrk = 6849,
  VCVTPH2PDZrrkz = 6850,
  VCVTPH2PSXZ128rm = 6851,
  VCVTPH2PSXZ128rmb = 6852,
  VCVTPH2PSXZ128rmbk = 6853,
  VCVTPH2PSXZ128rmbkz = 6854,
  VCVTPH2PSXZ128rmk = 6855,
  VCVTPH2PSXZ128rmkz = 6856,
  VCVTPH2PSXZ128rr = 6857,
  VCVTPH2PSXZ128rrk = 6858,
  VCVTPH2PSXZ128rrkz = 6859,
  VCVTPH2PSXZ256rm = 6860,
  VCVTPH2PSXZ256rmb = 6861,
  VCVTPH2PSXZ256rmbk = 6862,
  VCVTPH2PSXZ256rmbkz = 6863,
  VCVTPH2PSXZ256rmk = 6864,
  VCVTPH2PSXZ256rmkz = 6865,
  VCVTPH2PSXZ256rr = 6866,
  VCVTPH2PSXZ256rrb = 6867,
  VCVTPH2PSXZ256rrbk = 6868,
  VCVTPH2PSXZ256rrbkz = 6869,
  VCVTPH2PSXZ256rrk = 6870,
  VCVTPH2PSXZ256rrkz = 6871,
  VCVTPH2PSXZrm = 6872,
  VCVTPH2PSXZrmb = 6873,
  VCVTPH2PSXZrmbk = 6874,
  VCVTPH2PSXZrmbkz = 6875,
  VCVTPH2PSXZrmk = 6876,
  VCVTPH2PSXZrmkz = 6877,
  VCVTPH2PSXZrr = 6878,
  VCVTPH2PSXZrrb = 6879,
  VCVTPH2PSXZrrbk = 6880,
  VCVTPH2PSXZrrbkz = 6881,
  VCVTPH2PSXZrrk = 6882,
  VCVTPH2PSXZrrkz = 6883,
  VCVTPH2PSYrm = 6884,
  VCVTPH2PSYrr = 6885,
  VCVTPH2PSZ128rm = 6886,
  VCVTPH2PSZ128rmk = 6887,
  VCVTPH2PSZ128rmkz = 6888,
  VCVTPH2PSZ128rr = 6889,
  VCVTPH2PSZ128rrk = 6890,
  VCVTPH2PSZ128rrkz = 6891,
  VCVTPH2PSZ256rm = 6892,
  VCVTPH2PSZ256rmk = 6893,
  VCVTPH2PSZ256rmkz = 6894,
  VCVTPH2PSZ256rr = 6895,
  VCVTPH2PSZ256rrb = 6896,
  VCVTPH2PSZ256rrbk = 6897,
  VCVTPH2PSZ256rrbkz = 6898,
  VCVTPH2PSZ256rrk = 6899,
  VCVTPH2PSZ256rrkz = 6900,
  VCVTPH2PSZrm = 6901,
  VCVTPH2PSZrmk = 6902,
  VCVTPH2PSZrmkz = 6903,
  VCVTPH2PSZrr = 6904,
  VCVTPH2PSZrrb = 6905,
  VCVTPH2PSZrrbk = 6906,
  VCVTPH2PSZrrbkz = 6907,
  VCVTPH2PSZrrk = 6908,
  VCVTPH2PSZrrkz = 6909,
  VCVTPH2PSrm = 6910,
  VCVTPH2PSrr = 6911,
  VCVTPH2QQZ128rm = 6912,
  VCVTPH2QQZ128rmb = 6913,
  VCVTPH2QQZ128rmbk = 6914,
  VCVTPH2QQZ128rmbkz = 6915,
  VCVTPH2QQZ128rmk = 6916,
  VCVTPH2QQZ128rmkz = 6917,
  VCVTPH2QQZ128rr = 6918,
  VCVTPH2QQZ128rrk = 6919,
  VCVTPH2QQZ128rrkz = 6920,
  VCVTPH2QQZ256rm = 6921,
  VCVTPH2QQZ256rmb = 6922,
  VCVTPH2QQZ256rmbk = 6923,
  VCVTPH2QQZ256rmbkz = 6924,
  VCVTPH2QQZ256rmk = 6925,
  VCVTPH2QQZ256rmkz = 6926,
  VCVTPH2QQZ256rr = 6927,
  VCVTPH2QQZ256rrb = 6928,
  VCVTPH2QQZ256rrbk = 6929,
  VCVTPH2QQZ256rrbkz = 6930,
  VCVTPH2QQZ256rrk = 6931,
  VCVTPH2QQZ256rrkz = 6932,
  VCVTPH2QQZrm = 6933,
  VCVTPH2QQZrmb = 6934,
  VCVTPH2QQZrmbk = 6935,
  VCVTPH2QQZrmbkz = 6936,
  VCVTPH2QQZrmk = 6937,
  VCVTPH2QQZrmkz = 6938,
  VCVTPH2QQZrr = 6939,
  VCVTPH2QQZrrb = 6940,
  VCVTPH2QQZrrbk = 6941,
  VCVTPH2QQZrrbkz = 6942,
  VCVTPH2QQZrrk = 6943,
  VCVTPH2QQZrrkz = 6944,
  VCVTPH2UDQZ128rm = 6945,
  VCVTPH2UDQZ128rmb = 6946,
  VCVTPH2UDQZ128rmbk = 6947,
  VCVTPH2UDQZ128rmbkz = 6948,
  VCVTPH2UDQZ128rmk = 6949,
  VCVTPH2UDQZ128rmkz = 6950,
  VCVTPH2UDQZ128rr = 6951,
  VCVTPH2UDQZ128rrk = 6952,
  VCVTPH2UDQZ128rrkz = 6953,
  VCVTPH2UDQZ256rm = 6954,
  VCVTPH2UDQZ256rmb = 6955,
  VCVTPH2UDQZ256rmbk = 6956,
  VCVTPH2UDQZ256rmbkz = 6957,
  VCVTPH2UDQZ256rmk = 6958,
  VCVTPH2UDQZ256rmkz = 6959,
  VCVTPH2UDQZ256rr = 6960,
  VCVTPH2UDQZ256rrb = 6961,
  VCVTPH2UDQZ256rrbk = 6962,
  VCVTPH2UDQZ256rrbkz = 6963,
  VCVTPH2UDQZ256rrk = 6964,
  VCVTPH2UDQZ256rrkz = 6965,
  VCVTPH2UDQZrm = 6966,
  VCVTPH2UDQZrmb = 6967,
  VCVTPH2UDQZrmbk = 6968,
  VCVTPH2UDQZrmbkz = 6969,
  VCVTPH2UDQZrmk = 6970,
  VCVTPH2UDQZrmkz = 6971,
  VCVTPH2UDQZrr = 6972,
  VCVTPH2UDQZrrb = 6973,
  VCVTPH2UDQZrrbk = 6974,
  VCVTPH2UDQZrrbkz = 6975,
  VCVTPH2UDQZrrk = 6976,
  VCVTPH2UDQZrrkz = 6977,
  VCVTPH2UQQZ128rm = 6978,
  VCVTPH2UQQZ128rmb = 6979,
  VCVTPH2UQQZ128rmbk = 6980,
  VCVTPH2UQQZ128rmbkz = 6981,
  VCVTPH2UQQZ128rmk = 6982,
  VCVTPH2UQQZ128rmkz = 6983,
  VCVTPH2UQQZ128rr = 6984,
  VCVTPH2UQQZ128rrk = 6985,
  VCVTPH2UQQZ128rrkz = 6986,
  VCVTPH2UQQZ256rm = 6987,
  VCVTPH2UQQZ256rmb = 6988,
  VCVTPH2UQQZ256rmbk = 6989,
  VCVTPH2UQQZ256rmbkz = 6990,
  VCVTPH2UQQZ256rmk = 6991,
  VCVTPH2UQQZ256rmkz = 6992,
  VCVTPH2UQQZ256rr = 6993,
  VCVTPH2UQQZ256rrb = 6994,
  VCVTPH2UQQZ256rrbk = 6995,
  VCVTPH2UQQZ256rrbkz = 6996,
  VCVTPH2UQQZ256rrk = 6997,
  VCVTPH2UQQZ256rrkz = 6998,
  VCVTPH2UQQZrm = 6999,
  VCVTPH2UQQZrmb = 7000,
  VCVTPH2UQQZrmbk = 7001,
  VCVTPH2UQQZrmbkz = 7002,
  VCVTPH2UQQZrmk = 7003,
  VCVTPH2UQQZrmkz = 7004,
  VCVTPH2UQQZrr = 7005,
  VCVTPH2UQQZrrb = 7006,
  VCVTPH2UQQZrrbk = 7007,
  VCVTPH2UQQZrrbkz = 7008,
  VCVTPH2UQQZrrk = 7009,
  VCVTPH2UQQZrrkz = 7010,
  VCVTPH2UWZ128rm = 7011,
  VCVTPH2UWZ128rmb = 7012,
  VCVTPH2UWZ128rmbk = 7013,
  VCVTPH2UWZ128rmbkz = 7014,
  VCVTPH2UWZ128rmk = 7015,
  VCVTPH2UWZ128rmkz = 7016,
  VCVTPH2UWZ128rr = 7017,
  VCVTPH2UWZ128rrk = 7018,
  VCVTPH2UWZ128rrkz = 7019,
  VCVTPH2UWZ256rm = 7020,
  VCVTPH2UWZ256rmb = 7021,
  VCVTPH2UWZ256rmbk = 7022,
  VCVTPH2UWZ256rmbkz = 7023,
  VCVTPH2UWZ256rmk = 7024,
  VCVTPH2UWZ256rmkz = 7025,
  VCVTPH2UWZ256rr = 7026,
  VCVTPH2UWZ256rrb = 7027,
  VCVTPH2UWZ256rrbk = 7028,
  VCVTPH2UWZ256rrbkz = 7029,
  VCVTPH2UWZ256rrk = 7030,
  VCVTPH2UWZ256rrkz = 7031,
  VCVTPH2UWZrm = 7032,
  VCVTPH2UWZrmb = 7033,
  VCVTPH2UWZrmbk = 7034,
  VCVTPH2UWZrmbkz = 7035,
  VCVTPH2UWZrmk = 7036,
  VCVTPH2UWZrmkz = 7037,
  VCVTPH2UWZrr = 7038,
  VCVTPH2UWZrrb = 7039,
  VCVTPH2UWZrrbk = 7040,
  VCVTPH2UWZrrbkz = 7041,
  VCVTPH2UWZrrk = 7042,
  VCVTPH2UWZrrkz = 7043,
  VCVTPH2WZ128rm = 7044,
  VCVTPH2WZ128rmb = 7045,
  VCVTPH2WZ128rmbk = 7046,
  VCVTPH2WZ128rmbkz = 7047,
  VCVTPH2WZ128rmk = 7048,
  VCVTPH2WZ128rmkz = 7049,
  VCVTPH2WZ128rr = 7050,
  VCVTPH2WZ128rrk = 7051,
  VCVTPH2WZ128rrkz = 7052,
  VCVTPH2WZ256rm = 7053,
  VCVTPH2WZ256rmb = 7054,
  VCVTPH2WZ256rmbk = 7055,
  VCVTPH2WZ256rmbkz = 7056,
  VCVTPH2WZ256rmk = 7057,
  VCVTPH2WZ256rmkz = 7058,
  VCVTPH2WZ256rr = 7059,
  VCVTPH2WZ256rrb = 7060,
  VCVTPH2WZ256rrbk = 7061,
  VCVTPH2WZ256rrbkz = 7062,
  VCVTPH2WZ256rrk = 7063,
  VCVTPH2WZ256rrkz = 7064,
  VCVTPH2WZrm = 7065,
  VCVTPH2WZrmb = 7066,
  VCVTPH2WZrmbk = 7067,
  VCVTPH2WZrmbkz = 7068,
  VCVTPH2WZrmk = 7069,
  VCVTPH2WZrmkz = 7070,
  VCVTPH2WZrr = 7071,
  VCVTPH2WZrrb = 7072,
  VCVTPH2WZrrbk = 7073,
  VCVTPH2WZrrbkz = 7074,
  VCVTPH2WZrrk = 7075,
  VCVTPH2WZrrkz = 7076,
  VCVTPS2DQYrm = 7077,
  VCVTPS2DQYrr = 7078,
  VCVTPS2DQZ128rm = 7079,
  VCVTPS2DQZ128rmb = 7080,
  VCVTPS2DQZ128rmbk = 7081,
  VCVTPS2DQZ128rmbkz = 7082,
  VCVTPS2DQZ128rmk = 7083,
  VCVTPS2DQZ128rmkz = 7084,
  VCVTPS2DQZ128rr = 7085,
  VCVTPS2DQZ128rrk = 7086,
  VCVTPS2DQZ128rrkz = 7087,
  VCVTPS2DQZ256rm = 7088,
  VCVTPS2DQZ256rmb = 7089,
  VCVTPS2DQZ256rmbk = 7090,
  VCVTPS2DQZ256rmbkz = 7091,
  VCVTPS2DQZ256rmk = 7092,
  VCVTPS2DQZ256rmkz = 7093,
  VCVTPS2DQZ256rr = 7094,
  VCVTPS2DQZ256rrb = 7095,
  VCVTPS2DQZ256rrbk = 7096,
  VCVTPS2DQZ256rrbkz = 7097,
  VCVTPS2DQZ256rrk = 7098,
  VCVTPS2DQZ256rrkz = 7099,
  VCVTPS2DQZrm = 7100,
  VCVTPS2DQZrmb = 7101,
  VCVTPS2DQZrmbk = 7102,
  VCVTPS2DQZrmbkz = 7103,
  VCVTPS2DQZrmk = 7104,
  VCVTPS2DQZrmkz = 7105,
  VCVTPS2DQZrr = 7106,
  VCVTPS2DQZrrb = 7107,
  VCVTPS2DQZrrbk = 7108,
  VCVTPS2DQZrrbkz = 7109,
  VCVTPS2DQZrrk = 7110,
  VCVTPS2DQZrrkz = 7111,
  VCVTPS2DQrm = 7112,
  VCVTPS2DQrr = 7113,
  VCVTPS2IBSZ128rm = 7114,
  VCVTPS2IBSZ128rmb = 7115,
  VCVTPS2IBSZ128rmbk = 7116,
  VCVTPS2IBSZ128rmbkz = 7117,
  VCVTPS2IBSZ128rmk = 7118,
  VCVTPS2IBSZ128rmkz = 7119,
  VCVTPS2IBSZ128rr = 7120,
  VCVTPS2IBSZ128rrk = 7121,
  VCVTPS2IBSZ128rrkz = 7122,
  VCVTPS2IBSZ256rm = 7123,
  VCVTPS2IBSZ256rmb = 7124,
  VCVTPS2IBSZ256rmbk = 7125,
  VCVTPS2IBSZ256rmbkz = 7126,
  VCVTPS2IBSZ256rmk = 7127,
  VCVTPS2IBSZ256rmkz = 7128,
  VCVTPS2IBSZ256rr = 7129,
  VCVTPS2IBSZ256rrb = 7130,
  VCVTPS2IBSZ256rrbk = 7131,
  VCVTPS2IBSZ256rrbkz = 7132,
  VCVTPS2IBSZ256rrk = 7133,
  VCVTPS2IBSZ256rrkz = 7134,
  VCVTPS2IBSZrm = 7135,
  VCVTPS2IBSZrmb = 7136,
  VCVTPS2IBSZrmbk = 7137,
  VCVTPS2IBSZrmbkz = 7138,
  VCVTPS2IBSZrmk = 7139,
  VCVTPS2IBSZrmkz = 7140,
  VCVTPS2IBSZrr = 7141,
  VCVTPS2IBSZrrb = 7142,
  VCVTPS2IBSZrrbk = 7143,
  VCVTPS2IBSZrrbkz = 7144,
  VCVTPS2IBSZrrk = 7145,
  VCVTPS2IBSZrrkz = 7146,
  VCVTPS2IUBSZ128rm = 7147,
  VCVTPS2IUBSZ128rmb = 7148,
  VCVTPS2IUBSZ128rmbk = 7149,
  VCVTPS2IUBSZ128rmbkz = 7150,
  VCVTPS2IUBSZ128rmk = 7151,
  VCVTPS2IUBSZ128rmkz = 7152,
  VCVTPS2IUBSZ128rr = 7153,
  VCVTPS2IUBSZ128rrk = 7154,
  VCVTPS2IUBSZ128rrkz = 7155,
  VCVTPS2IUBSZ256rm = 7156,
  VCVTPS2IUBSZ256rmb = 7157,
  VCVTPS2IUBSZ256rmbk = 7158,
  VCVTPS2IUBSZ256rmbkz = 7159,
  VCVTPS2IUBSZ256rmk = 7160,
  VCVTPS2IUBSZ256rmkz = 7161,
  VCVTPS2IUBSZ256rr = 7162,
  VCVTPS2IUBSZ256rrb = 7163,
  VCVTPS2IUBSZ256rrbk = 7164,
  VCVTPS2IUBSZ256rrbkz = 7165,
  VCVTPS2IUBSZ256rrk = 7166,
  VCVTPS2IUBSZ256rrkz = 7167,
  VCVTPS2IUBSZrm = 7168,
  VCVTPS2IUBSZrmb = 7169,
  VCVTPS2IUBSZrmbk = 7170,
  VCVTPS2IUBSZrmbkz = 7171,
  VCVTPS2IUBSZrmk = 7172,
  VCVTPS2IUBSZrmkz = 7173,
  VCVTPS2IUBSZrr = 7174,
  VCVTPS2IUBSZrrb = 7175,
  VCVTPS2IUBSZrrbk = 7176,
  VCVTPS2IUBSZrrbkz = 7177,
  VCVTPS2IUBSZrrk = 7178,
  VCVTPS2IUBSZrrkz = 7179,
  VCVTPS2PDYrm = 7180,
  VCVTPS2PDYrr = 7181,
  VCVTPS2PDZ128rm = 7182,
  VCVTPS2PDZ128rmb = 7183,
  VCVTPS2PDZ128rmbk = 7184,
  VCVTPS2PDZ128rmbkz = 7185,
  VCVTPS2PDZ128rmk = 7186,
  VCVTPS2PDZ128rmkz = 7187,
  VCVTPS2PDZ128rr = 7188,
  VCVTPS2PDZ128rrk = 7189,
  VCVTPS2PDZ128rrkz = 7190,
  VCVTPS2PDZ256rm = 7191,
  VCVTPS2PDZ256rmb = 7192,
  VCVTPS2PDZ256rmbk = 7193,
  VCVTPS2PDZ256rmbkz = 7194,
  VCVTPS2PDZ256rmk = 7195,
  VCVTPS2PDZ256rmkz = 7196,
  VCVTPS2PDZ256rr = 7197,
  VCVTPS2PDZ256rrb = 7198,
  VCVTPS2PDZ256rrbk = 7199,
  VCVTPS2PDZ256rrbkz = 7200,
  VCVTPS2PDZ256rrk = 7201,
  VCVTPS2PDZ256rrkz = 7202,
  VCVTPS2PDZrm = 7203,
  VCVTPS2PDZrmb = 7204,
  VCVTPS2PDZrmbk = 7205,
  VCVTPS2PDZrmbkz = 7206,
  VCVTPS2PDZrmk = 7207,
  VCVTPS2PDZrmkz = 7208,
  VCVTPS2PDZrr = 7209,
  VCVTPS2PDZrrb = 7210,
  VCVTPS2PDZrrbk = 7211,
  VCVTPS2PDZrrbkz = 7212,
  VCVTPS2PDZrrk = 7213,
  VCVTPS2PDZrrkz = 7214,
  VCVTPS2PDrm = 7215,
  VCVTPS2PDrr = 7216,
  VCVTPS2PHXZ128rm = 7217,
  VCVTPS2PHXZ128rmb = 7218,
  VCVTPS2PHXZ128rmbk = 7219,
  VCVTPS2PHXZ128rmbkz = 7220,
  VCVTPS2PHXZ128rmk = 7221,
  VCVTPS2PHXZ128rmkz = 7222,
  VCVTPS2PHXZ128rr = 7223,
  VCVTPS2PHXZ128rrk = 7224,
  VCVTPS2PHXZ128rrkz = 7225,
  VCVTPS2PHXZ256rm = 7226,
  VCVTPS2PHXZ256rmb = 7227,
  VCVTPS2PHXZ256rmbk = 7228,
  VCVTPS2PHXZ256rmbkz = 7229,
  VCVTPS2PHXZ256rmk = 7230,
  VCVTPS2PHXZ256rmkz = 7231,
  VCVTPS2PHXZ256rr = 7232,
  VCVTPS2PHXZ256rrb = 7233,
  VCVTPS2PHXZ256rrbk = 7234,
  VCVTPS2PHXZ256rrbkz = 7235,
  VCVTPS2PHXZ256rrk = 7236,
  VCVTPS2PHXZ256rrkz = 7237,
  VCVTPS2PHXZrm = 7238,
  VCVTPS2PHXZrmb = 7239,
  VCVTPS2PHXZrmbk = 7240,
  VCVTPS2PHXZrmbkz = 7241,
  VCVTPS2PHXZrmk = 7242,
  VCVTPS2PHXZrmkz = 7243,
  VCVTPS2PHXZrr = 7244,
  VCVTPS2PHXZrrb = 7245,
  VCVTPS2PHXZrrbk = 7246,
  VCVTPS2PHXZrrbkz = 7247,
  VCVTPS2PHXZrrk = 7248,
  VCVTPS2PHXZrrkz = 7249,
  VCVTPS2PHYmr = 7250,
  VCVTPS2PHYrr = 7251,
  VCVTPS2PHZ128mr = 7252,
  VCVTPS2PHZ128mrk = 7253,
  VCVTPS2PHZ128rr = 7254,
  VCVTPS2PHZ128rrk = 7255,
  VCVTPS2PHZ128rrkz = 7256,
  VCVTPS2PHZ256mr = 7257,
  VCVTPS2PHZ256mrk = 7258,
  VCVTPS2PHZ256rr = 7259,
  VCVTPS2PHZ256rrb = 7260,
  VCVTPS2PHZ256rrbk = 7261,
  VCVTPS2PHZ256rrbkz = 7262,
  VCVTPS2PHZ256rrk = 7263,
  VCVTPS2PHZ256rrkz = 7264,
  VCVTPS2PHZmr = 7265,
  VCVTPS2PHZmrk = 7266,
  VCVTPS2PHZrr = 7267,
  VCVTPS2PHZrrb = 7268,
  VCVTPS2PHZrrbk = 7269,
  VCVTPS2PHZrrbkz = 7270,
  VCVTPS2PHZrrk = 7271,
  VCVTPS2PHZrrkz = 7272,
  VCVTPS2PHmr = 7273,
  VCVTPS2PHrr = 7274,
  VCVTPS2QQZ128rm = 7275,
  VCVTPS2QQZ128rmb = 7276,
  VCVTPS2QQZ128rmbk = 7277,
  VCVTPS2QQZ128rmbkz = 7278,
  VCVTPS2QQZ128rmk = 7279,
  VCVTPS2QQZ128rmkz = 7280,
  VCVTPS2QQZ128rr = 7281,
  VCVTPS2QQZ128rrk = 7282,
  VCVTPS2QQZ128rrkz = 7283,
  VCVTPS2QQZ256rm = 7284,
  VCVTPS2QQZ256rmb = 7285,
  VCVTPS2QQZ256rmbk = 7286,
  VCVTPS2QQZ256rmbkz = 7287,
  VCVTPS2QQZ256rmk = 7288,
  VCVTPS2QQZ256rmkz = 7289,
  VCVTPS2QQZ256rr = 7290,
  VCVTPS2QQZ256rrb = 7291,
  VCVTPS2QQZ256rrbk = 7292,
  VCVTPS2QQZ256rrbkz = 7293,
  VCVTPS2QQZ256rrk = 7294,
  VCVTPS2QQZ256rrkz = 7295,
  VCVTPS2QQZrm = 7296,
  VCVTPS2QQZrmb = 7297,
  VCVTPS2QQZrmbk = 7298,
  VCVTPS2QQZrmbkz = 7299,
  VCVTPS2QQZrmk = 7300,
  VCVTPS2QQZrmkz = 7301,
  VCVTPS2QQZrr = 7302,
  VCVTPS2QQZrrb = 7303,
  VCVTPS2QQZrrbk = 7304,
  VCVTPS2QQZrrbkz = 7305,
  VCVTPS2QQZrrk = 7306,
  VCVTPS2QQZrrkz = 7307,
  VCVTPS2UDQZ128rm = 7308,
  VCVTPS2UDQZ128rmb = 7309,
  VCVTPS2UDQZ128rmbk = 7310,
  VCVTPS2UDQZ128rmbkz = 7311,
  VCVTPS2UDQZ128rmk = 7312,
  VCVTPS2UDQZ128rmkz = 7313,
  VCVTPS2UDQZ128rr = 7314,
  VCVTPS2UDQZ128rrk = 7315,
  VCVTPS2UDQZ128rrkz = 7316,
  VCVTPS2UDQZ256rm = 7317,
  VCVTPS2UDQZ256rmb = 7318,
  VCVTPS2UDQZ256rmbk = 7319,
  VCVTPS2UDQZ256rmbkz = 7320,
  VCVTPS2UDQZ256rmk = 7321,
  VCVTPS2UDQZ256rmkz = 7322,
  VCVTPS2UDQZ256rr = 7323,
  VCVTPS2UDQZ256rrb = 7324,
  VCVTPS2UDQZ256rrbk = 7325,
  VCVTPS2UDQZ256rrbkz = 7326,
  VCVTPS2UDQZ256rrk = 7327,
  VCVTPS2UDQZ256rrkz = 7328,
  VCVTPS2UDQZrm = 7329,
  VCVTPS2UDQZrmb = 7330,
  VCVTPS2UDQZrmbk = 7331,
  VCVTPS2UDQZrmbkz = 7332,
  VCVTPS2UDQZrmk = 7333,
  VCVTPS2UDQZrmkz = 7334,
  VCVTPS2UDQZrr = 7335,
  VCVTPS2UDQZrrb = 7336,
  VCVTPS2UDQZrrbk = 7337,
  VCVTPS2UDQZrrbkz = 7338,
  VCVTPS2UDQZrrk = 7339,
  VCVTPS2UDQZrrkz = 7340,
  VCVTPS2UQQZ128rm = 7341,
  VCVTPS2UQQZ128rmb = 7342,
  VCVTPS2UQQZ128rmbk = 7343,
  VCVTPS2UQQZ128rmbkz = 7344,
  VCVTPS2UQQZ128rmk = 7345,
  VCVTPS2UQQZ128rmkz = 7346,
  VCVTPS2UQQZ128rr = 7347,
  VCVTPS2UQQZ128rrk = 7348,
  VCVTPS2UQQZ128rrkz = 7349,
  VCVTPS2UQQZ256rm = 7350,
  VCVTPS2UQQZ256rmb = 7351,
  VCVTPS2UQQZ256rmbk = 7352,
  VCVTPS2UQQZ256rmbkz = 7353,
  VCVTPS2UQQZ256rmk = 7354,
  VCVTPS2UQQZ256rmkz = 7355,
  VCVTPS2UQQZ256rr = 7356,
  VCVTPS2UQQZ256rrb = 7357,
  VCVTPS2UQQZ256rrbk = 7358,
  VCVTPS2UQQZ256rrbkz = 7359,
  VCVTPS2UQQZ256rrk = 7360,
  VCVTPS2UQQZ256rrkz = 7361,
  VCVTPS2UQQZrm = 7362,
  VCVTPS2UQQZrmb = 7363,
  VCVTPS2UQQZrmbk = 7364,
  VCVTPS2UQQZrmbkz = 7365,
  VCVTPS2UQQZrmk = 7366,
  VCVTPS2UQQZrmkz = 7367,
  VCVTPS2UQQZrr = 7368,
  VCVTPS2UQQZrrb = 7369,
  VCVTPS2UQQZrrbk = 7370,
  VCVTPS2UQQZrrbkz = 7371,
  VCVTPS2UQQZrrk = 7372,
  VCVTPS2UQQZrrkz = 7373,
  VCVTQQ2PDZ128rm = 7374,
  VCVTQQ2PDZ128rmb = 7375,
  VCVTQQ2PDZ128rmbk = 7376,
  VCVTQQ2PDZ128rmbkz = 7377,
  VCVTQQ2PDZ128rmk = 7378,
  VCVTQQ2PDZ128rmkz = 7379,
  VCVTQQ2PDZ128rr = 7380,
  VCVTQQ2PDZ128rrk = 7381,
  VCVTQQ2PDZ128rrkz = 7382,
  VCVTQQ2PDZ256rm = 7383,
  VCVTQQ2PDZ256rmb = 7384,
  VCVTQQ2PDZ256rmbk = 7385,
  VCVTQQ2PDZ256rmbkz = 7386,
  VCVTQQ2PDZ256rmk = 7387,
  VCVTQQ2PDZ256rmkz = 7388,
  VCVTQQ2PDZ256rr = 7389,
  VCVTQQ2PDZ256rrb = 7390,
  VCVTQQ2PDZ256rrbk = 7391,
  VCVTQQ2PDZ256rrbkz = 7392,
  VCVTQQ2PDZ256rrk = 7393,
  VCVTQQ2PDZ256rrkz = 7394,
  VCVTQQ2PDZrm = 7395,
  VCVTQQ2PDZrmb = 7396,
  VCVTQQ2PDZrmbk = 7397,
  VCVTQQ2PDZrmbkz = 7398,
  VCVTQQ2PDZrmk = 7399,
  VCVTQQ2PDZrmkz = 7400,
  VCVTQQ2PDZrr = 7401,
  VCVTQQ2PDZrrb = 7402,
  VCVTQQ2PDZrrbk = 7403,
  VCVTQQ2PDZrrbkz = 7404,
  VCVTQQ2PDZrrk = 7405,
  VCVTQQ2PDZrrkz = 7406,
  VCVTQQ2PHZ128rm = 7407,
  VCVTQQ2PHZ128rmb = 7408,
  VCVTQQ2PHZ128rmbk = 7409,
  VCVTQQ2PHZ128rmbkz = 7410,
  VCVTQQ2PHZ128rmk = 7411,
  VCVTQQ2PHZ128rmkz = 7412,
  VCVTQQ2PHZ128rr = 7413,
  VCVTQQ2PHZ128rrk = 7414,
  VCVTQQ2PHZ128rrkz = 7415,
  VCVTQQ2PHZ256rm = 7416,
  VCVTQQ2PHZ256rmb = 7417,
  VCVTQQ2PHZ256rmbk = 7418,
  VCVTQQ2PHZ256rmbkz = 7419,
  VCVTQQ2PHZ256rmk = 7420,
  VCVTQQ2PHZ256rmkz = 7421,
  VCVTQQ2PHZ256rr = 7422,
  VCVTQQ2PHZ256rrb = 7423,
  VCVTQQ2PHZ256rrbk = 7424,
  VCVTQQ2PHZ256rrbkz = 7425,
  VCVTQQ2PHZ256rrk = 7426,
  VCVTQQ2PHZ256rrkz = 7427,
  VCVTQQ2PHZrm = 7428,
  VCVTQQ2PHZrmb = 7429,
  VCVTQQ2PHZrmbk = 7430,
  VCVTQQ2PHZrmbkz = 7431,
  VCVTQQ2PHZrmk = 7432,
  VCVTQQ2PHZrmkz = 7433,
  VCVTQQ2PHZrr = 7434,
  VCVTQQ2PHZrrb = 7435,
  VCVTQQ2PHZrrbk = 7436,
  VCVTQQ2PHZrrbkz = 7437,
  VCVTQQ2PHZrrk = 7438,
  VCVTQQ2PHZrrkz = 7439,
  VCVTQQ2PSZ128rm = 7440,
  VCVTQQ2PSZ128rmb = 7441,
  VCVTQQ2PSZ128rmbk = 7442,
  VCVTQQ2PSZ128rmbkz = 7443,
  VCVTQQ2PSZ128rmk = 7444,
  VCVTQQ2PSZ128rmkz = 7445,
  VCVTQQ2PSZ128rr = 7446,
  VCVTQQ2PSZ128rrk = 7447,
  VCVTQQ2PSZ128rrkz = 7448,
  VCVTQQ2PSZ256rm = 7449,
  VCVTQQ2PSZ256rmb = 7450,
  VCVTQQ2PSZ256rmbk = 7451,
  VCVTQQ2PSZ256rmbkz = 7452,
  VCVTQQ2PSZ256rmk = 7453,
  VCVTQQ2PSZ256rmkz = 7454,
  VCVTQQ2PSZ256rr = 7455,
  VCVTQQ2PSZ256rrb = 7456,
  VCVTQQ2PSZ256rrbk = 7457,
  VCVTQQ2PSZ256rrbkz = 7458,
  VCVTQQ2PSZ256rrk = 7459,
  VCVTQQ2PSZ256rrkz = 7460,
  VCVTQQ2PSZrm = 7461,
  VCVTQQ2PSZrmb = 7462,
  VCVTQQ2PSZrmbk = 7463,
  VCVTQQ2PSZrmbkz = 7464,
  VCVTQQ2PSZrmk = 7465,
  VCVTQQ2PSZrmkz = 7466,
  VCVTQQ2PSZrr = 7467,
  VCVTQQ2PSZrrb = 7468,
  VCVTQQ2PSZrrbk = 7469,
  VCVTQQ2PSZrrbkz = 7470,
  VCVTQQ2PSZrrk = 7471,
  VCVTQQ2PSZrrkz = 7472,
  VCVTSD2SHZrm = 7473,
  VCVTSD2SHZrm_Int = 7474,
  VCVTSD2SHZrmk_Int = 7475,
  VCVTSD2SHZrmkz_Int = 7476,
  VCVTSD2SHZrr = 7477,
  VCVTSD2SHZrr_Int = 7478,
  VCVTSD2SHZrrb_Int = 7479,
  VCVTSD2SHZrrbk_Int = 7480,
  VCVTSD2SHZrrbkz_Int = 7481,
  VCVTSD2SHZrrk_Int = 7482,
  VCVTSD2SHZrrkz_Int = 7483,
  VCVTSD2SI64Zrm = 7484,
  VCVTSD2SI64Zrm_Int = 7485,
  VCVTSD2SI64Zrr = 7486,
  VCVTSD2SI64Zrr_Int = 7487,
  VCVTSD2SI64Zrrb_Int = 7488,
  VCVTSD2SI64rm = 7489,
  VCVTSD2SI64rm_Int = 7490,
  VCVTSD2SI64rr = 7491,
  VCVTSD2SI64rr_Int = 7492,
  VCVTSD2SIZrm = 7493,
  VCVTSD2SIZrm_Int = 7494,
  VCVTSD2SIZrr = 7495,
  VCVTSD2SIZrr_Int = 7496,
  VCVTSD2SIZrrb_Int = 7497,
  VCVTSD2SIrm = 7498,
  VCVTSD2SIrm_Int = 7499,
  VCVTSD2SIrr = 7500,
  VCVTSD2SIrr_Int = 7501,
  VCVTSD2SSZrm = 7502,
  VCVTSD2SSZrm_Int = 7503,
  VCVTSD2SSZrmk_Int = 7504,
  VCVTSD2SSZrmkz_Int = 7505,
  VCVTSD2SSZrr = 7506,
  VCVTSD2SSZrr_Int = 7507,
  VCVTSD2SSZrrb_Int = 7508,
  VCVTSD2SSZrrbk_Int = 7509,
  VCVTSD2SSZrrbkz_Int = 7510,
  VCVTSD2SSZrrk_Int = 7511,
  VCVTSD2SSZrrkz_Int = 7512,
  VCVTSD2SSrm = 7513,
  VCVTSD2SSrm_Int = 7514,
  VCVTSD2SSrr = 7515,
  VCVTSD2SSrr_Int = 7516,
  VCVTSD2USI64Zrm_Int = 7517,
  VCVTSD2USI64Zrr_Int = 7518,
  VCVTSD2USI64Zrrb_Int = 7519,
  VCVTSD2USIZrm_Int = 7520,
  VCVTSD2USIZrr_Int = 7521,
  VCVTSD2USIZrrb_Int = 7522,
  VCVTSH2SDZrm = 7523,
  VCVTSH2SDZrm_Int = 7524,
  VCVTSH2SDZrmk_Int = 7525,
  VCVTSH2SDZrmkz_Int = 7526,
  VCVTSH2SDZrr = 7527,
  VCVTSH2SDZrr_Int = 7528,
  VCVTSH2SDZrrb_Int = 7529,
  VCVTSH2SDZrrbk_Int = 7530,
  VCVTSH2SDZrrbkz_Int = 7531,
  VCVTSH2SDZrrk_Int = 7532,
  VCVTSH2SDZrrkz_Int = 7533,
  VCVTSH2SI64Zrm_Int = 7534,
  VCVTSH2SI64Zrr_Int = 7535,
  VCVTSH2SI64Zrrb_Int = 7536,
  VCVTSH2SIZrm_Int = 7537,
  VCVTSH2SIZrr_Int = 7538,
  VCVTSH2SIZrrb_Int = 7539,
  VCVTSH2SSZrm = 7540,
  VCVTSH2SSZrm_Int = 7541,
  VCVTSH2SSZrmk_Int = 7542,
  VCVTSH2SSZrmkz_Int = 7543,
  VCVTSH2SSZrr = 7544,
  VCVTSH2SSZrr_Int = 7545,
  VCVTSH2SSZrrb_Int = 7546,
  VCVTSH2SSZrrbk_Int = 7547,
  VCVTSH2SSZrrbkz_Int = 7548,
  VCVTSH2SSZrrk_Int = 7549,
  VCVTSH2SSZrrkz_Int = 7550,
  VCVTSH2USI64Zrm_Int = 7551,
  VCVTSH2USI64Zrr_Int = 7552,
  VCVTSH2USI64Zrrb_Int = 7553,
  VCVTSH2USIZrm_Int = 7554,
  VCVTSH2USIZrr_Int = 7555,
  VCVTSH2USIZrrb_Int = 7556,
  VCVTSI2SDZrm = 7557,
  VCVTSI2SDZrm_Int = 7558,
  VCVTSI2SDZrr = 7559,
  VCVTSI2SDZrr_Int = 7560,
  VCVTSI2SDrm = 7561,
  VCVTSI2SDrm_Int = 7562,
  VCVTSI2SDrr = 7563,
  VCVTSI2SDrr_Int = 7564,
  VCVTSI2SHZrm = 7565,
  VCVTSI2SHZrm_Int = 7566,
  VCVTSI2SHZrr = 7567,
  VCVTSI2SHZrr_Int = 7568,
  VCVTSI2SHZrrb_Int = 7569,
  VCVTSI2SSZrm = 7570,
  VCVTSI2SSZrm_Int = 7571,
  VCVTSI2SSZrr = 7572,
  VCVTSI2SSZrr_Int = 7573,
  VCVTSI2SSZrrb_Int = 7574,
  VCVTSI2SSrm = 7575,
  VCVTSI2SSrm_Int = 7576,
  VCVTSI2SSrr = 7577,
  VCVTSI2SSrr_Int = 7578,
  VCVTSI642SDZrm = 7579,
  VCVTSI642SDZrm_Int = 7580,
  VCVTSI642SDZrr = 7581,
  VCVTSI642SDZrr_Int = 7582,
  VCVTSI642SDZrrb_Int = 7583,
  VCVTSI642SDrm = 7584,
  VCVTSI642SDrm_Int = 7585,
  VCVTSI642SDrr = 7586,
  VCVTSI642SDrr_Int = 7587,
  VCVTSI642SHZrm = 7588,
  VCVTSI642SHZrm_Int = 7589,
  VCVTSI642SHZrr = 7590,
  VCVTSI642SHZrr_Int = 7591,
  VCVTSI642SHZrrb_Int = 7592,
  VCVTSI642SSZrm = 7593,
  VCVTSI642SSZrm_Int = 7594,
  VCVTSI642SSZrr = 7595,
  VCVTSI642SSZrr_Int = 7596,
  VCVTSI642SSZrrb_Int = 7597,
  VCVTSI642SSrm = 7598,
  VCVTSI642SSrm_Int = 7599,
  VCVTSI642SSrr = 7600,
  VCVTSI642SSrr_Int = 7601,
  VCVTSS2SDZrm = 7602,
  VCVTSS2SDZrm_Int = 7603,
  VCVTSS2SDZrmk_Int = 7604,
  VCVTSS2SDZrmkz_Int = 7605,
  VCVTSS2SDZrr = 7606,
  VCVTSS2SDZrr_Int = 7607,
  VCVTSS2SDZrrb_Int = 7608,
  VCVTSS2SDZrrbk_Int = 7609,
  VCVTSS2SDZrrbkz_Int = 7610,
  VCVTSS2SDZrrk_Int = 7611,
  VCVTSS2SDZrrkz_Int = 7612,
  VCVTSS2SDrm = 7613,
  VCVTSS2SDrm_Int = 7614,
  VCVTSS2SDrr = 7615,
  VCVTSS2SDrr_Int = 7616,
  VCVTSS2SHZrm = 7617,
  VCVTSS2SHZrm_Int = 7618,
  VCVTSS2SHZrmk_Int = 7619,
  VCVTSS2SHZrmkz_Int = 7620,
  VCVTSS2SHZrr = 7621,
  VCVTSS2SHZrr_Int = 7622,
  VCVTSS2SHZrrb_Int = 7623,
  VCVTSS2SHZrrbk_Int = 7624,
  VCVTSS2SHZrrbkz_Int = 7625,
  VCVTSS2SHZrrk_Int = 7626,
  VCVTSS2SHZrrkz_Int = 7627,
  VCVTSS2SI64Zrm = 7628,
  VCVTSS2SI64Zrm_Int = 7629,
  VCVTSS2SI64Zrr = 7630,
  VCVTSS2SI64Zrr_Int = 7631,
  VCVTSS2SI64Zrrb_Int = 7632,
  VCVTSS2SI64rm = 7633,
  VCVTSS2SI64rm_Int = 7634,
  VCVTSS2SI64rr = 7635,
  VCVTSS2SI64rr_Int = 7636,
  VCVTSS2SIZrm = 7637,
  VCVTSS2SIZrm_Int = 7638,
  VCVTSS2SIZrr = 7639,
  VCVTSS2SIZrr_Int = 7640,
  VCVTSS2SIZrrb_Int = 7641,
  VCVTSS2SIrm = 7642,
  VCVTSS2SIrm_Int = 7643,
  VCVTSS2SIrr = 7644,
  VCVTSS2SIrr_Int = 7645,
  VCVTSS2USI64Zrm_Int = 7646,
  VCVTSS2USI64Zrr_Int = 7647,
  VCVTSS2USI64Zrrb_Int = 7648,
  VCVTSS2USIZrm_Int = 7649,
  VCVTSS2USIZrr_Int = 7650,
  VCVTSS2USIZrrb_Int = 7651,
  VCVTTBF162IBSZ128rm = 7652,
  VCVTTBF162IBSZ128rmb = 7653,
  VCVTTBF162IBSZ128rmbk = 7654,
  VCVTTBF162IBSZ128rmbkz = 7655,
  VCVTTBF162IBSZ128rmk = 7656,
  VCVTTBF162IBSZ128rmkz = 7657,
  VCVTTBF162IBSZ128rr = 7658,
  VCVTTBF162IBSZ128rrk = 7659,
  VCVTTBF162IBSZ128rrkz = 7660,
  VCVTTBF162IBSZ256rm = 7661,
  VCVTTBF162IBSZ256rmb = 7662,
  VCVTTBF162IBSZ256rmbk = 7663,
  VCVTTBF162IBSZ256rmbkz = 7664,
  VCVTTBF162IBSZ256rmk = 7665,
  VCVTTBF162IBSZ256rmkz = 7666,
  VCVTTBF162IBSZ256rr = 7667,
  VCVTTBF162IBSZ256rrk = 7668,
  VCVTTBF162IBSZ256rrkz = 7669,
  VCVTTBF162IBSZrm = 7670,
  VCVTTBF162IBSZrmb = 7671,
  VCVTTBF162IBSZrmbk = 7672,
  VCVTTBF162IBSZrmbkz = 7673,
  VCVTTBF162IBSZrmk = 7674,
  VCVTTBF162IBSZrmkz = 7675,
  VCVTTBF162IBSZrr = 7676,
  VCVTTBF162IBSZrrk = 7677,
  VCVTTBF162IBSZrrkz = 7678,
  VCVTTBF162IUBSZ128rm = 7679,
  VCVTTBF162IUBSZ128rmb = 7680,
  VCVTTBF162IUBSZ128rmbk = 7681,
  VCVTTBF162IUBSZ128rmbkz = 7682,
  VCVTTBF162IUBSZ128rmk = 7683,
  VCVTTBF162IUBSZ128rmkz = 7684,
  VCVTTBF162IUBSZ128rr = 7685,
  VCVTTBF162IUBSZ128rrk = 7686,
  VCVTTBF162IUBSZ128rrkz = 7687,
  VCVTTBF162IUBSZ256rm = 7688,
  VCVTTBF162IUBSZ256rmb = 7689,
  VCVTTBF162IUBSZ256rmbk = 7690,
  VCVTTBF162IUBSZ256rmbkz = 7691,
  VCVTTBF162IUBSZ256rmk = 7692,
  VCVTTBF162IUBSZ256rmkz = 7693,
  VCVTTBF162IUBSZ256rr = 7694,
  VCVTTBF162IUBSZ256rrk = 7695,
  VCVTTBF162IUBSZ256rrkz = 7696,
  VCVTTBF162IUBSZrm = 7697,
  VCVTTBF162IUBSZrmb = 7698,
  VCVTTBF162IUBSZrmbk = 7699,
  VCVTTBF162IUBSZrmbkz = 7700,
  VCVTTBF162IUBSZrmk = 7701,
  VCVTTBF162IUBSZrmkz = 7702,
  VCVTTBF162IUBSZrr = 7703,
  VCVTTBF162IUBSZrrk = 7704,
  VCVTTBF162IUBSZrrkz = 7705,
  VCVTTPD2DQSZ128rm = 7706,
  VCVTTPD2DQSZ128rmb = 7707,
  VCVTTPD2DQSZ128rmbk = 7708,
  VCVTTPD2DQSZ128rmbkz = 7709,
  VCVTTPD2DQSZ128rmk = 7710,
  VCVTTPD2DQSZ128rmkz = 7711,
  VCVTTPD2DQSZ128rr = 7712,
  VCVTTPD2DQSZ128rrk = 7713,
  VCVTTPD2DQSZ128rrkz = 7714,
  VCVTTPD2DQSZ256rm = 7715,
  VCVTTPD2DQSZ256rmb = 7716,
  VCVTTPD2DQSZ256rmbk = 7717,
  VCVTTPD2DQSZ256rmbkz = 7718,
  VCVTTPD2DQSZ256rmk = 7719,
  VCVTTPD2DQSZ256rmkz = 7720,
  VCVTTPD2DQSZ256rr = 7721,
  VCVTTPD2DQSZ256rrb = 7722,
  VCVTTPD2DQSZ256rrbk = 7723,
  VCVTTPD2DQSZ256rrbkz = 7724,
  VCVTTPD2DQSZ256rrk = 7725,
  VCVTTPD2DQSZ256rrkz = 7726,
  VCVTTPD2DQSZrm = 7727,
  VCVTTPD2DQSZrmb = 7728,
  VCVTTPD2DQSZrmbk = 7729,
  VCVTTPD2DQSZrmbkz = 7730,
  VCVTTPD2DQSZrmk = 7731,
  VCVTTPD2DQSZrmkz = 7732,
  VCVTTPD2DQSZrr = 7733,
  VCVTTPD2DQSZrrb = 7734,
  VCVTTPD2DQSZrrbk = 7735,
  VCVTTPD2DQSZrrbkz = 7736,
  VCVTTPD2DQSZrrk = 7737,
  VCVTTPD2DQSZrrkz = 7738,
  VCVTTPD2DQYrm = 7739,
  VCVTTPD2DQYrr = 7740,
  VCVTTPD2DQZ128rm = 7741,
  VCVTTPD2DQZ128rmb = 7742,
  VCVTTPD2DQZ128rmbk = 7743,
  VCVTTPD2DQZ128rmbkz = 7744,
  VCVTTPD2DQZ128rmk = 7745,
  VCVTTPD2DQZ128rmkz = 7746,
  VCVTTPD2DQZ128rr = 7747,
  VCVTTPD2DQZ128rrk = 7748,
  VCVTTPD2DQZ128rrkz = 7749,
  VCVTTPD2DQZ256rm = 7750,
  VCVTTPD2DQZ256rmb = 7751,
  VCVTTPD2DQZ256rmbk = 7752,
  VCVTTPD2DQZ256rmbkz = 7753,
  VCVTTPD2DQZ256rmk = 7754,
  VCVTTPD2DQZ256rmkz = 7755,
  VCVTTPD2DQZ256rr = 7756,
  VCVTTPD2DQZ256rrb = 7757,
  VCVTTPD2DQZ256rrbk = 7758,
  VCVTTPD2DQZ256rrbkz = 7759,
  VCVTTPD2DQZ256rrk = 7760,
  VCVTTPD2DQZ256rrkz = 7761,
  VCVTTPD2DQZrm = 7762,
  VCVTTPD2DQZrmb = 7763,
  VCVTTPD2DQZrmbk = 7764,
  VCVTTPD2DQZrmbkz = 7765,
  VCVTTPD2DQZrmk = 7766,
  VCVTTPD2DQZrmkz = 7767,
  VCVTTPD2DQZrr = 7768,
  VCVTTPD2DQZrrb = 7769,
  VCVTTPD2DQZrrbk = 7770,
  VCVTTPD2DQZrrbkz = 7771,
  VCVTTPD2DQZrrk = 7772,
  VCVTTPD2DQZrrkz = 7773,
  VCVTTPD2DQrm = 7774,
  VCVTTPD2DQrr = 7775,
  VCVTTPD2QQSZ128rm = 7776,
  VCVTTPD2QQSZ128rmb = 7777,
  VCVTTPD2QQSZ128rmbk = 7778,
  VCVTTPD2QQSZ128rmbkz = 7779,
  VCVTTPD2QQSZ128rmk = 7780,
  VCVTTPD2QQSZ128rmkz = 7781,
  VCVTTPD2QQSZ128rr = 7782,
  VCVTTPD2QQSZ128rrk = 7783,
  VCVTTPD2QQSZ128rrkz = 7784,
  VCVTTPD2QQSZ256rm = 7785,
  VCVTTPD2QQSZ256rmb = 7786,
  VCVTTPD2QQSZ256rmbk = 7787,
  VCVTTPD2QQSZ256rmbkz = 7788,
  VCVTTPD2QQSZ256rmk = 7789,
  VCVTTPD2QQSZ256rmkz = 7790,
  VCVTTPD2QQSZ256rr = 7791,
  VCVTTPD2QQSZ256rrb = 7792,
  VCVTTPD2QQSZ256rrbk = 7793,
  VCVTTPD2QQSZ256rrbkz = 7794,
  VCVTTPD2QQSZ256rrk = 7795,
  VCVTTPD2QQSZ256rrkz = 7796,
  VCVTTPD2QQSZrm = 7797,
  VCVTTPD2QQSZrmb = 7798,
  VCVTTPD2QQSZrmbk = 7799,
  VCVTTPD2QQSZrmbkz = 7800,
  VCVTTPD2QQSZrmk = 7801,
  VCVTTPD2QQSZrmkz = 7802,
  VCVTTPD2QQSZrr = 7803,
  VCVTTPD2QQSZrrb = 7804,
  VCVTTPD2QQSZrrbk = 7805,
  VCVTTPD2QQSZrrbkz = 7806,
  VCVTTPD2QQSZrrk = 7807,
  VCVTTPD2QQSZrrkz = 7808,
  VCVTTPD2QQZ128rm = 7809,
  VCVTTPD2QQZ128rmb = 7810,
  VCVTTPD2QQZ128rmbk = 7811,
  VCVTTPD2QQZ128rmbkz = 7812,
  VCVTTPD2QQZ128rmk = 7813,
  VCVTTPD2QQZ128rmkz = 7814,
  VCVTTPD2QQZ128rr = 7815,
  VCVTTPD2QQZ128rrk = 7816,
  VCVTTPD2QQZ128rrkz = 7817,
  VCVTTPD2QQZ256rm = 7818,
  VCVTTPD2QQZ256rmb = 7819,
  VCVTTPD2QQZ256rmbk = 7820,
  VCVTTPD2QQZ256rmbkz = 7821,
  VCVTTPD2QQZ256rmk = 7822,
  VCVTTPD2QQZ256rmkz = 7823,
  VCVTTPD2QQZ256rr = 7824,
  VCVTTPD2QQZ256rrb = 7825,
  VCVTTPD2QQZ256rrbk = 7826,
  VCVTTPD2QQZ256rrbkz = 7827,
  VCVTTPD2QQZ256rrk = 7828,
  VCVTTPD2QQZ256rrkz = 7829,
  VCVTTPD2QQZrm = 7830,
  VCVTTPD2QQZrmb = 7831,
  VCVTTPD2QQZrmbk = 7832,
  VCVTTPD2QQZrmbkz = 7833,
  VCVTTPD2QQZrmk = 7834,
  VCVTTPD2QQZrmkz = 7835,
  VCVTTPD2QQZrr = 7836,
  VCVTTPD2QQZrrb = 7837,
  VCVTTPD2QQZrrbk = 7838,
  VCVTTPD2QQZrrbkz = 7839,
  VCVTTPD2QQZrrk = 7840,
  VCVTTPD2QQZrrkz = 7841,
  VCVTTPD2UDQSZ128rm = 7842,
  VCVTTPD2UDQSZ128rmb = 7843,
  VCVTTPD2UDQSZ128rmbk = 7844,
  VCVTTPD2UDQSZ128rmbkz = 7845,
  VCVTTPD2UDQSZ128rmk = 7846,
  VCVTTPD2UDQSZ128rmkz = 7847,
  VCVTTPD2UDQSZ128rr = 7848,
  VCVTTPD2UDQSZ128rrk = 7849,
  VCVTTPD2UDQSZ128rrkz = 7850,
  VCVTTPD2UDQSZ256rm = 7851,
  VCVTTPD2UDQSZ256rmb = 7852,
  VCVTTPD2UDQSZ256rmbk = 7853,
  VCVTTPD2UDQSZ256rmbkz = 7854,
  VCVTTPD2UDQSZ256rmk = 7855,
  VCVTTPD2UDQSZ256rmkz = 7856,
  VCVTTPD2UDQSZ256rr = 7857,
  VCVTTPD2UDQSZ256rrb = 7858,
  VCVTTPD2UDQSZ256rrbk = 7859,
  VCVTTPD2UDQSZ256rrbkz = 7860,
  VCVTTPD2UDQSZ256rrk = 7861,
  VCVTTPD2UDQSZ256rrkz = 7862,
  VCVTTPD2UDQSZrm = 7863,
  VCVTTPD2UDQSZrmb = 7864,
  VCVTTPD2UDQSZrmbk = 7865,
  VCVTTPD2UDQSZrmbkz = 7866,
  VCVTTPD2UDQSZrmk = 7867,
  VCVTTPD2UDQSZrmkz = 7868,
  VCVTTPD2UDQSZrr = 7869,
  VCVTTPD2UDQSZrrb = 7870,
  VCVTTPD2UDQSZrrbk = 7871,
  VCVTTPD2UDQSZrrbkz = 7872,
  VCVTTPD2UDQSZrrk = 7873,
  VCVTTPD2UDQSZrrkz = 7874,
  VCVTTPD2UDQZ128rm = 7875,
  VCVTTPD2UDQZ128rmb = 7876,
  VCVTTPD2UDQZ128rmbk = 7877,
  VCVTTPD2UDQZ128rmbkz = 7878,
  VCVTTPD2UDQZ128rmk = 7879,
  VCVTTPD2UDQZ128rmkz = 7880,
  VCVTTPD2UDQZ128rr = 7881,
  VCVTTPD2UDQZ128rrk = 7882,
  VCVTTPD2UDQZ128rrkz = 7883,
  VCVTTPD2UDQZ256rm = 7884,
  VCVTTPD2UDQZ256rmb = 7885,
  VCVTTPD2UDQZ256rmbk = 7886,
  VCVTTPD2UDQZ256rmbkz = 7887,
  VCVTTPD2UDQZ256rmk = 7888,
  VCVTTPD2UDQZ256rmkz = 7889,
  VCVTTPD2UDQZ256rr = 7890,
  VCVTTPD2UDQZ256rrb = 7891,
  VCVTTPD2UDQZ256rrbk = 7892,
  VCVTTPD2UDQZ256rrbkz = 7893,
  VCVTTPD2UDQZ256rrk = 7894,
  VCVTTPD2UDQZ256rrkz = 7895,
  VCVTTPD2UDQZrm = 7896,
  VCVTTPD2UDQZrmb = 7897,
  VCVTTPD2UDQZrmbk = 7898,
  VCVTTPD2UDQZrmbkz = 7899,
  VCVTTPD2UDQZrmk = 7900,
  VCVTTPD2UDQZrmkz = 7901,
  VCVTTPD2UDQZrr = 7902,
  VCVTTPD2UDQZrrb = 7903,
  VCVTTPD2UDQZrrbk = 7904,
  VCVTTPD2UDQZrrbkz = 7905,
  VCVTTPD2UDQZrrk = 7906,
  VCVTTPD2UDQZrrkz = 7907,
  VCVTTPD2UQQSZ128rm = 7908,
  VCVTTPD2UQQSZ128rmb = 7909,
  VCVTTPD2UQQSZ128rmbk = 7910,
  VCVTTPD2UQQSZ128rmbkz = 7911,
  VCVTTPD2UQQSZ128rmk = 7912,
  VCVTTPD2UQQSZ128rmkz = 7913,
  VCVTTPD2UQQSZ128rr = 7914,
  VCVTTPD2UQQSZ128rrk = 7915,
  VCVTTPD2UQQSZ128rrkz = 7916,
  VCVTTPD2UQQSZ256rm = 7917,
  VCVTTPD2UQQSZ256rmb = 7918,
  VCVTTPD2UQQSZ256rmbk = 7919,
  VCVTTPD2UQQSZ256rmbkz = 7920,
  VCVTTPD2UQQSZ256rmk = 7921,
  VCVTTPD2UQQSZ256rmkz = 7922,
  VCVTTPD2UQQSZ256rr = 7923,
  VCVTTPD2UQQSZ256rrb = 7924,
  VCVTTPD2UQQSZ256rrbk = 7925,
  VCVTTPD2UQQSZ256rrbkz = 7926,
  VCVTTPD2UQQSZ256rrk = 7927,
  VCVTTPD2UQQSZ256rrkz = 7928,
  VCVTTPD2UQQSZrm = 7929,
  VCVTTPD2UQQSZrmb = 7930,
  VCVTTPD2UQQSZrmbk = 7931,
  VCVTTPD2UQQSZrmbkz = 7932,
  VCVTTPD2UQQSZrmk = 7933,
  VCVTTPD2UQQSZrmkz = 7934,
  VCVTTPD2UQQSZrr = 7935,
  VCVTTPD2UQQSZrrb = 7936,
  VCVTTPD2UQQSZrrbk = 7937,
  VCVTTPD2UQQSZrrbkz = 7938,
  VCVTTPD2UQQSZrrk = 7939,
  VCVTTPD2UQQSZrrkz = 7940,
  VCVTTPD2UQQZ128rm = 7941,
  VCVTTPD2UQQZ128rmb = 7942,
  VCVTTPD2UQQZ128rmbk = 7943,
  VCVTTPD2UQQZ128rmbkz = 7944,
  VCVTTPD2UQQZ128rmk = 7945,
  VCVTTPD2UQQZ128rmkz = 7946,
  VCVTTPD2UQQZ128rr = 7947,
  VCVTTPD2UQQZ128rrk = 7948,
  VCVTTPD2UQQZ128rrkz = 7949,
  VCVTTPD2UQQZ256rm = 7950,
  VCVTTPD2UQQZ256rmb = 7951,
  VCVTTPD2UQQZ256rmbk = 7952,
  VCVTTPD2UQQZ256rmbkz = 7953,
  VCVTTPD2UQQZ256rmk = 7954,
  VCVTTPD2UQQZ256rmkz = 7955,
  VCVTTPD2UQQZ256rr = 7956,
  VCVTTPD2UQQZ256rrb = 7957,
  VCVTTPD2UQQZ256rrbk = 7958,
  VCVTTPD2UQQZ256rrbkz = 7959,
  VCVTTPD2UQQZ256rrk = 7960,
  VCVTTPD2UQQZ256rrkz = 7961,
  VCVTTPD2UQQZrm = 7962,
  VCVTTPD2UQQZrmb = 7963,
  VCVTTPD2UQQZrmbk = 7964,
  VCVTTPD2UQQZrmbkz = 7965,
  VCVTTPD2UQQZrmk = 7966,
  VCVTTPD2UQQZrmkz = 7967,
  VCVTTPD2UQQZrr = 7968,
  VCVTTPD2UQQZrrb = 7969,
  VCVTTPD2UQQZrrbk = 7970,
  VCVTTPD2UQQZrrbkz = 7971,
  VCVTTPD2UQQZrrk = 7972,
  VCVTTPD2UQQZrrkz = 7973,
  VCVTTPH2DQZ128rm = 7974,
  VCVTTPH2DQZ128rmb = 7975,
  VCVTTPH2DQZ128rmbk = 7976,
  VCVTTPH2DQZ128rmbkz = 7977,
  VCVTTPH2DQZ128rmk = 7978,
  VCVTTPH2DQZ128rmkz = 7979,
  VCVTTPH2DQZ128rr = 7980,
  VCVTTPH2DQZ128rrk = 7981,
  VCVTTPH2DQZ128rrkz = 7982,
  VCVTTPH2DQZ256rm = 7983,
  VCVTTPH2DQZ256rmb = 7984,
  VCVTTPH2DQZ256rmbk = 7985,
  VCVTTPH2DQZ256rmbkz = 7986,
  VCVTTPH2DQZ256rmk = 7987,
  VCVTTPH2DQZ256rmkz = 7988,
  VCVTTPH2DQZ256rr = 7989,
  VCVTTPH2DQZ256rrb = 7990,
  VCVTTPH2DQZ256rrbk = 7991,
  VCVTTPH2DQZ256rrbkz = 7992,
  VCVTTPH2DQZ256rrk = 7993,
  VCVTTPH2DQZ256rrkz = 7994,
  VCVTTPH2DQZrm = 7995,
  VCVTTPH2DQZrmb = 7996,
  VCVTTPH2DQZrmbk = 7997,
  VCVTTPH2DQZrmbkz = 7998,
  VCVTTPH2DQZrmk = 7999,
  VCVTTPH2DQZrmkz = 8000,
  VCVTTPH2DQZrr = 8001,
  VCVTTPH2DQZrrb = 8002,
  VCVTTPH2DQZrrbk = 8003,
  VCVTTPH2DQZrrbkz = 8004,
  VCVTTPH2DQZrrk = 8005,
  VCVTTPH2DQZrrkz = 8006,
  VCVTTPH2IBSZ128rm = 8007,
  VCVTTPH2IBSZ128rmb = 8008,
  VCVTTPH2IBSZ128rmbk = 8009,
  VCVTTPH2IBSZ128rmbkz = 8010,
  VCVTTPH2IBSZ128rmk = 8011,
  VCVTTPH2IBSZ128rmkz = 8012,
  VCVTTPH2IBSZ128rr = 8013,
  VCVTTPH2IBSZ128rrk = 8014,
  VCVTTPH2IBSZ128rrkz = 8015,
  VCVTTPH2IBSZ256rm = 8016,
  VCVTTPH2IBSZ256rmb = 8017,
  VCVTTPH2IBSZ256rmbk = 8018,
  VCVTTPH2IBSZ256rmbkz = 8019,
  VCVTTPH2IBSZ256rmk = 8020,
  VCVTTPH2IBSZ256rmkz = 8021,
  VCVTTPH2IBSZ256rr = 8022,
  VCVTTPH2IBSZ256rrb = 8023,
  VCVTTPH2IBSZ256rrbk = 8024,
  VCVTTPH2IBSZ256rrbkz = 8025,
  VCVTTPH2IBSZ256rrk = 8026,
  VCVTTPH2IBSZ256rrkz = 8027,
  VCVTTPH2IBSZrm = 8028,
  VCVTTPH2IBSZrmb = 8029,
  VCVTTPH2IBSZrmbk = 8030,
  VCVTTPH2IBSZrmbkz = 8031,
  VCVTTPH2IBSZrmk = 8032,
  VCVTTPH2IBSZrmkz = 8033,
  VCVTTPH2IBSZrr = 8034,
  VCVTTPH2IBSZrrb = 8035,
  VCVTTPH2IBSZrrbk = 8036,
  VCVTTPH2IBSZrrbkz = 8037,
  VCVTTPH2IBSZrrk = 8038,
  VCVTTPH2IBSZrrkz = 8039,
  VCVTTPH2IUBSZ128rm = 8040,
  VCVTTPH2IUBSZ128rmb = 8041,
  VCVTTPH2IUBSZ128rmbk = 8042,
  VCVTTPH2IUBSZ128rmbkz = 8043,
  VCVTTPH2IUBSZ128rmk = 8044,
  VCVTTPH2IUBSZ128rmkz = 8045,
  VCVTTPH2IUBSZ128rr = 8046,
  VCVTTPH2IUBSZ128rrk = 8047,
  VCVTTPH2IUBSZ128rrkz = 8048,
  VCVTTPH2IUBSZ256rm = 8049,
  VCVTTPH2IUBSZ256rmb = 8050,
  VCVTTPH2IUBSZ256rmbk = 8051,
  VCVTTPH2IUBSZ256rmbkz = 8052,
  VCVTTPH2IUBSZ256rmk = 8053,
  VCVTTPH2IUBSZ256rmkz = 8054,
  VCVTTPH2IUBSZ256rr = 8055,
  VCVTTPH2IUBSZ256rrb = 8056,
  VCVTTPH2IUBSZ256rrbk = 8057,
  VCVTTPH2IUBSZ256rrbkz = 8058,
  VCVTTPH2IUBSZ256rrk = 8059,
  VCVTTPH2IUBSZ256rrkz = 8060,
  VCVTTPH2IUBSZrm = 8061,
  VCVTTPH2IUBSZrmb = 8062,
  VCVTTPH2IUBSZrmbk = 8063,
  VCVTTPH2IUBSZrmbkz = 8064,
  VCVTTPH2IUBSZrmk = 8065,
  VCVTTPH2IUBSZrmkz = 8066,
  VCVTTPH2IUBSZrr = 8067,
  VCVTTPH2IUBSZrrb = 8068,
  VCVTTPH2IUBSZrrbk = 8069,
  VCVTTPH2IUBSZrrbkz = 8070,
  VCVTTPH2IUBSZrrk = 8071,
  VCVTTPH2IUBSZrrkz = 8072,
  VCVTTPH2QQZ128rm = 8073,
  VCVTTPH2QQZ128rmb = 8074,
  VCVTTPH2QQZ128rmbk = 8075,
  VCVTTPH2QQZ128rmbkz = 8076,
  VCVTTPH2QQZ128rmk = 8077,
  VCVTTPH2QQZ128rmkz = 8078,
  VCVTTPH2QQZ128rr = 8079,
  VCVTTPH2QQZ128rrk = 8080,
  VCVTTPH2QQZ128rrkz = 8081,
  VCVTTPH2QQZ256rm = 8082,
  VCVTTPH2QQZ256rmb = 8083,
  VCVTTPH2QQZ256rmbk = 8084,
  VCVTTPH2QQZ256rmbkz = 8085,
  VCVTTPH2QQZ256rmk = 8086,
  VCVTTPH2QQZ256rmkz = 8087,
  VCVTTPH2QQZ256rr = 8088,
  VCVTTPH2QQZ256rrb = 8089,
  VCVTTPH2QQZ256rrbk = 8090,
  VCVTTPH2QQZ256rrbkz = 8091,
  VCVTTPH2QQZ256rrk = 8092,
  VCVTTPH2QQZ256rrkz = 8093,
  VCVTTPH2QQZrm = 8094,
  VCVTTPH2QQZrmb = 8095,
  VCVTTPH2QQZrmbk = 8096,
  VCVTTPH2QQZrmbkz = 8097,
  VCVTTPH2QQZrmk = 8098,
  VCVTTPH2QQZrmkz = 8099,
  VCVTTPH2QQZrr = 8100,
  VCVTTPH2QQZrrb = 8101,
  VCVTTPH2QQZrrbk = 8102,
  VCVTTPH2QQZrrbkz = 8103,
  VCVTTPH2QQZrrk = 8104,
  VCVTTPH2QQZrrkz = 8105,
  VCVTTPH2UDQZ128rm = 8106,
  VCVTTPH2UDQZ128rmb = 8107,
  VCVTTPH2UDQZ128rmbk = 8108,
  VCVTTPH2UDQZ128rmbkz = 8109,
  VCVTTPH2UDQZ128rmk = 8110,
  VCVTTPH2UDQZ128rmkz = 8111,
  VCVTTPH2UDQZ128rr = 8112,
  VCVTTPH2UDQZ128rrk = 8113,
  VCVTTPH2UDQZ128rrkz = 8114,
  VCVTTPH2UDQZ256rm = 8115,
  VCVTTPH2UDQZ256rmb = 8116,
  VCVTTPH2UDQZ256rmbk = 8117,
  VCVTTPH2UDQZ256rmbkz = 8118,
  VCVTTPH2UDQZ256rmk = 8119,
  VCVTTPH2UDQZ256rmkz = 8120,
  VCVTTPH2UDQZ256rr = 8121,
  VCVTTPH2UDQZ256rrb = 8122,
  VCVTTPH2UDQZ256rrbk = 8123,
  VCVTTPH2UDQZ256rrbkz = 8124,
  VCVTTPH2UDQZ256rrk = 8125,
  VCVTTPH2UDQZ256rrkz = 8126,
  VCVTTPH2UDQZrm = 8127,
  VCVTTPH2UDQZrmb = 8128,
  VCVTTPH2UDQZrmbk = 8129,
  VCVTTPH2UDQZrmbkz = 8130,
  VCVTTPH2UDQZrmk = 8131,
  VCVTTPH2UDQZrmkz = 8132,
  VCVTTPH2UDQZrr = 8133,
  VCVTTPH2UDQZrrb = 8134,
  VCVTTPH2UDQZrrbk = 8135,
  VCVTTPH2UDQZrrbkz = 8136,
  VCVTTPH2UDQZrrk = 8137,
  VCVTTPH2UDQZrrkz = 8138,
  VCVTTPH2UQQZ128rm = 8139,
  VCVTTPH2UQQZ128rmb = 8140,
  VCVTTPH2UQQZ128rmbk = 8141,
  VCVTTPH2UQQZ128rmbkz = 8142,
  VCVTTPH2UQQZ128rmk = 8143,
  VCVTTPH2UQQZ128rmkz = 8144,
  VCVTTPH2UQQZ128rr = 8145,
  VCVTTPH2UQQZ128rrk = 8146,
  VCVTTPH2UQQZ128rrkz = 8147,
  VCVTTPH2UQQZ256rm = 8148,
  VCVTTPH2UQQZ256rmb = 8149,
  VCVTTPH2UQQZ256rmbk = 8150,
  VCVTTPH2UQQZ256rmbkz = 8151,
  VCVTTPH2UQQZ256rmk = 8152,
  VCVTTPH2UQQZ256rmkz = 8153,
  VCVTTPH2UQQZ256rr = 8154,
  VCVTTPH2UQQZ256rrb = 8155,
  VCVTTPH2UQQZ256rrbk = 8156,
  VCVTTPH2UQQZ256rrbkz = 8157,
  VCVTTPH2UQQZ256rrk = 8158,
  VCVTTPH2UQQZ256rrkz = 8159,
  VCVTTPH2UQQZrm = 8160,
  VCVTTPH2UQQZrmb = 8161,
  VCVTTPH2UQQZrmbk = 8162,
  VCVTTPH2UQQZrmbkz = 8163,
  VCVTTPH2UQQZrmk = 8164,
  VCVTTPH2UQQZrmkz = 8165,
  VCVTTPH2UQQZrr = 8166,
  VCVTTPH2UQQZrrb = 8167,
  VCVTTPH2UQQZrrbk = 8168,
  VCVTTPH2UQQZrrbkz = 8169,
  VCVTTPH2UQQZrrk = 8170,
  VCVTTPH2UQQZrrkz = 8171,
  VCVTTPH2UWZ128rm = 8172,
  VCVTTPH2UWZ128rmb = 8173,
  VCVTTPH2UWZ128rmbk = 8174,
  VCVTTPH2UWZ128rmbkz = 8175,
  VCVTTPH2UWZ128rmk = 8176,
  VCVTTPH2UWZ128rmkz = 8177,
  VCVTTPH2UWZ128rr = 8178,
  VCVTTPH2UWZ128rrk = 8179,
  VCVTTPH2UWZ128rrkz = 8180,
  VCVTTPH2UWZ256rm = 8181,
  VCVTTPH2UWZ256rmb = 8182,
  VCVTTPH2UWZ256rmbk = 8183,
  VCVTTPH2UWZ256rmbkz = 8184,
  VCVTTPH2UWZ256rmk = 8185,
  VCVTTPH2UWZ256rmkz = 8186,
  VCVTTPH2UWZ256rr = 8187,
  VCVTTPH2UWZ256rrb = 8188,
  VCVTTPH2UWZ256rrbk = 8189,
  VCVTTPH2UWZ256rrbkz = 8190,
  VCVTTPH2UWZ256rrk = 8191,
  VCVTTPH2UWZ256rrkz = 8192,
  VCVTTPH2UWZrm = 8193,
  VCVTTPH2UWZrmb = 8194,
  VCVTTPH2UWZrmbk = 8195,
  VCVTTPH2UWZrmbkz = 8196,
  VCVTTPH2UWZrmk = 8197,
  VCVTTPH2UWZrmkz = 8198,
  VCVTTPH2UWZrr = 8199,
  VCVTTPH2UWZrrb = 8200,
  VCVTTPH2UWZrrbk = 8201,
  VCVTTPH2UWZrrbkz = 8202,
  VCVTTPH2UWZrrk = 8203,
  VCVTTPH2UWZrrkz = 8204,
  VCVTTPH2WZ128rm = 8205,
  VCVTTPH2WZ128rmb = 8206,
  VCVTTPH2WZ128rmbk = 8207,
  VCVTTPH2WZ128rmbkz = 8208,
  VCVTTPH2WZ128rmk = 8209,
  VCVTTPH2WZ128rmkz = 8210,
  VCVTTPH2WZ128rr = 8211,
  VCVTTPH2WZ128rrk = 8212,
  VCVTTPH2WZ128rrkz = 8213,
  VCVTTPH2WZ256rm = 8214,
  VCVTTPH2WZ256rmb = 8215,
  VCVTTPH2WZ256rmbk = 8216,
  VCVTTPH2WZ256rmbkz = 8217,
  VCVTTPH2WZ256rmk = 8218,
  VCVTTPH2WZ256rmkz = 8219,
  VCVTTPH2WZ256rr = 8220,
  VCVTTPH2WZ256rrb = 8221,
  VCVTTPH2WZ256rrbk = 8222,
  VCVTTPH2WZ256rrbkz = 8223,
  VCVTTPH2WZ256rrk = 8224,
  VCVTTPH2WZ256rrkz = 8225,
  VCVTTPH2WZrm = 8226,
  VCVTTPH2WZrmb = 8227,
  VCVTTPH2WZrmbk = 8228,
  VCVTTPH2WZrmbkz = 8229,
  VCVTTPH2WZrmk = 8230,
  VCVTTPH2WZrmkz = 8231,
  VCVTTPH2WZrr = 8232,
  VCVTTPH2WZrrb = 8233,
  VCVTTPH2WZrrbk = 8234,
  VCVTTPH2WZrrbkz = 8235,
  VCVTTPH2WZrrk = 8236,
  VCVTTPH2WZrrkz = 8237,
  VCVTTPS2DQSZ128rm = 8238,
  VCVTTPS2DQSZ128rmb = 8239,
  VCVTTPS2DQSZ128rmbk = 8240,
  VCVTTPS2DQSZ128rmbkz = 8241,
  VCVTTPS2DQSZ128rmk = 8242,
  VCVTTPS2DQSZ128rmkz = 8243,
  VCVTTPS2DQSZ128rr = 8244,
  VCVTTPS2DQSZ128rrk = 8245,
  VCVTTPS2DQSZ128rrkz = 8246,
  VCVTTPS2DQSZ256rm = 8247,
  VCVTTPS2DQSZ256rmb = 8248,
  VCVTTPS2DQSZ256rmbk = 8249,
  VCVTTPS2DQSZ256rmbkz = 8250,
  VCVTTPS2DQSZ256rmk = 8251,
  VCVTTPS2DQSZ256rmkz = 8252,
  VCVTTPS2DQSZ256rr = 8253,
  VCVTTPS2DQSZ256rrb = 8254,
  VCVTTPS2DQSZ256rrbk = 8255,
  VCVTTPS2DQSZ256rrbkz = 8256,
  VCVTTPS2DQSZ256rrk = 8257,
  VCVTTPS2DQSZ256rrkz = 8258,
  VCVTTPS2DQSZrm = 8259,
  VCVTTPS2DQSZrmb = 8260,
  VCVTTPS2DQSZrmbk = 8261,
  VCVTTPS2DQSZrmbkz = 8262,
  VCVTTPS2DQSZrmk = 8263,
  VCVTTPS2DQSZrmkz = 8264,
  VCVTTPS2DQSZrr = 8265,
  VCVTTPS2DQSZrrb = 8266,
  VCVTTPS2DQSZrrbk = 8267,
  VCVTTPS2DQSZrrbkz = 8268,
  VCVTTPS2DQSZrrk = 8269,
  VCVTTPS2DQSZrrkz = 8270,
  VCVTTPS2DQYrm = 8271,
  VCVTTPS2DQYrr = 8272,
  VCVTTPS2DQZ128rm = 8273,
  VCVTTPS2DQZ128rmb = 8274,
  VCVTTPS2DQZ128rmbk = 8275,
  VCVTTPS2DQZ128rmbkz = 8276,
  VCVTTPS2DQZ128rmk = 8277,
  VCVTTPS2DQZ128rmkz = 8278,
  VCVTTPS2DQZ128rr = 8279,
  VCVTTPS2DQZ128rrk = 8280,
  VCVTTPS2DQZ128rrkz = 8281,
  VCVTTPS2DQZ256rm = 8282,
  VCVTTPS2DQZ256rmb = 8283,
  VCVTTPS2DQZ256rmbk = 8284,
  VCVTTPS2DQZ256rmbkz = 8285,
  VCVTTPS2DQZ256rmk = 8286,
  VCVTTPS2DQZ256rmkz = 8287,
  VCVTTPS2DQZ256rr = 8288,
  VCVTTPS2DQZ256rrb = 8289,
  VCVTTPS2DQZ256rrbk = 8290,
  VCVTTPS2DQZ256rrbkz = 8291,
  VCVTTPS2DQZ256rrk = 8292,
  VCVTTPS2DQZ256rrkz = 8293,
  VCVTTPS2DQZrm = 8294,
  VCVTTPS2DQZrmb = 8295,
  VCVTTPS2DQZrmbk = 8296,
  VCVTTPS2DQZrmbkz = 8297,
  VCVTTPS2DQZrmk = 8298,
  VCVTTPS2DQZrmkz = 8299,
  VCVTTPS2DQZrr = 8300,
  VCVTTPS2DQZrrb = 8301,
  VCVTTPS2DQZrrbk = 8302,
  VCVTTPS2DQZrrbkz = 8303,
  VCVTTPS2DQZrrk = 8304,
  VCVTTPS2DQZrrkz = 8305,
  VCVTTPS2DQrm = 8306,
  VCVTTPS2DQrr = 8307,
  VCVTTPS2IBSZ128rm = 8308,
  VCVTTPS2IBSZ128rmb = 8309,
  VCVTTPS2IBSZ128rmbk = 8310,
  VCVTTPS2IBSZ128rmbkz = 8311,
  VCVTTPS2IBSZ128rmk = 8312,
  VCVTTPS2IBSZ128rmkz = 8313,
  VCVTTPS2IBSZ128rr = 8314,
  VCVTTPS2IBSZ128rrk = 8315,
  VCVTTPS2IBSZ128rrkz = 8316,
  VCVTTPS2IBSZ256rm = 8317,
  VCVTTPS2IBSZ256rmb = 8318,
  VCVTTPS2IBSZ256rmbk = 8319,
  VCVTTPS2IBSZ256rmbkz = 8320,
  VCVTTPS2IBSZ256rmk = 8321,
  VCVTTPS2IBSZ256rmkz = 8322,
  VCVTTPS2IBSZ256rr = 8323,
  VCVTTPS2IBSZ256rrb = 8324,
  VCVTTPS2IBSZ256rrbk = 8325,
  VCVTTPS2IBSZ256rrbkz = 8326,
  VCVTTPS2IBSZ256rrk = 8327,
  VCVTTPS2IBSZ256rrkz = 8328,
  VCVTTPS2IBSZrm = 8329,
  VCVTTPS2IBSZrmb = 8330,
  VCVTTPS2IBSZrmbk = 8331,
  VCVTTPS2IBSZrmbkz = 8332,
  VCVTTPS2IBSZrmk = 8333,
  VCVTTPS2IBSZrmkz = 8334,
  VCVTTPS2IBSZrr = 8335,
  VCVTTPS2IBSZrrb = 8336,
  VCVTTPS2IBSZrrbk = 8337,
  VCVTTPS2IBSZrrbkz = 8338,
  VCVTTPS2IBSZrrk = 8339,
  VCVTTPS2IBSZrrkz = 8340,
  VCVTTPS2IUBSZ128rm = 8341,
  VCVTTPS2IUBSZ128rmb = 8342,
  VCVTTPS2IUBSZ128rmbk = 8343,
  VCVTTPS2IUBSZ128rmbkz = 8344,
  VCVTTPS2IUBSZ128rmk = 8345,
  VCVTTPS2IUBSZ128rmkz = 8346,
  VCVTTPS2IUBSZ128rr = 8347,
  VCVTTPS2IUBSZ128rrk = 8348,
  VCVTTPS2IUBSZ128rrkz = 8349,
  VCVTTPS2IUBSZ256rm = 8350,
  VCVTTPS2IUBSZ256rmb = 8351,
  VCVTTPS2IUBSZ256rmbk = 8352,
  VCVTTPS2IUBSZ256rmbkz = 8353,
  VCVTTPS2IUBSZ256rmk = 8354,
  VCVTTPS2IUBSZ256rmkz = 8355,
  VCVTTPS2IUBSZ256rr = 8356,
  VCVTTPS2IUBSZ256rrb = 8357,
  VCVTTPS2IUBSZ256rrbk = 8358,
  VCVTTPS2IUBSZ256rrbkz = 8359,
  VCVTTPS2IUBSZ256rrk = 8360,
  VCVTTPS2IUBSZ256rrkz = 8361,
  VCVTTPS2IUBSZrm = 8362,
  VCVTTPS2IUBSZrmb = 8363,
  VCVTTPS2IUBSZrmbk = 8364,
  VCVTTPS2IUBSZrmbkz = 8365,
  VCVTTPS2IUBSZrmk = 8366,
  VCVTTPS2IUBSZrmkz = 8367,
  VCVTTPS2IUBSZrr = 8368,
  VCVTTPS2IUBSZrrb = 8369,
  VCVTTPS2IUBSZrrbk = 8370,
  VCVTTPS2IUBSZrrbkz = 8371,
  VCVTTPS2IUBSZrrk = 8372,
  VCVTTPS2IUBSZrrkz = 8373,
  VCVTTPS2QQSZ128rm = 8374,
  VCVTTPS2QQSZ128rmb = 8375,
  VCVTTPS2QQSZ128rmbk = 8376,
  VCVTTPS2QQSZ128rmbkz = 8377,
  VCVTTPS2QQSZ128rmk = 8378,
  VCVTTPS2QQSZ128rmkz = 8379,
  VCVTTPS2QQSZ128rr = 8380,
  VCVTTPS2QQSZ128rrk = 8381,
  VCVTTPS2QQSZ128rrkz = 8382,
  VCVTTPS2QQSZ256rm = 8383,
  VCVTTPS2QQSZ256rmb = 8384,
  VCVTTPS2QQSZ256rmbk = 8385,
  VCVTTPS2QQSZ256rmbkz = 8386,
  VCVTTPS2QQSZ256rmk = 8387,
  VCVTTPS2QQSZ256rmkz = 8388,
  VCVTTPS2QQSZ256rr = 8389,
  VCVTTPS2QQSZ256rrb = 8390,
  VCVTTPS2QQSZ256rrbk = 8391,
  VCVTTPS2QQSZ256rrbkz = 8392,
  VCVTTPS2QQSZ256rrk = 8393,
  VCVTTPS2QQSZ256rrkz = 8394,
  VCVTTPS2QQSZrm = 8395,
  VCVTTPS2QQSZrmb = 8396,
  VCVTTPS2QQSZrmbk = 8397,
  VCVTTPS2QQSZrmbkz = 8398,
  VCVTTPS2QQSZrmk = 8399,
  VCVTTPS2QQSZrmkz = 8400,
  VCVTTPS2QQSZrr = 8401,
  VCVTTPS2QQSZrrb = 8402,
  VCVTTPS2QQSZrrbk = 8403,
  VCVTTPS2QQSZrrbkz = 8404,
  VCVTTPS2QQSZrrk = 8405,
  VCVTTPS2QQSZrrkz = 8406,
  VCVTTPS2QQZ128rm = 8407,
  VCVTTPS2QQZ128rmb = 8408,
  VCVTTPS2QQZ128rmbk = 8409,
  VCVTTPS2QQZ128rmbkz = 8410,
  VCVTTPS2QQZ128rmk = 8411,
  VCVTTPS2QQZ128rmkz = 8412,
  VCVTTPS2QQZ128rr = 8413,
  VCVTTPS2QQZ128rrk = 8414,
  VCVTTPS2QQZ128rrkz = 8415,
  VCVTTPS2QQZ256rm = 8416,
  VCVTTPS2QQZ256rmb = 8417,
  VCVTTPS2QQZ256rmbk = 8418,
  VCVTTPS2QQZ256rmbkz = 8419,
  VCVTTPS2QQZ256rmk = 8420,
  VCVTTPS2QQZ256rmkz = 8421,
  VCVTTPS2QQZ256rr = 8422,
  VCVTTPS2QQZ256rrb = 8423,
  VCVTTPS2QQZ256rrbk = 8424,
  VCVTTPS2QQZ256rrbkz = 8425,
  VCVTTPS2QQZ256rrk = 8426,
  VCVTTPS2QQZ256rrkz = 8427,
  VCVTTPS2QQZrm = 8428,
  VCVTTPS2QQZrmb = 8429,
  VCVTTPS2QQZrmbk = 8430,
  VCVTTPS2QQZrmbkz = 8431,
  VCVTTPS2QQZrmk = 8432,
  VCVTTPS2QQZrmkz = 8433,
  VCVTTPS2QQZrr = 8434,
  VCVTTPS2QQZrrb = 8435,
  VCVTTPS2QQZrrbk = 8436,
  VCVTTPS2QQZrrbkz = 8437,
  VCVTTPS2QQZrrk = 8438,
  VCVTTPS2QQZrrkz = 8439,
  VCVTTPS2UDQSZ128rm = 8440,
  VCVTTPS2UDQSZ128rmb = 8441,
  VCVTTPS2UDQSZ128rmbk = 8442,
  VCVTTPS2UDQSZ128rmbkz = 8443,
  VCVTTPS2UDQSZ128rmk = 8444,
  VCVTTPS2UDQSZ128rmkz = 8445,
  VCVTTPS2UDQSZ128rr = 8446,
  VCVTTPS2UDQSZ128rrk = 8447,
  VCVTTPS2UDQSZ128rrkz = 8448,
  VCVTTPS2UDQSZ256rm = 8449,
  VCVTTPS2UDQSZ256rmb = 8450,
  VCVTTPS2UDQSZ256rmbk = 8451,
  VCVTTPS2UDQSZ256rmbkz = 8452,
  VCVTTPS2UDQSZ256rmk = 8453,
  VCVTTPS2UDQSZ256rmkz = 8454,
  VCVTTPS2UDQSZ256rr = 8455,
  VCVTTPS2UDQSZ256rrb = 8456,
  VCVTTPS2UDQSZ256rrbk = 8457,
  VCVTTPS2UDQSZ256rrbkz = 8458,
  VCVTTPS2UDQSZ256rrk = 8459,
  VCVTTPS2UDQSZ256rrkz = 8460,
  VCVTTPS2UDQSZrm = 8461,
  VCVTTPS2UDQSZrmb = 8462,
  VCVTTPS2UDQSZrmbk = 8463,
  VCVTTPS2UDQSZrmbkz = 8464,
  VCVTTPS2UDQSZrmk = 8465,
  VCVTTPS2UDQSZrmkz = 8466,
  VCVTTPS2UDQSZrr = 8467,
  VCVTTPS2UDQSZrrb = 8468,
  VCVTTPS2UDQSZrrbk = 8469,
  VCVTTPS2UDQSZrrbkz = 8470,
  VCVTTPS2UDQSZrrk = 8471,
  VCVTTPS2UDQSZrrkz = 8472,
  VCVTTPS2UDQZ128rm = 8473,
  VCVTTPS2UDQZ128rmb = 8474,
  VCVTTPS2UDQZ128rmbk = 8475,
  VCVTTPS2UDQZ128rmbkz = 8476,
  VCVTTPS2UDQZ128rmk = 8477,
  VCVTTPS2UDQZ128rmkz = 8478,
  VCVTTPS2UDQZ128rr = 8479,
  VCVTTPS2UDQZ128rrk = 8480,
  VCVTTPS2UDQZ128rrkz = 8481,
  VCVTTPS2UDQZ256rm = 8482,
  VCVTTPS2UDQZ256rmb = 8483,
  VCVTTPS2UDQZ256rmbk = 8484,
  VCVTTPS2UDQZ256rmbkz = 8485,
  VCVTTPS2UDQZ256rmk = 8486,
  VCVTTPS2UDQZ256rmkz = 8487,
  VCVTTPS2UDQZ256rr = 8488,
  VCVTTPS2UDQZ256rrb = 8489,
  VCVTTPS2UDQZ256rrbk = 8490,
  VCVTTPS2UDQZ256rrbkz = 8491,
  VCVTTPS2UDQZ256rrk = 8492,
  VCVTTPS2UDQZ256rrkz = 8493,
  VCVTTPS2UDQZrm = 8494,
  VCVTTPS2UDQZrmb = 8495,
  VCVTTPS2UDQZrmbk = 8496,
  VCVTTPS2UDQZrmbkz = 8497,
  VCVTTPS2UDQZrmk = 8498,
  VCVTTPS2UDQZrmkz = 8499,
  VCVTTPS2UDQZrr = 8500,
  VCVTTPS2UDQZrrb = 8501,
  VCVTTPS2UDQZrrbk = 8502,
  VCVTTPS2UDQZrrbkz = 8503,
  VCVTTPS2UDQZrrk = 8504,
  VCVTTPS2UDQZrrkz = 8505,
  VCVTTPS2UQQSZ128rm = 8506,
  VCVTTPS2UQQSZ128rmb = 8507,
  VCVTTPS2UQQSZ128rmbk = 8508,
  VCVTTPS2UQQSZ128rmbkz = 8509,
  VCVTTPS2UQQSZ128rmk = 8510,
  VCVTTPS2UQQSZ128rmkz = 8511,
  VCVTTPS2UQQSZ128rr = 8512,
  VCVTTPS2UQQSZ128rrk = 8513,
  VCVTTPS2UQQSZ128rrkz = 8514,
  VCVTTPS2UQQSZ256rm = 8515,
  VCVTTPS2UQQSZ256rmb = 8516,
  VCVTTPS2UQQSZ256rmbk = 8517,
  VCVTTPS2UQQSZ256rmbkz = 8518,
  VCVTTPS2UQQSZ256rmk = 8519,
  VCVTTPS2UQQSZ256rmkz = 8520,
  VCVTTPS2UQQSZ256rr = 8521,
  VCVTTPS2UQQSZ256rrb = 8522,
  VCVTTPS2UQQSZ256rrbk = 8523,
  VCVTTPS2UQQSZ256rrbkz = 8524,
  VCVTTPS2UQQSZ256rrk = 8525,
  VCVTTPS2UQQSZ256rrkz = 8526,
  VCVTTPS2UQQSZrm = 8527,
  VCVTTPS2UQQSZrmb = 8528,
  VCVTTPS2UQQSZrmbk = 8529,
  VCVTTPS2UQQSZrmbkz = 8530,
  VCVTTPS2UQQSZrmk = 8531,
  VCVTTPS2UQQSZrmkz = 8532,
  VCVTTPS2UQQSZrr = 8533,
  VCVTTPS2UQQSZrrb = 8534,
  VCVTTPS2UQQSZrrbk = 8535,
  VCVTTPS2UQQSZrrbkz = 8536,
  VCVTTPS2UQQSZrrk = 8537,
  VCVTTPS2UQQSZrrkz = 8538,
  VCVTTPS2UQQZ128rm = 8539,
  VCVTTPS2UQQZ128rmb = 8540,
  VCVTTPS2UQQZ128rmbk = 8541,
  VCVTTPS2UQQZ128rmbkz = 8542,
  VCVTTPS2UQQZ128rmk = 8543,
  VCVTTPS2UQQZ128rmkz = 8544,
  VCVTTPS2UQQZ128rr = 8545,
  VCVTTPS2UQQZ128rrk = 8546,
  VCVTTPS2UQQZ128rrkz = 8547,
  VCVTTPS2UQQZ256rm = 8548,
  VCVTTPS2UQQZ256rmb = 8549,
  VCVTTPS2UQQZ256rmbk = 8550,
  VCVTTPS2UQQZ256rmbkz = 8551,
  VCVTTPS2UQQZ256rmk = 8552,
  VCVTTPS2UQQZ256rmkz = 8553,
  VCVTTPS2UQQZ256rr = 8554,
  VCVTTPS2UQQZ256rrb = 8555,
  VCVTTPS2UQQZ256rrbk = 8556,
  VCVTTPS2UQQZ256rrbkz = 8557,
  VCVTTPS2UQQZ256rrk = 8558,
  VCVTTPS2UQQZ256rrkz = 8559,
  VCVTTPS2UQQZrm = 8560,
  VCVTTPS2UQQZrmb = 8561,
  VCVTTPS2UQQZrmbk = 8562,
  VCVTTPS2UQQZrmbkz = 8563,
  VCVTTPS2UQQZrmk = 8564,
  VCVTTPS2UQQZrmkz = 8565,
  VCVTTPS2UQQZrr = 8566,
  VCVTTPS2UQQZrrb = 8567,
  VCVTTPS2UQQZrrbk = 8568,
  VCVTTPS2UQQZrrbkz = 8569,
  VCVTTPS2UQQZrrk = 8570,
  VCVTTPS2UQQZrrkz = 8571,
  VCVTTSD2SI64Srm = 8572,
  VCVTTSD2SI64Srm_Int = 8573,
  VCVTTSD2SI64Srr = 8574,
  VCVTTSD2SI64Srr_Int = 8575,
  VCVTTSD2SI64Srrb_Int = 8576,
  VCVTTSD2SI64Zrm = 8577,
  VCVTTSD2SI64Zrm_Int = 8578,
  VCVTTSD2SI64Zrr = 8579,
  VCVTTSD2SI64Zrr_Int = 8580,
  VCVTTSD2SI64Zrrb_Int = 8581,
  VCVTTSD2SI64rm = 8582,
  VCVTTSD2SI64rm_Int = 8583,
  VCVTTSD2SI64rr = 8584,
  VCVTTSD2SI64rr_Int = 8585,
  VCVTTSD2SISrm = 8586,
  VCVTTSD2SISrm_Int = 8587,
  VCVTTSD2SISrr = 8588,
  VCVTTSD2SISrr_Int = 8589,
  VCVTTSD2SISrrb_Int = 8590,
  VCVTTSD2SIZrm = 8591,
  VCVTTSD2SIZrm_Int = 8592,
  VCVTTSD2SIZrr = 8593,
  VCVTTSD2SIZrr_Int = 8594,
  VCVTTSD2SIZrrb_Int = 8595,
  VCVTTSD2SIrm = 8596,
  VCVTTSD2SIrm_Int = 8597,
  VCVTTSD2SIrr = 8598,
  VCVTTSD2SIrr_Int = 8599,
  VCVTTSD2USI64Srm = 8600,
  VCVTTSD2USI64Srm_Int = 8601,
  VCVTTSD2USI64Srr = 8602,
  VCVTTSD2USI64Srr_Int = 8603,
  VCVTTSD2USI64Srrb_Int = 8604,
  VCVTTSD2USI64Zrm = 8605,
  VCVTTSD2USI64Zrm_Int = 8606,
  VCVTTSD2USI64Zrr = 8607,
  VCVTTSD2USI64Zrr_Int = 8608,
  VCVTTSD2USI64Zrrb_Int = 8609,
  VCVTTSD2USISrm = 8610,
  VCVTTSD2USISrm_Int = 8611,
  VCVTTSD2USISrr = 8612,
  VCVTTSD2USISrr_Int = 8613,
  VCVTTSD2USISrrb_Int = 8614,
  VCVTTSD2USIZrm = 8615,
  VCVTTSD2USIZrm_Int = 8616,
  VCVTTSD2USIZrr = 8617,
  VCVTTSD2USIZrr_Int = 8618,
  VCVTTSD2USIZrrb_Int = 8619,
  VCVTTSH2SI64Zrm = 8620,
  VCVTTSH2SI64Zrm_Int = 8621,
  VCVTTSH2SI64Zrr = 8622,
  VCVTTSH2SI64Zrr_Int = 8623,
  VCVTTSH2SI64Zrrb_Int = 8624,
  VCVTTSH2SIZrm = 8625,
  VCVTTSH2SIZrm_Int = 8626,
  VCVTTSH2SIZrr = 8627,
  VCVTTSH2SIZrr_Int = 8628,
  VCVTTSH2SIZrrb_Int = 8629,
  VCVTTSH2USI64Zrm = 8630,
  VCVTTSH2USI64Zrm_Int = 8631,
  VCVTTSH2USI64Zrr = 8632,
  VCVTTSH2USI64Zrr_Int = 8633,
  VCVTTSH2USI64Zrrb_Int = 8634,
  VCVTTSH2USIZrm = 8635,
  VCVTTSH2USIZrm_Int = 8636,
  VCVTTSH2USIZrr = 8637,
  VCVTTSH2USIZrr_Int = 8638,
  VCVTTSH2USIZrrb_Int = 8639,
  VCVTTSS2SI64Srm = 8640,
  VCVTTSS2SI64Srm_Int = 8641,
  VCVTTSS2SI64Srr = 8642,
  VCVTTSS2SI64Srr_Int = 8643,
  VCVTTSS2SI64Srrb_Int = 8644,
  VCVTTSS2SI64Zrm = 8645,
  VCVTTSS2SI64Zrm_Int = 8646,
  VCVTTSS2SI64Zrr = 8647,
  VCVTTSS2SI64Zrr_Int = 8648,
  VCVTTSS2SI64Zrrb_Int = 8649,
  VCVTTSS2SI64rm = 8650,
  VCVTTSS2SI64rm_Int = 8651,
  VCVTTSS2SI64rr = 8652,
  VCVTTSS2SI64rr_Int = 8653,
  VCVTTSS2SISrm = 8654,
  VCVTTSS2SISrm_Int = 8655,
  VCVTTSS2SISrr = 8656,
  VCVTTSS2SISrr_Int = 8657,
  VCVTTSS2SISrrb_Int = 8658,
  VCVTTSS2SIZrm = 8659,
  VCVTTSS2SIZrm_Int = 8660,
  VCVTTSS2SIZrr = 8661,
  VCVTTSS2SIZrr_Int = 8662,
  VCVTTSS2SIZrrb_Int = 8663,
  VCVTTSS2SIrm = 8664,
  VCVTTSS2SIrm_Int = 8665,
  VCVTTSS2SIrr = 8666,
  VCVTTSS2SIrr_Int = 8667,
  VCVTTSS2USI64Srm = 8668,
  VCVTTSS2USI64Srm_Int = 8669,
  VCVTTSS2USI64Srr = 8670,
  VCVTTSS2USI64Srr_Int = 8671,
  VCVTTSS2USI64Srrb_Int = 8672,
  VCVTTSS2USI64Zrm = 8673,
  VCVTTSS2USI64Zrm_Int = 8674,
  VCVTTSS2USI64Zrr = 8675,
  VCVTTSS2USI64Zrr_Int = 8676,
  VCVTTSS2USI64Zrrb_Int = 8677,
  VCVTTSS2USISrm = 8678,
  VCVTTSS2USISrm_Int = 8679,
  VCVTTSS2USISrr = 8680,
  VCVTTSS2USISrr_Int = 8681,
  VCVTTSS2USISrrb_Int = 8682,
  VCVTTSS2USIZrm = 8683,
  VCVTTSS2USIZrm_Int = 8684,
  VCVTTSS2USIZrr = 8685,
  VCVTTSS2USIZrr_Int = 8686,
  VCVTTSS2USIZrrb_Int = 8687,
  VCVTUDQ2PDZ128rm = 8688,
  VCVTUDQ2PDZ128rmb = 8689,
  VCVTUDQ2PDZ128rmbk = 8690,
  VCVTUDQ2PDZ128rmbkz = 8691,
  VCVTUDQ2PDZ128rmk = 8692,
  VCVTUDQ2PDZ128rmkz = 8693,
  VCVTUDQ2PDZ128rr = 8694,
  VCVTUDQ2PDZ128rrk = 8695,
  VCVTUDQ2PDZ128rrkz = 8696,
  VCVTUDQ2PDZ256rm = 8697,
  VCVTUDQ2PDZ256rmb = 8698,
  VCVTUDQ2PDZ256rmbk = 8699,
  VCVTUDQ2PDZ256rmbkz = 8700,
  VCVTUDQ2PDZ256rmk = 8701,
  VCVTUDQ2PDZ256rmkz = 8702,
  VCVTUDQ2PDZ256rr = 8703,
  VCVTUDQ2PDZ256rrk = 8704,
  VCVTUDQ2PDZ256rrkz = 8705,
  VCVTUDQ2PDZrm = 8706,
  VCVTUDQ2PDZrmb = 8707,
  VCVTUDQ2PDZrmbk = 8708,
  VCVTUDQ2PDZrmbkz = 8709,
  VCVTUDQ2PDZrmk = 8710,
  VCVTUDQ2PDZrmkz = 8711,
  VCVTUDQ2PDZrr = 8712,
  VCVTUDQ2PDZrrk = 8713,
  VCVTUDQ2PDZrrkz = 8714,
  VCVTUDQ2PHZ128rm = 8715,
  VCVTUDQ2PHZ128rmb = 8716,
  VCVTUDQ2PHZ128rmbk = 8717,
  VCVTUDQ2PHZ128rmbkz = 8718,
  VCVTUDQ2PHZ128rmk = 8719,
  VCVTUDQ2PHZ128rmkz = 8720,
  VCVTUDQ2PHZ128rr = 8721,
  VCVTUDQ2PHZ128rrk = 8722,
  VCVTUDQ2PHZ128rrkz = 8723,
  VCVTUDQ2PHZ256rm = 8724,
  VCVTUDQ2PHZ256rmb = 8725,
  VCVTUDQ2PHZ256rmbk = 8726,
  VCVTUDQ2PHZ256rmbkz = 8727,
  VCVTUDQ2PHZ256rmk = 8728,
  VCVTUDQ2PHZ256rmkz = 8729,
  VCVTUDQ2PHZ256rr = 8730,
  VCVTUDQ2PHZ256rrb = 8731,
  VCVTUDQ2PHZ256rrbk = 8732,
  VCVTUDQ2PHZ256rrbkz = 8733,
  VCVTUDQ2PHZ256rrk = 8734,
  VCVTUDQ2PHZ256rrkz = 8735,
  VCVTUDQ2PHZrm = 8736,
  VCVTUDQ2PHZrmb = 8737,
  VCVTUDQ2PHZrmbk = 8738,
  VCVTUDQ2PHZrmbkz = 8739,
  VCVTUDQ2PHZrmk = 8740,
  VCVTUDQ2PHZrmkz = 8741,
  VCVTUDQ2PHZrr = 8742,
  VCVTUDQ2PHZrrb = 8743,
  VCVTUDQ2PHZrrbk = 8744,
  VCVTUDQ2PHZrrbkz = 8745,
  VCVTUDQ2PHZrrk = 8746,
  VCVTUDQ2PHZrrkz = 8747,
  VCVTUDQ2PSZ128rm = 8748,
  VCVTUDQ2PSZ128rmb = 8749,
  VCVTUDQ2PSZ128rmbk = 8750,
  VCVTUDQ2PSZ128rmbkz = 8751,
  VCVTUDQ2PSZ128rmk = 8752,
  VCVTUDQ2PSZ128rmkz = 8753,
  VCVTUDQ2PSZ128rr = 8754,
  VCVTUDQ2PSZ128rrk = 8755,
  VCVTUDQ2PSZ128rrkz = 8756,
  VCVTUDQ2PSZ256rm = 8757,
  VCVTUDQ2PSZ256rmb = 8758,
  VCVTUDQ2PSZ256rmbk = 8759,
  VCVTUDQ2PSZ256rmbkz = 8760,
  VCVTUDQ2PSZ256rmk = 8761,
  VCVTUDQ2PSZ256rmkz = 8762,
  VCVTUDQ2PSZ256rr = 8763,
  VCVTUDQ2PSZ256rrb = 8764,
  VCVTUDQ2PSZ256rrbk = 8765,
  VCVTUDQ2PSZ256rrbkz = 8766,
  VCVTUDQ2PSZ256rrk = 8767,
  VCVTUDQ2PSZ256rrkz = 8768,
  VCVTUDQ2PSZrm = 8769,
  VCVTUDQ2PSZrmb = 8770,
  VCVTUDQ2PSZrmbk = 8771,
  VCVTUDQ2PSZrmbkz = 8772,
  VCVTUDQ2PSZrmk = 8773,
  VCVTUDQ2PSZrmkz = 8774,
  VCVTUDQ2PSZrr = 8775,
  VCVTUDQ2PSZrrb = 8776,
  VCVTUDQ2PSZrrbk = 8777,
  VCVTUDQ2PSZrrbkz = 8778,
  VCVTUDQ2PSZrrk = 8779,
  VCVTUDQ2PSZrrkz = 8780,
  VCVTUQQ2PDZ128rm = 8781,
  VCVTUQQ2PDZ128rmb = 8782,
  VCVTUQQ2PDZ128rmbk = 8783,
  VCVTUQQ2PDZ128rmbkz = 8784,
  VCVTUQQ2PDZ128rmk = 8785,
  VCVTUQQ2PDZ128rmkz = 8786,
  VCVTUQQ2PDZ128rr = 8787,
  VCVTUQQ2PDZ128rrk = 8788,
  VCVTUQQ2PDZ128rrkz = 8789,
  VCVTUQQ2PDZ256rm = 8790,
  VCVTUQQ2PDZ256rmb = 8791,
  VCVTUQQ2PDZ256rmbk = 8792,
  VCVTUQQ2PDZ256rmbkz = 8793,
  VCVTUQQ2PDZ256rmk = 8794,
  VCVTUQQ2PDZ256rmkz = 8795,
  VCVTUQQ2PDZ256rr = 8796,
  VCVTUQQ2PDZ256rrb = 8797,
  VCVTUQQ2PDZ256rrbk = 8798,
  VCVTUQQ2PDZ256rrbkz = 8799,
  VCVTUQQ2PDZ256rrk = 8800,
  VCVTUQQ2PDZ256rrkz = 8801,
  VCVTUQQ2PDZrm = 8802,
  VCVTUQQ2PDZrmb = 8803,
  VCVTUQQ2PDZrmbk = 8804,
  VCVTUQQ2PDZrmbkz = 8805,
  VCVTUQQ2PDZrmk = 8806,
  VCVTUQQ2PDZrmkz = 8807,
  VCVTUQQ2PDZrr = 8808,
  VCVTUQQ2PDZrrb = 8809,
  VCVTUQQ2PDZrrbk = 8810,
  VCVTUQQ2PDZrrbkz = 8811,
  VCVTUQQ2PDZrrk = 8812,
  VCVTUQQ2PDZrrkz = 8813,
  VCVTUQQ2PHZ128rm = 8814,
  VCVTUQQ2PHZ128rmb = 8815,
  VCVTUQQ2PHZ128rmbk = 8816,
  VCVTUQQ2PHZ128rmbkz = 8817,
  VCVTUQQ2PHZ128rmk = 8818,
  VCVTUQQ2PHZ128rmkz = 8819,
  VCVTUQQ2PHZ128rr = 8820,
  VCVTUQQ2PHZ128rrk = 8821,
  VCVTUQQ2PHZ128rrkz = 8822,
  VCVTUQQ2PHZ256rm = 8823,
  VCVTUQQ2PHZ256rmb = 8824,
  VCVTUQQ2PHZ256rmbk = 8825,
  VCVTUQQ2PHZ256rmbkz = 8826,
  VCVTUQQ2PHZ256rmk = 8827,
  VCVTUQQ2PHZ256rmkz = 8828,
  VCVTUQQ2PHZ256rr = 8829,
  VCVTUQQ2PHZ256rrb = 8830,
  VCVTUQQ2PHZ256rrbk = 8831,
  VCVTUQQ2PHZ256rrbkz = 8832,
  VCVTUQQ2PHZ256rrk = 8833,
  VCVTUQQ2PHZ256rrkz = 8834,
  VCVTUQQ2PHZrm = 8835,
  VCVTUQQ2PHZrmb = 8836,
  VCVTUQQ2PHZrmbk = 8837,
  VCVTUQQ2PHZrmbkz = 8838,
  VCVTUQQ2PHZrmk = 8839,
  VCVTUQQ2PHZrmkz = 8840,
  VCVTUQQ2PHZrr = 8841,
  VCVTUQQ2PHZrrb = 8842,
  VCVTUQQ2PHZrrbk = 8843,
  VCVTUQQ2PHZrrbkz = 8844,
  VCVTUQQ2PHZrrk = 8845,
  VCVTUQQ2PHZrrkz = 8846,
  VCVTUQQ2PSZ128rm = 8847,
  VCVTUQQ2PSZ128rmb = 8848,
  VCVTUQQ2PSZ128rmbk = 8849,
  VCVTUQQ2PSZ128rmbkz = 8850,
  VCVTUQQ2PSZ128rmk = 8851,
  VCVTUQQ2PSZ128rmkz = 8852,
  VCVTUQQ2PSZ128rr = 8853,
  VCVTUQQ2PSZ128rrk = 8854,
  VCVTUQQ2PSZ128rrkz = 8855,
  VCVTUQQ2PSZ256rm = 8856,
  VCVTUQQ2PSZ256rmb = 8857,
  VCVTUQQ2PSZ256rmbk = 8858,
  VCVTUQQ2PSZ256rmbkz = 8859,
  VCVTUQQ2PSZ256rmk = 8860,
  VCVTUQQ2PSZ256rmkz = 8861,
  VCVTUQQ2PSZ256rr = 8862,
  VCVTUQQ2PSZ256rrb = 8863,
  VCVTUQQ2PSZ256rrbk = 8864,
  VCVTUQQ2PSZ256rrbkz = 8865,
  VCVTUQQ2PSZ256rrk = 8866,
  VCVTUQQ2PSZ256rrkz = 8867,
  VCVTUQQ2PSZrm = 8868,
  VCVTUQQ2PSZrmb = 8869,
  VCVTUQQ2PSZrmbk = 8870,
  VCVTUQQ2PSZrmbkz = 8871,
  VCVTUQQ2PSZrmk = 8872,
  VCVTUQQ2PSZrmkz = 8873,
  VCVTUQQ2PSZrr = 8874,
  VCVTUQQ2PSZrrb = 8875,
  VCVTUQQ2PSZrrbk = 8876,
  VCVTUQQ2PSZrrbkz = 8877,
  VCVTUQQ2PSZrrk = 8878,
  VCVTUQQ2PSZrrkz = 8879,
  VCVTUSI2SDZrm = 8880,
  VCVTUSI2SDZrm_Int = 8881,
  VCVTUSI2SDZrr = 8882,
  VCVTUSI2SDZrr_Int = 8883,
  VCVTUSI2SHZrm = 8884,
  VCVTUSI2SHZrm_Int = 8885,
  VCVTUSI2SHZrr = 8886,
  VCVTUSI2SHZrr_Int = 8887,
  VCVTUSI2SHZrrb_Int = 8888,
  VCVTUSI2SSZrm = 8889,
  VCVTUSI2SSZrm_Int = 8890,
  VCVTUSI2SSZrr = 8891,
  VCVTUSI2SSZrr_Int = 8892,
  VCVTUSI2SSZrrb_Int = 8893,
  VCVTUSI642SDZrm = 8894,
  VCVTUSI642SDZrm_Int = 8895,
  VCVTUSI642SDZrr = 8896,
  VCVTUSI642SDZrr_Int = 8897,
  VCVTUSI642SDZrrb_Int = 8898,
  VCVTUSI642SHZrm = 8899,
  VCVTUSI642SHZrm_Int = 8900,
  VCVTUSI642SHZrr = 8901,
  VCVTUSI642SHZrr_Int = 8902,
  VCVTUSI642SHZrrb_Int = 8903,
  VCVTUSI642SSZrm = 8904,
  VCVTUSI642SSZrm_Int = 8905,
  VCVTUSI642SSZrr = 8906,
  VCVTUSI642SSZrr_Int = 8907,
  VCVTUSI642SSZrrb_Int = 8908,
  VCVTUW2PHZ128rm = 8909,
  VCVTUW2PHZ128rmb = 8910,
  VCVTUW2PHZ128rmbk = 8911,
  VCVTUW2PHZ128rmbkz = 8912,
  VCVTUW2PHZ128rmk = 8913,
  VCVTUW2PHZ128rmkz = 8914,
  VCVTUW2PHZ128rr = 8915,
  VCVTUW2PHZ128rrk = 8916,
  VCVTUW2PHZ128rrkz = 8917,
  VCVTUW2PHZ256rm = 8918,
  VCVTUW2PHZ256rmb = 8919,
  VCVTUW2PHZ256rmbk = 8920,
  VCVTUW2PHZ256rmbkz = 8921,
  VCVTUW2PHZ256rmk = 8922,
  VCVTUW2PHZ256rmkz = 8923,
  VCVTUW2PHZ256rr = 8924,
  VCVTUW2PHZ256rrb = 8925,
  VCVTUW2PHZ256rrbk = 8926,
  VCVTUW2PHZ256rrbkz = 8927,
  VCVTUW2PHZ256rrk = 8928,
  VCVTUW2PHZ256rrkz = 8929,
  VCVTUW2PHZrm = 8930,
  VCVTUW2PHZrmb = 8931,
  VCVTUW2PHZrmbk = 8932,
  VCVTUW2PHZrmbkz = 8933,
  VCVTUW2PHZrmk = 8934,
  VCVTUW2PHZrmkz = 8935,
  VCVTUW2PHZrr = 8936,
  VCVTUW2PHZrrb = 8937,
  VCVTUW2PHZrrbk = 8938,
  VCVTUW2PHZrrbkz = 8939,
  VCVTUW2PHZrrk = 8940,
  VCVTUW2PHZrrkz = 8941,
  VCVTW2PHZ128rm = 8942,
  VCVTW2PHZ128rmb = 8943,
  VCVTW2PHZ128rmbk = 8944,
  VCVTW2PHZ128rmbkz = 8945,
  VCVTW2PHZ128rmk = 8946,
  VCVTW2PHZ128rmkz = 8947,
  VCVTW2PHZ128rr = 8948,
  VCVTW2PHZ128rrk = 8949,
  VCVTW2PHZ128rrkz = 8950,
  VCVTW2PHZ256rm = 8951,
  VCVTW2PHZ256rmb = 8952,
  VCVTW2PHZ256rmbk = 8953,
  VCVTW2PHZ256rmbkz = 8954,
  VCVTW2PHZ256rmk = 8955,
  VCVTW2PHZ256rmkz = 8956,
  VCVTW2PHZ256rr = 8957,
  VCVTW2PHZ256rrb = 8958,
  VCVTW2PHZ256rrbk = 8959,
  VCVTW2PHZ256rrbkz = 8960,
  VCVTW2PHZ256rrk = 8961,
  VCVTW2PHZ256rrkz = 8962,
  VCVTW2PHZrm = 8963,
  VCVTW2PHZrmb = 8964,
  VCVTW2PHZrmbk = 8965,
  VCVTW2PHZrmbkz = 8966,
  VCVTW2PHZrmk = 8967,
  VCVTW2PHZrmkz = 8968,
  VCVTW2PHZrr = 8969,
  VCVTW2PHZrrb = 8970,
  VCVTW2PHZrrbk = 8971,
  VCVTW2PHZrrbkz = 8972,
  VCVTW2PHZrrk = 8973,
  VCVTW2PHZrrkz = 8974,
  VDBPSADBWZ128rmi = 8975,
  VDBPSADBWZ128rmik = 8976,
  VDBPSADBWZ128rmikz = 8977,
  VDBPSADBWZ128rri = 8978,
  VDBPSADBWZ128rrik = 8979,
  VDBPSADBWZ128rrikz = 8980,
  VDBPSADBWZ256rmi = 8981,
  VDBPSADBWZ256rmik = 8982,
  VDBPSADBWZ256rmikz = 8983,
  VDBPSADBWZ256rri = 8984,
  VDBPSADBWZ256rrik = 8985,
  VDBPSADBWZ256rrikz = 8986,
  VDBPSADBWZrmi = 8987,
  VDBPSADBWZrmik = 8988,
  VDBPSADBWZrmikz = 8989,
  VDBPSADBWZrri = 8990,
  VDBPSADBWZrrik = 8991,
  VDBPSADBWZrrikz = 8992,
  VDIVBF16Z128rm = 8993,
  VDIVBF16Z128rmb = 8994,
  VDIVBF16Z128rmbk = 8995,
  VDIVBF16Z128rmbkz = 8996,
  VDIVBF16Z128rmk = 8997,
  VDIVBF16Z128rmkz = 8998,
  VDIVBF16Z128rr = 8999,
  VDIVBF16Z128rrk = 9000,
  VDIVBF16Z128rrkz = 9001,
  VDIVBF16Z256rm = 9002,
  VDIVBF16Z256rmb = 9003,
  VDIVBF16Z256rmbk = 9004,
  VDIVBF16Z256rmbkz = 9005,
  VDIVBF16Z256rmk = 9006,
  VDIVBF16Z256rmkz = 9007,
  VDIVBF16Z256rr = 9008,
  VDIVBF16Z256rrk = 9009,
  VDIVBF16Z256rrkz = 9010,
  VDIVBF16Zrm = 9011,
  VDIVBF16Zrmb = 9012,
  VDIVBF16Zrmbk = 9013,
  VDIVBF16Zrmbkz = 9014,
  VDIVBF16Zrmk = 9015,
  VDIVBF16Zrmkz = 9016,
  VDIVBF16Zrr = 9017,
  VDIVBF16Zrrk = 9018,
  VDIVBF16Zrrkz = 9019,
  VDIVPDYrm = 9020,
  VDIVPDYrr = 9021,
  VDIVPDZ128rm = 9022,
  VDIVPDZ128rmb = 9023,
  VDIVPDZ128rmbk = 9024,
  VDIVPDZ128rmbkz = 9025,
  VDIVPDZ128rmk = 9026,
  VDIVPDZ128rmkz = 9027,
  VDIVPDZ128rr = 9028,
  VDIVPDZ128rrk = 9029,
  VDIVPDZ128rrkz = 9030,
  VDIVPDZ256rm = 9031,
  VDIVPDZ256rmb = 9032,
  VDIVPDZ256rmbk = 9033,
  VDIVPDZ256rmbkz = 9034,
  VDIVPDZ256rmk = 9035,
  VDIVPDZ256rmkz = 9036,
  VDIVPDZ256rr = 9037,
  VDIVPDZ256rrb = 9038,
  VDIVPDZ256rrbk = 9039,
  VDIVPDZ256rrbkz = 9040,
  VDIVPDZ256rrk = 9041,
  VDIVPDZ256rrkz = 9042,
  VDIVPDZrm = 9043,
  VDIVPDZrmb = 9044,
  VDIVPDZrmbk = 9045,
  VDIVPDZrmbkz = 9046,
  VDIVPDZrmk = 9047,
  VDIVPDZrmkz = 9048,
  VDIVPDZrr = 9049,
  VDIVPDZrrb = 9050,
  VDIVPDZrrbk = 9051,
  VDIVPDZrrbkz = 9052,
  VDIVPDZrrk = 9053,
  VDIVPDZrrkz = 9054,
  VDIVPDrm = 9055,
  VDIVPDrr = 9056,
  VDIVPHZ128rm = 9057,
  VDIVPHZ128rmb = 9058,
  VDIVPHZ128rmbk = 9059,
  VDIVPHZ128rmbkz = 9060,
  VDIVPHZ128rmk = 9061,
  VDIVPHZ128rmkz = 9062,
  VDIVPHZ128rr = 9063,
  VDIVPHZ128rrk = 9064,
  VDIVPHZ128rrkz = 9065,
  VDIVPHZ256rm = 9066,
  VDIVPHZ256rmb = 9067,
  VDIVPHZ256rmbk = 9068,
  VDIVPHZ256rmbkz = 9069,
  VDIVPHZ256rmk = 9070,
  VDIVPHZ256rmkz = 9071,
  VDIVPHZ256rr = 9072,
  VDIVPHZ256rrb = 9073,
  VDIVPHZ256rrbk = 9074,
  VDIVPHZ256rrbkz = 9075,
  VDIVPHZ256rrk = 9076,
  VDIVPHZ256rrkz = 9077,
  VDIVPHZrm = 9078,
  VDIVPHZrmb = 9079,
  VDIVPHZrmbk = 9080,
  VDIVPHZrmbkz = 9081,
  VDIVPHZrmk = 9082,
  VDIVPHZrmkz = 9083,
  VDIVPHZrr = 9084,
  VDIVPHZrrb = 9085,
  VDIVPHZrrbk = 9086,
  VDIVPHZrrbkz = 9087,
  VDIVPHZrrk = 9088,
  VDIVPHZrrkz = 9089,
  VDIVPSYrm = 9090,
  VDIVPSYrr = 9091,
  VDIVPSZ128rm = 9092,
  VDIVPSZ128rmb = 9093,
  VDIVPSZ128rmbk = 9094,
  VDIVPSZ128rmbkz = 9095,
  VDIVPSZ128rmk = 9096,
  VDIVPSZ128rmkz = 9097,
  VDIVPSZ128rr = 9098,
  VDIVPSZ128rrk = 9099,
  VDIVPSZ128rrkz = 9100,
  VDIVPSZ256rm = 9101,
  VDIVPSZ256rmb = 9102,
  VDIVPSZ256rmbk = 9103,
  VDIVPSZ256rmbkz = 9104,
  VDIVPSZ256rmk = 9105,
  VDIVPSZ256rmkz = 9106,
  VDIVPSZ256rr = 9107,
  VDIVPSZ256rrb = 9108,
  VDIVPSZ256rrbk = 9109,
  VDIVPSZ256rrbkz = 9110,
  VDIVPSZ256rrk = 9111,
  VDIVPSZ256rrkz = 9112,
  VDIVPSZrm = 9113,
  VDIVPSZrmb = 9114,
  VDIVPSZrmbk = 9115,
  VDIVPSZrmbkz = 9116,
  VDIVPSZrmk = 9117,
  VDIVPSZrmkz = 9118,
  VDIVPSZrr = 9119,
  VDIVPSZrrb = 9120,
  VDIVPSZrrbk = 9121,
  VDIVPSZrrbkz = 9122,
  VDIVPSZrrk = 9123,
  VDIVPSZrrkz = 9124,
  VDIVPSrm = 9125,
  VDIVPSrr = 9126,
  VDIVSDZrm = 9127,
  VDIVSDZrm_Int = 9128,
  VDIVSDZrmk_Int = 9129,
  VDIVSDZrmkz_Int = 9130,
  VDIVSDZrr = 9131,
  VDIVSDZrr_Int = 9132,
  VDIVSDZrrb_Int = 9133,
  VDIVSDZrrbk_Int = 9134,
  VDIVSDZrrbkz_Int = 9135,
  VDIVSDZrrk_Int = 9136,
  VDIVSDZrrkz_Int = 9137,
  VDIVSDrm = 9138,
  VDIVSDrm_Int = 9139,
  VDIVSDrr = 9140,
  VDIVSDrr_Int = 9141,
  VDIVSHZrm = 9142,
  VDIVSHZrm_Int = 9143,
  VDIVSHZrmk_Int = 9144,
  VDIVSHZrmkz_Int = 9145,
  VDIVSHZrr = 9146,
  VDIVSHZrr_Int = 9147,
  VDIVSHZrrb_Int = 9148,
  VDIVSHZrrbk_Int = 9149,
  VDIVSHZrrbkz_Int = 9150,
  VDIVSHZrrk_Int = 9151,
  VDIVSHZrrkz_Int = 9152,
  VDIVSSZrm = 9153,
  VDIVSSZrm_Int = 9154,
  VDIVSSZrmk_Int = 9155,
  VDIVSSZrmkz_Int = 9156,
  VDIVSSZrr = 9157,
  VDIVSSZrr_Int = 9158,
  VDIVSSZrrb_Int = 9159,
  VDIVSSZrrbk_Int = 9160,
  VDIVSSZrrbkz_Int = 9161,
  VDIVSSZrrk_Int = 9162,
  VDIVSSZrrkz_Int = 9163,
  VDIVSSrm = 9164,
  VDIVSSrm_Int = 9165,
  VDIVSSrr = 9166,
  VDIVSSrr_Int = 9167,
  VDPBF16PSZ128m = 9168,
  VDPBF16PSZ128mb = 9169,
  VDPBF16PSZ128mbk = 9170,
  VDPBF16PSZ128mbkz = 9171,
  VDPBF16PSZ128mk = 9172,
  VDPBF16PSZ128mkz = 9173,
  VDPBF16PSZ128r = 9174,
  VDPBF16PSZ128rk = 9175,
  VDPBF16PSZ128rkz = 9176,
  VDPBF16PSZ256m = 9177,
  VDPBF16PSZ256mb = 9178,
  VDPBF16PSZ256mbk = 9179,
  VDPBF16PSZ256mbkz = 9180,
  VDPBF16PSZ256mk = 9181,
  VDPBF16PSZ256mkz = 9182,
  VDPBF16PSZ256r = 9183,
  VDPBF16PSZ256rk = 9184,
  VDPBF16PSZ256rkz = 9185,
  VDPBF16PSZm = 9186,
  VDPBF16PSZmb = 9187,
  VDPBF16PSZmbk = 9188,
  VDPBF16PSZmbkz = 9189,
  VDPBF16PSZmk = 9190,
  VDPBF16PSZmkz = 9191,
  VDPBF16PSZr = 9192,
  VDPBF16PSZrk = 9193,
  VDPBF16PSZrkz = 9194,
  VDPPDrmi = 9195,
  VDPPDrri = 9196,
  VDPPHPSZ128m = 9197,
  VDPPHPSZ128mb = 9198,
  VDPPHPSZ128mbk = 9199,
  VDPPHPSZ128mbkz = 9200,
  VDPPHPSZ128mk = 9201,
  VDPPHPSZ128mkz = 9202,
  VDPPHPSZ128r = 9203,
  VDPPHPSZ128rk = 9204,
  VDPPHPSZ128rkz = 9205,
  VDPPHPSZ256m = 9206,
  VDPPHPSZ256mb = 9207,
  VDPPHPSZ256mbk = 9208,
  VDPPHPSZ256mbkz = 9209,
  VDPPHPSZ256mk = 9210,
  VDPPHPSZ256mkz = 9211,
  VDPPHPSZ256r = 9212,
  VDPPHPSZ256rk = 9213,
  VDPPHPSZ256rkz = 9214,
  VDPPHPSZm = 9215,
  VDPPHPSZmb = 9216,
  VDPPHPSZmbk = 9217,
  VDPPHPSZmbkz = 9218,
  VDPPHPSZmk = 9219,
  VDPPHPSZmkz = 9220,
  VDPPHPSZr = 9221,
  VDPPHPSZrk = 9222,
  VDPPHPSZrkz = 9223,
  VDPPSYrmi = 9224,
  VDPPSYrri = 9225,
  VDPPSrmi = 9226,
  VDPPSrri = 9227,
  VERRm = 9228,
  VERRr = 9229,
  VERWm = 9230,
  VERWr = 9231,
  VEXP2PDZm = 9232,
  VEXP2PDZmb = 9233,
  VEXP2PDZmbk = 9234,
  VEXP2PDZmbkz = 9235,
  VEXP2PDZmk = 9236,
  VEXP2PDZmkz = 9237,
  VEXP2PDZr = 9238,
  VEXP2PDZrb = 9239,
  VEXP2PDZrbk = 9240,
  VEXP2PDZrbkz = 9241,
  VEXP2PDZrk = 9242,
  VEXP2PDZrkz = 9243,
  VEXP2PSZm = 9244,
  VEXP2PSZmb = 9245,
  VEXP2PSZmbk = 9246,
  VEXP2PSZmbkz = 9247,
  VEXP2PSZmk = 9248,
  VEXP2PSZmkz = 9249,
  VEXP2PSZr = 9250,
  VEXP2PSZrb = 9251,
  VEXP2PSZrbk = 9252,
  VEXP2PSZrbkz = 9253,
  VEXP2PSZrk = 9254,
  VEXP2PSZrkz = 9255,
  VEXPANDPDZ128rm = 9256,
  VEXPANDPDZ128rmk = 9257,
  VEXPANDPDZ128rmkz = 9258,
  VEXPANDPDZ128rr = 9259,
  VEXPANDPDZ128rrk = 9260,
  VEXPANDPDZ128rrkz = 9261,
  VEXPANDPDZ256rm = 9262,
  VEXPANDPDZ256rmk = 9263,
  VEXPANDPDZ256rmkz = 9264,
  VEXPANDPDZ256rr = 9265,
  VEXPANDPDZ256rrk = 9266,
  VEXPANDPDZ256rrkz = 9267,
  VEXPANDPDZrm = 9268,
  VEXPANDPDZrmk = 9269,
  VEXPANDPDZrmkz = 9270,
  VEXPANDPDZrr = 9271,
  VEXPANDPDZrrk = 9272,
  VEXPANDPDZrrkz = 9273,
  VEXPANDPSZ128rm = 9274,
  VEXPANDPSZ128rmk = 9275,
  VEXPANDPSZ128rmkz = 9276,
  VEXPANDPSZ128rr = 9277,
  VEXPANDPSZ128rrk = 9278,
  VEXPANDPSZ128rrkz = 9279,
  VEXPANDPSZ256rm = 9280,
  VEXPANDPSZ256rmk = 9281,
  VEXPANDPSZ256rmkz = 9282,
  VEXPANDPSZ256rr = 9283,
  VEXPANDPSZ256rrk = 9284,
  VEXPANDPSZ256rrkz = 9285,
  VEXPANDPSZrm = 9286,
  VEXPANDPSZrmk = 9287,
  VEXPANDPSZrmkz = 9288,
  VEXPANDPSZrr = 9289,
  VEXPANDPSZrrk = 9290,
  VEXPANDPSZrrkz = 9291,
  VEXTRACTF128mri = 9292,
  VEXTRACTF128rri = 9293,
  VEXTRACTF32X4Z256mri = 9294,
  VEXTRACTF32X4Z256mrik = 9295,
  VEXTRACTF32X4Z256rri = 9296,
  VEXTRACTF32X4Z256rrik = 9297,
  VEXTRACTF32X4Z256rrikz = 9298,
  VEXTRACTF32X4Zmri = 9299,
  VEXTRACTF32X4Zmrik = 9300,
  VEXTRACTF32X4Zrri = 9301,
  VEXTRACTF32X4Zrrik = 9302,
  VEXTRACTF32X4Zrrikz = 9303,
  VEXTRACTF32X8Zmri = 9304,
  VEXTRACTF32X8Zmrik = 9305,
  VEXTRACTF32X8Zrri = 9306,
  VEXTRACTF32X8Zrrik = 9307,
  VEXTRACTF32X8Zrrikz = 9308,
  VEXTRACTF64X2Z256mri = 9309,
  VEXTRACTF64X2Z256mrik = 9310,
  VEXTRACTF64X2Z256rri = 9311,
  VEXTRACTF64X2Z256rrik = 9312,
  VEXTRACTF64X2Z256rrikz = 9313,
  VEXTRACTF64X2Zmri = 9314,
  VEXTRACTF64X2Zmrik = 9315,
  VEXTRACTF64X2Zrri = 9316,
  VEXTRACTF64X2Zrrik = 9317,
  VEXTRACTF64X2Zrrikz = 9318,
  VEXTRACTF64X4Zmri = 9319,
  VEXTRACTF64X4Zmrik = 9320,
  VEXTRACTF64X4Zrri = 9321,
  VEXTRACTF64X4Zrrik = 9322,
  VEXTRACTF64X4Zrrikz = 9323,
  VEXTRACTI128mri = 9324,
  VEXTRACTI128rri = 9325,
  VEXTRACTI32X4Z256mri = 9326,
  VEXTRACTI32X4Z256mrik = 9327,
  VEXTRACTI32X4Z256rri = 9328,
  VEXTRACTI32X4Z256rrik = 9329,
  VEXTRACTI32X4Z256rrikz = 9330,
  VEXTRACTI32X4Zmri = 9331,
  VEXTRACTI32X4Zmrik = 9332,
  VEXTRACTI32X4Zrri = 9333,
  VEXTRACTI32X4Zrrik = 9334,
  VEXTRACTI32X4Zrrikz = 9335,
  VEXTRACTI32X8Zmri = 9336,
  VEXTRACTI32X8Zmrik = 9337,
  VEXTRACTI32X8Zrri = 9338,
  VEXTRACTI32X8Zrrik = 9339,
  VEXTRACTI32X8Zrrikz = 9340,
  VEXTRACTI64X2Z256mri = 9341,
  VEXTRACTI64X2Z256mrik = 9342,
  VEXTRACTI64X2Z256rri = 9343,
  VEXTRACTI64X2Z256rrik = 9344,
  VEXTRACTI64X2Z256rrikz = 9345,
  VEXTRACTI64X2Zmri = 9346,
  VEXTRACTI64X2Zmrik = 9347,
  VEXTRACTI64X2Zrri = 9348,
  VEXTRACTI64X2Zrrik = 9349,
  VEXTRACTI64X2Zrrikz = 9350,
  VEXTRACTI64X4Zmri = 9351,
  VEXTRACTI64X4Zmrik = 9352,
  VEXTRACTI64X4Zrri = 9353,
  VEXTRACTI64X4Zrrik = 9354,
  VEXTRACTI64X4Zrrikz = 9355,
  VEXTRACTPSZmri = 9356,
  VEXTRACTPSZrri = 9357,
  VEXTRACTPSmri = 9358,
  VEXTRACTPSrri = 9359,
  VFCMADDCPHZ128m = 9360,
  VFCMADDCPHZ128mb = 9361,
  VFCMADDCPHZ128mbk = 9362,
  VFCMADDCPHZ128mbkz = 9363,
  VFCMADDCPHZ128mk = 9364,
  VFCMADDCPHZ128mkz = 9365,
  VFCMADDCPHZ128r = 9366,
  VFCMADDCPHZ128rk = 9367,
  VFCMADDCPHZ128rkz = 9368,
  VFCMADDCPHZ256m = 9369,
  VFCMADDCPHZ256mb = 9370,
  VFCMADDCPHZ256mbk = 9371,
  VFCMADDCPHZ256mbkz = 9372,
  VFCMADDCPHZ256mk = 9373,
  VFCMADDCPHZ256mkz = 9374,
  VFCMADDCPHZ256r = 9375,
  VFCMADDCPHZ256rb = 9376,
  VFCMADDCPHZ256rbk = 9377,
  VFCMADDCPHZ256rbkz = 9378,
  VFCMADDCPHZ256rk = 9379,
  VFCMADDCPHZ256rkz = 9380,
  VFCMADDCPHZm = 9381,
  VFCMADDCPHZmb = 9382,
  VFCMADDCPHZmbk = 9383,
  VFCMADDCPHZmbkz = 9384,
  VFCMADDCPHZmk = 9385,
  VFCMADDCPHZmkz = 9386,
  VFCMADDCPHZr = 9387,
  VFCMADDCPHZrb = 9388,
  VFCMADDCPHZrbk = 9389,
  VFCMADDCPHZrbkz = 9390,
  VFCMADDCPHZrk = 9391,
  VFCMADDCPHZrkz = 9392,
  VFCMADDCSHZm = 9393,
  VFCMADDCSHZmk = 9394,
  VFCMADDCSHZmkz = 9395,
  VFCMADDCSHZr = 9396,
  VFCMADDCSHZrb = 9397,
  VFCMADDCSHZrbk = 9398,
  VFCMADDCSHZrbkz = 9399,
  VFCMADDCSHZrk = 9400,
  VFCMADDCSHZrkz = 9401,
  VFCMULCPHZ128rm = 9402,
  VFCMULCPHZ128rmb = 9403,
  VFCMULCPHZ128rmbk = 9404,
  VFCMULCPHZ128rmbkz = 9405,
  VFCMULCPHZ128rmk = 9406,
  VFCMULCPHZ128rmkz = 9407,
  VFCMULCPHZ128rr = 9408,
  VFCMULCPHZ128rrk = 9409,
  VFCMULCPHZ128rrkz = 9410,
  VFCMULCPHZ256rm = 9411,
  VFCMULCPHZ256rmb = 9412,
  VFCMULCPHZ256rmbk = 9413,
  VFCMULCPHZ256rmbkz = 9414,
  VFCMULCPHZ256rmk = 9415,
  VFCMULCPHZ256rmkz = 9416,
  VFCMULCPHZ256rr = 9417,
  VFCMULCPHZ256rrb = 9418,
  VFCMULCPHZ256rrbk = 9419,
  VFCMULCPHZ256rrbkz = 9420,
  VFCMULCPHZ256rrk = 9421,
  VFCMULCPHZ256rrkz = 9422,
  VFCMULCPHZrm = 9423,
  VFCMULCPHZrmb = 9424,
  VFCMULCPHZrmbk = 9425,
  VFCMULCPHZrmbkz = 9426,
  VFCMULCPHZrmk = 9427,
  VFCMULCPHZrmkz = 9428,
  VFCMULCPHZrr = 9429,
  VFCMULCPHZrrb = 9430,
  VFCMULCPHZrrbk = 9431,
  VFCMULCPHZrrbkz = 9432,
  VFCMULCPHZrrk = 9433,
  VFCMULCPHZrrkz = 9434,
  VFCMULCSHZrm = 9435,
  VFCMULCSHZrmk = 9436,
  VFCMULCSHZrmkz = 9437,
  VFCMULCSHZrr = 9438,
  VFCMULCSHZrrb = 9439,
  VFCMULCSHZrrbk = 9440,
  VFCMULCSHZrrbkz = 9441,
  VFCMULCSHZrrk = 9442,
  VFCMULCSHZrrkz = 9443,
  VFIXUPIMMPDZ128rmbi = 9444,
  VFIXUPIMMPDZ128rmbik = 9445,
  VFIXUPIMMPDZ128rmbikz = 9446,
  VFIXUPIMMPDZ128rmi = 9447,
  VFIXUPIMMPDZ128rmik = 9448,
  VFIXUPIMMPDZ128rmikz = 9449,
  VFIXUPIMMPDZ128rri = 9450,
  VFIXUPIMMPDZ128rrik = 9451,
  VFIXUPIMMPDZ128rrikz = 9452,
  VFIXUPIMMPDZ256rmbi = 9453,
  VFIXUPIMMPDZ256rmbik = 9454,
  VFIXUPIMMPDZ256rmbikz = 9455,
  VFIXUPIMMPDZ256rmi = 9456,
  VFIXUPIMMPDZ256rmik = 9457,
  VFIXUPIMMPDZ256rmikz = 9458,
  VFIXUPIMMPDZ256rri = 9459,
  VFIXUPIMMPDZ256rrib = 9460,
  VFIXUPIMMPDZ256rribk = 9461,
  VFIXUPIMMPDZ256rribkz = 9462,
  VFIXUPIMMPDZ256rrik = 9463,
  VFIXUPIMMPDZ256rrikz = 9464,
  VFIXUPIMMPDZrmbi = 9465,
  VFIXUPIMMPDZrmbik = 9466,
  VFIXUPIMMPDZrmbikz = 9467,
  VFIXUPIMMPDZrmi = 9468,
  VFIXUPIMMPDZrmik = 9469,
  VFIXUPIMMPDZrmikz = 9470,
  VFIXUPIMMPDZrri = 9471,
  VFIXUPIMMPDZrrib = 9472,
  VFIXUPIMMPDZrribk = 9473,
  VFIXUPIMMPDZrribkz = 9474,
  VFIXUPIMMPDZrrik = 9475,
  VFIXUPIMMPDZrrikz = 9476,
  VFIXUPIMMPSZ128rmbi = 9477,
  VFIXUPIMMPSZ128rmbik = 9478,
  VFIXUPIMMPSZ128rmbikz = 9479,
  VFIXUPIMMPSZ128rmi = 9480,
  VFIXUPIMMPSZ128rmik = 9481,
  VFIXUPIMMPSZ128rmikz = 9482,
  VFIXUPIMMPSZ128rri = 9483,
  VFIXUPIMMPSZ128rrik = 9484,
  VFIXUPIMMPSZ128rrikz = 9485,
  VFIXUPIMMPSZ256rmbi = 9486,
  VFIXUPIMMPSZ256rmbik = 9487,
  VFIXUPIMMPSZ256rmbikz = 9488,
  VFIXUPIMMPSZ256rmi = 9489,
  VFIXUPIMMPSZ256rmik = 9490,
  VFIXUPIMMPSZ256rmikz = 9491,
  VFIXUPIMMPSZ256rri = 9492,
  VFIXUPIMMPSZ256rrib = 9493,
  VFIXUPIMMPSZ256rribk = 9494,
  VFIXUPIMMPSZ256rribkz = 9495,
  VFIXUPIMMPSZ256rrik = 9496,
  VFIXUPIMMPSZ256rrikz = 9497,
  VFIXUPIMMPSZrmbi = 9498,
  VFIXUPIMMPSZrmbik = 9499,
  VFIXUPIMMPSZrmbikz = 9500,
  VFIXUPIMMPSZrmi = 9501,
  VFIXUPIMMPSZrmik = 9502,
  VFIXUPIMMPSZrmikz = 9503,
  VFIXUPIMMPSZrri = 9504,
  VFIXUPIMMPSZrrib = 9505,
  VFIXUPIMMPSZrribk = 9506,
  VFIXUPIMMPSZrribkz = 9507,
  VFIXUPIMMPSZrrik = 9508,
  VFIXUPIMMPSZrrikz = 9509,
  VFIXUPIMMSDZrmi = 9510,
  VFIXUPIMMSDZrmik = 9511,
  VFIXUPIMMSDZrmikz = 9512,
  VFIXUPIMMSDZrri = 9513,
  VFIXUPIMMSDZrrib = 9514,
  VFIXUPIMMSDZrribk = 9515,
  VFIXUPIMMSDZrribkz = 9516,
  VFIXUPIMMSDZrrik = 9517,
  VFIXUPIMMSDZrrikz = 9518,
  VFIXUPIMMSSZrmi = 9519,
  VFIXUPIMMSSZrmik = 9520,
  VFIXUPIMMSSZrmikz = 9521,
  VFIXUPIMMSSZrri = 9522,
  VFIXUPIMMSSZrrib = 9523,
  VFIXUPIMMSSZrribk = 9524,
  VFIXUPIMMSSZrribkz = 9525,
  VFIXUPIMMSSZrrik = 9526,
  VFIXUPIMMSSZrrikz = 9527,
  VFMADD132BF16Z128m = 9528,
  VFMADD132BF16Z128mb = 9529,
  VFMADD132BF16Z128mbk = 9530,
  VFMADD132BF16Z128mbkz = 9531,
  VFMADD132BF16Z128mk = 9532,
  VFMADD132BF16Z128mkz = 9533,
  VFMADD132BF16Z128r = 9534,
  VFMADD132BF16Z128rk = 9535,
  VFMADD132BF16Z128rkz = 9536,
  VFMADD132BF16Z256m = 9537,
  VFMADD132BF16Z256mb = 9538,
  VFMADD132BF16Z256mbk = 9539,
  VFMADD132BF16Z256mbkz = 9540,
  VFMADD132BF16Z256mk = 9541,
  VFMADD132BF16Z256mkz = 9542,
  VFMADD132BF16Z256r = 9543,
  VFMADD132BF16Z256rk = 9544,
  VFMADD132BF16Z256rkz = 9545,
  VFMADD132BF16Zm = 9546,
  VFMADD132BF16Zmb = 9547,
  VFMADD132BF16Zmbk = 9548,
  VFMADD132BF16Zmbkz = 9549,
  VFMADD132BF16Zmk = 9550,
  VFMADD132BF16Zmkz = 9551,
  VFMADD132BF16Zr = 9552,
  VFMADD132BF16Zrk = 9553,
  VFMADD132BF16Zrkz = 9554,
  VFMADD132PDYm = 9555,
  VFMADD132PDYr = 9556,
  VFMADD132PDZ128m = 9557,
  VFMADD132PDZ128mb = 9558,
  VFMADD132PDZ128mbk = 9559,
  VFMADD132PDZ128mbkz = 9560,
  VFMADD132PDZ128mk = 9561,
  VFMADD132PDZ128mkz = 9562,
  VFMADD132PDZ128r = 9563,
  VFMADD132PDZ128rk = 9564,
  VFMADD132PDZ128rkz = 9565,
  VFMADD132PDZ256m = 9566,
  VFMADD132PDZ256mb = 9567,
  VFMADD132PDZ256mbk = 9568,
  VFMADD132PDZ256mbkz = 9569,
  VFMADD132PDZ256mk = 9570,
  VFMADD132PDZ256mkz = 9571,
  VFMADD132PDZ256r = 9572,
  VFMADD132PDZ256rb = 9573,
  VFMADD132PDZ256rbk = 9574,
  VFMADD132PDZ256rbkz = 9575,
  VFMADD132PDZ256rk = 9576,
  VFMADD132PDZ256rkz = 9577,
  VFMADD132PDZm = 9578,
  VFMADD132PDZmb = 9579,
  VFMADD132PDZmbk = 9580,
  VFMADD132PDZmbkz = 9581,
  VFMADD132PDZmk = 9582,
  VFMADD132PDZmkz = 9583,
  VFMADD132PDZr = 9584,
  VFMADD132PDZrb = 9585,
  VFMADD132PDZrbk = 9586,
  VFMADD132PDZrbkz = 9587,
  VFMADD132PDZrk = 9588,
  VFMADD132PDZrkz = 9589,
  VFMADD132PDm = 9590,
  VFMADD132PDr = 9591,
  VFMADD132PHZ128m = 9592,
  VFMADD132PHZ128mb = 9593,
  VFMADD132PHZ128mbk = 9594,
  VFMADD132PHZ128mbkz = 9595,
  VFMADD132PHZ128mk = 9596,
  VFMADD132PHZ128mkz = 9597,
  VFMADD132PHZ128r = 9598,
  VFMADD132PHZ128rk = 9599,
  VFMADD132PHZ128rkz = 9600,
  VFMADD132PHZ256m = 9601,
  VFMADD132PHZ256mb = 9602,
  VFMADD132PHZ256mbk = 9603,
  VFMADD132PHZ256mbkz = 9604,
  VFMADD132PHZ256mk = 9605,
  VFMADD132PHZ256mkz = 9606,
  VFMADD132PHZ256r = 9607,
  VFMADD132PHZ256rb = 9608,
  VFMADD132PHZ256rbk = 9609,
  VFMADD132PHZ256rbkz = 9610,
  VFMADD132PHZ256rk = 9611,
  VFMADD132PHZ256rkz = 9612,
  VFMADD132PHZm = 9613,
  VFMADD132PHZmb = 9614,
  VFMADD132PHZmbk = 9615,
  VFMADD132PHZmbkz = 9616,
  VFMADD132PHZmk = 9617,
  VFMADD132PHZmkz = 9618,
  VFMADD132PHZr = 9619,
  VFMADD132PHZrb = 9620,
  VFMADD132PHZrbk = 9621,
  VFMADD132PHZrbkz = 9622,
  VFMADD132PHZrk = 9623,
  VFMADD132PHZrkz = 9624,
  VFMADD132PSYm = 9625,
  VFMADD132PSYr = 9626,
  VFMADD132PSZ128m = 9627,
  VFMADD132PSZ128mb = 9628,
  VFMADD132PSZ128mbk = 9629,
  VFMADD132PSZ128mbkz = 9630,
  VFMADD132PSZ128mk = 9631,
  VFMADD132PSZ128mkz = 9632,
  VFMADD132PSZ128r = 9633,
  VFMADD132PSZ128rk = 9634,
  VFMADD132PSZ128rkz = 9635,
  VFMADD132PSZ256m = 9636,
  VFMADD132PSZ256mb = 9637,
  VFMADD132PSZ256mbk = 9638,
  VFMADD132PSZ256mbkz = 9639,
  VFMADD132PSZ256mk = 9640,
  VFMADD132PSZ256mkz = 9641,
  VFMADD132PSZ256r = 9642,
  VFMADD132PSZ256rb = 9643,
  VFMADD132PSZ256rbk = 9644,
  VFMADD132PSZ256rbkz = 9645,
  VFMADD132PSZ256rk = 9646,
  VFMADD132PSZ256rkz = 9647,
  VFMADD132PSZm = 9648,
  VFMADD132PSZmb = 9649,
  VFMADD132PSZmbk = 9650,
  VFMADD132PSZmbkz = 9651,
  VFMADD132PSZmk = 9652,
  VFMADD132PSZmkz = 9653,
  VFMADD132PSZr = 9654,
  VFMADD132PSZrb = 9655,
  VFMADD132PSZrbk = 9656,
  VFMADD132PSZrbkz = 9657,
  VFMADD132PSZrk = 9658,
  VFMADD132PSZrkz = 9659,
  VFMADD132PSm = 9660,
  VFMADD132PSr = 9661,
  VFMADD132SDZm = 9662,
  VFMADD132SDZm_Int = 9663,
  VFMADD132SDZmk_Int = 9664,
  VFMADD132SDZmkz_Int = 9665,
  VFMADD132SDZr = 9666,
  VFMADD132SDZr_Int = 9667,
  VFMADD132SDZrb = 9668,
  VFMADD132SDZrb_Int = 9669,
  VFMADD132SDZrbk_Int = 9670,
  VFMADD132SDZrbkz_Int = 9671,
  VFMADD132SDZrk_Int = 9672,
  VFMADD132SDZrkz_Int = 9673,
  VFMADD132SDm = 9674,
  VFMADD132SDm_Int = 9675,
  VFMADD132SDr = 9676,
  VFMADD132SDr_Int = 9677,
  VFMADD132SHZm = 9678,
  VFMADD132SHZm_Int = 9679,
  VFMADD132SHZmk_Int = 9680,
  VFMADD132SHZmkz_Int = 9681,
  VFMADD132SHZr = 9682,
  VFMADD132SHZr_Int = 9683,
  VFMADD132SHZrb = 9684,
  VFMADD132SHZrb_Int = 9685,
  VFMADD132SHZrbk_Int = 9686,
  VFMADD132SHZrbkz_Int = 9687,
  VFMADD132SHZrk_Int = 9688,
  VFMADD132SHZrkz_Int = 9689,
  VFMADD132SSZm = 9690,
  VFMADD132SSZm_Int = 9691,
  VFMADD132SSZmk_Int = 9692,
  VFMADD132SSZmkz_Int = 9693,
  VFMADD132SSZr = 9694,
  VFMADD132SSZr_Int = 9695,
  VFMADD132SSZrb = 9696,
  VFMADD132SSZrb_Int = 9697,
  VFMADD132SSZrbk_Int = 9698,
  VFMADD132SSZrbkz_Int = 9699,
  VFMADD132SSZrk_Int = 9700,
  VFMADD132SSZrkz_Int = 9701,
  VFMADD132SSm = 9702,
  VFMADD132SSm_Int = 9703,
  VFMADD132SSr = 9704,
  VFMADD132SSr_Int = 9705,
  VFMADD213BF16Z128m = 9706,
  VFMADD213BF16Z128mb = 9707,
  VFMADD213BF16Z128mbk = 9708,
  VFMADD213BF16Z128mbkz = 9709,
  VFMADD213BF16Z128mk = 9710,
  VFMADD213BF16Z128mkz = 9711,
  VFMADD213BF16Z128r = 9712,
  VFMADD213BF16Z128rk = 9713,
  VFMADD213BF16Z128rkz = 9714,
  VFMADD213BF16Z256m = 9715,
  VFMADD213BF16Z256mb = 9716,
  VFMADD213BF16Z256mbk = 9717,
  VFMADD213BF16Z256mbkz = 9718,
  VFMADD213BF16Z256mk = 9719,
  VFMADD213BF16Z256mkz = 9720,
  VFMADD213BF16Z256r = 9721,
  VFMADD213BF16Z256rk = 9722,
  VFMADD213BF16Z256rkz = 9723,
  VFMADD213BF16Zm = 9724,
  VFMADD213BF16Zmb = 9725,
  VFMADD213BF16Zmbk = 9726,
  VFMADD213BF16Zmbkz = 9727,
  VFMADD213BF16Zmk = 9728,
  VFMADD213BF16Zmkz = 9729,
  VFMADD213BF16Zr = 9730,
  VFMADD213BF16Zrk = 9731,
  VFMADD213BF16Zrkz = 9732,
  VFMADD213PDYm = 9733,
  VFMADD213PDYr = 9734,
  VFMADD213PDZ128m = 9735,
  VFMADD213PDZ128mb = 9736,
  VFMADD213PDZ128mbk = 9737,
  VFMADD213PDZ128mbkz = 9738,
  VFMADD213PDZ128mk = 9739,
  VFMADD213PDZ128mkz = 9740,
  VFMADD213PDZ128r = 9741,
  VFMADD213PDZ128rk = 9742,
  VFMADD213PDZ128rkz = 9743,
  VFMADD213PDZ256m = 9744,
  VFMADD213PDZ256mb = 9745,
  VFMADD213PDZ256mbk = 9746,
  VFMADD213PDZ256mbkz = 9747,
  VFMADD213PDZ256mk = 9748,
  VFMADD213PDZ256mkz = 9749,
  VFMADD213PDZ256r = 9750,
  VFMADD213PDZ256rb = 9751,
  VFMADD213PDZ256rbk = 9752,
  VFMADD213PDZ256rbkz = 9753,
  VFMADD213PDZ256rk = 9754,
  VFMADD213PDZ256rkz = 9755,
  VFMADD213PDZm = 9756,
  VFMADD213PDZmb = 9757,
  VFMADD213PDZmbk = 9758,
  VFMADD213PDZmbkz = 9759,
  VFMADD213PDZmk = 9760,
  VFMADD213PDZmkz = 9761,
  VFMADD213PDZr = 9762,
  VFMADD213PDZrb = 9763,
  VFMADD213PDZrbk = 9764,
  VFMADD213PDZrbkz = 9765,
  VFMADD213PDZrk = 9766,
  VFMADD213PDZrkz = 9767,
  VFMADD213PDm = 9768,
  VFMADD213PDr = 9769,
  VFMADD213PHZ128m = 9770,
  VFMADD213PHZ128mb = 9771,
  VFMADD213PHZ128mbk = 9772,
  VFMADD213PHZ128mbkz = 9773,
  VFMADD213PHZ128mk = 9774,
  VFMADD213PHZ128mkz = 9775,
  VFMADD213PHZ128r = 9776,
  VFMADD213PHZ128rk = 9777,
  VFMADD213PHZ128rkz = 9778,
  VFMADD213PHZ256m = 9779,
  VFMADD213PHZ256mb = 9780,
  VFMADD213PHZ256mbk = 9781,
  VFMADD213PHZ256mbkz = 9782,
  VFMADD213PHZ256mk = 9783,
  VFMADD213PHZ256mkz = 9784,
  VFMADD213PHZ256r = 9785,
  VFMADD213PHZ256rb = 9786,
  VFMADD213PHZ256rbk = 9787,
  VFMADD213PHZ256rbkz = 9788,
  VFMADD213PHZ256rk = 9789,
  VFMADD213PHZ256rkz = 9790,
  VFMADD213PHZm = 9791,
  VFMADD213PHZmb = 9792,
  VFMADD213PHZmbk = 9793,
  VFMADD213PHZmbkz = 9794,
  VFMADD213PHZmk = 9795,
  VFMADD213PHZmkz = 9796,
  VFMADD213PHZr = 9797,
  VFMADD213PHZrb = 9798,
  VFMADD213PHZrbk = 9799,
  VFMADD213PHZrbkz = 9800,
  VFMADD213PHZrk = 9801,
  VFMADD213PHZrkz = 9802,
  VFMADD213PSYm = 9803,
  VFMADD213PSYr = 9804,
  VFMADD213PSZ128m = 9805,
  VFMADD213PSZ128mb = 9806,
  VFMADD213PSZ128mbk = 9807,
  VFMADD213PSZ128mbkz = 9808,
  VFMADD213PSZ128mk = 9809,
  VFMADD213PSZ128mkz = 9810,
  VFMADD213PSZ128r = 9811,
  VFMADD213PSZ128rk = 9812,
  VFMADD213PSZ128rkz = 9813,
  VFMADD213PSZ256m = 9814,
  VFMADD213PSZ256mb = 9815,
  VFMADD213PSZ256mbk = 9816,
  VFMADD213PSZ256mbkz = 9817,
  VFMADD213PSZ256mk = 9818,
  VFMADD213PSZ256mkz = 9819,
  VFMADD213PSZ256r = 9820,
  VFMADD213PSZ256rb = 9821,
  VFMADD213PSZ256rbk = 9822,
  VFMADD213PSZ256rbkz = 9823,
  VFMADD213PSZ256rk = 9824,
  VFMADD213PSZ256rkz = 9825,
  VFMADD213PSZm = 9826,
  VFMADD213PSZmb = 9827,
  VFMADD213PSZmbk = 9828,
  VFMADD213PSZmbkz = 9829,
  VFMADD213PSZmk = 9830,
  VFMADD213PSZmkz = 9831,
  VFMADD213PSZr = 9832,
  VFMADD213PSZrb = 9833,
  VFMADD213PSZrbk = 9834,
  VFMADD213PSZrbkz = 9835,
  VFMADD213PSZrk = 9836,
  VFMADD213PSZrkz = 9837,
  VFMADD213PSm = 9838,
  VFMADD213PSr = 9839,
  VFMADD213SDZm = 9840,
  VFMADD213SDZm_Int = 9841,
  VFMADD213SDZmk_Int = 9842,
  VFMADD213SDZmkz_Int = 9843,
  VFMADD213SDZr = 9844,
  VFMADD213SDZr_Int = 9845,
  VFMADD213SDZrb = 9846,
  VFMADD213SDZrb_Int = 9847,
  VFMADD213SDZrbk_Int = 9848,
  VFMADD213SDZrbkz_Int = 9849,
  VFMADD213SDZrk_Int = 9850,
  VFMADD213SDZrkz_Int = 9851,
  VFMADD213SDm = 9852,
  VFMADD213SDm_Int = 9853,
  VFMADD213SDr = 9854,
  VFMADD213SDr_Int = 9855,
  VFMADD213SHZm = 9856,
  VFMADD213SHZm_Int = 9857,
  VFMADD213SHZmk_Int = 9858,
  VFMADD213SHZmkz_Int = 9859,
  VFMADD213SHZr = 9860,
  VFMADD213SHZr_Int = 9861,
  VFMADD213SHZrb = 9862,
  VFMADD213SHZrb_Int = 9863,
  VFMADD213SHZrbk_Int = 9864,
  VFMADD213SHZrbkz_Int = 9865,
  VFMADD213SHZrk_Int = 9866,
  VFMADD213SHZrkz_Int = 9867,
  VFMADD213SSZm = 9868,
  VFMADD213SSZm_Int = 9869,
  VFMADD213SSZmk_Int = 9870,
  VFMADD213SSZmkz_Int = 9871,
  VFMADD213SSZr = 9872,
  VFMADD213SSZr_Int = 9873,
  VFMADD213SSZrb = 9874,
  VFMADD213SSZrb_Int = 9875,
  VFMADD213SSZrbk_Int = 9876,
  VFMADD213SSZrbkz_Int = 9877,
  VFMADD213SSZrk_Int = 9878,
  VFMADD213SSZrkz_Int = 9879,
  VFMADD213SSm = 9880,
  VFMADD213SSm_Int = 9881,
  VFMADD213SSr = 9882,
  VFMADD213SSr_Int = 9883,
  VFMADD231BF16Z128m = 9884,
  VFMADD231BF16Z128mb = 9885,
  VFMADD231BF16Z128mbk = 9886,
  VFMADD231BF16Z128mbkz = 9887,
  VFMADD231BF16Z128mk = 9888,
  VFMADD231BF16Z128mkz = 9889,
  VFMADD231BF16Z128r = 9890,
  VFMADD231BF16Z128rk = 9891,
  VFMADD231BF16Z128rkz = 9892,
  VFMADD231BF16Z256m = 9893,
  VFMADD231BF16Z256mb = 9894,
  VFMADD231BF16Z256mbk = 9895,
  VFMADD231BF16Z256mbkz = 9896,
  VFMADD231BF16Z256mk = 9897,
  VFMADD231BF16Z256mkz = 9898,
  VFMADD231BF16Z256r = 9899,
  VFMADD231BF16Z256rk = 9900,
  VFMADD231BF16Z256rkz = 9901,
  VFMADD231BF16Zm = 9902,
  VFMADD231BF16Zmb = 9903,
  VFMADD231BF16Zmbk = 9904,
  VFMADD231BF16Zmbkz = 9905,
  VFMADD231BF16Zmk = 9906,
  VFMADD231BF16Zmkz = 9907,
  VFMADD231BF16Zr = 9908,
  VFMADD231BF16Zrk = 9909,
  VFMADD231BF16Zrkz = 9910,
  VFMADD231PDYm = 9911,
  VFMADD231PDYr = 9912,
  VFMADD231PDZ128m = 9913,
  VFMADD231PDZ128mb = 9914,
  VFMADD231PDZ128mbk = 9915,
  VFMADD231PDZ128mbkz = 9916,
  VFMADD231PDZ128mk = 9917,
  VFMADD231PDZ128mkz = 9918,
  VFMADD231PDZ128r = 9919,
  VFMADD231PDZ128rk = 9920,
  VFMADD231PDZ128rkz = 9921,
  VFMADD231PDZ256m = 9922,
  VFMADD231PDZ256mb = 9923,
  VFMADD231PDZ256mbk = 9924,
  VFMADD231PDZ256mbkz = 9925,
  VFMADD231PDZ256mk = 9926,
  VFMADD231PDZ256mkz = 9927,
  VFMADD231PDZ256r = 9928,
  VFMADD231PDZ256rb = 9929,
  VFMADD231PDZ256rbk = 9930,
  VFMADD231PDZ256rbkz = 9931,
  VFMADD231PDZ256rk = 9932,
  VFMADD231PDZ256rkz = 9933,
  VFMADD231PDZm = 9934,
  VFMADD231PDZmb = 9935,
  VFMADD231PDZmbk = 9936,
  VFMADD231PDZmbkz = 9937,
  VFMADD231PDZmk = 9938,
  VFMADD231PDZmkz = 9939,
  VFMADD231PDZr = 9940,
  VFMADD231PDZrb = 9941,
  VFMADD231PDZrbk = 9942,
  VFMADD231PDZrbkz = 9943,
  VFMADD231PDZrk = 9944,
  VFMADD231PDZrkz = 9945,
  VFMADD231PDm = 9946,
  VFMADD231PDr = 9947,
  VFMADD231PHZ128m = 9948,
  VFMADD231PHZ128mb = 9949,
  VFMADD231PHZ128mbk = 9950,
  VFMADD231PHZ128mbkz = 9951,
  VFMADD231PHZ128mk = 9952,
  VFMADD231PHZ128mkz = 9953,
  VFMADD231PHZ128r = 9954,
  VFMADD231PHZ128rk = 9955,
  VFMADD231PHZ128rkz = 9956,
  VFMADD231PHZ256m = 9957,
  VFMADD231PHZ256mb = 9958,
  VFMADD231PHZ256mbk = 9959,
  VFMADD231PHZ256mbkz = 9960,
  VFMADD231PHZ256mk = 9961,
  VFMADD231PHZ256mkz = 9962,
  VFMADD231PHZ256r = 9963,
  VFMADD231PHZ256rb = 9964,
  VFMADD231PHZ256rbk = 9965,
  VFMADD231PHZ256rbkz = 9966,
  VFMADD231PHZ256rk = 9967,
  VFMADD231PHZ256rkz = 9968,
  VFMADD231PHZm = 9969,
  VFMADD231PHZmb = 9970,
  VFMADD231PHZmbk = 9971,
  VFMADD231PHZmbkz = 9972,
  VFMADD231PHZmk = 9973,
  VFMADD231PHZmkz = 9974,
  VFMADD231PHZr = 9975,
  VFMADD231PHZrb = 9976,
  VFMADD231PHZrbk = 9977,
  VFMADD231PHZrbkz = 9978,
  VFMADD231PHZrk = 9979,
  VFMADD231PHZrkz = 9980,
  VFMADD231PSYm = 9981,
  VFMADD231PSYr = 9982,
  VFMADD231PSZ128m = 9983,
  VFMADD231PSZ128mb = 9984,
  VFMADD231PSZ128mbk = 9985,
  VFMADD231PSZ128mbkz = 9986,
  VFMADD231PSZ128mk = 9987,
  VFMADD231PSZ128mkz = 9988,
  VFMADD231PSZ128r = 9989,
  VFMADD231PSZ128rk = 9990,
  VFMADD231PSZ128rkz = 9991,
  VFMADD231PSZ256m = 9992,
  VFMADD231PSZ256mb = 9993,
  VFMADD231PSZ256mbk = 9994,
  VFMADD231PSZ256mbkz = 9995,
  VFMADD231PSZ256mk = 9996,
  VFMADD231PSZ256mkz = 9997,
  VFMADD231PSZ256r = 9998,
  VFMADD231PSZ256rb = 9999,
  VFMADD231PSZ256rbk = 10000,
  VFMADD231PSZ256rbkz = 10001,
  VFMADD231PSZ256rk = 10002,
  VFMADD231PSZ256rkz = 10003,
  VFMADD231PSZm = 10004,
  VFMADD231PSZmb = 10005,
  VFMADD231PSZmbk = 10006,
  VFMADD231PSZmbkz = 10007,
  VFMADD231PSZmk = 10008,
  VFMADD231PSZmkz = 10009,
  VFMADD231PSZr = 10010,
  VFMADD231PSZrb = 10011,
  VFMADD231PSZrbk = 10012,
  VFMADD231PSZrbkz = 10013,
  VFMADD231PSZrk = 10014,
  VFMADD231PSZrkz = 10015,
  VFMADD231PSm = 10016,
  VFMADD231PSr = 10017,
  VFMADD231SDZm = 10018,
  VFMADD231SDZm_Int = 10019,
  VFMADD231SDZmk_Int = 10020,
  VFMADD231SDZmkz_Int = 10021,
  VFMADD231SDZr = 10022,
  VFMADD231SDZr_Int = 10023,
  VFMADD231SDZrb = 10024,
  VFMADD231SDZrb_Int = 10025,
  VFMADD231SDZrbk_Int = 10026,
  VFMADD231SDZrbkz_Int = 10027,
  VFMADD231SDZrk_Int = 10028,
  VFMADD231SDZrkz_Int = 10029,
  VFMADD231SDm = 10030,
  VFMADD231SDm_Int = 10031,
  VFMADD231SDr = 10032,
  VFMADD231SDr_Int = 10033,
  VFMADD231SHZm = 10034,
  VFMADD231SHZm_Int = 10035,
  VFMADD231SHZmk_Int = 10036,
  VFMADD231SHZmkz_Int = 10037,
  VFMADD231SHZr = 10038,
  VFMADD231SHZr_Int = 10039,
  VFMADD231SHZrb = 10040,
  VFMADD231SHZrb_Int = 10041,
  VFMADD231SHZrbk_Int = 10042,
  VFMADD231SHZrbkz_Int = 10043,
  VFMADD231SHZrk_Int = 10044,
  VFMADD231SHZrkz_Int = 10045,
  VFMADD231SSZm = 10046,
  VFMADD231SSZm_Int = 10047,
  VFMADD231SSZmk_Int = 10048,
  VFMADD231SSZmkz_Int = 10049,
  VFMADD231SSZr = 10050,
  VFMADD231SSZr_Int = 10051,
  VFMADD231SSZrb = 10052,
  VFMADD231SSZrb_Int = 10053,
  VFMADD231SSZrbk_Int = 10054,
  VFMADD231SSZrbkz_Int = 10055,
  VFMADD231SSZrk_Int = 10056,
  VFMADD231SSZrkz_Int = 10057,
  VFMADD231SSm = 10058,
  VFMADD231SSm_Int = 10059,
  VFMADD231SSr = 10060,
  VFMADD231SSr_Int = 10061,
  VFMADDCPHZ128m = 10062,
  VFMADDCPHZ128mb = 10063,
  VFMADDCPHZ128mbk = 10064,
  VFMADDCPHZ128mbkz = 10065,
  VFMADDCPHZ128mk = 10066,
  VFMADDCPHZ128mkz = 10067,
  VFMADDCPHZ128r = 10068,
  VFMADDCPHZ128rk = 10069,
  VFMADDCPHZ128rkz = 10070,
  VFMADDCPHZ256m = 10071,
  VFMADDCPHZ256mb = 10072,
  VFMADDCPHZ256mbk = 10073,
  VFMADDCPHZ256mbkz = 10074,
  VFMADDCPHZ256mk = 10075,
  VFMADDCPHZ256mkz = 10076,
  VFMADDCPHZ256r = 10077,
  VFMADDCPHZ256rb = 10078,
  VFMADDCPHZ256rbk = 10079,
  VFMADDCPHZ256rbkz = 10080,
  VFMADDCPHZ256rk = 10081,
  VFMADDCPHZ256rkz = 10082,
  VFMADDCPHZm = 10083,
  VFMADDCPHZmb = 10084,
  VFMADDCPHZmbk = 10085,
  VFMADDCPHZmbkz = 10086,
  VFMADDCPHZmk = 10087,
  VFMADDCPHZmkz = 10088,
  VFMADDCPHZr = 10089,
  VFMADDCPHZrb = 10090,
  VFMADDCPHZrbk = 10091,
  VFMADDCPHZrbkz = 10092,
  VFMADDCPHZrk = 10093,
  VFMADDCPHZrkz = 10094,
  VFMADDCSHZm = 10095,
  VFMADDCSHZmk = 10096,
  VFMADDCSHZmkz = 10097,
  VFMADDCSHZr = 10098,
  VFMADDCSHZrb = 10099,
  VFMADDCSHZrbk = 10100,
  VFMADDCSHZrbkz = 10101,
  VFMADDCSHZrk = 10102,
  VFMADDCSHZrkz = 10103,
  VFMADDPD4Ymr = 10104,
  VFMADDPD4Yrm = 10105,
  VFMADDPD4Yrr = 10106,
  VFMADDPD4Yrr_REV = 10107,
  VFMADDPD4mr = 10108,
  VFMADDPD4rm = 10109,
  VFMADDPD4rr = 10110,
  VFMADDPD4rr_REV = 10111,
  VFMADDPS4Ymr = 10112,
  VFMADDPS4Yrm = 10113,
  VFMADDPS4Yrr = 10114,
  VFMADDPS4Yrr_REV = 10115,
  VFMADDPS4mr = 10116,
  VFMADDPS4rm = 10117,
  VFMADDPS4rr = 10118,
  VFMADDPS4rr_REV = 10119,
  VFMADDSD4mr = 10120,
  VFMADDSD4mr_Int = 10121,
  VFMADDSD4rm = 10122,
  VFMADDSD4rm_Int = 10123,
  VFMADDSD4rr = 10124,
  VFMADDSD4rr_Int = 10125,
  VFMADDSD4rr_Int_REV = 10126,
  VFMADDSD4rr_REV = 10127,
  VFMADDSS4mr = 10128,
  VFMADDSS4mr_Int = 10129,
  VFMADDSS4rm = 10130,
  VFMADDSS4rm_Int = 10131,
  VFMADDSS4rr = 10132,
  VFMADDSS4rr_Int = 10133,
  VFMADDSS4rr_Int_REV = 10134,
  VFMADDSS4rr_REV = 10135,
  VFMADDSUB132PDYm = 10136,
  VFMADDSUB132PDYr = 10137,
  VFMADDSUB132PDZ128m = 10138,
  VFMADDSUB132PDZ128mb = 10139,
  VFMADDSUB132PDZ128mbk = 10140,
  VFMADDSUB132PDZ128mbkz = 10141,
  VFMADDSUB132PDZ128mk = 10142,
  VFMADDSUB132PDZ128mkz = 10143,
  VFMADDSUB132PDZ128r = 10144,
  VFMADDSUB132PDZ128rk = 10145,
  VFMADDSUB132PDZ128rkz = 10146,
  VFMADDSUB132PDZ256m = 10147,
  VFMADDSUB132PDZ256mb = 10148,
  VFMADDSUB132PDZ256mbk = 10149,
  VFMADDSUB132PDZ256mbkz = 10150,
  VFMADDSUB132PDZ256mk = 10151,
  VFMADDSUB132PDZ256mkz = 10152,
  VFMADDSUB132PDZ256r = 10153,
  VFMADDSUB132PDZ256rb = 10154,
  VFMADDSUB132PDZ256rbk = 10155,
  VFMADDSUB132PDZ256rbkz = 10156,
  VFMADDSUB132PDZ256rk = 10157,
  VFMADDSUB132PDZ256rkz = 10158,
  VFMADDSUB132PDZm = 10159,
  VFMADDSUB132PDZmb = 10160,
  VFMADDSUB132PDZmbk = 10161,
  VFMADDSUB132PDZmbkz = 10162,
  VFMADDSUB132PDZmk = 10163,
  VFMADDSUB132PDZmkz = 10164,
  VFMADDSUB132PDZr = 10165,
  VFMADDSUB132PDZrb = 10166,
  VFMADDSUB132PDZrbk = 10167,
  VFMADDSUB132PDZrbkz = 10168,
  VFMADDSUB132PDZrk = 10169,
  VFMADDSUB132PDZrkz = 10170,
  VFMADDSUB132PDm = 10171,
  VFMADDSUB132PDr = 10172,
  VFMADDSUB132PHZ128m = 10173,
  VFMADDSUB132PHZ128mb = 10174,
  VFMADDSUB132PHZ128mbk = 10175,
  VFMADDSUB132PHZ128mbkz = 10176,
  VFMADDSUB132PHZ128mk = 10177,
  VFMADDSUB132PHZ128mkz = 10178,
  VFMADDSUB132PHZ128r = 10179,
  VFMADDSUB132PHZ128rk = 10180,
  VFMADDSUB132PHZ128rkz = 10181,
  VFMADDSUB132PHZ256m = 10182,
  VFMADDSUB132PHZ256mb = 10183,
  VFMADDSUB132PHZ256mbk = 10184,
  VFMADDSUB132PHZ256mbkz = 10185,
  VFMADDSUB132PHZ256mk = 10186,
  VFMADDSUB132PHZ256mkz = 10187,
  VFMADDSUB132PHZ256r = 10188,
  VFMADDSUB132PHZ256rb = 10189,
  VFMADDSUB132PHZ256rbk = 10190,
  VFMADDSUB132PHZ256rbkz = 10191,
  VFMADDSUB132PHZ256rk = 10192,
  VFMADDSUB132PHZ256rkz = 10193,
  VFMADDSUB132PHZm = 10194,
  VFMADDSUB132PHZmb = 10195,
  VFMADDSUB132PHZmbk = 10196,
  VFMADDSUB132PHZmbkz = 10197,
  VFMADDSUB132PHZmk = 10198,
  VFMADDSUB132PHZmkz = 10199,
  VFMADDSUB132PHZr = 10200,
  VFMADDSUB132PHZrb = 10201,
  VFMADDSUB132PHZrbk = 10202,
  VFMADDSUB132PHZrbkz = 10203,
  VFMADDSUB132PHZrk = 10204,
  VFMADDSUB132PHZrkz = 10205,
  VFMADDSUB132PSYm = 10206,
  VFMADDSUB132PSYr = 10207,
  VFMADDSUB132PSZ128m = 10208,
  VFMADDSUB132PSZ128mb = 10209,
  VFMADDSUB132PSZ128mbk = 10210,
  VFMADDSUB132PSZ128mbkz = 10211,
  VFMADDSUB132PSZ128mk = 10212,
  VFMADDSUB132PSZ128mkz = 10213,
  VFMADDSUB132PSZ128r = 10214,
  VFMADDSUB132PSZ128rk = 10215,
  VFMADDSUB132PSZ128rkz = 10216,
  VFMADDSUB132PSZ256m = 10217,
  VFMADDSUB132PSZ256mb = 10218,
  VFMADDSUB132PSZ256mbk = 10219,
  VFMADDSUB132PSZ256mbkz = 10220,
  VFMADDSUB132PSZ256mk = 10221,
  VFMADDSUB132PSZ256mkz = 10222,
  VFMADDSUB132PSZ256r = 10223,
  VFMADDSUB132PSZ256rb = 10224,
  VFMADDSUB132PSZ256rbk = 10225,
  VFMADDSUB132PSZ256rbkz = 10226,
  VFMADDSUB132PSZ256rk = 10227,
  VFMADDSUB132PSZ256rkz = 10228,
  VFMADDSUB132PSZm = 10229,
  VFMADDSUB132PSZmb = 10230,
  VFMADDSUB132PSZmbk = 10231,
  VFMADDSUB132PSZmbkz = 10232,
  VFMADDSUB132PSZmk = 10233,
  VFMADDSUB132PSZmkz = 10234,
  VFMADDSUB132PSZr = 10235,
  VFMADDSUB132PSZrb = 10236,
  VFMADDSUB132PSZrbk = 10237,
  VFMADDSUB132PSZrbkz = 10238,
  VFMADDSUB132PSZrk = 10239,
  VFMADDSUB132PSZrkz = 10240,
  VFMADDSUB132PSm = 10241,
  VFMADDSUB132PSr = 10242,
  VFMADDSUB213PDYm = 10243,
  VFMADDSUB213PDYr = 10244,
  VFMADDSUB213PDZ128m = 10245,
  VFMADDSUB213PDZ128mb = 10246,
  VFMADDSUB213PDZ128mbk = 10247,
  VFMADDSUB213PDZ128mbkz = 10248,
  VFMADDSUB213PDZ128mk = 10249,
  VFMADDSUB213PDZ128mkz = 10250,
  VFMADDSUB213PDZ128r = 10251,
  VFMADDSUB213PDZ128rk = 10252,
  VFMADDSUB213PDZ128rkz = 10253,
  VFMADDSUB213PDZ256m = 10254,
  VFMADDSUB213PDZ256mb = 10255,
  VFMADDSUB213PDZ256mbk = 10256,
  VFMADDSUB213PDZ256mbkz = 10257,
  VFMADDSUB213PDZ256mk = 10258,
  VFMADDSUB213PDZ256mkz = 10259,
  VFMADDSUB213PDZ256r = 10260,
  VFMADDSUB213PDZ256rb = 10261,
  VFMADDSUB213PDZ256rbk = 10262,
  VFMADDSUB213PDZ256rbkz = 10263,
  VFMADDSUB213PDZ256rk = 10264,
  VFMADDSUB213PDZ256rkz = 10265,
  VFMADDSUB213PDZm = 10266,
  VFMADDSUB213PDZmb = 10267,
  VFMADDSUB213PDZmbk = 10268,
  VFMADDSUB213PDZmbkz = 10269,
  VFMADDSUB213PDZmk = 10270,
  VFMADDSUB213PDZmkz = 10271,
  VFMADDSUB213PDZr = 10272,
  VFMADDSUB213PDZrb = 10273,
  VFMADDSUB213PDZrbk = 10274,
  VFMADDSUB213PDZrbkz = 10275,
  VFMADDSUB213PDZrk = 10276,
  VFMADDSUB213PDZrkz = 10277,
  VFMADDSUB213PDm = 10278,
  VFMADDSUB213PDr = 10279,
  VFMADDSUB213PHZ128m = 10280,
  VFMADDSUB213PHZ128mb = 10281,
  VFMADDSUB213PHZ128mbk = 10282,
  VFMADDSUB213PHZ128mbkz = 10283,
  VFMADDSUB213PHZ128mk = 10284,
  VFMADDSUB213PHZ128mkz = 10285,
  VFMADDSUB213PHZ128r = 10286,
  VFMADDSUB213PHZ128rk = 10287,
  VFMADDSUB213PHZ128rkz = 10288,
  VFMADDSUB213PHZ256m = 10289,
  VFMADDSUB213PHZ256mb = 10290,
  VFMADDSUB213PHZ256mbk = 10291,
  VFMADDSUB213PHZ256mbkz = 10292,
  VFMADDSUB213PHZ256mk = 10293,
  VFMADDSUB213PHZ256mkz = 10294,
  VFMADDSUB213PHZ256r = 10295,
  VFMADDSUB213PHZ256rb = 10296,
  VFMADDSUB213PHZ256rbk = 10297,
  VFMADDSUB213PHZ256rbkz = 10298,
  VFMADDSUB213PHZ256rk = 10299,
  VFMADDSUB213PHZ256rkz = 10300,
  VFMADDSUB213PHZm = 10301,
  VFMADDSUB213PHZmb = 10302,
  VFMADDSUB213PHZmbk = 10303,
  VFMADDSUB213PHZmbkz = 10304,
  VFMADDSUB213PHZmk = 10305,
  VFMADDSUB213PHZmkz = 10306,
  VFMADDSUB213PHZr = 10307,
  VFMADDSUB213PHZrb = 10308,
  VFMADDSUB213PHZrbk = 10309,
  VFMADDSUB213PHZrbkz = 10310,
  VFMADDSUB213PHZrk = 10311,
  VFMADDSUB213PHZrkz = 10312,
  VFMADDSUB213PSYm = 10313,
  VFMADDSUB213PSYr = 10314,
  VFMADDSUB213PSZ128m = 10315,
  VFMADDSUB213PSZ128mb = 10316,
  VFMADDSUB213PSZ128mbk = 10317,
  VFMADDSUB213PSZ128mbkz = 10318,
  VFMADDSUB213PSZ128mk = 10319,
  VFMADDSUB213PSZ128mkz = 10320,
  VFMADDSUB213PSZ128r = 10321,
  VFMADDSUB213PSZ128rk = 10322,
  VFMADDSUB213PSZ128rkz = 10323,
  VFMADDSUB213PSZ256m = 10324,
  VFMADDSUB213PSZ256mb = 10325,
  VFMADDSUB213PSZ256mbk = 10326,
  VFMADDSUB213PSZ256mbkz = 10327,
  VFMADDSUB213PSZ256mk = 10328,
  VFMADDSUB213PSZ256mkz = 10329,
  VFMADDSUB213PSZ256r = 10330,
  VFMADDSUB213PSZ256rb = 10331,
  VFMADDSUB213PSZ256rbk = 10332,
  VFMADDSUB213PSZ256rbkz = 10333,
  VFMADDSUB213PSZ256rk = 10334,
  VFMADDSUB213PSZ256rkz = 10335,
  VFMADDSUB213PSZm = 10336,
  VFMADDSUB213PSZmb = 10337,
  VFMADDSUB213PSZmbk = 10338,
  VFMADDSUB213PSZmbkz = 10339,
  VFMADDSUB213PSZmk = 10340,
  VFMADDSUB213PSZmkz = 10341,
  VFMADDSUB213PSZr = 10342,
  VFMADDSUB213PSZrb = 10343,
  VFMADDSUB213PSZrbk = 10344,
  VFMADDSUB213PSZrbkz = 10345,
  VFMADDSUB213PSZrk = 10346,
  VFMADDSUB213PSZrkz = 10347,
  VFMADDSUB213PSm = 10348,
  VFMADDSUB213PSr = 10349,
  VFMADDSUB231PDYm = 10350,
  VFMADDSUB231PDYr = 10351,
  VFMADDSUB231PDZ128m = 10352,
  VFMADDSUB231PDZ128mb = 10353,
  VFMADDSUB231PDZ128mbk = 10354,
  VFMADDSUB231PDZ128mbkz = 10355,
  VFMADDSUB231PDZ128mk = 10356,
  VFMADDSUB231PDZ128mkz = 10357,
  VFMADDSUB231PDZ128r = 10358,
  VFMADDSUB231PDZ128rk = 10359,
  VFMADDSUB231PDZ128rkz = 10360,
  VFMADDSUB231PDZ256m = 10361,
  VFMADDSUB231PDZ256mb = 10362,
  VFMADDSUB231PDZ256mbk = 10363,
  VFMADDSUB231PDZ256mbkz = 10364,
  VFMADDSUB231PDZ256mk = 10365,
  VFMADDSUB231PDZ256mkz = 10366,
  VFMADDSUB231PDZ256r = 10367,
  VFMADDSUB231PDZ256rb = 10368,
  VFMADDSUB231PDZ256rbk = 10369,
  VFMADDSUB231PDZ256rbkz = 10370,
  VFMADDSUB231PDZ256rk = 10371,
  VFMADDSUB231PDZ256rkz = 10372,
  VFMADDSUB231PDZm = 10373,
  VFMADDSUB231PDZmb = 10374,
  VFMADDSUB231PDZmbk = 10375,
  VFMADDSUB231PDZmbkz = 10376,
  VFMADDSUB231PDZmk = 10377,
  VFMADDSUB231PDZmkz = 10378,
  VFMADDSUB231PDZr = 10379,
  VFMADDSUB231PDZrb = 10380,
  VFMADDSUB231PDZrbk = 10381,
  VFMADDSUB231PDZrbkz = 10382,
  VFMADDSUB231PDZrk = 10383,
  VFMADDSUB231PDZrkz = 10384,
  VFMADDSUB231PDm = 10385,
  VFMADDSUB231PDr = 10386,
  VFMADDSUB231PHZ128m = 10387,
  VFMADDSUB231PHZ128mb = 10388,
  VFMADDSUB231PHZ128mbk = 10389,
  VFMADDSUB231PHZ128mbkz = 10390,
  VFMADDSUB231PHZ128mk = 10391,
  VFMADDSUB231PHZ128mkz = 10392,
  VFMADDSUB231PHZ128r = 10393,
  VFMADDSUB231PHZ128rk = 10394,
  VFMADDSUB231PHZ128rkz = 10395,
  VFMADDSUB231PHZ256m = 10396,
  VFMADDSUB231PHZ256mb = 10397,
  VFMADDSUB231PHZ256mbk = 10398,
  VFMADDSUB231PHZ256mbkz = 10399,
  VFMADDSUB231PHZ256mk = 10400,
  VFMADDSUB231PHZ256mkz = 10401,
  VFMADDSUB231PHZ256r = 10402,
  VFMADDSUB231PHZ256rb = 10403,
  VFMADDSUB231PHZ256rbk = 10404,
  VFMADDSUB231PHZ256rbkz = 10405,
  VFMADDSUB231PHZ256rk = 10406,
  VFMADDSUB231PHZ256rkz = 10407,
  VFMADDSUB231PHZm = 10408,
  VFMADDSUB231PHZmb = 10409,
  VFMADDSUB231PHZmbk = 10410,
  VFMADDSUB231PHZmbkz = 10411,
  VFMADDSUB231PHZmk = 10412,
  VFMADDSUB231PHZmkz = 10413,
  VFMADDSUB231PHZr = 10414,
  VFMADDSUB231PHZrb = 10415,
  VFMADDSUB231PHZrbk = 10416,
  VFMADDSUB231PHZrbkz = 10417,
  VFMADDSUB231PHZrk = 10418,
  VFMADDSUB231PHZrkz = 10419,
  VFMADDSUB231PSYm = 10420,
  VFMADDSUB231PSYr = 10421,
  VFMADDSUB231PSZ128m = 10422,
  VFMADDSUB231PSZ128mb = 10423,
  VFMADDSUB231PSZ128mbk = 10424,
  VFMADDSUB231PSZ128mbkz = 10425,
  VFMADDSUB231PSZ128mk = 10426,
  VFMADDSUB231PSZ128mkz = 10427,
  VFMADDSUB231PSZ128r = 10428,
  VFMADDSUB231PSZ128rk = 10429,
  VFMADDSUB231PSZ128rkz = 10430,
  VFMADDSUB231PSZ256m = 10431,
  VFMADDSUB231PSZ256mb = 10432,
  VFMADDSUB231PSZ256mbk = 10433,
  VFMADDSUB231PSZ256mbkz = 10434,
  VFMADDSUB231PSZ256mk = 10435,
  VFMADDSUB231PSZ256mkz = 10436,
  VFMADDSUB231PSZ256r = 10437,
  VFMADDSUB231PSZ256rb = 10438,
  VFMADDSUB231PSZ256rbk = 10439,
  VFMADDSUB231PSZ256rbkz = 10440,
  VFMADDSUB231PSZ256rk = 10441,
  VFMADDSUB231PSZ256rkz = 10442,
  VFMADDSUB231PSZm = 10443,
  VFMADDSUB231PSZmb = 10444,
  VFMADDSUB231PSZmbk = 10445,
  VFMADDSUB231PSZmbkz = 10446,
  VFMADDSUB231PSZmk = 10447,
  VFMADDSUB231PSZmkz = 10448,
  VFMADDSUB231PSZr = 10449,
  VFMADDSUB231PSZrb = 10450,
  VFMADDSUB231PSZrbk = 10451,
  VFMADDSUB231PSZrbkz = 10452,
  VFMADDSUB231PSZrk = 10453,
  VFMADDSUB231PSZrkz = 10454,
  VFMADDSUB231PSm = 10455,
  VFMADDSUB231PSr = 10456,
  VFMADDSUBPD4Ymr = 10457,
  VFMADDSUBPD4Yrm = 10458,
  VFMADDSUBPD4Yrr = 10459,
  VFMADDSUBPD4Yrr_REV = 10460,
  VFMADDSUBPD4mr = 10461,
  VFMADDSUBPD4rm = 10462,
  VFMADDSUBPD4rr = 10463,
  VFMADDSUBPD4rr_REV = 10464,
  VFMADDSUBPS4Ymr = 10465,
  VFMADDSUBPS4Yrm = 10466,
  VFMADDSUBPS4Yrr = 10467,
  VFMADDSUBPS4Yrr_REV = 10468,
  VFMADDSUBPS4mr = 10469,
  VFMADDSUBPS4rm = 10470,
  VFMADDSUBPS4rr = 10471,
  VFMADDSUBPS4rr_REV = 10472,
  VFMSUB132BF16Z128m = 10473,
  VFMSUB132BF16Z128mb = 10474,
  VFMSUB132BF16Z128mbk = 10475,
  VFMSUB132BF16Z128mbkz = 10476,
  VFMSUB132BF16Z128mk = 10477,
  VFMSUB132BF16Z128mkz = 10478,
  VFMSUB132BF16Z128r = 10479,
  VFMSUB132BF16Z128rk = 10480,
  VFMSUB132BF16Z128rkz = 10481,
  VFMSUB132BF16Z256m = 10482,
  VFMSUB132BF16Z256mb = 10483,
  VFMSUB132BF16Z256mbk = 10484,
  VFMSUB132BF16Z256mbkz = 10485,
  VFMSUB132BF16Z256mk = 10486,
  VFMSUB132BF16Z256mkz = 10487,
  VFMSUB132BF16Z256r = 10488,
  VFMSUB132BF16Z256rk = 10489,
  VFMSUB132BF16Z256rkz = 10490,
  VFMSUB132BF16Zm = 10491,
  VFMSUB132BF16Zmb = 10492,
  VFMSUB132BF16Zmbk = 10493,
  VFMSUB132BF16Zmbkz = 10494,
  VFMSUB132BF16Zmk = 10495,
  VFMSUB132BF16Zmkz = 10496,
  VFMSUB132BF16Zr = 10497,
  VFMSUB132BF16Zrk = 10498,
  VFMSUB132BF16Zrkz = 10499,
  VFMSUB132PDYm = 10500,
  VFMSUB132PDYr = 10501,
  VFMSUB132PDZ128m = 10502,
  VFMSUB132PDZ128mb = 10503,
  VFMSUB132PDZ128mbk = 10504,
  VFMSUB132PDZ128mbkz = 10505,
  VFMSUB132PDZ128mk = 10506,
  VFMSUB132PDZ128mkz = 10507,
  VFMSUB132PDZ128r = 10508,
  VFMSUB132PDZ128rk = 10509,
  VFMSUB132PDZ128rkz = 10510,
  VFMSUB132PDZ256m = 10511,
  VFMSUB132PDZ256mb = 10512,
  VFMSUB132PDZ256mbk = 10513,
  VFMSUB132PDZ256mbkz = 10514,
  VFMSUB132PDZ256mk = 10515,
  VFMSUB132PDZ256mkz = 10516,
  VFMSUB132PDZ256r = 10517,
  VFMSUB132PDZ256rb = 10518,
  VFMSUB132PDZ256rbk = 10519,
  VFMSUB132PDZ256rbkz = 10520,
  VFMSUB132PDZ256rk = 10521,
  VFMSUB132PDZ256rkz = 10522,
  VFMSUB132PDZm = 10523,
  VFMSUB132PDZmb = 10524,
  VFMSUB132PDZmbk = 10525,
  VFMSUB132PDZmbkz = 10526,
  VFMSUB132PDZmk = 10527,
  VFMSUB132PDZmkz = 10528,
  VFMSUB132PDZr = 10529,
  VFMSUB132PDZrb = 10530,
  VFMSUB132PDZrbk = 10531,
  VFMSUB132PDZrbkz = 10532,
  VFMSUB132PDZrk = 10533,
  VFMSUB132PDZrkz = 10534,
  VFMSUB132PDm = 10535,
  VFMSUB132PDr = 10536,
  VFMSUB132PHZ128m = 10537,
  VFMSUB132PHZ128mb = 10538,
  VFMSUB132PHZ128mbk = 10539,
  VFMSUB132PHZ128mbkz = 10540,
  VFMSUB132PHZ128mk = 10541,
  VFMSUB132PHZ128mkz = 10542,
  VFMSUB132PHZ128r = 10543,
  VFMSUB132PHZ128rk = 10544,
  VFMSUB132PHZ128rkz = 10545,
  VFMSUB132PHZ256m = 10546,
  VFMSUB132PHZ256mb = 10547,
  VFMSUB132PHZ256mbk = 10548,
  VFMSUB132PHZ256mbkz = 10549,
  VFMSUB132PHZ256mk = 10550,
  VFMSUB132PHZ256mkz = 10551,
  VFMSUB132PHZ256r = 10552,
  VFMSUB132PHZ256rb = 10553,
  VFMSUB132PHZ256rbk = 10554,
  VFMSUB132PHZ256rbkz = 10555,
  VFMSUB132PHZ256rk = 10556,
  VFMSUB132PHZ256rkz = 10557,
  VFMSUB132PHZm = 10558,
  VFMSUB132PHZmb = 10559,
  VFMSUB132PHZmbk = 10560,
  VFMSUB132PHZmbkz = 10561,
  VFMSUB132PHZmk = 10562,
  VFMSUB132PHZmkz = 10563,
  VFMSUB132PHZr = 10564,
  VFMSUB132PHZrb = 10565,
  VFMSUB132PHZrbk = 10566,
  VFMSUB132PHZrbkz = 10567,
  VFMSUB132PHZrk = 10568,
  VFMSUB132PHZrkz = 10569,
  VFMSUB132PSYm = 10570,
  VFMSUB132PSYr = 10571,
  VFMSUB132PSZ128m = 10572,
  VFMSUB132PSZ128mb = 10573,
  VFMSUB132PSZ128mbk = 10574,
  VFMSUB132PSZ128mbkz = 10575,
  VFMSUB132PSZ128mk = 10576,
  VFMSUB132PSZ128mkz = 10577,
  VFMSUB132PSZ128r = 10578,
  VFMSUB132PSZ128rk = 10579,
  VFMSUB132PSZ128rkz = 10580,
  VFMSUB132PSZ256m = 10581,
  VFMSUB132PSZ256mb = 10582,
  VFMSUB132PSZ256mbk = 10583,
  VFMSUB132PSZ256mbkz = 10584,
  VFMSUB132PSZ256mk = 10585,
  VFMSUB132PSZ256mkz = 10586,
  VFMSUB132PSZ256r = 10587,
  VFMSUB132PSZ256rb = 10588,
  VFMSUB132PSZ256rbk = 10589,
  VFMSUB132PSZ256rbkz = 10590,
  VFMSUB132PSZ256rk = 10591,
  VFMSUB132PSZ256rkz = 10592,
  VFMSUB132PSZm = 10593,
  VFMSUB132PSZmb = 10594,
  VFMSUB132PSZmbk = 10595,
  VFMSUB132PSZmbkz = 10596,
  VFMSUB132PSZmk = 10597,
  VFMSUB132PSZmkz = 10598,
  VFMSUB132PSZr = 10599,
  VFMSUB132PSZrb = 10600,
  VFMSUB132PSZrbk = 10601,
  VFMSUB132PSZrbkz = 10602,
  VFMSUB132PSZrk = 10603,
  VFMSUB132PSZrkz = 10604,
  VFMSUB132PSm = 10605,
  VFMSUB132PSr = 10606,
  VFMSUB132SDZm = 10607,
  VFMSUB132SDZm_Int = 10608,
  VFMSUB132SDZmk_Int = 10609,
  VFMSUB132SDZmkz_Int = 10610,
  VFMSUB132SDZr = 10611,
  VFMSUB132SDZr_Int = 10612,
  VFMSUB132SDZrb = 10613,
  VFMSUB132SDZrb_Int = 10614,
  VFMSUB132SDZrbk_Int = 10615,
  VFMSUB132SDZrbkz_Int = 10616,
  VFMSUB132SDZrk_Int = 10617,
  VFMSUB132SDZrkz_Int = 10618,
  VFMSUB132SDm = 10619,
  VFMSUB132SDm_Int = 10620,
  VFMSUB132SDr = 10621,
  VFMSUB132SDr_Int = 10622,
  VFMSUB132SHZm = 10623,
  VFMSUB132SHZm_Int = 10624,
  VFMSUB132SHZmk_Int = 10625,
  VFMSUB132SHZmkz_Int = 10626,
  VFMSUB132SHZr = 10627,
  VFMSUB132SHZr_Int = 10628,
  VFMSUB132SHZrb = 10629,
  VFMSUB132SHZrb_Int = 10630,
  VFMSUB132SHZrbk_Int = 10631,
  VFMSUB132SHZrbkz_Int = 10632,
  VFMSUB132SHZrk_Int = 10633,
  VFMSUB132SHZrkz_Int = 10634,
  VFMSUB132SSZm = 10635,
  VFMSUB132SSZm_Int = 10636,
  VFMSUB132SSZmk_Int = 10637,
  VFMSUB132SSZmkz_Int = 10638,
  VFMSUB132SSZr = 10639,
  VFMSUB132SSZr_Int = 10640,
  VFMSUB132SSZrb = 10641,
  VFMSUB132SSZrb_Int = 10642,
  VFMSUB132SSZrbk_Int = 10643,
  VFMSUB132SSZrbkz_Int = 10644,
  VFMSUB132SSZrk_Int = 10645,
  VFMSUB132SSZrkz_Int = 10646,
  VFMSUB132SSm = 10647,
  VFMSUB132SSm_Int = 10648,
  VFMSUB132SSr = 10649,
  VFMSUB132SSr_Int = 10650,
  VFMSUB213BF16Z128m = 10651,
  VFMSUB213BF16Z128mb = 10652,
  VFMSUB213BF16Z128mbk = 10653,
  VFMSUB213BF16Z128mbkz = 10654,
  VFMSUB213BF16Z128mk = 10655,
  VFMSUB213BF16Z128mkz = 10656,
  VFMSUB213BF16Z128r = 10657,
  VFMSUB213BF16Z128rk = 10658,
  VFMSUB213BF16Z128rkz = 10659,
  VFMSUB213BF16Z256m = 10660,
  VFMSUB213BF16Z256mb = 10661,
  VFMSUB213BF16Z256mbk = 10662,
  VFMSUB213BF16Z256mbkz = 10663,
  VFMSUB213BF16Z256mk = 10664,
  VFMSUB213BF16Z256mkz = 10665,
  VFMSUB213BF16Z256r = 10666,
  VFMSUB213BF16Z256rk = 10667,
  VFMSUB213BF16Z256rkz = 10668,
  VFMSUB213BF16Zm = 10669,
  VFMSUB213BF16Zmb = 10670,
  VFMSUB213BF16Zmbk = 10671,
  VFMSUB213BF16Zmbkz = 10672,
  VFMSUB213BF16Zmk = 10673,
  VFMSUB213BF16Zmkz = 10674,
  VFMSUB213BF16Zr = 10675,
  VFMSUB213BF16Zrk = 10676,
  VFMSUB213BF16Zrkz = 10677,
  VFMSUB213PDYm = 10678,
  VFMSUB213PDYr = 10679,
  VFMSUB213PDZ128m = 10680,
  VFMSUB213PDZ128mb = 10681,
  VFMSUB213PDZ128mbk = 10682,
  VFMSUB213PDZ128mbkz = 10683,
  VFMSUB213PDZ128mk = 10684,
  VFMSUB213PDZ128mkz = 10685,
  VFMSUB213PDZ128r = 10686,
  VFMSUB213PDZ128rk = 10687,
  VFMSUB213PDZ128rkz = 10688,
  VFMSUB213PDZ256m = 10689,
  VFMSUB213PDZ256mb = 10690,
  VFMSUB213PDZ256mbk = 10691,
  VFMSUB213PDZ256mbkz = 10692,
  VFMSUB213PDZ256mk = 10693,
  VFMSUB213PDZ256mkz = 10694,
  VFMSUB213PDZ256r = 10695,
  VFMSUB213PDZ256rb = 10696,
  VFMSUB213PDZ256rbk = 10697,
  VFMSUB213PDZ256rbkz = 10698,
  VFMSUB213PDZ256rk = 10699,
  VFMSUB213PDZ256rkz = 10700,
  VFMSUB213PDZm = 10701,
  VFMSUB213PDZmb = 10702,
  VFMSUB213PDZmbk = 10703,
  VFMSUB213PDZmbkz = 10704,
  VFMSUB213PDZmk = 10705,
  VFMSUB213PDZmkz = 10706,
  VFMSUB213PDZr = 10707,
  VFMSUB213PDZrb = 10708,
  VFMSUB213PDZrbk = 10709,
  VFMSUB213PDZrbkz = 10710,
  VFMSUB213PDZrk = 10711,
  VFMSUB213PDZrkz = 10712,
  VFMSUB213PDm = 10713,
  VFMSUB213PDr = 10714,
  VFMSUB213PHZ128m = 10715,
  VFMSUB213PHZ128mb = 10716,
  VFMSUB213PHZ128mbk = 10717,
  VFMSUB213PHZ128mbkz = 10718,
  VFMSUB213PHZ128mk = 10719,
  VFMSUB213PHZ128mkz = 10720,
  VFMSUB213PHZ128r = 10721,
  VFMSUB213PHZ128rk = 10722,
  VFMSUB213PHZ128rkz = 10723,
  VFMSUB213PHZ256m = 10724,
  VFMSUB213PHZ256mb = 10725,
  VFMSUB213PHZ256mbk = 10726,
  VFMSUB213PHZ256mbkz = 10727,
  VFMSUB213PHZ256mk = 10728,
  VFMSUB213PHZ256mkz = 10729,
  VFMSUB213PHZ256r = 10730,
  VFMSUB213PHZ256rb = 10731,
  VFMSUB213PHZ256rbk = 10732,
  VFMSUB213PHZ256rbkz = 10733,
  VFMSUB213PHZ256rk = 10734,
  VFMSUB213PHZ256rkz = 10735,
  VFMSUB213PHZm = 10736,
  VFMSUB213PHZmb = 10737,
  VFMSUB213PHZmbk = 10738,
  VFMSUB213PHZmbkz = 10739,
  VFMSUB213PHZmk = 10740,
  VFMSUB213PHZmkz = 10741,
  VFMSUB213PHZr = 10742,
  VFMSUB213PHZrb = 10743,
  VFMSUB213PHZrbk = 10744,
  VFMSUB213PHZrbkz = 10745,
  VFMSUB213PHZrk = 10746,
  VFMSUB213PHZrkz = 10747,
  VFMSUB213PSYm = 10748,
  VFMSUB213PSYr = 10749,
  VFMSUB213PSZ128m = 10750,
  VFMSUB213PSZ128mb = 10751,
  VFMSUB213PSZ128mbk = 10752,
  VFMSUB213PSZ128mbkz = 10753,
  VFMSUB213PSZ128mk = 10754,
  VFMSUB213PSZ128mkz = 10755,
  VFMSUB213PSZ128r = 10756,
  VFMSUB213PSZ128rk = 10757,
  VFMSUB213PSZ128rkz = 10758,
  VFMSUB213PSZ256m = 10759,
  VFMSUB213PSZ256mb = 10760,
  VFMSUB213PSZ256mbk = 10761,
  VFMSUB213PSZ256mbkz = 10762,
  VFMSUB213PSZ256mk = 10763,
  VFMSUB213PSZ256mkz = 10764,
  VFMSUB213PSZ256r = 10765,
  VFMSUB213PSZ256rb = 10766,
  VFMSUB213PSZ256rbk = 10767,
  VFMSUB213PSZ256rbkz = 10768,
  VFMSUB213PSZ256rk = 10769,
  VFMSUB213PSZ256rkz = 10770,
  VFMSUB213PSZm = 10771,
  VFMSUB213PSZmb = 10772,
  VFMSUB213PSZmbk = 10773,
  VFMSUB213PSZmbkz = 10774,
  VFMSUB213PSZmk = 10775,
  VFMSUB213PSZmkz = 10776,
  VFMSUB213PSZr = 10777,
  VFMSUB213PSZrb = 10778,
  VFMSUB213PSZrbk = 10779,
  VFMSUB213PSZrbkz = 10780,
  VFMSUB213PSZrk = 10781,
  VFMSUB213PSZrkz = 10782,
  VFMSUB213PSm = 10783,
  VFMSUB213PSr = 10784,
  VFMSUB213SDZm = 10785,
  VFMSUB213SDZm_Int = 10786,
  VFMSUB213SDZmk_Int = 10787,
  VFMSUB213SDZmkz_Int = 10788,
  VFMSUB213SDZr = 10789,
  VFMSUB213SDZr_Int = 10790,
  VFMSUB213SDZrb = 10791,
  VFMSUB213SDZrb_Int = 10792,
  VFMSUB213SDZrbk_Int = 10793,
  VFMSUB213SDZrbkz_Int = 10794,
  VFMSUB213SDZrk_Int = 10795,
  VFMSUB213SDZrkz_Int = 10796,
  VFMSUB213SDm = 10797,
  VFMSUB213SDm_Int = 10798,
  VFMSUB213SDr = 10799,
  VFMSUB213SDr_Int = 10800,
  VFMSUB213SHZm = 10801,
  VFMSUB213SHZm_Int = 10802,
  VFMSUB213SHZmk_Int = 10803,
  VFMSUB213SHZmkz_Int = 10804,
  VFMSUB213SHZr = 10805,
  VFMSUB213SHZr_Int = 10806,
  VFMSUB213SHZrb = 10807,
  VFMSUB213SHZrb_Int = 10808,
  VFMSUB213SHZrbk_Int = 10809,
  VFMSUB213SHZrbkz_Int = 10810,
  VFMSUB213SHZrk_Int = 10811,
  VFMSUB213SHZrkz_Int = 10812,
  VFMSUB213SSZm = 10813,
  VFMSUB213SSZm_Int = 10814,
  VFMSUB213SSZmk_Int = 10815,
  VFMSUB213SSZmkz_Int = 10816,
  VFMSUB213SSZr = 10817,
  VFMSUB213SSZr_Int = 10818,
  VFMSUB213SSZrb = 10819,
  VFMSUB213SSZrb_Int = 10820,
  VFMSUB213SSZrbk_Int = 10821,
  VFMSUB213SSZrbkz_Int = 10822,
  VFMSUB213SSZrk_Int = 10823,
  VFMSUB213SSZrkz_Int = 10824,
  VFMSUB213SSm = 10825,
  VFMSUB213SSm_Int = 10826,
  VFMSUB213SSr = 10827,
  VFMSUB213SSr_Int = 10828,
  VFMSUB231BF16Z128m = 10829,
  VFMSUB231BF16Z128mb = 10830,
  VFMSUB231BF16Z128mbk = 10831,
  VFMSUB231BF16Z128mbkz = 10832,
  VFMSUB231BF16Z128mk = 10833,
  VFMSUB231BF16Z128mkz = 10834,
  VFMSUB231BF16Z128r = 10835,
  VFMSUB231BF16Z128rk = 10836,
  VFMSUB231BF16Z128rkz = 10837,
  VFMSUB231BF16Z256m = 10838,
  VFMSUB231BF16Z256mb = 10839,
  VFMSUB231BF16Z256mbk = 10840,
  VFMSUB231BF16Z256mbkz = 10841,
  VFMSUB231BF16Z256mk = 10842,
  VFMSUB231BF16Z256mkz = 10843,
  VFMSUB231BF16Z256r = 10844,
  VFMSUB231BF16Z256rk = 10845,
  VFMSUB231BF16Z256rkz = 10846,
  VFMSUB231BF16Zm = 10847,
  VFMSUB231BF16Zmb = 10848,
  VFMSUB231BF16Zmbk = 10849,
  VFMSUB231BF16Zmbkz = 10850,
  VFMSUB231BF16Zmk = 10851,
  VFMSUB231BF16Zmkz = 10852,
  VFMSUB231BF16Zr = 10853,
  VFMSUB231BF16Zrk = 10854,
  VFMSUB231BF16Zrkz = 10855,
  VFMSUB231PDYm = 10856,
  VFMSUB231PDYr = 10857,
  VFMSUB231PDZ128m = 10858,
  VFMSUB231PDZ128mb = 10859,
  VFMSUB231PDZ128mbk = 10860,
  VFMSUB231PDZ128mbkz = 10861,
  VFMSUB231PDZ128mk = 10862,
  VFMSUB231PDZ128mkz = 10863,
  VFMSUB231PDZ128r = 10864,
  VFMSUB231PDZ128rk = 10865,
  VFMSUB231PDZ128rkz = 10866,
  VFMSUB231PDZ256m = 10867,
  VFMSUB231PDZ256mb = 10868,
  VFMSUB231PDZ256mbk = 10869,
  VFMSUB231PDZ256mbkz = 10870,
  VFMSUB231PDZ256mk = 10871,
  VFMSUB231PDZ256mkz = 10872,
  VFMSUB231PDZ256r = 10873,
  VFMSUB231PDZ256rb = 10874,
  VFMSUB231PDZ256rbk = 10875,
  VFMSUB231PDZ256rbkz = 10876,
  VFMSUB231PDZ256rk = 10877,
  VFMSUB231PDZ256rkz = 10878,
  VFMSUB231PDZm = 10879,
  VFMSUB231PDZmb = 10880,
  VFMSUB231PDZmbk = 10881,
  VFMSUB231PDZmbkz = 10882,
  VFMSUB231PDZmk = 10883,
  VFMSUB231PDZmkz = 10884,
  VFMSUB231PDZr = 10885,
  VFMSUB231PDZrb = 10886,
  VFMSUB231PDZrbk = 10887,
  VFMSUB231PDZrbkz = 10888,
  VFMSUB231PDZrk = 10889,
  VFMSUB231PDZrkz = 10890,
  VFMSUB231PDm = 10891,
  VFMSUB231PDr = 10892,
  VFMSUB231PHZ128m = 10893,
  VFMSUB231PHZ128mb = 10894,
  VFMSUB231PHZ128mbk = 10895,
  VFMSUB231PHZ128mbkz = 10896,
  VFMSUB231PHZ128mk = 10897,
  VFMSUB231PHZ128mkz = 10898,
  VFMSUB231PHZ128r = 10899,
  VFMSUB231PHZ128rk = 10900,
  VFMSUB231PHZ128rkz = 10901,
  VFMSUB231PHZ256m = 10902,
  VFMSUB231PHZ256mb = 10903,
  VFMSUB231PHZ256mbk = 10904,
  VFMSUB231PHZ256mbkz = 10905,
  VFMSUB231PHZ256mk = 10906,
  VFMSUB231PHZ256mkz = 10907,
  VFMSUB231PHZ256r = 10908,
  VFMSUB231PHZ256rb = 10909,
  VFMSUB231PHZ256rbk = 10910,
  VFMSUB231PHZ256rbkz = 10911,
  VFMSUB231PHZ256rk = 10912,
  VFMSUB231PHZ256rkz = 10913,
  VFMSUB231PHZm = 10914,
  VFMSUB231PHZmb = 10915,
  VFMSUB231PHZmbk = 10916,
  VFMSUB231PHZmbkz = 10917,
  VFMSUB231PHZmk = 10918,
  VFMSUB231PHZmkz = 10919,
  VFMSUB231PHZr = 10920,
  VFMSUB231PHZrb = 10921,
  VFMSUB231PHZrbk = 10922,
  VFMSUB231PHZrbkz = 10923,
  VFMSUB231PHZrk = 10924,
  VFMSUB231PHZrkz = 10925,
  VFMSUB231PSYm = 10926,
  VFMSUB231PSYr = 10927,
  VFMSUB231PSZ128m = 10928,
  VFMSUB231PSZ128mb = 10929,
  VFMSUB231PSZ128mbk = 10930,
  VFMSUB231PSZ128mbkz = 10931,
  VFMSUB231PSZ128mk = 10932,
  VFMSUB231PSZ128mkz = 10933,
  VFMSUB231PSZ128r = 10934,
  VFMSUB231PSZ128rk = 10935,
  VFMSUB231PSZ128rkz = 10936,
  VFMSUB231PSZ256m = 10937,
  VFMSUB231PSZ256mb = 10938,
  VFMSUB231PSZ256mbk = 10939,
  VFMSUB231PSZ256mbkz = 10940,
  VFMSUB231PSZ256mk = 10941,
  VFMSUB231PSZ256mkz = 10942,
  VFMSUB231PSZ256r = 10943,
  VFMSUB231PSZ256rb = 10944,
  VFMSUB231PSZ256rbk = 10945,
  VFMSUB231PSZ256rbkz = 10946,
  VFMSUB231PSZ256rk = 10947,
  VFMSUB231PSZ256rkz = 10948,
  VFMSUB231PSZm = 10949,
  VFMSUB231PSZmb = 10950,
  VFMSUB231PSZmbk = 10951,
  VFMSUB231PSZmbkz = 10952,
  VFMSUB231PSZmk = 10953,
  VFMSUB231PSZmkz = 10954,
  VFMSUB231PSZr = 10955,
  VFMSUB231PSZrb = 10956,
  VFMSUB231PSZrbk = 10957,
  VFMSUB231PSZrbkz = 10958,
  VFMSUB231PSZrk = 10959,
  VFMSUB231PSZrkz = 10960,
  VFMSUB231PSm = 10961,
  VFMSUB231PSr = 10962,
  VFMSUB231SDZm = 10963,
  VFMSUB231SDZm_Int = 10964,
  VFMSUB231SDZmk_Int = 10965,
  VFMSUB231SDZmkz_Int = 10966,
  VFMSUB231SDZr = 10967,
  VFMSUB231SDZr_Int = 10968,
  VFMSUB231SDZrb = 10969,
  VFMSUB231SDZrb_Int = 10970,
  VFMSUB231SDZrbk_Int = 10971,
  VFMSUB231SDZrbkz_Int = 10972,
  VFMSUB231SDZrk_Int = 10973,
  VFMSUB231SDZrkz_Int = 10974,
  VFMSUB231SDm = 10975,
  VFMSUB231SDm_Int = 10976,
  VFMSUB231SDr = 10977,
  VFMSUB231SDr_Int = 10978,
  VFMSUB231SHZm = 10979,
  VFMSUB231SHZm_Int = 10980,
  VFMSUB231SHZmk_Int = 10981,
  VFMSUB231SHZmkz_Int = 10982,
  VFMSUB231SHZr = 10983,
  VFMSUB231SHZr_Int = 10984,
  VFMSUB231SHZrb = 10985,
  VFMSUB231SHZrb_Int = 10986,
  VFMSUB231SHZrbk_Int = 10987,
  VFMSUB231SHZrbkz_Int = 10988,
  VFMSUB231SHZrk_Int = 10989,
  VFMSUB231SHZrkz_Int = 10990,
  VFMSUB231SSZm = 10991,
  VFMSUB231SSZm_Int = 10992,
  VFMSUB231SSZmk_Int = 10993,
  VFMSUB231SSZmkz_Int = 10994,
  VFMSUB231SSZr = 10995,
  VFMSUB231SSZr_Int = 10996,
  VFMSUB231SSZrb = 10997,
  VFMSUB231SSZrb_Int = 10998,
  VFMSUB231SSZrbk_Int = 10999,
  VFMSUB231SSZrbkz_Int = 11000,
  VFMSUB231SSZrk_Int = 11001,
  VFMSUB231SSZrkz_Int = 11002,
  VFMSUB231SSm = 11003,
  VFMSUB231SSm_Int = 11004,
  VFMSUB231SSr = 11005,
  VFMSUB231SSr_Int = 11006,
  VFMSUBADD132PDYm = 11007,
  VFMSUBADD132PDYr = 11008,
  VFMSUBADD132PDZ128m = 11009,
  VFMSUBADD132PDZ128mb = 11010,
  VFMSUBADD132PDZ128mbk = 11011,
  VFMSUBADD132PDZ128mbkz = 11012,
  VFMSUBADD132PDZ128mk = 11013,
  VFMSUBADD132PDZ128mkz = 11014,
  VFMSUBADD132PDZ128r = 11015,
  VFMSUBADD132PDZ128rk = 11016,
  VFMSUBADD132PDZ128rkz = 11017,
  VFMSUBADD132PDZ256m = 11018,
  VFMSUBADD132PDZ256mb = 11019,
  VFMSUBADD132PDZ256mbk = 11020,
  VFMSUBADD132PDZ256mbkz = 11021,
  VFMSUBADD132PDZ256mk = 11022,
  VFMSUBADD132PDZ256mkz = 11023,
  VFMSUBADD132PDZ256r = 11024,
  VFMSUBADD132PDZ256rb = 11025,
  VFMSUBADD132PDZ256rbk = 11026,
  VFMSUBADD132PDZ256rbkz = 11027,
  VFMSUBADD132PDZ256rk = 11028,
  VFMSUBADD132PDZ256rkz = 11029,
  VFMSUBADD132PDZm = 11030,
  VFMSUBADD132PDZmb = 11031,
  VFMSUBADD132PDZmbk = 11032,
  VFMSUBADD132PDZmbkz = 11033,
  VFMSUBADD132PDZmk = 11034,
  VFMSUBADD132PDZmkz = 11035,
  VFMSUBADD132PDZr = 11036,
  VFMSUBADD132PDZrb = 11037,
  VFMSUBADD132PDZrbk = 11038,
  VFMSUBADD132PDZrbkz = 11039,
  VFMSUBADD132PDZrk = 11040,
  VFMSUBADD132PDZrkz = 11041,
  VFMSUBADD132PDm = 11042,
  VFMSUBADD132PDr = 11043,
  VFMSUBADD132PHZ128m = 11044,
  VFMSUBADD132PHZ128mb = 11045,
  VFMSUBADD132PHZ128mbk = 11046,
  VFMSUBADD132PHZ128mbkz = 11047,
  VFMSUBADD132PHZ128mk = 11048,
  VFMSUBADD132PHZ128mkz = 11049,
  VFMSUBADD132PHZ128r = 11050,
  VFMSUBADD132PHZ128rk = 11051,
  VFMSUBADD132PHZ128rkz = 11052,
  VFMSUBADD132PHZ256m = 11053,
  VFMSUBADD132PHZ256mb = 11054,
  VFMSUBADD132PHZ256mbk = 11055,
  VFMSUBADD132PHZ256mbkz = 11056,
  VFMSUBADD132PHZ256mk = 11057,
  VFMSUBADD132PHZ256mkz = 11058,
  VFMSUBADD132PHZ256r = 11059,
  VFMSUBADD132PHZ256rb = 11060,
  VFMSUBADD132PHZ256rbk = 11061,
  VFMSUBADD132PHZ256rbkz = 11062,
  VFMSUBADD132PHZ256rk = 11063,
  VFMSUBADD132PHZ256rkz = 11064,
  VFMSUBADD132PHZm = 11065,
  VFMSUBADD132PHZmb = 11066,
  VFMSUBADD132PHZmbk = 11067,
  VFMSUBADD132PHZmbkz = 11068,
  VFMSUBADD132PHZmk = 11069,
  VFMSUBADD132PHZmkz = 11070,
  VFMSUBADD132PHZr = 11071,
  VFMSUBADD132PHZrb = 11072,
  VFMSUBADD132PHZrbk = 11073,
  VFMSUBADD132PHZrbkz = 11074,
  VFMSUBADD132PHZrk = 11075,
  VFMSUBADD132PHZrkz = 11076,
  VFMSUBADD132PSYm = 11077,
  VFMSUBADD132PSYr = 11078,
  VFMSUBADD132PSZ128m = 11079,
  VFMSUBADD132PSZ128mb = 11080,
  VFMSUBADD132PSZ128mbk = 11081,
  VFMSUBADD132PSZ128mbkz = 11082,
  VFMSUBADD132PSZ128mk = 11083,
  VFMSUBADD132PSZ128mkz = 11084,
  VFMSUBADD132PSZ128r = 11085,
  VFMSUBADD132PSZ128rk = 11086,
  VFMSUBADD132PSZ128rkz = 11087,
  VFMSUBADD132PSZ256m = 11088,
  VFMSUBADD132PSZ256mb = 11089,
  VFMSUBADD132PSZ256mbk = 11090,
  VFMSUBADD132PSZ256mbkz = 11091,
  VFMSUBADD132PSZ256mk = 11092,
  VFMSUBADD132PSZ256mkz = 11093,
  VFMSUBADD132PSZ256r = 11094,
  VFMSUBADD132PSZ256rb = 11095,
  VFMSUBADD132PSZ256rbk = 11096,
  VFMSUBADD132PSZ256rbkz = 11097,
  VFMSUBADD132PSZ256rk = 11098,
  VFMSUBADD132PSZ256rkz = 11099,
  VFMSUBADD132PSZm = 11100,
  VFMSUBADD132PSZmb = 11101,
  VFMSUBADD132PSZmbk = 11102,
  VFMSUBADD132PSZmbkz = 11103,
  VFMSUBADD132PSZmk = 11104,
  VFMSUBADD132PSZmkz = 11105,
  VFMSUBADD132PSZr = 11106,
  VFMSUBADD132PSZrb = 11107,
  VFMSUBADD132PSZrbk = 11108,
  VFMSUBADD132PSZrbkz = 11109,
  VFMSUBADD132PSZrk = 11110,
  VFMSUBADD132PSZrkz = 11111,
  VFMSUBADD132PSm = 11112,
  VFMSUBADD132PSr = 11113,
  VFMSUBADD213PDYm = 11114,
  VFMSUBADD213PDYr = 11115,
  VFMSUBADD213PDZ128m = 11116,
  VFMSUBADD213PDZ128mb = 11117,
  VFMSUBADD213PDZ128mbk = 11118,
  VFMSUBADD213PDZ128mbkz = 11119,
  VFMSUBADD213PDZ128mk = 11120,
  VFMSUBADD213PDZ128mkz = 11121,
  VFMSUBADD213PDZ128r = 11122,
  VFMSUBADD213PDZ128rk = 11123,
  VFMSUBADD213PDZ128rkz = 11124,
  VFMSUBADD213PDZ256m = 11125,
  VFMSUBADD213PDZ256mb = 11126,
  VFMSUBADD213PDZ256mbk = 11127,
  VFMSUBADD213PDZ256mbkz = 11128,
  VFMSUBADD213PDZ256mk = 11129,
  VFMSUBADD213PDZ256mkz = 11130,
  VFMSUBADD213PDZ256r = 11131,
  VFMSUBADD213PDZ256rb = 11132,
  VFMSUBADD213PDZ256rbk = 11133,
  VFMSUBADD213PDZ256rbkz = 11134,
  VFMSUBADD213PDZ256rk = 11135,
  VFMSUBADD213PDZ256rkz = 11136,
  VFMSUBADD213PDZm = 11137,
  VFMSUBADD213PDZmb = 11138,
  VFMSUBADD213PDZmbk = 11139,
  VFMSUBADD213PDZmbkz = 11140,
  VFMSUBADD213PDZmk = 11141,
  VFMSUBADD213PDZmkz = 11142,
  VFMSUBADD213PDZr = 11143,
  VFMSUBADD213PDZrb = 11144,
  VFMSUBADD213PDZrbk = 11145,
  VFMSUBADD213PDZrbkz = 11146,
  VFMSUBADD213PDZrk = 11147,
  VFMSUBADD213PDZrkz = 11148,
  VFMSUBADD213PDm = 11149,
  VFMSUBADD213PDr = 11150,
  VFMSUBADD213PHZ128m = 11151,
  VFMSUBADD213PHZ128mb = 11152,
  VFMSUBADD213PHZ128mbk = 11153,
  VFMSUBADD213PHZ128mbkz = 11154,
  VFMSUBADD213PHZ128mk = 11155,
  VFMSUBADD213PHZ128mkz = 11156,
  VFMSUBADD213PHZ128r = 11157,
  VFMSUBADD213PHZ128rk = 11158,
  VFMSUBADD213PHZ128rkz = 11159,
  VFMSUBADD213PHZ256m = 11160,
  VFMSUBADD213PHZ256mb = 11161,
  VFMSUBADD213PHZ256mbk = 11162,
  VFMSUBADD213PHZ256mbkz = 11163,
  VFMSUBADD213PHZ256mk = 11164,
  VFMSUBADD213PHZ256mkz = 11165,
  VFMSUBADD213PHZ256r = 11166,
  VFMSUBADD213PHZ256rb = 11167,
  VFMSUBADD213PHZ256rbk = 11168,
  VFMSUBADD213PHZ256rbkz = 11169,
  VFMSUBADD213PHZ256rk = 11170,
  VFMSUBADD213PHZ256rkz = 11171,
  VFMSUBADD213PHZm = 11172,
  VFMSUBADD213PHZmb = 11173,
  VFMSUBADD213PHZmbk = 11174,
  VFMSUBADD213PHZmbkz = 11175,
  VFMSUBADD213PHZmk = 11176,
  VFMSUBADD213PHZmkz = 11177,
  VFMSUBADD213PHZr = 11178,
  VFMSUBADD213PHZrb = 11179,
  VFMSUBADD213PHZrbk = 11180,
  VFMSUBADD213PHZrbkz = 11181,
  VFMSUBADD213PHZrk = 11182,
  VFMSUBADD213PHZrkz = 11183,
  VFMSUBADD213PSYm = 11184,
  VFMSUBADD213PSYr = 11185,
  VFMSUBADD213PSZ128m = 11186,
  VFMSUBADD213PSZ128mb = 11187,
  VFMSUBADD213PSZ128mbk = 11188,
  VFMSUBADD213PSZ128mbkz = 11189,
  VFMSUBADD213PSZ128mk = 11190,
  VFMSUBADD213PSZ128mkz = 11191,
  VFMSUBADD213PSZ128r = 11192,
  VFMSUBADD213PSZ128rk = 11193,
  VFMSUBADD213PSZ128rkz = 11194,
  VFMSUBADD213PSZ256m = 11195,
  VFMSUBADD213PSZ256mb = 11196,
  VFMSUBADD213PSZ256mbk = 11197,
  VFMSUBADD213PSZ256mbkz = 11198,
  VFMSUBADD213PSZ256mk = 11199,
  VFMSUBADD213PSZ256mkz = 11200,
  VFMSUBADD213PSZ256r = 11201,
  VFMSUBADD213PSZ256rb = 11202,
  VFMSUBADD213PSZ256rbk = 11203,
  VFMSUBADD213PSZ256rbkz = 11204,
  VFMSUBADD213PSZ256rk = 11205,
  VFMSUBADD213PSZ256rkz = 11206,
  VFMSUBADD213PSZm = 11207,
  VFMSUBADD213PSZmb = 11208,
  VFMSUBADD213PSZmbk = 11209,
  VFMSUBADD213PSZmbkz = 11210,
  VFMSUBADD213PSZmk = 11211,
  VFMSUBADD213PSZmkz = 11212,
  VFMSUBADD213PSZr = 11213,
  VFMSUBADD213PSZrb = 11214,
  VFMSUBADD213PSZrbk = 11215,
  VFMSUBADD213PSZrbkz = 11216,
  VFMSUBADD213PSZrk = 11217,
  VFMSUBADD213PSZrkz = 11218,
  VFMSUBADD213PSm = 11219,
  VFMSUBADD213PSr = 11220,
  VFMSUBADD231PDYm = 11221,
  VFMSUBADD231PDYr = 11222,
  VFMSUBADD231PDZ128m = 11223,
  VFMSUBADD231PDZ128mb = 11224,
  VFMSUBADD231PDZ128mbk = 11225,
  VFMSUBADD231PDZ128mbkz = 11226,
  VFMSUBADD231PDZ128mk = 11227,
  VFMSUBADD231PDZ128mkz = 11228,
  VFMSUBADD231PDZ128r = 11229,
  VFMSUBADD231PDZ128rk = 11230,
  VFMSUBADD231PDZ128rkz = 11231,
  VFMSUBADD231PDZ256m = 11232,
  VFMSUBADD231PDZ256mb = 11233,
  VFMSUBADD231PDZ256mbk = 11234,
  VFMSUBADD231PDZ256mbkz = 11235,
  VFMSUBADD231PDZ256mk = 11236,
  VFMSUBADD231PDZ256mkz = 11237,
  VFMSUBADD231PDZ256r = 11238,
  VFMSUBADD231PDZ256rb = 11239,
  VFMSUBADD231PDZ256rbk = 11240,
  VFMSUBADD231PDZ256rbkz = 11241,
  VFMSUBADD231PDZ256rk = 11242,
  VFMSUBADD231PDZ256rkz = 11243,
  VFMSUBADD231PDZm = 11244,
  VFMSUBADD231PDZmb = 11245,
  VFMSUBADD231PDZmbk = 11246,
  VFMSUBADD231PDZmbkz = 11247,
  VFMSUBADD231PDZmk = 11248,
  VFMSUBADD231PDZmkz = 11249,
  VFMSUBADD231PDZr = 11250,
  VFMSUBADD231PDZrb = 11251,
  VFMSUBADD231PDZrbk = 11252,
  VFMSUBADD231PDZrbkz = 11253,
  VFMSUBADD231PDZrk = 11254,
  VFMSUBADD231PDZrkz = 11255,
  VFMSUBADD231PDm = 11256,
  VFMSUBADD231PDr = 11257,
  VFMSUBADD231PHZ128m = 11258,
  VFMSUBADD231PHZ128mb = 11259,
  VFMSUBADD231PHZ128mbk = 11260,
  VFMSUBADD231PHZ128mbkz = 11261,
  VFMSUBADD231PHZ128mk = 11262,
  VFMSUBADD231PHZ128mkz = 11263,
  VFMSUBADD231PHZ128r = 11264,
  VFMSUBADD231PHZ128rk = 11265,
  VFMSUBADD231PHZ128rkz = 11266,
  VFMSUBADD231PHZ256m = 11267,
  VFMSUBADD231PHZ256mb = 11268,
  VFMSUBADD231PHZ256mbk = 11269,
  VFMSUBADD231PHZ256mbkz = 11270,
  VFMSUBADD231PHZ256mk = 11271,
  VFMSUBADD231PHZ256mkz = 11272,
  VFMSUBADD231PHZ256r = 11273,
  VFMSUBADD231PHZ256rb = 11274,
  VFMSUBADD231PHZ256rbk = 11275,
  VFMSUBADD231PHZ256rbkz = 11276,
  VFMSUBADD231PHZ256rk = 11277,
  VFMSUBADD231PHZ256rkz = 11278,
  VFMSUBADD231PHZm = 11279,
  VFMSUBADD231PHZmb = 11280,
  VFMSUBADD231PHZmbk = 11281,
  VFMSUBADD231PHZmbkz = 11282,
  VFMSUBADD231PHZmk = 11283,
  VFMSUBADD231PHZmkz = 11284,
  VFMSUBADD231PHZr = 11285,
  VFMSUBADD231PHZrb = 11286,
  VFMSUBADD231PHZrbk = 11287,
  VFMSUBADD231PHZrbkz = 11288,
  VFMSUBADD231PHZrk = 11289,
  VFMSUBADD231PHZrkz = 11290,
  VFMSUBADD231PSYm = 11291,
  VFMSUBADD231PSYr = 11292,
  VFMSUBADD231PSZ128m = 11293,
  VFMSUBADD231PSZ128mb = 11294,
  VFMSUBADD231PSZ128mbk = 11295,
  VFMSUBADD231PSZ128mbkz = 11296,
  VFMSUBADD231PSZ128mk = 11297,
  VFMSUBADD231PSZ128mkz = 11298,
  VFMSUBADD231PSZ128r = 11299,
  VFMSUBADD231PSZ128rk = 11300,
  VFMSUBADD231PSZ128rkz = 11301,
  VFMSUBADD231PSZ256m = 11302,
  VFMSUBADD231PSZ256mb = 11303,
  VFMSUBADD231PSZ256mbk = 11304,
  VFMSUBADD231PSZ256mbkz = 11305,
  VFMSUBADD231PSZ256mk = 11306,
  VFMSUBADD231PSZ256mkz = 11307,
  VFMSUBADD231PSZ256r = 11308,
  VFMSUBADD231PSZ256rb = 11309,
  VFMSUBADD231PSZ256rbk = 11310,
  VFMSUBADD231PSZ256rbkz = 11311,
  VFMSUBADD231PSZ256rk = 11312,
  VFMSUBADD231PSZ256rkz = 11313,
  VFMSUBADD231PSZm = 11314,
  VFMSUBADD231PSZmb = 11315,
  VFMSUBADD231PSZmbk = 11316,
  VFMSUBADD231PSZmbkz = 11317,
  VFMSUBADD231PSZmk = 11318,
  VFMSUBADD231PSZmkz = 11319,
  VFMSUBADD231PSZr = 11320,
  VFMSUBADD231PSZrb = 11321,
  VFMSUBADD231PSZrbk = 11322,
  VFMSUBADD231PSZrbkz = 11323,
  VFMSUBADD231PSZrk = 11324,
  VFMSUBADD231PSZrkz = 11325,
  VFMSUBADD231PSm = 11326,
  VFMSUBADD231PSr = 11327,
  VFMSUBADDPD4Ymr = 11328,
  VFMSUBADDPD4Yrm = 11329,
  VFMSUBADDPD4Yrr = 11330,
  VFMSUBADDPD4Yrr_REV = 11331,
  VFMSUBADDPD4mr = 11332,
  VFMSUBADDPD4rm = 11333,
  VFMSUBADDPD4rr = 11334,
  VFMSUBADDPD4rr_REV = 11335,
  VFMSUBADDPS4Ymr = 11336,
  VFMSUBADDPS4Yrm = 11337,
  VFMSUBADDPS4Yrr = 11338,
  VFMSUBADDPS4Yrr_REV = 11339,
  VFMSUBADDPS4mr = 11340,
  VFMSUBADDPS4rm = 11341,
  VFMSUBADDPS4rr = 11342,
  VFMSUBADDPS4rr_REV = 11343,
  VFMSUBPD4Ymr = 11344,
  VFMSUBPD4Yrm = 11345,
  VFMSUBPD4Yrr = 11346,
  VFMSUBPD4Yrr_REV = 11347,
  VFMSUBPD4mr = 11348,
  VFMSUBPD4rm = 11349,
  VFMSUBPD4rr = 11350,
  VFMSUBPD4rr_REV = 11351,
  VFMSUBPS4Ymr = 11352,
  VFMSUBPS4Yrm = 11353,
  VFMSUBPS4Yrr = 11354,
  VFMSUBPS4Yrr_REV = 11355,
  VFMSUBPS4mr = 11356,
  VFMSUBPS4rm = 11357,
  VFMSUBPS4rr = 11358,
  VFMSUBPS4rr_REV = 11359,
  VFMSUBSD4mr = 11360,
  VFMSUBSD4mr_Int = 11361,
  VFMSUBSD4rm = 11362,
  VFMSUBSD4rm_Int = 11363,
  VFMSUBSD4rr = 11364,
  VFMSUBSD4rr_Int = 11365,
  VFMSUBSD4rr_Int_REV = 11366,
  VFMSUBSD4rr_REV = 11367,
  VFMSUBSS4mr = 11368,
  VFMSUBSS4mr_Int = 11369,
  VFMSUBSS4rm = 11370,
  VFMSUBSS4rm_Int = 11371,
  VFMSUBSS4rr = 11372,
  VFMSUBSS4rr_Int = 11373,
  VFMSUBSS4rr_Int_REV = 11374,
  VFMSUBSS4rr_REV = 11375,
  VFMULCPHZ128rm = 11376,
  VFMULCPHZ128rmb = 11377,
  VFMULCPHZ128rmbk = 11378,
  VFMULCPHZ128rmbkz = 11379,
  VFMULCPHZ128rmk = 11380,
  VFMULCPHZ128rmkz = 11381,
  VFMULCPHZ128rr = 11382,
  VFMULCPHZ128rrk = 11383,
  VFMULCPHZ128rrkz = 11384,
  VFMULCPHZ256rm = 11385,
  VFMULCPHZ256rmb = 11386,
  VFMULCPHZ256rmbk = 11387,
  VFMULCPHZ256rmbkz = 11388,
  VFMULCPHZ256rmk = 11389,
  VFMULCPHZ256rmkz = 11390,
  VFMULCPHZ256rr = 11391,
  VFMULCPHZ256rrb = 11392,
  VFMULCPHZ256rrbk = 11393,
  VFMULCPHZ256rrbkz = 11394,
  VFMULCPHZ256rrk = 11395,
  VFMULCPHZ256rrkz = 11396,
  VFMULCPHZrm = 11397,
  VFMULCPHZrmb = 11398,
  VFMULCPHZrmbk = 11399,
  VFMULCPHZrmbkz = 11400,
  VFMULCPHZrmk = 11401,
  VFMULCPHZrmkz = 11402,
  VFMULCPHZrr = 11403,
  VFMULCPHZrrb = 11404,
  VFMULCPHZrrbk = 11405,
  VFMULCPHZrrbkz = 11406,
  VFMULCPHZrrk = 11407,
  VFMULCPHZrrkz = 11408,
  VFMULCSHZrm = 11409,
  VFMULCSHZrmk = 11410,
  VFMULCSHZrmkz = 11411,
  VFMULCSHZrr = 11412,
  VFMULCSHZrrb = 11413,
  VFMULCSHZrrbk = 11414,
  VFMULCSHZrrbkz = 11415,
  VFMULCSHZrrk = 11416,
  VFMULCSHZrrkz = 11417,
  VFNMADD132BF16Z128m = 11418,
  VFNMADD132BF16Z128mb = 11419,
  VFNMADD132BF16Z128mbk = 11420,
  VFNMADD132BF16Z128mbkz = 11421,
  VFNMADD132BF16Z128mk = 11422,
  VFNMADD132BF16Z128mkz = 11423,
  VFNMADD132BF16Z128r = 11424,
  VFNMADD132BF16Z128rk = 11425,
  VFNMADD132BF16Z128rkz = 11426,
  VFNMADD132BF16Z256m = 11427,
  VFNMADD132BF16Z256mb = 11428,
  VFNMADD132BF16Z256mbk = 11429,
  VFNMADD132BF16Z256mbkz = 11430,
  VFNMADD132BF16Z256mk = 11431,
  VFNMADD132BF16Z256mkz = 11432,
  VFNMADD132BF16Z256r = 11433,
  VFNMADD132BF16Z256rk = 11434,
  VFNMADD132BF16Z256rkz = 11435,
  VFNMADD132BF16Zm = 11436,
  VFNMADD132BF16Zmb = 11437,
  VFNMADD132BF16Zmbk = 11438,
  VFNMADD132BF16Zmbkz = 11439,
  VFNMADD132BF16Zmk = 11440,
  VFNMADD132BF16Zmkz = 11441,
  VFNMADD132BF16Zr = 11442,
  VFNMADD132BF16Zrk = 11443,
  VFNMADD132BF16Zrkz = 11444,
  VFNMADD132PDYm = 11445,
  VFNMADD132PDYr = 11446,
  VFNMADD132PDZ128m = 11447,
  VFNMADD132PDZ128mb = 11448,
  VFNMADD132PDZ128mbk = 11449,
  VFNMADD132PDZ128mbkz = 11450,
  VFNMADD132PDZ128mk = 11451,
  VFNMADD132PDZ128mkz = 11452,
  VFNMADD132PDZ128r = 11453,
  VFNMADD132PDZ128rk = 11454,
  VFNMADD132PDZ128rkz = 11455,
  VFNMADD132PDZ256m = 11456,
  VFNMADD132PDZ256mb = 11457,
  VFNMADD132PDZ256mbk = 11458,
  VFNMADD132PDZ256mbkz = 11459,
  VFNMADD132PDZ256mk = 11460,
  VFNMADD132PDZ256mkz = 11461,
  VFNMADD132PDZ256r = 11462,
  VFNMADD132PDZ256rb = 11463,
  VFNMADD132PDZ256rbk = 11464,
  VFNMADD132PDZ256rbkz = 11465,
  VFNMADD132PDZ256rk = 11466,
  VFNMADD132PDZ256rkz = 11467,
  VFNMADD132PDZm = 11468,
  VFNMADD132PDZmb = 11469,
  VFNMADD132PDZmbk = 11470,
  VFNMADD132PDZmbkz = 11471,
  VFNMADD132PDZmk = 11472,
  VFNMADD132PDZmkz = 11473,
  VFNMADD132PDZr = 11474,
  VFNMADD132PDZrb = 11475,
  VFNMADD132PDZrbk = 11476,
  VFNMADD132PDZrbkz = 11477,
  VFNMADD132PDZrk = 11478,
  VFNMADD132PDZrkz = 11479,
  VFNMADD132PDm = 11480,
  VFNMADD132PDr = 11481,
  VFNMADD132PHZ128m = 11482,
  VFNMADD132PHZ128mb = 11483,
  VFNMADD132PHZ128mbk = 11484,
  VFNMADD132PHZ128mbkz = 11485,
  VFNMADD132PHZ128mk = 11486,
  VFNMADD132PHZ128mkz = 11487,
  VFNMADD132PHZ128r = 11488,
  VFNMADD132PHZ128rk = 11489,
  VFNMADD132PHZ128rkz = 11490,
  VFNMADD132PHZ256m = 11491,
  VFNMADD132PHZ256mb = 11492,
  VFNMADD132PHZ256mbk = 11493,
  VFNMADD132PHZ256mbkz = 11494,
  VFNMADD132PHZ256mk = 11495,
  VFNMADD132PHZ256mkz = 11496,
  VFNMADD132PHZ256r = 11497,
  VFNMADD132PHZ256rb = 11498,
  VFNMADD132PHZ256rbk = 11499,
  VFNMADD132PHZ256rbkz = 11500,
  VFNMADD132PHZ256rk = 11501,
  VFNMADD132PHZ256rkz = 11502,
  VFNMADD132PHZm = 11503,
  VFNMADD132PHZmb = 11504,
  VFNMADD132PHZmbk = 11505,
  VFNMADD132PHZmbkz = 11506,
  VFNMADD132PHZmk = 11507,
  VFNMADD132PHZmkz = 11508,
  VFNMADD132PHZr = 11509,
  VFNMADD132PHZrb = 11510,
  VFNMADD132PHZrbk = 11511,
  VFNMADD132PHZrbkz = 11512,
  VFNMADD132PHZrk = 11513,
  VFNMADD132PHZrkz = 11514,
  VFNMADD132PSYm = 11515,
  VFNMADD132PSYr = 11516,
  VFNMADD132PSZ128m = 11517,
  VFNMADD132PSZ128mb = 11518,
  VFNMADD132PSZ128mbk = 11519,
  VFNMADD132PSZ128mbkz = 11520,
  VFNMADD132PSZ128mk = 11521,
  VFNMADD132PSZ128mkz = 11522,
  VFNMADD132PSZ128r = 11523,
  VFNMADD132PSZ128rk = 11524,
  VFNMADD132PSZ128rkz = 11525,
  VFNMADD132PSZ256m = 11526,
  VFNMADD132PSZ256mb = 11527,
  VFNMADD132PSZ256mbk = 11528,
  VFNMADD132PSZ256mbkz = 11529,
  VFNMADD132PSZ256mk = 11530,
  VFNMADD132PSZ256mkz = 11531,
  VFNMADD132PSZ256r = 11532,
  VFNMADD132PSZ256rb = 11533,
  VFNMADD132PSZ256rbk = 11534,
  VFNMADD132PSZ256rbkz = 11535,
  VFNMADD132PSZ256rk = 11536,
  VFNMADD132PSZ256rkz = 11537,
  VFNMADD132PSZm = 11538,
  VFNMADD132PSZmb = 11539,
  VFNMADD132PSZmbk = 11540,
  VFNMADD132PSZmbkz = 11541,
  VFNMADD132PSZmk = 11542,
  VFNMADD132PSZmkz = 11543,
  VFNMADD132PSZr = 11544,
  VFNMADD132PSZrb = 11545,
  VFNMADD132PSZrbk = 11546,
  VFNMADD132PSZrbkz = 11547,
  VFNMADD132PSZrk = 11548,
  VFNMADD132PSZrkz = 11549,
  VFNMADD132PSm = 11550,
  VFNMADD132PSr = 11551,
  VFNMADD132SDZm = 11552,
  VFNMADD132SDZm_Int = 11553,
  VFNMADD132SDZmk_Int = 11554,
  VFNMADD132SDZmkz_Int = 11555,
  VFNMADD132SDZr = 11556,
  VFNMADD132SDZr_Int = 11557,
  VFNMADD132SDZrb = 11558,
  VFNMADD132SDZrb_Int = 11559,
  VFNMADD132SDZrbk_Int = 11560,
  VFNMADD132SDZrbkz_Int = 11561,
  VFNMADD132SDZrk_Int = 11562,
  VFNMADD132SDZrkz_Int = 11563,
  VFNMADD132SDm = 11564,
  VFNMADD132SDm_Int = 11565,
  VFNMADD132SDr = 11566,
  VFNMADD132SDr_Int = 11567,
  VFNMADD132SHZm = 11568,
  VFNMADD132SHZm_Int = 11569,
  VFNMADD132SHZmk_Int = 11570,
  VFNMADD132SHZmkz_Int = 11571,
  VFNMADD132SHZr = 11572,
  VFNMADD132SHZr_Int = 11573,
  VFNMADD132SHZrb = 11574,
  VFNMADD132SHZrb_Int = 11575,
  VFNMADD132SHZrbk_Int = 11576,
  VFNMADD132SHZrbkz_Int = 11577,
  VFNMADD132SHZrk_Int = 11578,
  VFNMADD132SHZrkz_Int = 11579,
  VFNMADD132SSZm = 11580,
  VFNMADD132SSZm_Int = 11581,
  VFNMADD132SSZmk_Int = 11582,
  VFNMADD132SSZmkz_Int = 11583,
  VFNMADD132SSZr = 11584,
  VFNMADD132SSZr_Int = 11585,
  VFNMADD132SSZrb = 11586,
  VFNMADD132SSZrb_Int = 11587,
  VFNMADD132SSZrbk_Int = 11588,
  VFNMADD132SSZrbkz_Int = 11589,
  VFNMADD132SSZrk_Int = 11590,
  VFNMADD132SSZrkz_Int = 11591,
  VFNMADD132SSm = 11592,
  VFNMADD132SSm_Int = 11593,
  VFNMADD132SSr = 11594,
  VFNMADD132SSr_Int = 11595,
  VFNMADD213BF16Z128m = 11596,
  VFNMADD213BF16Z128mb = 11597,
  VFNMADD213BF16Z128mbk = 11598,
  VFNMADD213BF16Z128mbkz = 11599,
  VFNMADD213BF16Z128mk = 11600,
  VFNMADD213BF16Z128mkz = 11601,
  VFNMADD213BF16Z128r = 11602,
  VFNMADD213BF16Z128rk = 11603,
  VFNMADD213BF16Z128rkz = 11604,
  VFNMADD213BF16Z256m = 11605,
  VFNMADD213BF16Z256mb = 11606,
  VFNMADD213BF16Z256mbk = 11607,
  VFNMADD213BF16Z256mbkz = 11608,
  VFNMADD213BF16Z256mk = 11609,
  VFNMADD213BF16Z256mkz = 11610,
  VFNMADD213BF16Z256r = 11611,
  VFNMADD213BF16Z256rk = 11612,
  VFNMADD213BF16Z256rkz = 11613,
  VFNMADD213BF16Zm = 11614,
  VFNMADD213BF16Zmb = 11615,
  VFNMADD213BF16Zmbk = 11616,
  VFNMADD213BF16Zmbkz = 11617,
  VFNMADD213BF16Zmk = 11618,
  VFNMADD213BF16Zmkz = 11619,
  VFNMADD213BF16Zr = 11620,
  VFNMADD213BF16Zrk = 11621,
  VFNMADD213BF16Zrkz = 11622,
  VFNMADD213PDYm = 11623,
  VFNMADD213PDYr = 11624,
  VFNMADD213PDZ128m = 11625,
  VFNMADD213PDZ128mb = 11626,
  VFNMADD213PDZ128mbk = 11627,
  VFNMADD213PDZ128mbkz = 11628,
  VFNMADD213PDZ128mk = 11629,
  VFNMADD213PDZ128mkz = 11630,
  VFNMADD213PDZ128r = 11631,
  VFNMADD213PDZ128rk = 11632,
  VFNMADD213PDZ128rkz = 11633,
  VFNMADD213PDZ256m = 11634,
  VFNMADD213PDZ256mb = 11635,
  VFNMADD213PDZ256mbk = 11636,
  VFNMADD213PDZ256mbkz = 11637,
  VFNMADD213PDZ256mk = 11638,
  VFNMADD213PDZ256mkz = 11639,
  VFNMADD213PDZ256r = 11640,
  VFNMADD213PDZ256rb = 11641,
  VFNMADD213PDZ256rbk = 11642,
  VFNMADD213PDZ256rbkz = 11643,
  VFNMADD213PDZ256rk = 11644,
  VFNMADD213PDZ256rkz = 11645,
  VFNMADD213PDZm = 11646,
  VFNMADD213PDZmb = 11647,
  VFNMADD213PDZmbk = 11648,
  VFNMADD213PDZmbkz = 11649,
  VFNMADD213PDZmk = 11650,
  VFNMADD213PDZmkz = 11651,
  VFNMADD213PDZr = 11652,
  VFNMADD213PDZrb = 11653,
  VFNMADD213PDZrbk = 11654,
  VFNMADD213PDZrbkz = 11655,
  VFNMADD213PDZrk = 11656,
  VFNMADD213PDZrkz = 11657,
  VFNMADD213PDm = 11658,
  VFNMADD213PDr = 11659,
  VFNMADD213PHZ128m = 11660,
  VFNMADD213PHZ128mb = 11661,
  VFNMADD213PHZ128mbk = 11662,
  VFNMADD213PHZ128mbkz = 11663,
  VFNMADD213PHZ128mk = 11664,
  VFNMADD213PHZ128mkz = 11665,
  VFNMADD213PHZ128r = 11666,
  VFNMADD213PHZ128rk = 11667,
  VFNMADD213PHZ128rkz = 11668,
  VFNMADD213PHZ256m = 11669,
  VFNMADD213PHZ256mb = 11670,
  VFNMADD213PHZ256mbk = 11671,
  VFNMADD213PHZ256mbkz = 11672,
  VFNMADD213PHZ256mk = 11673,
  VFNMADD213PHZ256mkz = 11674,
  VFNMADD213PHZ256r = 11675,
  VFNMADD213PHZ256rb = 11676,
  VFNMADD213PHZ256rbk = 11677,
  VFNMADD213PHZ256rbkz = 11678,
  VFNMADD213PHZ256rk = 11679,
  VFNMADD213PHZ256rkz = 11680,
  VFNMADD213PHZm = 11681,
  VFNMADD213PHZmb = 11682,
  VFNMADD213PHZmbk = 11683,
  VFNMADD213PHZmbkz = 11684,
  VFNMADD213PHZmk = 11685,
  VFNMADD213PHZmkz = 11686,
  VFNMADD213PHZr = 11687,
  VFNMADD213PHZrb = 11688,
  VFNMADD213PHZrbk = 11689,
  VFNMADD213PHZrbkz = 11690,
  VFNMADD213PHZrk = 11691,
  VFNMADD213PHZrkz = 11692,
  VFNMADD213PSYm = 11693,
  VFNMADD213PSYr = 11694,
  VFNMADD213PSZ128m = 11695,
  VFNMADD213PSZ128mb = 11696,
  VFNMADD213PSZ128mbk = 11697,
  VFNMADD213PSZ128mbkz = 11698,
  VFNMADD213PSZ128mk = 11699,
  VFNMADD213PSZ128mkz = 11700,
  VFNMADD213PSZ128r = 11701,
  VFNMADD213PSZ128rk = 11702,
  VFNMADD213PSZ128rkz = 11703,
  VFNMADD213PSZ256m = 11704,
  VFNMADD213PSZ256mb = 11705,
  VFNMADD213PSZ256mbk = 11706,
  VFNMADD213PSZ256mbkz = 11707,
  VFNMADD213PSZ256mk = 11708,
  VFNMADD213PSZ256mkz = 11709,
  VFNMADD213PSZ256r = 11710,
  VFNMADD213PSZ256rb = 11711,
  VFNMADD213PSZ256rbk = 11712,
  VFNMADD213PSZ256rbkz = 11713,
  VFNMADD213PSZ256rk = 11714,
  VFNMADD213PSZ256rkz = 11715,
  VFNMADD213PSZm = 11716,
  VFNMADD213PSZmb = 11717,
  VFNMADD213PSZmbk = 11718,
  VFNMADD213PSZmbkz = 11719,
  VFNMADD213PSZmk = 11720,
  VFNMADD213PSZmkz = 11721,
  VFNMADD213PSZr = 11722,
  VFNMADD213PSZrb = 11723,
  VFNMADD213PSZrbk = 11724,
  VFNMADD213PSZrbkz = 11725,
  VFNMADD213PSZrk = 11726,
  VFNMADD213PSZrkz = 11727,
  VFNMADD213PSm = 11728,
  VFNMADD213PSr = 11729,
  VFNMADD213SDZm = 11730,
  VFNMADD213SDZm_Int = 11731,
  VFNMADD213SDZmk_Int = 11732,
  VFNMADD213SDZmkz_Int = 11733,
  VFNMADD213SDZr = 11734,
  VFNMADD213SDZr_Int = 11735,
  VFNMADD213SDZrb = 11736,
  VFNMADD213SDZrb_Int = 11737,
  VFNMADD213SDZrbk_Int = 11738,
  VFNMADD213SDZrbkz_Int = 11739,
  VFNMADD213SDZrk_Int = 11740,
  VFNMADD213SDZrkz_Int = 11741,
  VFNMADD213SDm = 11742,
  VFNMADD213SDm_Int = 11743,
  VFNMADD213SDr = 11744,
  VFNMADD213SDr_Int = 11745,
  VFNMADD213SHZm = 11746,
  VFNMADD213SHZm_Int = 11747,
  VFNMADD213SHZmk_Int = 11748,
  VFNMADD213SHZmkz_Int = 11749,
  VFNMADD213SHZr = 11750,
  VFNMADD213SHZr_Int = 11751,
  VFNMADD213SHZrb = 11752,
  VFNMADD213SHZrb_Int = 11753,
  VFNMADD213SHZrbk_Int = 11754,
  VFNMADD213SHZrbkz_Int = 11755,
  VFNMADD213SHZrk_Int = 11756,
  VFNMADD213SHZrkz_Int = 11757,
  VFNMADD213SSZm = 11758,
  VFNMADD213SSZm_Int = 11759,
  VFNMADD213SSZmk_Int = 11760,
  VFNMADD213SSZmkz_Int = 11761,
  VFNMADD213SSZr = 11762,
  VFNMADD213SSZr_Int = 11763,
  VFNMADD213SSZrb = 11764,
  VFNMADD213SSZrb_Int = 11765,
  VFNMADD213SSZrbk_Int = 11766,
  VFNMADD213SSZrbkz_Int = 11767,
  VFNMADD213SSZrk_Int = 11768,
  VFNMADD213SSZrkz_Int = 11769,
  VFNMADD213SSm = 11770,
  VFNMADD213SSm_Int = 11771,
  VFNMADD213SSr = 11772,
  VFNMADD213SSr_Int = 11773,
  VFNMADD231BF16Z128m = 11774,
  VFNMADD231BF16Z128mb = 11775,
  VFNMADD231BF16Z128mbk = 11776,
  VFNMADD231BF16Z128mbkz = 11777,
  VFNMADD231BF16Z128mk = 11778,
  VFNMADD231BF16Z128mkz = 11779,
  VFNMADD231BF16Z128r = 11780,
  VFNMADD231BF16Z128rk = 11781,
  VFNMADD231BF16Z128rkz = 11782,
  VFNMADD231BF16Z256m = 11783,
  VFNMADD231BF16Z256mb = 11784,
  VFNMADD231BF16Z256mbk = 11785,
  VFNMADD231BF16Z256mbkz = 11786,
  VFNMADD231BF16Z256mk = 11787,
  VFNMADD231BF16Z256mkz = 11788,
  VFNMADD231BF16Z256r = 11789,
  VFNMADD231BF16Z256rk = 11790,
  VFNMADD231BF16Z256rkz = 11791,
  VFNMADD231BF16Zm = 11792,
  VFNMADD231BF16Zmb = 11793,
  VFNMADD231BF16Zmbk = 11794,
  VFNMADD231BF16Zmbkz = 11795,
  VFNMADD231BF16Zmk = 11796,
  VFNMADD231BF16Zmkz = 11797,
  VFNMADD231BF16Zr = 11798,
  VFNMADD231BF16Zrk = 11799,
  VFNMADD231BF16Zrkz = 11800,
  VFNMADD231PDYm = 11801,
  VFNMADD231PDYr = 11802,
  VFNMADD231PDZ128m = 11803,
  VFNMADD231PDZ128mb = 11804,
  VFNMADD231PDZ128mbk = 11805,
  VFNMADD231PDZ128mbkz = 11806,
  VFNMADD231PDZ128mk = 11807,
  VFNMADD231PDZ128mkz = 11808,
  VFNMADD231PDZ128r = 11809,
  VFNMADD231PDZ128rk = 11810,
  VFNMADD231PDZ128rkz = 11811,
  VFNMADD231PDZ256m = 11812,
  VFNMADD231PDZ256mb = 11813,
  VFNMADD231PDZ256mbk = 11814,
  VFNMADD231PDZ256mbkz = 11815,
  VFNMADD231PDZ256mk = 11816,
  VFNMADD231PDZ256mkz = 11817,
  VFNMADD231PDZ256r = 11818,
  VFNMADD231PDZ256rb = 11819,
  VFNMADD231PDZ256rbk = 11820,
  VFNMADD231PDZ256rbkz = 11821,
  VFNMADD231PDZ256rk = 11822,
  VFNMADD231PDZ256rkz = 11823,
  VFNMADD231PDZm = 11824,
  VFNMADD231PDZmb = 11825,
  VFNMADD231PDZmbk = 11826,
  VFNMADD231PDZmbkz = 11827,
  VFNMADD231PDZmk = 11828,
  VFNMADD231PDZmkz = 11829,
  VFNMADD231PDZr = 11830,
  VFNMADD231PDZrb = 11831,
  VFNMADD231PDZrbk = 11832,
  VFNMADD231PDZrbkz = 11833,
  VFNMADD231PDZrk = 11834,
  VFNMADD231PDZrkz = 11835,
  VFNMADD231PDm = 11836,
  VFNMADD231PDr = 11837,
  VFNMADD231PHZ128m = 11838,
  VFNMADD231PHZ128mb = 11839,
  VFNMADD231PHZ128mbk = 11840,
  VFNMADD231PHZ128mbkz = 11841,
  VFNMADD231PHZ128mk = 11842,
  VFNMADD231PHZ128mkz = 11843,
  VFNMADD231PHZ128r = 11844,
  VFNMADD231PHZ128rk = 11845,
  VFNMADD231PHZ128rkz = 11846,
  VFNMADD231PHZ256m = 11847,
  VFNMADD231PHZ256mb = 11848,
  VFNMADD231PHZ256mbk = 11849,
  VFNMADD231PHZ256mbkz = 11850,
  VFNMADD231PHZ256mk = 11851,
  VFNMADD231PHZ256mkz = 11852,
  VFNMADD231PHZ256r = 11853,
  VFNMADD231PHZ256rb = 11854,
  VFNMADD231PHZ256rbk = 11855,
  VFNMADD231PHZ256rbkz = 11856,
  VFNMADD231PHZ256rk = 11857,
  VFNMADD231PHZ256rkz = 11858,
  VFNMADD231PHZm = 11859,
  VFNMADD231PHZmb = 11860,
  VFNMADD231PHZmbk = 11861,
  VFNMADD231PHZmbkz = 11862,
  VFNMADD231PHZmk = 11863,
  VFNMADD231PHZmkz = 11864,
  VFNMADD231PHZr = 11865,
  VFNMADD231PHZrb = 11866,
  VFNMADD231PHZrbk = 11867,
  VFNMADD231PHZrbkz = 11868,
  VFNMADD231PHZrk = 11869,
  VFNMADD231PHZrkz = 11870,
  VFNMADD231PSYm = 11871,
  VFNMADD231PSYr = 11872,
  VFNMADD231PSZ128m = 11873,
  VFNMADD231PSZ128mb = 11874,
  VFNMADD231PSZ128mbk = 11875,
  VFNMADD231PSZ128mbkz = 11876,
  VFNMADD231PSZ128mk = 11877,
  VFNMADD231PSZ128mkz = 11878,
  VFNMADD231PSZ128r = 11879,
  VFNMADD231PSZ128rk = 11880,
  VFNMADD231PSZ128rkz = 11881,
  VFNMADD231PSZ256m = 11882,
  VFNMADD231PSZ256mb = 11883,
  VFNMADD231PSZ256mbk = 11884,
  VFNMADD231PSZ256mbkz = 11885,
  VFNMADD231PSZ256mk = 11886,
  VFNMADD231PSZ256mkz = 11887,
  VFNMADD231PSZ256r = 11888,
  VFNMADD231PSZ256rb = 11889,
  VFNMADD231PSZ256rbk = 11890,
  VFNMADD231PSZ256rbkz = 11891,
  VFNMADD231PSZ256rk = 11892,
  VFNMADD231PSZ256rkz = 11893,
  VFNMADD231PSZm = 11894,
  VFNMADD231PSZmb = 11895,
  VFNMADD231PSZmbk = 11896,
  VFNMADD231PSZmbkz = 11897,
  VFNMADD231PSZmk = 11898,
  VFNMADD231PSZmkz = 11899,
  VFNMADD231PSZr = 11900,
  VFNMADD231PSZrb = 11901,
  VFNMADD231PSZrbk = 11902,
  VFNMADD231PSZrbkz = 11903,
  VFNMADD231PSZrk = 11904,
  VFNMADD231PSZrkz = 11905,
  VFNMADD231PSm = 11906,
  VFNMADD231PSr = 11907,
  VFNMADD231SDZm = 11908,
  VFNMADD231SDZm_Int = 11909,
  VFNMADD231SDZmk_Int = 11910,
  VFNMADD231SDZmkz_Int = 11911,
  VFNMADD231SDZr = 11912,
  VFNMADD231SDZr_Int = 11913,
  VFNMADD231SDZrb = 11914,
  VFNMADD231SDZrb_Int = 11915,
  VFNMADD231SDZrbk_Int = 11916,
  VFNMADD231SDZrbkz_Int = 11917,
  VFNMADD231SDZrk_Int = 11918,
  VFNMADD231SDZrkz_Int = 11919,
  VFNMADD231SDm = 11920,
  VFNMADD231SDm_Int = 11921,
  VFNMADD231SDr = 11922,
  VFNMADD231SDr_Int = 11923,
  VFNMADD231SHZm = 11924,
  VFNMADD231SHZm_Int = 11925,
  VFNMADD231SHZmk_Int = 11926,
  VFNMADD231SHZmkz_Int = 11927,
  VFNMADD231SHZr = 11928,
  VFNMADD231SHZr_Int = 11929,
  VFNMADD231SHZrb = 11930,
  VFNMADD231SHZrb_Int = 11931,
  VFNMADD231SHZrbk_Int = 11932,
  VFNMADD231SHZrbkz_Int = 11933,
  VFNMADD231SHZrk_Int = 11934,
  VFNMADD231SHZrkz_Int = 11935,
  VFNMADD231SSZm = 11936,
  VFNMADD231SSZm_Int = 11937,
  VFNMADD231SSZmk_Int = 11938,
  VFNMADD231SSZmkz_Int = 11939,
  VFNMADD231SSZr = 11940,
  VFNMADD231SSZr_Int = 11941,
  VFNMADD231SSZrb = 11942,
  VFNMADD231SSZrb_Int = 11943,
  VFNMADD231SSZrbk_Int = 11944,
  VFNMADD231SSZrbkz_Int = 11945,
  VFNMADD231SSZrk_Int = 11946,
  VFNMADD231SSZrkz_Int = 11947,
  VFNMADD231SSm = 11948,
  VFNMADD231SSm_Int = 11949,
  VFNMADD231SSr = 11950,
  VFNMADD231SSr_Int = 11951,
  VFNMADDPD4Ymr = 11952,
  VFNMADDPD4Yrm = 11953,
  VFNMADDPD4Yrr = 11954,
  VFNMADDPD4Yrr_REV = 11955,
  VFNMADDPD4mr = 11956,
  VFNMADDPD4rm = 11957,
  VFNMADDPD4rr = 11958,
  VFNMADDPD4rr_REV = 11959,
  VFNMADDPS4Ymr = 11960,
  VFNMADDPS4Yrm = 11961,
  VFNMADDPS4Yrr = 11962,
  VFNMADDPS4Yrr_REV = 11963,
  VFNMADDPS4mr = 11964,
  VFNMADDPS4rm = 11965,
  VFNMADDPS4rr = 11966,
  VFNMADDPS4rr_REV = 11967,
  VFNMADDSD4mr = 11968,
  VFNMADDSD4mr_Int = 11969,
  VFNMADDSD4rm = 11970,
  VFNMADDSD4rm_Int = 11971,
  VFNMADDSD4rr = 11972,
  VFNMADDSD4rr_Int = 11973,
  VFNMADDSD4rr_Int_REV = 11974,
  VFNMADDSD4rr_REV = 11975,
  VFNMADDSS4mr = 11976,
  VFNMADDSS4mr_Int = 11977,
  VFNMADDSS4rm = 11978,
  VFNMADDSS4rm_Int = 11979,
  VFNMADDSS4rr = 11980,
  VFNMADDSS4rr_Int = 11981,
  VFNMADDSS4rr_Int_REV = 11982,
  VFNMADDSS4rr_REV = 11983,
  VFNMSUB132BF16Z128m = 11984,
  VFNMSUB132BF16Z128mb = 11985,
  VFNMSUB132BF16Z128mbk = 11986,
  VFNMSUB132BF16Z128mbkz = 11987,
  VFNMSUB132BF16Z128mk = 11988,
  VFNMSUB132BF16Z128mkz = 11989,
  VFNMSUB132BF16Z128r = 11990,
  VFNMSUB132BF16Z128rk = 11991,
  VFNMSUB132BF16Z128rkz = 11992,
  VFNMSUB132BF16Z256m = 11993,
  VFNMSUB132BF16Z256mb = 11994,
  VFNMSUB132BF16Z256mbk = 11995,
  VFNMSUB132BF16Z256mbkz = 11996,
  VFNMSUB132BF16Z256mk = 11997,
  VFNMSUB132BF16Z256mkz = 11998,
  VFNMSUB132BF16Z256r = 11999,
  VFNMSUB132BF16Z256rk = 12000,
  VFNMSUB132BF16Z256rkz = 12001,
  VFNMSUB132BF16Zm = 12002,
  VFNMSUB132BF16Zmb = 12003,
  VFNMSUB132BF16Zmbk = 12004,
  VFNMSUB132BF16Zmbkz = 12005,
  VFNMSUB132BF16Zmk = 12006,
  VFNMSUB132BF16Zmkz = 12007,
  VFNMSUB132BF16Zr = 12008,
  VFNMSUB132BF16Zrk = 12009,
  VFNMSUB132BF16Zrkz = 12010,
  VFNMSUB132PDYm = 12011,
  VFNMSUB132PDYr = 12012,
  VFNMSUB132PDZ128m = 12013,
  VFNMSUB132PDZ128mb = 12014,
  VFNMSUB132PDZ128mbk = 12015,
  VFNMSUB132PDZ128mbkz = 12016,
  VFNMSUB132PDZ128mk = 12017,
  VFNMSUB132PDZ128mkz = 12018,
  VFNMSUB132PDZ128r = 12019,
  VFNMSUB132PDZ128rk = 12020,
  VFNMSUB132PDZ128rkz = 12021,
  VFNMSUB132PDZ256m = 12022,
  VFNMSUB132PDZ256mb = 12023,
  VFNMSUB132PDZ256mbk = 12024,
  VFNMSUB132PDZ256mbkz = 12025,
  VFNMSUB132PDZ256mk = 12026,
  VFNMSUB132PDZ256mkz = 12027,
  VFNMSUB132PDZ256r = 12028,
  VFNMSUB132PDZ256rb = 12029,
  VFNMSUB132PDZ256rbk = 12030,
  VFNMSUB132PDZ256rbkz = 12031,
  VFNMSUB132PDZ256rk = 12032,
  VFNMSUB132PDZ256rkz = 12033,
  VFNMSUB132PDZm = 12034,
  VFNMSUB132PDZmb = 12035,
  VFNMSUB132PDZmbk = 12036,
  VFNMSUB132PDZmbkz = 12037,
  VFNMSUB132PDZmk = 12038,
  VFNMSUB132PDZmkz = 12039,
  VFNMSUB132PDZr = 12040,
  VFNMSUB132PDZrb = 12041,
  VFNMSUB132PDZrbk = 12042,
  VFNMSUB132PDZrbkz = 12043,
  VFNMSUB132PDZrk = 12044,
  VFNMSUB132PDZrkz = 12045,
  VFNMSUB132PDm = 12046,
  VFNMSUB132PDr = 12047,
  VFNMSUB132PHZ128m = 12048,
  VFNMSUB132PHZ128mb = 12049,
  VFNMSUB132PHZ128mbk = 12050,
  VFNMSUB132PHZ128mbkz = 12051,
  VFNMSUB132PHZ128mk = 12052,
  VFNMSUB132PHZ128mkz = 12053,
  VFNMSUB132PHZ128r = 12054,
  VFNMSUB132PHZ128rk = 12055,
  VFNMSUB132PHZ128rkz = 12056,
  VFNMSUB132PHZ256m = 12057,
  VFNMSUB132PHZ256mb = 12058,
  VFNMSUB132PHZ256mbk = 12059,
  VFNMSUB132PHZ256mbkz = 12060,
  VFNMSUB132PHZ256mk = 12061,
  VFNMSUB132PHZ256mkz = 12062,
  VFNMSUB132PHZ256r = 12063,
  VFNMSUB132PHZ256rb = 12064,
  VFNMSUB132PHZ256rbk = 12065,
  VFNMSUB132PHZ256rbkz = 12066,
  VFNMSUB132PHZ256rk = 12067,
  VFNMSUB132PHZ256rkz = 12068,
  VFNMSUB132PHZm = 12069,
  VFNMSUB132PHZmb = 12070,
  VFNMSUB132PHZmbk = 12071,
  VFNMSUB132PHZmbkz = 12072,
  VFNMSUB132PHZmk = 12073,
  VFNMSUB132PHZmkz = 12074,
  VFNMSUB132PHZr = 12075,
  VFNMSUB132PHZrb = 12076,
  VFNMSUB132PHZrbk = 12077,
  VFNMSUB132PHZrbkz = 12078,
  VFNMSUB132PHZrk = 12079,
  VFNMSUB132PHZrkz = 12080,
  VFNMSUB132PSYm = 12081,
  VFNMSUB132PSYr = 12082,
  VFNMSUB132PSZ128m = 12083,
  VFNMSUB132PSZ128mb = 12084,
  VFNMSUB132PSZ128mbk = 12085,
  VFNMSUB132PSZ128mbkz = 12086,
  VFNMSUB132PSZ128mk = 12087,
  VFNMSUB132PSZ128mkz = 12088,
  VFNMSUB132PSZ128r = 12089,
  VFNMSUB132PSZ128rk = 12090,
  VFNMSUB132PSZ128rkz = 12091,
  VFNMSUB132PSZ256m = 12092,
  VFNMSUB132PSZ256mb = 12093,
  VFNMSUB132PSZ256mbk = 12094,
  VFNMSUB132PSZ256mbkz = 12095,
  VFNMSUB132PSZ256mk = 12096,
  VFNMSUB132PSZ256mkz = 12097,
  VFNMSUB132PSZ256r = 12098,
  VFNMSUB132PSZ256rb = 12099,
  VFNMSUB132PSZ256rbk = 12100,
  VFNMSUB132PSZ256rbkz = 12101,
  VFNMSUB132PSZ256rk = 12102,
  VFNMSUB132PSZ256rkz = 12103,
  VFNMSUB132PSZm = 12104,
  VFNMSUB132PSZmb = 12105,
  VFNMSUB132PSZmbk = 12106,
  VFNMSUB132PSZmbkz = 12107,
  VFNMSUB132PSZmk = 12108,
  VFNMSUB132PSZmkz = 12109,
  VFNMSUB132PSZr = 12110,
  VFNMSUB132PSZrb = 12111,
  VFNMSUB132PSZrbk = 12112,
  VFNMSUB132PSZrbkz = 12113,
  VFNMSUB132PSZrk = 12114,
  VFNMSUB132PSZrkz = 12115,
  VFNMSUB132PSm = 12116,
  VFNMSUB132PSr = 12117,
  VFNMSUB132SDZm = 12118,
  VFNMSUB132SDZm_Int = 12119,
  VFNMSUB132SDZmk_Int = 12120,
  VFNMSUB132SDZmkz_Int = 12121,
  VFNMSUB132SDZr = 12122,
  VFNMSUB132SDZr_Int = 12123,
  VFNMSUB132SDZrb = 12124,
  VFNMSUB132SDZrb_Int = 12125,
  VFNMSUB132SDZrbk_Int = 12126,
  VFNMSUB132SDZrbkz_Int = 12127,
  VFNMSUB132SDZrk_Int = 12128,
  VFNMSUB132SDZrkz_Int = 12129,
  VFNMSUB132SDm = 12130,
  VFNMSUB132SDm_Int = 12131,
  VFNMSUB132SDr = 12132,
  VFNMSUB132SDr_Int = 12133,
  VFNMSUB132SHZm = 12134,
  VFNMSUB132SHZm_Int = 12135,
  VFNMSUB132SHZmk_Int = 12136,
  VFNMSUB132SHZmkz_Int = 12137,
  VFNMSUB132SHZr = 12138,
  VFNMSUB132SHZr_Int = 12139,
  VFNMSUB132SHZrb = 12140,
  VFNMSUB132SHZrb_Int = 12141,
  VFNMSUB132SHZrbk_Int = 12142,
  VFNMSUB132SHZrbkz_Int = 12143,
  VFNMSUB132SHZrk_Int = 12144,
  VFNMSUB132SHZrkz_Int = 12145,
  VFNMSUB132SSZm = 12146,
  VFNMSUB132SSZm_Int = 12147,
  VFNMSUB132SSZmk_Int = 12148,
  VFNMSUB132SSZmkz_Int = 12149,
  VFNMSUB132SSZr = 12150,
  VFNMSUB132SSZr_Int = 12151,
  VFNMSUB132SSZrb = 12152,
  VFNMSUB132SSZrb_Int = 12153,
  VFNMSUB132SSZrbk_Int = 12154,
  VFNMSUB132SSZrbkz_Int = 12155,
  VFNMSUB132SSZrk_Int = 12156,
  VFNMSUB132SSZrkz_Int = 12157,
  VFNMSUB132SSm = 12158,
  VFNMSUB132SSm_Int = 12159,
  VFNMSUB132SSr = 12160,
  VFNMSUB132SSr_Int = 12161,
  VFNMSUB213BF16Z128m = 12162,
  VFNMSUB213BF16Z128mb = 12163,
  VFNMSUB213BF16Z128mbk = 12164,
  VFNMSUB213BF16Z128mbkz = 12165,
  VFNMSUB213BF16Z128mk = 12166,
  VFNMSUB213BF16Z128mkz = 12167,
  VFNMSUB213BF16Z128r = 12168,
  VFNMSUB213BF16Z128rk = 12169,
  VFNMSUB213BF16Z128rkz = 12170,
  VFNMSUB213BF16Z256m = 12171,
  VFNMSUB213BF16Z256mb = 12172,
  VFNMSUB213BF16Z256mbk = 12173,
  VFNMSUB213BF16Z256mbkz = 12174,
  VFNMSUB213BF16Z256mk = 12175,
  VFNMSUB213BF16Z256mkz = 12176,
  VFNMSUB213BF16Z256r = 12177,
  VFNMSUB213BF16Z256rk = 12178,
  VFNMSUB213BF16Z256rkz = 12179,
  VFNMSUB213BF16Zm = 12180,
  VFNMSUB213BF16Zmb = 12181,
  VFNMSUB213BF16Zmbk = 12182,
  VFNMSUB213BF16Zmbkz = 12183,
  VFNMSUB213BF16Zmk = 12184,
  VFNMSUB213BF16Zmkz = 12185,
  VFNMSUB213BF16Zr = 12186,
  VFNMSUB213BF16Zrk = 12187,
  VFNMSUB213BF16Zrkz = 12188,
  VFNMSUB213PDYm = 12189,
  VFNMSUB213PDYr = 12190,
  VFNMSUB213PDZ128m = 12191,
  VFNMSUB213PDZ128mb = 12192,
  VFNMSUB213PDZ128mbk = 12193,
  VFNMSUB213PDZ128mbkz = 12194,
  VFNMSUB213PDZ128mk = 12195,
  VFNMSUB213PDZ128mkz = 12196,
  VFNMSUB213PDZ128r = 12197,
  VFNMSUB213PDZ128rk = 12198,
  VFNMSUB213PDZ128rkz = 12199,
  VFNMSUB213PDZ256m = 12200,
  VFNMSUB213PDZ256mb = 12201,
  VFNMSUB213PDZ256mbk = 12202,
  VFNMSUB213PDZ256mbkz = 12203,
  VFNMSUB213PDZ256mk = 12204,
  VFNMSUB213PDZ256mkz = 12205,
  VFNMSUB213PDZ256r = 12206,
  VFNMSUB213PDZ256rb = 12207,
  VFNMSUB213PDZ256rbk = 12208,
  VFNMSUB213PDZ256rbkz = 12209,
  VFNMSUB213PDZ256rk = 12210,
  VFNMSUB213PDZ256rkz = 12211,
  VFNMSUB213PDZm = 12212,
  VFNMSUB213PDZmb = 12213,
  VFNMSUB213PDZmbk = 12214,
  VFNMSUB213PDZmbkz = 12215,
  VFNMSUB213PDZmk = 12216,
  VFNMSUB213PDZmkz = 12217,
  VFNMSUB213PDZr = 12218,
  VFNMSUB213PDZrb = 12219,
  VFNMSUB213PDZrbk = 12220,
  VFNMSUB213PDZrbkz = 12221,
  VFNMSUB213PDZrk = 12222,
  VFNMSUB213PDZrkz = 12223,
  VFNMSUB213PDm = 12224,
  VFNMSUB213PDr = 12225,
  VFNMSUB213PHZ128m = 12226,
  VFNMSUB213PHZ128mb = 12227,
  VFNMSUB213PHZ128mbk = 12228,
  VFNMSUB213PHZ128mbkz = 12229,
  VFNMSUB213PHZ128mk = 12230,
  VFNMSUB213PHZ128mkz = 12231,
  VFNMSUB213PHZ128r = 12232,
  VFNMSUB213PHZ128rk = 12233,
  VFNMSUB213PHZ128rkz = 12234,
  VFNMSUB213PHZ256m = 12235,
  VFNMSUB213PHZ256mb = 12236,
  VFNMSUB213PHZ256mbk = 12237,
  VFNMSUB213PHZ256mbkz = 12238,
  VFNMSUB213PHZ256mk = 12239,
  VFNMSUB213PHZ256mkz = 12240,
  VFNMSUB213PHZ256r = 12241,
  VFNMSUB213PHZ256rb = 12242,
  VFNMSUB213PHZ256rbk = 12243,
  VFNMSUB213PHZ256rbkz = 12244,
  VFNMSUB213PHZ256rk = 12245,
  VFNMSUB213PHZ256rkz = 12246,
  VFNMSUB213PHZm = 12247,
  VFNMSUB213PHZmb = 12248,
  VFNMSUB213PHZmbk = 12249,
  VFNMSUB213PHZmbkz = 12250,
  VFNMSUB213PHZmk = 12251,
  VFNMSUB213PHZmkz = 12252,
  VFNMSUB213PHZr = 12253,
  VFNMSUB213PHZrb = 12254,
  VFNMSUB213PHZrbk = 12255,
  VFNMSUB213PHZrbkz = 12256,
  VFNMSUB213PHZrk = 12257,
  VFNMSUB213PHZrkz = 12258,
  VFNMSUB213PSYm = 12259,
  VFNMSUB213PSYr = 12260,
  VFNMSUB213PSZ128m = 12261,
  VFNMSUB213PSZ128mb = 12262,
  VFNMSUB213PSZ128mbk = 12263,
  VFNMSUB213PSZ128mbkz = 12264,
  VFNMSUB213PSZ128mk = 12265,
  VFNMSUB213PSZ128mkz = 12266,
  VFNMSUB213PSZ128r = 12267,
  VFNMSUB213PSZ128rk = 12268,
  VFNMSUB213PSZ128rkz = 12269,
  VFNMSUB213PSZ256m = 12270,
  VFNMSUB213PSZ256mb = 12271,
  VFNMSUB213PSZ256mbk = 12272,
  VFNMSUB213PSZ256mbkz = 12273,
  VFNMSUB213PSZ256mk = 12274,
  VFNMSUB213PSZ256mkz = 12275,
  VFNMSUB213PSZ256r = 12276,
  VFNMSUB213PSZ256rb = 12277,
  VFNMSUB213PSZ256rbk = 12278,
  VFNMSUB213PSZ256rbkz = 12279,
  VFNMSUB213PSZ256rk = 12280,
  VFNMSUB213PSZ256rkz = 12281,
  VFNMSUB213PSZm = 12282,
  VFNMSUB213PSZmb = 12283,
  VFNMSUB213PSZmbk = 12284,
  VFNMSUB213PSZmbkz = 12285,
  VFNMSUB213PSZmk = 12286,
  VFNMSUB213PSZmkz = 12287,
  VFNMSUB213PSZr = 12288,
  VFNMSUB213PSZrb = 12289,
  VFNMSUB213PSZrbk = 12290,
  VFNMSUB213PSZrbkz = 12291,
  VFNMSUB213PSZrk = 12292,
  VFNMSUB213PSZrkz = 12293,
  VFNMSUB213PSm = 12294,
  VFNMSUB213PSr = 12295,
  VFNMSUB213SDZm = 12296,
  VFNMSUB213SDZm_Int = 12297,
  VFNMSUB213SDZmk_Int = 12298,
  VFNMSUB213SDZmkz_Int = 12299,
  VFNMSUB213SDZr = 12300,
  VFNMSUB213SDZr_Int = 12301,
  VFNMSUB213SDZrb = 12302,
  VFNMSUB213SDZrb_Int = 12303,
  VFNMSUB213SDZrbk_Int = 12304,
  VFNMSUB213SDZrbkz_Int = 12305,
  VFNMSUB213SDZrk_Int = 12306,
  VFNMSUB213SDZrkz_Int = 12307,
  VFNMSUB213SDm = 12308,
  VFNMSUB213SDm_Int = 12309,
  VFNMSUB213SDr = 12310,
  VFNMSUB213SDr_Int = 12311,
  VFNMSUB213SHZm = 12312,
  VFNMSUB213SHZm_Int = 12313,
  VFNMSUB213SHZmk_Int = 12314,
  VFNMSUB213SHZmkz_Int = 12315,
  VFNMSUB213SHZr = 12316,
  VFNMSUB213SHZr_Int = 12317,
  VFNMSUB213SHZrb = 12318,
  VFNMSUB213SHZrb_Int = 12319,
  VFNMSUB213SHZrbk_Int = 12320,
  VFNMSUB213SHZrbkz_Int = 12321,
  VFNMSUB213SHZrk_Int = 12322,
  VFNMSUB213SHZrkz_Int = 12323,
  VFNMSUB213SSZm = 12324,
  VFNMSUB213SSZm_Int = 12325,
  VFNMSUB213SSZmk_Int = 12326,
  VFNMSUB213SSZmkz_Int = 12327,
  VFNMSUB213SSZr = 12328,
  VFNMSUB213SSZr_Int = 12329,
  VFNMSUB213SSZrb = 12330,
  VFNMSUB213SSZrb_Int = 12331,
  VFNMSUB213SSZrbk_Int = 12332,
  VFNMSUB213SSZrbkz_Int = 12333,
  VFNMSUB213SSZrk_Int = 12334,
  VFNMSUB213SSZrkz_Int = 12335,
  VFNMSUB213SSm = 12336,
  VFNMSUB213SSm_Int = 12337,
  VFNMSUB213SSr = 12338,
  VFNMSUB213SSr_Int = 12339,
  VFNMSUB231BF16Z128m = 12340,
  VFNMSUB231BF16Z128mb = 12341,
  VFNMSUB231BF16Z128mbk = 12342,
  VFNMSUB231BF16Z128mbkz = 12343,
  VFNMSUB231BF16Z128mk = 12344,
  VFNMSUB231BF16Z128mkz = 12345,
  VFNMSUB231BF16Z128r = 12346,
  VFNMSUB231BF16Z128rk = 12347,
  VFNMSUB231BF16Z128rkz = 12348,
  VFNMSUB231BF16Z256m = 12349,
  VFNMSUB231BF16Z256mb = 12350,
  VFNMSUB231BF16Z256mbk = 12351,
  VFNMSUB231BF16Z256mbkz = 12352,
  VFNMSUB231BF16Z256mk = 12353,
  VFNMSUB231BF16Z256mkz = 12354,
  VFNMSUB231BF16Z256r = 12355,
  VFNMSUB231BF16Z256rk = 12356,
  VFNMSUB231BF16Z256rkz = 12357,
  VFNMSUB231BF16Zm = 12358,
  VFNMSUB231BF16Zmb = 12359,
  VFNMSUB231BF16Zmbk = 12360,
  VFNMSUB231BF16Zmbkz = 12361,
  VFNMSUB231BF16Zmk = 12362,
  VFNMSUB231BF16Zmkz = 12363,
  VFNMSUB231BF16Zr = 12364,
  VFNMSUB231BF16Zrk = 12365,
  VFNMSUB231BF16Zrkz = 12366,
  VFNMSUB231PDYm = 12367,
  VFNMSUB231PDYr = 12368,
  VFNMSUB231PDZ128m = 12369,
  VFNMSUB231PDZ128mb = 12370,
  VFNMSUB231PDZ128mbk = 12371,
  VFNMSUB231PDZ128mbkz = 12372,
  VFNMSUB231PDZ128mk = 12373,
  VFNMSUB231PDZ128mkz = 12374,
  VFNMSUB231PDZ128r = 12375,
  VFNMSUB231PDZ128rk = 12376,
  VFNMSUB231PDZ128rkz = 12377,
  VFNMSUB231PDZ256m = 12378,
  VFNMSUB231PDZ256mb = 12379,
  VFNMSUB231PDZ256mbk = 12380,
  VFNMSUB231PDZ256mbkz = 12381,
  VFNMSUB231PDZ256mk = 12382,
  VFNMSUB231PDZ256mkz = 12383,
  VFNMSUB231PDZ256r = 12384,
  VFNMSUB231PDZ256rb = 12385,
  VFNMSUB231PDZ256rbk = 12386,
  VFNMSUB231PDZ256rbkz = 12387,
  VFNMSUB231PDZ256rk = 12388,
  VFNMSUB231PDZ256rkz = 12389,
  VFNMSUB231PDZm = 12390,
  VFNMSUB231PDZmb = 12391,
  VFNMSUB231PDZmbk = 12392,
  VFNMSUB231PDZmbkz = 12393,
  VFNMSUB231PDZmk = 12394,
  VFNMSUB231PDZmkz = 12395,
  VFNMSUB231PDZr = 12396,
  VFNMSUB231PDZrb = 12397,
  VFNMSUB231PDZrbk = 12398,
  VFNMSUB231PDZrbkz = 12399,
  VFNMSUB231PDZrk = 12400,
  VFNMSUB231PDZrkz = 12401,
  VFNMSUB231PDm = 12402,
  VFNMSUB231PDr = 12403,
  VFNMSUB231PHZ128m = 12404,
  VFNMSUB231PHZ128mb = 12405,
  VFNMSUB231PHZ128mbk = 12406,
  VFNMSUB231PHZ128mbkz = 12407,
  VFNMSUB231PHZ128mk = 12408,
  VFNMSUB231PHZ128mkz = 12409,
  VFNMSUB231PHZ128r = 12410,
  VFNMSUB231PHZ128rk = 12411,
  VFNMSUB231PHZ128rkz = 12412,
  VFNMSUB231PHZ256m = 12413,
  VFNMSUB231PHZ256mb = 12414,
  VFNMSUB231PHZ256mbk = 12415,
  VFNMSUB231PHZ256mbkz = 12416,
  VFNMSUB231PHZ256mk = 12417,
  VFNMSUB231PHZ256mkz = 12418,
  VFNMSUB231PHZ256r = 12419,
  VFNMSUB231PHZ256rb = 12420,
  VFNMSUB231PHZ256rbk = 12421,
  VFNMSUB231PHZ256rbkz = 12422,
  VFNMSUB231PHZ256rk = 12423,
  VFNMSUB231PHZ256rkz = 12424,
  VFNMSUB231PHZm = 12425,
  VFNMSUB231PHZmb = 12426,
  VFNMSUB231PHZmbk = 12427,
  VFNMSUB231PHZmbkz = 12428,
  VFNMSUB231PHZmk = 12429,
  VFNMSUB231PHZmkz = 12430,
  VFNMSUB231PHZr = 12431,
  VFNMSUB231PHZrb = 12432,
  VFNMSUB231PHZrbk = 12433,
  VFNMSUB231PHZrbkz = 12434,
  VFNMSUB231PHZrk = 12435,
  VFNMSUB231PHZrkz = 12436,
  VFNMSUB231PSYm = 12437,
  VFNMSUB231PSYr = 12438,
  VFNMSUB231PSZ128m = 12439,
  VFNMSUB231PSZ128mb = 12440,
  VFNMSUB231PSZ128mbk = 12441,
  VFNMSUB231PSZ128mbkz = 12442,
  VFNMSUB231PSZ128mk = 12443,
  VFNMSUB231PSZ128mkz = 12444,
  VFNMSUB231PSZ128r = 12445,
  VFNMSUB231PSZ128rk = 12446,
  VFNMSUB231PSZ128rkz = 12447,
  VFNMSUB231PSZ256m = 12448,
  VFNMSUB231PSZ256mb = 12449,
  VFNMSUB231PSZ256mbk = 12450,
  VFNMSUB231PSZ256mbkz = 12451,
  VFNMSUB231PSZ256mk = 12452,
  VFNMSUB231PSZ256mkz = 12453,
  VFNMSUB231PSZ256r = 12454,
  VFNMSUB231PSZ256rb = 12455,
  VFNMSUB231PSZ256rbk = 12456,
  VFNMSUB231PSZ256rbkz = 12457,
  VFNMSUB231PSZ256rk = 12458,
  VFNMSUB231PSZ256rkz = 12459,
  VFNMSUB231PSZm = 12460,
  VFNMSUB231PSZmb = 12461,
  VFNMSUB231PSZmbk = 12462,
  VFNMSUB231PSZmbkz = 12463,
  VFNMSUB231PSZmk = 12464,
  VFNMSUB231PSZmkz = 12465,
  VFNMSUB231PSZr = 12466,
  VFNMSUB231PSZrb = 12467,
  VFNMSUB231PSZrbk = 12468,
  VFNMSUB231PSZrbkz = 12469,
  VFNMSUB231PSZrk = 12470,
  VFNMSUB231PSZrkz = 12471,
  VFNMSUB231PSm = 12472,
  VFNMSUB231PSr = 12473,
  VFNMSUB231SDZm = 12474,
  VFNMSUB231SDZm_Int = 12475,
  VFNMSUB231SDZmk_Int = 12476,
  VFNMSUB231SDZmkz_Int = 12477,
  VFNMSUB231SDZr = 12478,
  VFNMSUB231SDZr_Int = 12479,
  VFNMSUB231SDZrb = 12480,
  VFNMSUB231SDZrb_Int = 12481,
  VFNMSUB231SDZrbk_Int = 12482,
  VFNMSUB231SDZrbkz_Int = 12483,
  VFNMSUB231SDZrk_Int = 12484,
  VFNMSUB231SDZrkz_Int = 12485,
  VFNMSUB231SDm = 12486,
  VFNMSUB231SDm_Int = 12487,
  VFNMSUB231SDr = 12488,
  VFNMSUB231SDr_Int = 12489,
  VFNMSUB231SHZm = 12490,
  VFNMSUB231SHZm_Int = 12491,
  VFNMSUB231SHZmk_Int = 12492,
  VFNMSUB231SHZmkz_Int = 12493,
  VFNMSUB231SHZr = 12494,
  VFNMSUB231SHZr_Int = 12495,
  VFNMSUB231SHZrb = 12496,
  VFNMSUB231SHZrb_Int = 12497,
  VFNMSUB231SHZrbk_Int = 12498,
  VFNMSUB231SHZrbkz_Int = 12499,
  VFNMSUB231SHZrk_Int = 12500,
  VFNMSUB231SHZrkz_Int = 12501,
  VFNMSUB231SSZm = 12502,
  VFNMSUB231SSZm_Int = 12503,
  VFNMSUB231SSZmk_Int = 12504,
  VFNMSUB231SSZmkz_Int = 12505,
  VFNMSUB231SSZr = 12506,
  VFNMSUB231SSZr_Int = 12507,
  VFNMSUB231SSZrb = 12508,
  VFNMSUB231SSZrb_Int = 12509,
  VFNMSUB231SSZrbk_Int = 12510,
  VFNMSUB231SSZrbkz_Int = 12511,
  VFNMSUB231SSZrk_Int = 12512,
  VFNMSUB231SSZrkz_Int = 12513,
  VFNMSUB231SSm = 12514,
  VFNMSUB231SSm_Int = 12515,
  VFNMSUB231SSr = 12516,
  VFNMSUB231SSr_Int = 12517,
  VFNMSUBPD4Ymr = 12518,
  VFNMSUBPD4Yrm = 12519,
  VFNMSUBPD4Yrr = 12520,
  VFNMSUBPD4Yrr_REV = 12521,
  VFNMSUBPD4mr = 12522,
  VFNMSUBPD4rm = 12523,
  VFNMSUBPD4rr = 12524,
  VFNMSUBPD4rr_REV = 12525,
  VFNMSUBPS4Ymr = 12526,
  VFNMSUBPS4Yrm = 12527,
  VFNMSUBPS4Yrr = 12528,
  VFNMSUBPS4Yrr_REV = 12529,
  VFNMSUBPS4mr = 12530,
  VFNMSUBPS4rm = 12531,
  VFNMSUBPS4rr = 12532,
  VFNMSUBPS4rr_REV = 12533,
  VFNMSUBSD4mr = 12534,
  VFNMSUBSD4mr_Int = 12535,
  VFNMSUBSD4rm = 12536,
  VFNMSUBSD4rm_Int = 12537,
  VFNMSUBSD4rr = 12538,
  VFNMSUBSD4rr_Int = 12539,
  VFNMSUBSD4rr_Int_REV = 12540,
  VFNMSUBSD4rr_REV = 12541,
  VFNMSUBSS4mr = 12542,
  VFNMSUBSS4mr_Int = 12543,
  VFNMSUBSS4rm = 12544,
  VFNMSUBSS4rm_Int = 12545,
  VFNMSUBSS4rr = 12546,
  VFNMSUBSS4rr_Int = 12547,
  VFNMSUBSS4rr_Int_REV = 12548,
  VFNMSUBSS4rr_REV = 12549,
  VFPCLASSBF16Z128mbi = 12550,
  VFPCLASSBF16Z128mbik = 12551,
  VFPCLASSBF16Z128mi = 12552,
  VFPCLASSBF16Z128mik = 12553,
  VFPCLASSBF16Z128ri = 12554,
  VFPCLASSBF16Z128rik = 12555,
  VFPCLASSBF16Z256mbi = 12556,
  VFPCLASSBF16Z256mbik = 12557,
  VFPCLASSBF16Z256mi = 12558,
  VFPCLASSBF16Z256mik = 12559,
  VFPCLASSBF16Z256ri = 12560,
  VFPCLASSBF16Z256rik = 12561,
  VFPCLASSBF16Zmbi = 12562,
  VFPCLASSBF16Zmbik = 12563,
  VFPCLASSBF16Zmi = 12564,
  VFPCLASSBF16Zmik = 12565,
  VFPCLASSBF16Zri = 12566,
  VFPCLASSBF16Zrik = 12567,
  VFPCLASSPDZ128mbi = 12568,
  VFPCLASSPDZ128mbik = 12569,
  VFPCLASSPDZ128mi = 12570,
  VFPCLASSPDZ128mik = 12571,
  VFPCLASSPDZ128ri = 12572,
  VFPCLASSPDZ128rik = 12573,
  VFPCLASSPDZ256mbi = 12574,
  VFPCLASSPDZ256mbik = 12575,
  VFPCLASSPDZ256mi = 12576,
  VFPCLASSPDZ256mik = 12577,
  VFPCLASSPDZ256ri = 12578,
  VFPCLASSPDZ256rik = 12579,
  VFPCLASSPDZmbi = 12580,
  VFPCLASSPDZmbik = 12581,
  VFPCLASSPDZmi = 12582,
  VFPCLASSPDZmik = 12583,
  VFPCLASSPDZri = 12584,
  VFPCLASSPDZrik = 12585,
  VFPCLASSPHZ128mbi = 12586,
  VFPCLASSPHZ128mbik = 12587,
  VFPCLASSPHZ128mi = 12588,
  VFPCLASSPHZ128mik = 12589,
  VFPCLASSPHZ128ri = 12590,
  VFPCLASSPHZ128rik = 12591,
  VFPCLASSPHZ256mbi = 12592,
  VFPCLASSPHZ256mbik = 12593,
  VFPCLASSPHZ256mi = 12594,
  VFPCLASSPHZ256mik = 12595,
  VFPCLASSPHZ256ri = 12596,
  VFPCLASSPHZ256rik = 12597,
  VFPCLASSPHZmbi = 12598,
  VFPCLASSPHZmbik = 12599,
  VFPCLASSPHZmi = 12600,
  VFPCLASSPHZmik = 12601,
  VFPCLASSPHZri = 12602,
  VFPCLASSPHZrik = 12603,
  VFPCLASSPSZ128mbi = 12604,
  VFPCLASSPSZ128mbik = 12605,
  VFPCLASSPSZ128mi = 12606,
  VFPCLASSPSZ128mik = 12607,
  VFPCLASSPSZ128ri = 12608,
  VFPCLASSPSZ128rik = 12609,
  VFPCLASSPSZ256mbi = 12610,
  VFPCLASSPSZ256mbik = 12611,
  VFPCLASSPSZ256mi = 12612,
  VFPCLASSPSZ256mik = 12613,
  VFPCLASSPSZ256ri = 12614,
  VFPCLASSPSZ256rik = 12615,
  VFPCLASSPSZmbi = 12616,
  VFPCLASSPSZmbik = 12617,
  VFPCLASSPSZmi = 12618,
  VFPCLASSPSZmik = 12619,
  VFPCLASSPSZri = 12620,
  VFPCLASSPSZrik = 12621,
  VFPCLASSSDZmi = 12622,
  VFPCLASSSDZmik = 12623,
  VFPCLASSSDZri = 12624,
  VFPCLASSSDZrik = 12625,
  VFPCLASSSHZmi = 12626,
  VFPCLASSSHZmik = 12627,
  VFPCLASSSHZri = 12628,
  VFPCLASSSHZrik = 12629,
  VFPCLASSSSZmi = 12630,
  VFPCLASSSSZmik = 12631,
  VFPCLASSSSZri = 12632,
  VFPCLASSSSZrik = 12633,
  VFRCZPDYrm = 12634,
  VFRCZPDYrr = 12635,
  VFRCZPDrm = 12636,
  VFRCZPDrr = 12637,
  VFRCZPSYrm = 12638,
  VFRCZPSYrr = 12639,
  VFRCZPSrm = 12640,
  VFRCZPSrr = 12641,
  VFRCZSDrm = 12642,
  VFRCZSDrr = 12643,
  VFRCZSSrm = 12644,
  VFRCZSSrr = 12645,
  VGATHERDPDYrm = 12646,
  VGATHERDPDZ128rm = 12647,
  VGATHERDPDZ256rm = 12648,
  VGATHERDPDZrm = 12649,
  VGATHERDPDrm = 12650,
  VGATHERDPSYrm = 12651,
  VGATHERDPSZ128rm = 12652,
  VGATHERDPSZ256rm = 12653,
  VGATHERDPSZrm = 12654,
  VGATHERDPSrm = 12655,
  VGATHERPF0DPDm = 12656,
  VGATHERPF0DPSm = 12657,
  VGATHERPF0QPDm = 12658,
  VGATHERPF0QPSm = 12659,
  VGATHERPF1DPDm = 12660,
  VGATHERPF1DPSm = 12661,
  VGATHERPF1QPDm = 12662,
  VGATHERPF1QPSm = 12663,
  VGATHERQPDYrm = 12664,
  VGATHERQPDZ128rm = 12665,
  VGATHERQPDZ256rm = 12666,
  VGATHERQPDZrm = 12667,
  VGATHERQPDrm = 12668,
  VGATHERQPSYrm = 12669,
  VGATHERQPSZ128rm = 12670,
  VGATHERQPSZ256rm = 12671,
  VGATHERQPSZrm = 12672,
  VGATHERQPSrm = 12673,
  VGETEXPBF16Z128m = 12674,
  VGETEXPBF16Z128mb = 12675,
  VGETEXPBF16Z128mbk = 12676,
  VGETEXPBF16Z128mbkz = 12677,
  VGETEXPBF16Z128mk = 12678,
  VGETEXPBF16Z128mkz = 12679,
  VGETEXPBF16Z128r = 12680,
  VGETEXPBF16Z128rk = 12681,
  VGETEXPBF16Z128rkz = 12682,
  VGETEXPBF16Z256m = 12683,
  VGETEXPBF16Z256mb = 12684,
  VGETEXPBF16Z256mbk = 12685,
  VGETEXPBF16Z256mbkz = 12686,
  VGETEXPBF16Z256mk = 12687,
  VGETEXPBF16Z256mkz = 12688,
  VGETEXPBF16Z256r = 12689,
  VGETEXPBF16Z256rk = 12690,
  VGETEXPBF16Z256rkz = 12691,
  VGETEXPBF16Zm = 12692,
  VGETEXPBF16Zmb = 12693,
  VGETEXPBF16Zmbk = 12694,
  VGETEXPBF16Zmbkz = 12695,
  VGETEXPBF16Zmk = 12696,
  VGETEXPBF16Zmkz = 12697,
  VGETEXPBF16Zr = 12698,
  VGETEXPBF16Zrk = 12699,
  VGETEXPBF16Zrkz = 12700,
  VGETEXPPDZ128m = 12701,
  VGETEXPPDZ128mb = 12702,
  VGETEXPPDZ128mbk = 12703,
  VGETEXPPDZ128mbkz = 12704,
  VGETEXPPDZ128mk = 12705,
  VGETEXPPDZ128mkz = 12706,
  VGETEXPPDZ128r = 12707,
  VGETEXPPDZ128rk = 12708,
  VGETEXPPDZ128rkz = 12709,
  VGETEXPPDZ256m = 12710,
  VGETEXPPDZ256mb = 12711,
  VGETEXPPDZ256mbk = 12712,
  VGETEXPPDZ256mbkz = 12713,
  VGETEXPPDZ256mk = 12714,
  VGETEXPPDZ256mkz = 12715,
  VGETEXPPDZ256r = 12716,
  VGETEXPPDZ256rb = 12717,
  VGETEXPPDZ256rbk = 12718,
  VGETEXPPDZ256rbkz = 12719,
  VGETEXPPDZ256rk = 12720,
  VGETEXPPDZ256rkz = 12721,
  VGETEXPPDZm = 12722,
  VGETEXPPDZmb = 12723,
  VGETEXPPDZmbk = 12724,
  VGETEXPPDZmbkz = 12725,
  VGETEXPPDZmk = 12726,
  VGETEXPPDZmkz = 12727,
  VGETEXPPDZr = 12728,
  VGETEXPPDZrb = 12729,
  VGETEXPPDZrbk = 12730,
  VGETEXPPDZrbkz = 12731,
  VGETEXPPDZrk = 12732,
  VGETEXPPDZrkz = 12733,
  VGETEXPPHZ128m = 12734,
  VGETEXPPHZ128mb = 12735,
  VGETEXPPHZ128mbk = 12736,
  VGETEXPPHZ128mbkz = 12737,
  VGETEXPPHZ128mk = 12738,
  VGETEXPPHZ128mkz = 12739,
  VGETEXPPHZ128r = 12740,
  VGETEXPPHZ128rk = 12741,
  VGETEXPPHZ128rkz = 12742,
  VGETEXPPHZ256m = 12743,
  VGETEXPPHZ256mb = 12744,
  VGETEXPPHZ256mbk = 12745,
  VGETEXPPHZ256mbkz = 12746,
  VGETEXPPHZ256mk = 12747,
  VGETEXPPHZ256mkz = 12748,
  VGETEXPPHZ256r = 12749,
  VGETEXPPHZ256rb = 12750,
  VGETEXPPHZ256rbk = 12751,
  VGETEXPPHZ256rbkz = 12752,
  VGETEXPPHZ256rk = 12753,
  VGETEXPPHZ256rkz = 12754,
  VGETEXPPHZm = 12755,
  VGETEXPPHZmb = 12756,
  VGETEXPPHZmbk = 12757,
  VGETEXPPHZmbkz = 12758,
  VGETEXPPHZmk = 12759,
  VGETEXPPHZmkz = 12760,
  VGETEXPPHZr = 12761,
  VGETEXPPHZrb = 12762,
  VGETEXPPHZrbk = 12763,
  VGETEXPPHZrbkz = 12764,
  VGETEXPPHZrk = 12765,
  VGETEXPPHZrkz = 12766,
  VGETEXPPSZ128m = 12767,
  VGETEXPPSZ128mb = 12768,
  VGETEXPPSZ128mbk = 12769,
  VGETEXPPSZ128mbkz = 12770,
  VGETEXPPSZ128mk = 12771,
  VGETEXPPSZ128mkz = 12772,
  VGETEXPPSZ128r = 12773,
  VGETEXPPSZ128rk = 12774,
  VGETEXPPSZ128rkz = 12775,
  VGETEXPPSZ256m = 12776,
  VGETEXPPSZ256mb = 12777,
  VGETEXPPSZ256mbk = 12778,
  VGETEXPPSZ256mbkz = 12779,
  VGETEXPPSZ256mk = 12780,
  VGETEXPPSZ256mkz = 12781,
  VGETEXPPSZ256r = 12782,
  VGETEXPPSZ256rb = 12783,
  VGETEXPPSZ256rbk = 12784,
  VGETEXPPSZ256rbkz = 12785,
  VGETEXPPSZ256rk = 12786,
  VGETEXPPSZ256rkz = 12787,
  VGETEXPPSZm = 12788,
  VGETEXPPSZmb = 12789,
  VGETEXPPSZmbk = 12790,
  VGETEXPPSZmbkz = 12791,
  VGETEXPPSZmk = 12792,
  VGETEXPPSZmkz = 12793,
  VGETEXPPSZr = 12794,
  VGETEXPPSZrb = 12795,
  VGETEXPPSZrbk = 12796,
  VGETEXPPSZrbkz = 12797,
  VGETEXPPSZrk = 12798,
  VGETEXPPSZrkz = 12799,
  VGETEXPSDZm = 12800,
  VGETEXPSDZmk = 12801,
  VGETEXPSDZmkz = 12802,
  VGETEXPSDZr = 12803,
  VGETEXPSDZrb = 12804,
  VGETEXPSDZrbk = 12805,
  VGETEXPSDZrbkz = 12806,
  VGETEXPSDZrk = 12807,
  VGETEXPSDZrkz = 12808,
  VGETEXPSHZm = 12809,
  VGETEXPSHZmk = 12810,
  VGETEXPSHZmkz = 12811,
  VGETEXPSHZr = 12812,
  VGETEXPSHZrb = 12813,
  VGETEXPSHZrbk = 12814,
  VGETEXPSHZrbkz = 12815,
  VGETEXPSHZrk = 12816,
  VGETEXPSHZrkz = 12817,
  VGETEXPSSZm = 12818,
  VGETEXPSSZmk = 12819,
  VGETEXPSSZmkz = 12820,
  VGETEXPSSZr = 12821,
  VGETEXPSSZrb = 12822,
  VGETEXPSSZrbk = 12823,
  VGETEXPSSZrbkz = 12824,
  VGETEXPSSZrk = 12825,
  VGETEXPSSZrkz = 12826,
  VGETMANTBF16Z128rmbi = 12827,
  VGETMANTBF16Z128rmbik = 12828,
  VGETMANTBF16Z128rmbikz = 12829,
  VGETMANTBF16Z128rmi = 12830,
  VGETMANTBF16Z128rmik = 12831,
  VGETMANTBF16Z128rmikz = 12832,
  VGETMANTBF16Z128rri = 12833,
  VGETMANTBF16Z128rrik = 12834,
  VGETMANTBF16Z128rrikz = 12835,
  VGETMANTBF16Z256rmbi = 12836,
  VGETMANTBF16Z256rmbik = 12837,
  VGETMANTBF16Z256rmbikz = 12838,
  VGETMANTBF16Z256rmi = 12839,
  VGETMANTBF16Z256rmik = 12840,
  VGETMANTBF16Z256rmikz = 12841,
  VGETMANTBF16Z256rri = 12842,
  VGETMANTBF16Z256rrik = 12843,
  VGETMANTBF16Z256rrikz = 12844,
  VGETMANTBF16Zrmbi = 12845,
  VGETMANTBF16Zrmbik = 12846,
  VGETMANTBF16Zrmbikz = 12847,
  VGETMANTBF16Zrmi = 12848,
  VGETMANTBF16Zrmik = 12849,
  VGETMANTBF16Zrmikz = 12850,
  VGETMANTBF16Zrri = 12851,
  VGETMANTBF16Zrrik = 12852,
  VGETMANTBF16Zrrikz = 12853,
  VGETMANTPDZ128rmbi = 12854,
  VGETMANTPDZ128rmbik = 12855,
  VGETMANTPDZ128rmbikz = 12856,
  VGETMANTPDZ128rmi = 12857,
  VGETMANTPDZ128rmik = 12858,
  VGETMANTPDZ128rmikz = 12859,
  VGETMANTPDZ128rri = 12860,
  VGETMANTPDZ128rrik = 12861,
  VGETMANTPDZ128rrikz = 12862,
  VGETMANTPDZ256rmbi = 12863,
  VGETMANTPDZ256rmbik = 12864,
  VGETMANTPDZ256rmbikz = 12865,
  VGETMANTPDZ256rmi = 12866,
  VGETMANTPDZ256rmik = 12867,
  VGETMANTPDZ256rmikz = 12868,
  VGETMANTPDZ256rri = 12869,
  VGETMANTPDZ256rrib = 12870,
  VGETMANTPDZ256rribk = 12871,
  VGETMANTPDZ256rribkz = 12872,
  VGETMANTPDZ256rrik = 12873,
  VGETMANTPDZ256rrikz = 12874,
  VGETMANTPDZrmbi = 12875,
  VGETMANTPDZrmbik = 12876,
  VGETMANTPDZrmbikz = 12877,
  VGETMANTPDZrmi = 12878,
  VGETMANTPDZrmik = 12879,
  VGETMANTPDZrmikz = 12880,
  VGETMANTPDZrri = 12881,
  VGETMANTPDZrrib = 12882,
  VGETMANTPDZrribk = 12883,
  VGETMANTPDZrribkz = 12884,
  VGETMANTPDZrrik = 12885,
  VGETMANTPDZrrikz = 12886,
  VGETMANTPHZ128rmbi = 12887,
  VGETMANTPHZ128rmbik = 12888,
  VGETMANTPHZ128rmbikz = 12889,
  VGETMANTPHZ128rmi = 12890,
  VGETMANTPHZ128rmik = 12891,
  VGETMANTPHZ128rmikz = 12892,
  VGETMANTPHZ128rri = 12893,
  VGETMANTPHZ128rrik = 12894,
  VGETMANTPHZ128rrikz = 12895,
  VGETMANTPHZ256rmbi = 12896,
  VGETMANTPHZ256rmbik = 12897,
  VGETMANTPHZ256rmbikz = 12898,
  VGETMANTPHZ256rmi = 12899,
  VGETMANTPHZ256rmik = 12900,
  VGETMANTPHZ256rmikz = 12901,
  VGETMANTPHZ256rri = 12902,
  VGETMANTPHZ256rrib = 12903,
  VGETMANTPHZ256rribk = 12904,
  VGETMANTPHZ256rribkz = 12905,
  VGETMANTPHZ256rrik = 12906,
  VGETMANTPHZ256rrikz = 12907,
  VGETMANTPHZrmbi = 12908,
  VGETMANTPHZrmbik = 12909,
  VGETMANTPHZrmbikz = 12910,
  VGETMANTPHZrmi = 12911,
  VGETMANTPHZrmik = 12912,
  VGETMANTPHZrmikz = 12913,
  VGETMANTPHZrri = 12914,
  VGETMANTPHZrrib = 12915,
  VGETMANTPHZrribk = 12916,
  VGETMANTPHZrribkz = 12917,
  VGETMANTPHZrrik = 12918,
  VGETMANTPHZrrikz = 12919,
  VGETMANTPSZ128rmbi = 12920,
  VGETMANTPSZ128rmbik = 12921,
  VGETMANTPSZ128rmbikz = 12922,
  VGETMANTPSZ128rmi = 12923,
  VGETMANTPSZ128rmik = 12924,
  VGETMANTPSZ128rmikz = 12925,
  VGETMANTPSZ128rri = 12926,
  VGETMANTPSZ128rrik = 12927,
  VGETMANTPSZ128rrikz = 12928,
  VGETMANTPSZ256rmbi = 12929,
  VGETMANTPSZ256rmbik = 12930,
  VGETMANTPSZ256rmbikz = 12931,
  VGETMANTPSZ256rmi = 12932,
  VGETMANTPSZ256rmik = 12933,
  VGETMANTPSZ256rmikz = 12934,
  VGETMANTPSZ256rri = 12935,
  VGETMANTPSZ256rrib = 12936,
  VGETMANTPSZ256rribk = 12937,
  VGETMANTPSZ256rribkz = 12938,
  VGETMANTPSZ256rrik = 12939,
  VGETMANTPSZ256rrikz = 12940,
  VGETMANTPSZrmbi = 12941,
  VGETMANTPSZrmbik = 12942,
  VGETMANTPSZrmbikz = 12943,
  VGETMANTPSZrmi = 12944,
  VGETMANTPSZrmik = 12945,
  VGETMANTPSZrmikz = 12946,
  VGETMANTPSZrri = 12947,
  VGETMANTPSZrrib = 12948,
  VGETMANTPSZrribk = 12949,
  VGETMANTPSZrribkz = 12950,
  VGETMANTPSZrrik = 12951,
  VGETMANTPSZrrikz = 12952,
  VGETMANTSDZrmi = 12953,
  VGETMANTSDZrmik = 12954,
  VGETMANTSDZrmikz = 12955,
  VGETMANTSDZrri = 12956,
  VGETMANTSDZrrib = 12957,
  VGETMANTSDZrribk = 12958,
  VGETMANTSDZrribkz = 12959,
  VGETMANTSDZrrik = 12960,
  VGETMANTSDZrrikz = 12961,
  VGETMANTSHZrmi = 12962,
  VGETMANTSHZrmik = 12963,
  VGETMANTSHZrmikz = 12964,
  VGETMANTSHZrri = 12965,
  VGETMANTSHZrrib = 12966,
  VGETMANTSHZrribk = 12967,
  VGETMANTSHZrribkz = 12968,
  VGETMANTSHZrrik = 12969,
  VGETMANTSHZrrikz = 12970,
  VGETMANTSSZrmi = 12971,
  VGETMANTSSZrmik = 12972,
  VGETMANTSSZrmikz = 12973,
  VGETMANTSSZrri = 12974,
  VGETMANTSSZrrib = 12975,
  VGETMANTSSZrribk = 12976,
  VGETMANTSSZrribkz = 12977,
  VGETMANTSSZrrik = 12978,
  VGETMANTSSZrrikz = 12979,
  VGF2P8AFFINEINVQBYrmi = 12980,
  VGF2P8AFFINEINVQBYrri = 12981,
  VGF2P8AFFINEINVQBZ128rmbi = 12982,
  VGF2P8AFFINEINVQBZ128rmbik = 12983,
  VGF2P8AFFINEINVQBZ128rmbikz = 12984,
  VGF2P8AFFINEINVQBZ128rmi = 12985,
  VGF2P8AFFINEINVQBZ128rmik = 12986,
  VGF2P8AFFINEINVQBZ128rmikz = 12987,
  VGF2P8AFFINEINVQBZ128rri = 12988,
  VGF2P8AFFINEINVQBZ128rrik = 12989,
  VGF2P8AFFINEINVQBZ128rrikz = 12990,
  VGF2P8AFFINEINVQBZ256rmbi = 12991,
  VGF2P8AFFINEINVQBZ256rmbik = 12992,
  VGF2P8AFFINEINVQBZ256rmbikz = 12993,
  VGF2P8AFFINEINVQBZ256rmi = 12994,
  VGF2P8AFFINEINVQBZ256rmik = 12995,
  VGF2P8AFFINEINVQBZ256rmikz = 12996,
  VGF2P8AFFINEINVQBZ256rri = 12997,
  VGF2P8AFFINEINVQBZ256rrik = 12998,
  VGF2P8AFFINEINVQBZ256rrikz = 12999,
  VGF2P8AFFINEINVQBZrmbi = 13000,
  VGF2P8AFFINEINVQBZrmbik = 13001,
  VGF2P8AFFINEINVQBZrmbikz = 13002,
  VGF2P8AFFINEINVQBZrmi = 13003,
  VGF2P8AFFINEINVQBZrmik = 13004,
  VGF2P8AFFINEINVQBZrmikz = 13005,
  VGF2P8AFFINEINVQBZrri = 13006,
  VGF2P8AFFINEINVQBZrrik = 13007,
  VGF2P8AFFINEINVQBZrrikz = 13008,
  VGF2P8AFFINEINVQBrmi = 13009,
  VGF2P8AFFINEINVQBrri = 13010,
  VGF2P8AFFINEQBYrmi = 13011,
  VGF2P8AFFINEQBYrri = 13012,
  VGF2P8AFFINEQBZ128rmbi = 13013,
  VGF2P8AFFINEQBZ128rmbik = 13014,
  VGF2P8AFFINEQBZ128rmbikz = 13015,
  VGF2P8AFFINEQBZ128rmi = 13016,
  VGF2P8AFFINEQBZ128rmik = 13017,
  VGF2P8AFFINEQBZ128rmikz = 13018,
  VGF2P8AFFINEQBZ128rri = 13019,
  VGF2P8AFFINEQBZ128rrik = 13020,
  VGF2P8AFFINEQBZ128rrikz = 13021,
  VGF2P8AFFINEQBZ256rmbi = 13022,
  VGF2P8AFFINEQBZ256rmbik = 13023,
  VGF2P8AFFINEQBZ256rmbikz = 13024,
  VGF2P8AFFINEQBZ256rmi = 13025,
  VGF2P8AFFINEQBZ256rmik = 13026,
  VGF2P8AFFINEQBZ256rmikz = 13027,
  VGF2P8AFFINEQBZ256rri = 13028,
  VGF2P8AFFINEQBZ256rrik = 13029,
  VGF2P8AFFINEQBZ256rrikz = 13030,
  VGF2P8AFFINEQBZrmbi = 13031,
  VGF2P8AFFINEQBZrmbik = 13032,
  VGF2P8AFFINEQBZrmbikz = 13033,
  VGF2P8AFFINEQBZrmi = 13034,
  VGF2P8AFFINEQBZrmik = 13035,
  VGF2P8AFFINEQBZrmikz = 13036,
  VGF2P8AFFINEQBZrri = 13037,
  VGF2P8AFFINEQBZrrik = 13038,
  VGF2P8AFFINEQBZrrikz = 13039,
  VGF2P8AFFINEQBrmi = 13040,
  VGF2P8AFFINEQBrri = 13041,
  VGF2P8MULBYrm = 13042,
  VGF2P8MULBYrr = 13043,
  VGF2P8MULBZ128rm = 13044,
  VGF2P8MULBZ128rmk = 13045,
  VGF2P8MULBZ128rmkz = 13046,
  VGF2P8MULBZ128rr = 13047,
  VGF2P8MULBZ128rrk = 13048,
  VGF2P8MULBZ128rrkz = 13049,
  VGF2P8MULBZ256rm = 13050,
  VGF2P8MULBZ256rmk = 13051,
  VGF2P8MULBZ256rmkz = 13052,
  VGF2P8MULBZ256rr = 13053,
  VGF2P8MULBZ256rrk = 13054,
  VGF2P8MULBZ256rrkz = 13055,
  VGF2P8MULBZrm = 13056,
  VGF2P8MULBZrmk = 13057,
  VGF2P8MULBZrmkz = 13058,
  VGF2P8MULBZrr = 13059,
  VGF2P8MULBZrrk = 13060,
  VGF2P8MULBZrrkz = 13061,
  VGF2P8MULBrm = 13062,
  VGF2P8MULBrr = 13063,
  VHADDPDYrm = 13064,
  VHADDPDYrr = 13065,
  VHADDPDrm = 13066,
  VHADDPDrr = 13067,
  VHADDPSYrm = 13068,
  VHADDPSYrr = 13069,
  VHADDPSrm = 13070,
  VHADDPSrr = 13071,
  VHSUBPDYrm = 13072,
  VHSUBPDYrr = 13073,
  VHSUBPDrm = 13074,
  VHSUBPDrr = 13075,
  VHSUBPSYrm = 13076,
  VHSUBPSYrr = 13077,
  VHSUBPSrm = 13078,
  VHSUBPSrr = 13079,
  VINSERTF128rmi = 13080,
  VINSERTF128rri = 13081,
  VINSERTF32X4Z256rmi = 13082,
  VINSERTF32X4Z256rmik = 13083,
  VINSERTF32X4Z256rmikz = 13084,
  VINSERTF32X4Z256rri = 13085,
  VINSERTF32X4Z256rrik = 13086,
  VINSERTF32X4Z256rrikz = 13087,
  VINSERTF32X4Zrmi = 13088,
  VINSERTF32X4Zrmik = 13089,
  VINSERTF32X4Zrmikz = 13090,
  VINSERTF32X4Zrri = 13091,
  VINSERTF32X4Zrrik = 13092,
  VINSERTF32X4Zrrikz = 13093,
  VINSERTF32X8Zrmi = 13094,
  VINSERTF32X8Zrmik = 13095,
  VINSERTF32X8Zrmikz = 13096,
  VINSERTF32X8Zrri = 13097,
  VINSERTF32X8Zrrik = 13098,
  VINSERTF32X8Zrrikz = 13099,
  VINSERTF64X2Z256rmi = 13100,
  VINSERTF64X2Z256rmik = 13101,
  VINSERTF64X2Z256rmikz = 13102,
  VINSERTF64X2Z256rri = 13103,
  VINSERTF64X2Z256rrik = 13104,
  VINSERTF64X2Z256rrikz = 13105,
  VINSERTF64X2Zrmi = 13106,
  VINSERTF64X2Zrmik = 13107,
  VINSERTF64X2Zrmikz = 13108,
  VINSERTF64X2Zrri = 13109,
  VINSERTF64X2Zrrik = 13110,
  VINSERTF64X2Zrrikz = 13111,
  VINSERTF64X4Zrmi = 13112,
  VINSERTF64X4Zrmik = 13113,
  VINSERTF64X4Zrmikz = 13114,
  VINSERTF64X4Zrri = 13115,
  VINSERTF64X4Zrrik = 13116,
  VINSERTF64X4Zrrikz = 13117,
  VINSERTI128rmi = 13118,
  VINSERTI128rri = 13119,
  VINSERTI32X4Z256rmi = 13120,
  VINSERTI32X4Z256rmik = 13121,
  VINSERTI32X4Z256rmikz = 13122,
  VINSERTI32X4Z256rri = 13123,
  VINSERTI32X4Z256rrik = 13124,
  VINSERTI32X4Z256rrikz = 13125,
  VINSERTI32X4Zrmi = 13126,
  VINSERTI32X4Zrmik = 13127,
  VINSERTI32X4Zrmikz = 13128,
  VINSERTI32X4Zrri = 13129,
  VINSERTI32X4Zrrik = 13130,
  VINSERTI32X4Zrrikz = 13131,
  VINSERTI32X8Zrmi = 13132,
  VINSERTI32X8Zrmik = 13133,
  VINSERTI32X8Zrmikz = 13134,
  VINSERTI32X8Zrri = 13135,
  VINSERTI32X8Zrrik = 13136,
  VINSERTI32X8Zrrikz = 13137,
  VINSERTI64X2Z256rmi = 13138,
  VINSERTI64X2Z256rmik = 13139,
  VINSERTI64X2Z256rmikz = 13140,
  VINSERTI64X2Z256rri = 13141,
  VINSERTI64X2Z256rrik = 13142,
  VINSERTI64X2Z256rrikz = 13143,
  VINSERTI64X2Zrmi = 13144,
  VINSERTI64X2Zrmik = 13145,
  VINSERTI64X2Zrmikz = 13146,
  VINSERTI64X2Zrri = 13147,
  VINSERTI64X2Zrrik = 13148,
  VINSERTI64X2Zrrikz = 13149,
  VINSERTI64X4Zrmi = 13150,
  VINSERTI64X4Zrmik = 13151,
  VINSERTI64X4Zrmikz = 13152,
  VINSERTI64X4Zrri = 13153,
  VINSERTI64X4Zrrik = 13154,
  VINSERTI64X4Zrrikz = 13155,
  VINSERTPSZrmi = 13156,
  VINSERTPSZrri = 13157,
  VINSERTPSrmi = 13158,
  VINSERTPSrri = 13159,
  VLDDQUYrm = 13160,
  VLDDQUrm = 13161,
  VLDMXCSR = 13162,
  VMASKMOVDQU = 13163,
  VMASKMOVDQU64 = 13164,
  VMASKMOVPDYmr = 13165,
  VMASKMOVPDYrm = 13166,
  VMASKMOVPDmr = 13167,
  VMASKMOVPDrm = 13168,
  VMASKMOVPSYmr = 13169,
  VMASKMOVPSYrm = 13170,
  VMASKMOVPSmr = 13171,
  VMASKMOVPSrm = 13172,
  VMAXBF16Z128rm = 13173,
  VMAXBF16Z128rmb = 13174,
  VMAXBF16Z128rmbk = 13175,
  VMAXBF16Z128rmbkz = 13176,
  VMAXBF16Z128rmk = 13177,
  VMAXBF16Z128rmkz = 13178,
  VMAXBF16Z128rr = 13179,
  VMAXBF16Z128rrk = 13180,
  VMAXBF16Z128rrkz = 13181,
  VMAXBF16Z256rm = 13182,
  VMAXBF16Z256rmb = 13183,
  VMAXBF16Z256rmbk = 13184,
  VMAXBF16Z256rmbkz = 13185,
  VMAXBF16Z256rmk = 13186,
  VMAXBF16Z256rmkz = 13187,
  VMAXBF16Z256rr = 13188,
  VMAXBF16Z256rrk = 13189,
  VMAXBF16Z256rrkz = 13190,
  VMAXBF16Zrm = 13191,
  VMAXBF16Zrmb = 13192,
  VMAXBF16Zrmbk = 13193,
  VMAXBF16Zrmbkz = 13194,
  VMAXBF16Zrmk = 13195,
  VMAXBF16Zrmkz = 13196,
  VMAXBF16Zrr = 13197,
  VMAXBF16Zrrk = 13198,
  VMAXBF16Zrrkz = 13199,
  VMAXCPDYrm = 13200,
  VMAXCPDYrr = 13201,
  VMAXCPDZ128rm = 13202,
  VMAXCPDZ128rmb = 13203,
  VMAXCPDZ128rmbk = 13204,
  VMAXCPDZ128rmbkz = 13205,
  VMAXCPDZ128rmk = 13206,
  VMAXCPDZ128rmkz = 13207,
  VMAXCPDZ128rr = 13208,
  VMAXCPDZ128rrk = 13209,
  VMAXCPDZ128rrkz = 13210,
  VMAXCPDZ256rm = 13211,
  VMAXCPDZ256rmb = 13212,
  VMAXCPDZ256rmbk = 13213,
  VMAXCPDZ256rmbkz = 13214,
  VMAXCPDZ256rmk = 13215,
  VMAXCPDZ256rmkz = 13216,
  VMAXCPDZ256rr = 13217,
  VMAXCPDZ256rrk = 13218,
  VMAXCPDZ256rrkz = 13219,
  VMAXCPDZrm = 13220,
  VMAXCPDZrmb = 13221,
  VMAXCPDZrmbk = 13222,
  VMAXCPDZrmbkz = 13223,
  VMAXCPDZrmk = 13224,
  VMAXCPDZrmkz = 13225,
  VMAXCPDZrr = 13226,
  VMAXCPDZrrk = 13227,
  VMAXCPDZrrkz = 13228,
  VMAXCPDrm = 13229,
  VMAXCPDrr = 13230,
  VMAXCPHZ128rm = 13231,
  VMAXCPHZ128rmb = 13232,
  VMAXCPHZ128rmbk = 13233,
  VMAXCPHZ128rmbkz = 13234,
  VMAXCPHZ128rmk = 13235,
  VMAXCPHZ128rmkz = 13236,
  VMAXCPHZ128rr = 13237,
  VMAXCPHZ128rrk = 13238,
  VMAXCPHZ128rrkz = 13239,
  VMAXCPHZ256rm = 13240,
  VMAXCPHZ256rmb = 13241,
  VMAXCPHZ256rmbk = 13242,
  VMAXCPHZ256rmbkz = 13243,
  VMAXCPHZ256rmk = 13244,
  VMAXCPHZ256rmkz = 13245,
  VMAXCPHZ256rr = 13246,
  VMAXCPHZ256rrk = 13247,
  VMAXCPHZ256rrkz = 13248,
  VMAXCPHZrm = 13249,
  VMAXCPHZrmb = 13250,
  VMAXCPHZrmbk = 13251,
  VMAXCPHZrmbkz = 13252,
  VMAXCPHZrmk = 13253,
  VMAXCPHZrmkz = 13254,
  VMAXCPHZrr = 13255,
  VMAXCPHZrrk = 13256,
  VMAXCPHZrrkz = 13257,
  VMAXCPSYrm = 13258,
  VMAXCPSYrr = 13259,
  VMAXCPSZ128rm = 13260,
  VMAXCPSZ128rmb = 13261,
  VMAXCPSZ128rmbk = 13262,
  VMAXCPSZ128rmbkz = 13263,
  VMAXCPSZ128rmk = 13264,
  VMAXCPSZ128rmkz = 13265,
  VMAXCPSZ128rr = 13266,
  VMAXCPSZ128rrk = 13267,
  VMAXCPSZ128rrkz = 13268,
  VMAXCPSZ256rm = 13269,
  VMAXCPSZ256rmb = 13270,
  VMAXCPSZ256rmbk = 13271,
  VMAXCPSZ256rmbkz = 13272,
  VMAXCPSZ256rmk = 13273,
  VMAXCPSZ256rmkz = 13274,
  VMAXCPSZ256rr = 13275,
  VMAXCPSZ256rrk = 13276,
  VMAXCPSZ256rrkz = 13277,
  VMAXCPSZrm = 13278,
  VMAXCPSZrmb = 13279,
  VMAXCPSZrmbk = 13280,
  VMAXCPSZrmbkz = 13281,
  VMAXCPSZrmk = 13282,
  VMAXCPSZrmkz = 13283,
  VMAXCPSZrr = 13284,
  VMAXCPSZrrk = 13285,
  VMAXCPSZrrkz = 13286,
  VMAXCPSrm = 13287,
  VMAXCPSrr = 13288,
  VMAXCSDZrm = 13289,
  VMAXCSDZrr = 13290,
  VMAXCSDrm = 13291,
  VMAXCSDrr = 13292,
  VMAXCSHZrm = 13293,
  VMAXCSHZrr = 13294,
  VMAXCSSZrm = 13295,
  VMAXCSSZrr = 13296,
  VMAXCSSrm = 13297,
  VMAXCSSrr = 13298,
  VMAXPDYrm = 13299,
  VMAXPDYrr = 13300,
  VMAXPDZ128rm = 13301,
  VMAXPDZ128rmb = 13302,
  VMAXPDZ128rmbk = 13303,
  VMAXPDZ128rmbkz = 13304,
  VMAXPDZ128rmk = 13305,
  VMAXPDZ128rmkz = 13306,
  VMAXPDZ128rr = 13307,
  VMAXPDZ128rrk = 13308,
  VMAXPDZ128rrkz = 13309,
  VMAXPDZ256rm = 13310,
  VMAXPDZ256rmb = 13311,
  VMAXPDZ256rmbk = 13312,
  VMAXPDZ256rmbkz = 13313,
  VMAXPDZ256rmk = 13314,
  VMAXPDZ256rmkz = 13315,
  VMAXPDZ256rr = 13316,
  VMAXPDZ256rrb = 13317,
  VMAXPDZ256rrbk = 13318,
  VMAXPDZ256rrbkz = 13319,
  VMAXPDZ256rrk = 13320,
  VMAXPDZ256rrkz = 13321,
  VMAXPDZrm = 13322,
  VMAXPDZrmb = 13323,
  VMAXPDZrmbk = 13324,
  VMAXPDZrmbkz = 13325,
  VMAXPDZrmk = 13326,
  VMAXPDZrmkz = 13327,
  VMAXPDZrr = 13328,
  VMAXPDZrrb = 13329,
  VMAXPDZrrbk = 13330,
  VMAXPDZrrbkz = 13331,
  VMAXPDZrrk = 13332,
  VMAXPDZrrkz = 13333,
  VMAXPDrm = 13334,
  VMAXPDrr = 13335,
  VMAXPHZ128rm = 13336,
  VMAXPHZ128rmb = 13337,
  VMAXPHZ128rmbk = 13338,
  VMAXPHZ128rmbkz = 13339,
  VMAXPHZ128rmk = 13340,
  VMAXPHZ128rmkz = 13341,
  VMAXPHZ128rr = 13342,
  VMAXPHZ128rrk = 13343,
  VMAXPHZ128rrkz = 13344,
  VMAXPHZ256rm = 13345,
  VMAXPHZ256rmb = 13346,
  VMAXPHZ256rmbk = 13347,
  VMAXPHZ256rmbkz = 13348,
  VMAXPHZ256rmk = 13349,
  VMAXPHZ256rmkz = 13350,
  VMAXPHZ256rr = 13351,
  VMAXPHZ256rrb = 13352,
  VMAXPHZ256rrbk = 13353,
  VMAXPHZ256rrbkz = 13354,
  VMAXPHZ256rrk = 13355,
  VMAXPHZ256rrkz = 13356,
  VMAXPHZrm = 13357,
  VMAXPHZrmb = 13358,
  VMAXPHZrmbk = 13359,
  VMAXPHZrmbkz = 13360,
  VMAXPHZrmk = 13361,
  VMAXPHZrmkz = 13362,
  VMAXPHZrr = 13363,
  VMAXPHZrrb = 13364,
  VMAXPHZrrbk = 13365,
  VMAXPHZrrbkz = 13366,
  VMAXPHZrrk = 13367,
  VMAXPHZrrkz = 13368,
  VMAXPSYrm = 13369,
  VMAXPSYrr = 13370,
  VMAXPSZ128rm = 13371,
  VMAXPSZ128rmb = 13372,
  VMAXPSZ128rmbk = 13373,
  VMAXPSZ128rmbkz = 13374,
  VMAXPSZ128rmk = 13375,
  VMAXPSZ128rmkz = 13376,
  VMAXPSZ128rr = 13377,
  VMAXPSZ128rrk = 13378,
  VMAXPSZ128rrkz = 13379,
  VMAXPSZ256rm = 13380,
  VMAXPSZ256rmb = 13381,
  VMAXPSZ256rmbk = 13382,
  VMAXPSZ256rmbkz = 13383,
  VMAXPSZ256rmk = 13384,
  VMAXPSZ256rmkz = 13385,
  VMAXPSZ256rr = 13386,
  VMAXPSZ256rrb = 13387,
  VMAXPSZ256rrbk = 13388,
  VMAXPSZ256rrbkz = 13389,
  VMAXPSZ256rrk = 13390,
  VMAXPSZ256rrkz = 13391,
  VMAXPSZrm = 13392,
  VMAXPSZrmb = 13393,
  VMAXPSZrmbk = 13394,
  VMAXPSZrmbkz = 13395,
  VMAXPSZrmk = 13396,
  VMAXPSZrmkz = 13397,
  VMAXPSZrr = 13398,
  VMAXPSZrrb = 13399,
  VMAXPSZrrbk = 13400,
  VMAXPSZrrbkz = 13401,
  VMAXPSZrrk = 13402,
  VMAXPSZrrkz = 13403,
  VMAXPSrm = 13404,
  VMAXPSrr = 13405,
  VMAXSDZrm = 13406,
  VMAXSDZrm_Int = 13407,
  VMAXSDZrmk_Int = 13408,
  VMAXSDZrmkz_Int = 13409,
  VMAXSDZrr = 13410,
  VMAXSDZrr_Int = 13411,
  VMAXSDZrrb_Int = 13412,
  VMAXSDZrrbk_Int = 13413,
  VMAXSDZrrbkz_Int = 13414,
  VMAXSDZrrk_Int = 13415,
  VMAXSDZrrkz_Int = 13416,
  VMAXSDrm = 13417,
  VMAXSDrm_Int = 13418,
  VMAXSDrr = 13419,
  VMAXSDrr_Int = 13420,
  VMAXSHZrm = 13421,
  VMAXSHZrm_Int = 13422,
  VMAXSHZrmk_Int = 13423,
  VMAXSHZrmkz_Int = 13424,
  VMAXSHZrr = 13425,
  VMAXSHZrr_Int = 13426,
  VMAXSHZrrb_Int = 13427,
  VMAXSHZrrbk_Int = 13428,
  VMAXSHZrrbkz_Int = 13429,
  VMAXSHZrrk_Int = 13430,
  VMAXSHZrrkz_Int = 13431,
  VMAXSSZrm = 13432,
  VMAXSSZrm_Int = 13433,
  VMAXSSZrmk_Int = 13434,
  VMAXSSZrmkz_Int = 13435,
  VMAXSSZrr = 13436,
  VMAXSSZrr_Int = 13437,
  VMAXSSZrrb_Int = 13438,
  VMAXSSZrrbk_Int = 13439,
  VMAXSSZrrbkz_Int = 13440,
  VMAXSSZrrk_Int = 13441,
  VMAXSSZrrkz_Int = 13442,
  VMAXSSrm = 13443,
  VMAXSSrm_Int = 13444,
  VMAXSSrr = 13445,
  VMAXSSrr_Int = 13446,
  VMCALL = 13447,
  VMCLEARm = 13448,
  VMFUNC = 13449,
  VMINBF16Z128rm = 13450,
  VMINBF16Z128rmb = 13451,
  VMINBF16Z128rmbk = 13452,
  VMINBF16Z128rmbkz = 13453,
  VMINBF16Z128rmk = 13454,
  VMINBF16Z128rmkz = 13455,
  VMINBF16Z128rr = 13456,
  VMINBF16Z128rrk = 13457,
  VMINBF16Z128rrkz = 13458,
  VMINBF16Z256rm = 13459,
  VMINBF16Z256rmb = 13460,
  VMINBF16Z256rmbk = 13461,
  VMINBF16Z256rmbkz = 13462,
  VMINBF16Z256rmk = 13463,
  VMINBF16Z256rmkz = 13464,
  VMINBF16Z256rr = 13465,
  VMINBF16Z256rrk = 13466,
  VMINBF16Z256rrkz = 13467,
  VMINBF16Zrm = 13468,
  VMINBF16Zrmb = 13469,
  VMINBF16Zrmbk = 13470,
  VMINBF16Zrmbkz = 13471,
  VMINBF16Zrmk = 13472,
  VMINBF16Zrmkz = 13473,
  VMINBF16Zrr = 13474,
  VMINBF16Zrrk = 13475,
  VMINBF16Zrrkz = 13476,
  VMINCPDYrm = 13477,
  VMINCPDYrr = 13478,
  VMINCPDZ128rm = 13479,
  VMINCPDZ128rmb = 13480,
  VMINCPDZ128rmbk = 13481,
  VMINCPDZ128rmbkz = 13482,
  VMINCPDZ128rmk = 13483,
  VMINCPDZ128rmkz = 13484,
  VMINCPDZ128rr = 13485,
  VMINCPDZ128rrk = 13486,
  VMINCPDZ128rrkz = 13487,
  VMINCPDZ256rm = 13488,
  VMINCPDZ256rmb = 13489,
  VMINCPDZ256rmbk = 13490,
  VMINCPDZ256rmbkz = 13491,
  VMINCPDZ256rmk = 13492,
  VMINCPDZ256rmkz = 13493,
  VMINCPDZ256rr = 13494,
  VMINCPDZ256rrk = 13495,
  VMINCPDZ256rrkz = 13496,
  VMINCPDZrm = 13497,
  VMINCPDZrmb = 13498,
  VMINCPDZrmbk = 13499,
  VMINCPDZrmbkz = 13500,
  VMINCPDZrmk = 13501,
  VMINCPDZrmkz = 13502,
  VMINCPDZrr = 13503,
  VMINCPDZrrk = 13504,
  VMINCPDZrrkz = 13505,
  VMINCPDrm = 13506,
  VMINCPDrr = 13507,
  VMINCPHZ128rm = 13508,
  VMINCPHZ128rmb = 13509,
  VMINCPHZ128rmbk = 13510,
  VMINCPHZ128rmbkz = 13511,
  VMINCPHZ128rmk = 13512,
  VMINCPHZ128rmkz = 13513,
  VMINCPHZ128rr = 13514,
  VMINCPHZ128rrk = 13515,
  VMINCPHZ128rrkz = 13516,
  VMINCPHZ256rm = 13517,
  VMINCPHZ256rmb = 13518,
  VMINCPHZ256rmbk = 13519,
  VMINCPHZ256rmbkz = 13520,
  VMINCPHZ256rmk = 13521,
  VMINCPHZ256rmkz = 13522,
  VMINCPHZ256rr = 13523,
  VMINCPHZ256rrk = 13524,
  VMINCPHZ256rrkz = 13525,
  VMINCPHZrm = 13526,
  VMINCPHZrmb = 13527,
  VMINCPHZrmbk = 13528,
  VMINCPHZrmbkz = 13529,
  VMINCPHZrmk = 13530,
  VMINCPHZrmkz = 13531,
  VMINCPHZrr = 13532,
  VMINCPHZrrk = 13533,
  VMINCPHZrrkz = 13534,
  VMINCPSYrm = 13535,
  VMINCPSYrr = 13536,
  VMINCPSZ128rm = 13537,
  VMINCPSZ128rmb = 13538,
  VMINCPSZ128rmbk = 13539,
  VMINCPSZ128rmbkz = 13540,
  VMINCPSZ128rmk = 13541,
  VMINCPSZ128rmkz = 13542,
  VMINCPSZ128rr = 13543,
  VMINCPSZ128rrk = 13544,
  VMINCPSZ128rrkz = 13545,
  VMINCPSZ256rm = 13546,
  VMINCPSZ256rmb = 13547,
  VMINCPSZ256rmbk = 13548,
  VMINCPSZ256rmbkz = 13549,
  VMINCPSZ256rmk = 13550,
  VMINCPSZ256rmkz = 13551,
  VMINCPSZ256rr = 13552,
  VMINCPSZ256rrk = 13553,
  VMINCPSZ256rrkz = 13554,
  VMINCPSZrm = 13555,
  VMINCPSZrmb = 13556,
  VMINCPSZrmbk = 13557,
  VMINCPSZrmbkz = 13558,
  VMINCPSZrmk = 13559,
  VMINCPSZrmkz = 13560,
  VMINCPSZrr = 13561,
  VMINCPSZrrk = 13562,
  VMINCPSZrrkz = 13563,
  VMINCPSrm = 13564,
  VMINCPSrr = 13565,
  VMINCSDZrm = 13566,
  VMINCSDZrr = 13567,
  VMINCSDrm = 13568,
  VMINCSDrr = 13569,
  VMINCSHZrm = 13570,
  VMINCSHZrr = 13571,
  VMINCSSZrm = 13572,
  VMINCSSZrr = 13573,
  VMINCSSrm = 13574,
  VMINCSSrr = 13575,
  VMINMAXBF16Z128rmbi = 13576,
  VMINMAXBF16Z128rmbik = 13577,
  VMINMAXBF16Z128rmbikz = 13578,
  VMINMAXBF16Z128rmi = 13579,
  VMINMAXBF16Z128rmik = 13580,
  VMINMAXBF16Z128rmikz = 13581,
  VMINMAXBF16Z128rri = 13582,
  VMINMAXBF16Z128rrik = 13583,
  VMINMAXBF16Z128rrikz = 13584,
  VMINMAXBF16Z256rmbi = 13585,
  VMINMAXBF16Z256rmbik = 13586,
  VMINMAXBF16Z256rmbikz = 13587,
  VMINMAXBF16Z256rmi = 13588,
  VMINMAXBF16Z256rmik = 13589,
  VMINMAXBF16Z256rmikz = 13590,
  VMINMAXBF16Z256rri = 13591,
  VMINMAXBF16Z256rrik = 13592,
  VMINMAXBF16Z256rrikz = 13593,
  VMINMAXBF16Zrmbi = 13594,
  VMINMAXBF16Zrmbik = 13595,
  VMINMAXBF16Zrmbikz = 13596,
  VMINMAXBF16Zrmi = 13597,
  VMINMAXBF16Zrmik = 13598,
  VMINMAXBF16Zrmikz = 13599,
  VMINMAXBF16Zrri = 13600,
  VMINMAXBF16Zrrik = 13601,
  VMINMAXBF16Zrrikz = 13602,
  VMINMAXPDZ128rmbi = 13603,
  VMINMAXPDZ128rmbik = 13604,
  VMINMAXPDZ128rmbikz = 13605,
  VMINMAXPDZ128rmi = 13606,
  VMINMAXPDZ128rmik = 13607,
  VMINMAXPDZ128rmikz = 13608,
  VMINMAXPDZ128rri = 13609,
  VMINMAXPDZ128rrik = 13610,
  VMINMAXPDZ128rrikz = 13611,
  VMINMAXPDZ256rmbi = 13612,
  VMINMAXPDZ256rmbik = 13613,
  VMINMAXPDZ256rmbikz = 13614,
  VMINMAXPDZ256rmi = 13615,
  VMINMAXPDZ256rmik = 13616,
  VMINMAXPDZ256rmikz = 13617,
  VMINMAXPDZ256rri = 13618,
  VMINMAXPDZ256rrib = 13619,
  VMINMAXPDZ256rribk = 13620,
  VMINMAXPDZ256rribkz = 13621,
  VMINMAXPDZ256rrik = 13622,
  VMINMAXPDZ256rrikz = 13623,
  VMINMAXPDZrmbi = 13624,
  VMINMAXPDZrmbik = 13625,
  VMINMAXPDZrmbikz = 13626,
  VMINMAXPDZrmi = 13627,
  VMINMAXPDZrmik = 13628,
  VMINMAXPDZrmikz = 13629,
  VMINMAXPDZrri = 13630,
  VMINMAXPDZrrib = 13631,
  VMINMAXPDZrribk = 13632,
  VMINMAXPDZrribkz = 13633,
  VMINMAXPDZrrik = 13634,
  VMINMAXPDZrrikz = 13635,
  VMINMAXPHZ128rmbi = 13636,
  VMINMAXPHZ128rmbik = 13637,
  VMINMAXPHZ128rmbikz = 13638,
  VMINMAXPHZ128rmi = 13639,
  VMINMAXPHZ128rmik = 13640,
  VMINMAXPHZ128rmikz = 13641,
  VMINMAXPHZ128rri = 13642,
  VMINMAXPHZ128rrik = 13643,
  VMINMAXPHZ128rrikz = 13644,
  VMINMAXPHZ256rmbi = 13645,
  VMINMAXPHZ256rmbik = 13646,
  VMINMAXPHZ256rmbikz = 13647,
  VMINMAXPHZ256rmi = 13648,
  VMINMAXPHZ256rmik = 13649,
  VMINMAXPHZ256rmikz = 13650,
  VMINMAXPHZ256rri = 13651,
  VMINMAXPHZ256rrib = 13652,
  VMINMAXPHZ256rribk = 13653,
  VMINMAXPHZ256rribkz = 13654,
  VMINMAXPHZ256rrik = 13655,
  VMINMAXPHZ256rrikz = 13656,
  VMINMAXPHZrmbi = 13657,
  VMINMAXPHZrmbik = 13658,
  VMINMAXPHZrmbikz = 13659,
  VMINMAXPHZrmi = 13660,
  VMINMAXPHZrmik = 13661,
  VMINMAXPHZrmikz = 13662,
  VMINMAXPHZrri = 13663,
  VMINMAXPHZrrib = 13664,
  VMINMAXPHZrribk = 13665,
  VMINMAXPHZrribkz = 13666,
  VMINMAXPHZrrik = 13667,
  VMINMAXPHZrrikz = 13668,
  VMINMAXPSZ128rmbi = 13669,
  VMINMAXPSZ128rmbik = 13670,
  VMINMAXPSZ128rmbikz = 13671,
  VMINMAXPSZ128rmi = 13672,
  VMINMAXPSZ128rmik = 13673,
  VMINMAXPSZ128rmikz = 13674,
  VMINMAXPSZ128rri = 13675,
  VMINMAXPSZ128rrik = 13676,
  VMINMAXPSZ128rrikz = 13677,
  VMINMAXPSZ256rmbi = 13678,
  VMINMAXPSZ256rmbik = 13679,
  VMINMAXPSZ256rmbikz = 13680,
  VMINMAXPSZ256rmi = 13681,
  VMINMAXPSZ256rmik = 13682,
  VMINMAXPSZ256rmikz = 13683,
  VMINMAXPSZ256rri = 13684,
  VMINMAXPSZ256rrib = 13685,
  VMINMAXPSZ256rribk = 13686,
  VMINMAXPSZ256rribkz = 13687,
  VMINMAXPSZ256rrik = 13688,
  VMINMAXPSZ256rrikz = 13689,
  VMINMAXPSZrmbi = 13690,
  VMINMAXPSZrmbik = 13691,
  VMINMAXPSZrmbikz = 13692,
  VMINMAXPSZrmi = 13693,
  VMINMAXPSZrmik = 13694,
  VMINMAXPSZrmikz = 13695,
  VMINMAXPSZrri = 13696,
  VMINMAXPSZrrib = 13697,
  VMINMAXPSZrribk = 13698,
  VMINMAXPSZrribkz = 13699,
  VMINMAXPSZrrik = 13700,
  VMINMAXPSZrrikz = 13701,
  VMINMAXSDrmi = 13702,
  VMINMAXSDrmi_Int = 13703,
  VMINMAXSDrmik_Int = 13704,
  VMINMAXSDrmikz_Int = 13705,
  VMINMAXSDrri = 13706,
  VMINMAXSDrri_Int = 13707,
  VMINMAXSDrrib_Int = 13708,
  VMINMAXSDrribk_Int = 13709,
  VMINMAXSDrribkz_Int = 13710,
  VMINMAXSDrrik_Int = 13711,
  VMINMAXSDrrikz_Int = 13712,
  VMINMAXSHrmi = 13713,
  VMINMAXSHrmi_Int = 13714,
  VMINMAXSHrmik_Int = 13715,
  VMINMAXSHrmikz_Int = 13716,
  VMINMAXSHrri = 13717,
  VMINMAXSHrri_Int = 13718,
  VMINMAXSHrrib_Int = 13719,
  VMINMAXSHrribk_Int = 13720,
  VMINMAXSHrribkz_Int = 13721,
  VMINMAXSHrrik_Int = 13722,
  VMINMAXSHrrikz_Int = 13723,
  VMINMAXSSrmi = 13724,
  VMINMAXSSrmi_Int = 13725,
  VMINMAXSSrmik_Int = 13726,
  VMINMAXSSrmikz_Int = 13727,
  VMINMAXSSrri = 13728,
  VMINMAXSSrri_Int = 13729,
  VMINMAXSSrrib_Int = 13730,
  VMINMAXSSrribk_Int = 13731,
  VMINMAXSSrribkz_Int = 13732,
  VMINMAXSSrrik_Int = 13733,
  VMINMAXSSrrikz_Int = 13734,
  VMINPDYrm = 13735,
  VMINPDYrr = 13736,
  VMINPDZ128rm = 13737,
  VMINPDZ128rmb = 13738,
  VMINPDZ128rmbk = 13739,
  VMINPDZ128rmbkz = 13740,
  VMINPDZ128rmk = 13741,
  VMINPDZ128rmkz = 13742,
  VMINPDZ128rr = 13743,
  VMINPDZ128rrk = 13744,
  VMINPDZ128rrkz = 13745,
  VMINPDZ256rm = 13746,
  VMINPDZ256rmb = 13747,
  VMINPDZ256rmbk = 13748,
  VMINPDZ256rmbkz = 13749,
  VMINPDZ256rmk = 13750,
  VMINPDZ256rmkz = 13751,
  VMINPDZ256rr = 13752,
  VMINPDZ256rrb = 13753,
  VMINPDZ256rrbk = 13754,
  VMINPDZ256rrbkz = 13755,
  VMINPDZ256rrk = 13756,
  VMINPDZ256rrkz = 13757,
  VMINPDZrm = 13758,
  VMINPDZrmb = 13759,
  VMINPDZrmbk = 13760,
  VMINPDZrmbkz = 13761,
  VMINPDZrmk = 13762,
  VMINPDZrmkz = 13763,
  VMINPDZrr = 13764,
  VMINPDZrrb = 13765,
  VMINPDZrrbk = 13766,
  VMINPDZrrbkz = 13767,
  VMINPDZrrk = 13768,
  VMINPDZrrkz = 13769,
  VMINPDrm = 13770,
  VMINPDrr = 13771,
  VMINPHZ128rm = 13772,
  VMINPHZ128rmb = 13773,
  VMINPHZ128rmbk = 13774,
  VMINPHZ128rmbkz = 13775,
  VMINPHZ128rmk = 13776,
  VMINPHZ128rmkz = 13777,
  VMINPHZ128rr = 13778,
  VMINPHZ128rrk = 13779,
  VMINPHZ128rrkz = 13780,
  VMINPHZ256rm = 13781,
  VMINPHZ256rmb = 13782,
  VMINPHZ256rmbk = 13783,
  VMINPHZ256rmbkz = 13784,
  VMINPHZ256rmk = 13785,
  VMINPHZ256rmkz = 13786,
  VMINPHZ256rr = 13787,
  VMINPHZ256rrb = 13788,
  VMINPHZ256rrbk = 13789,
  VMINPHZ256rrbkz = 13790,
  VMINPHZ256rrk = 13791,
  VMINPHZ256rrkz = 13792,
  VMINPHZrm = 13793,
  VMINPHZrmb = 13794,
  VMINPHZrmbk = 13795,
  VMINPHZrmbkz = 13796,
  VMINPHZrmk = 13797,
  VMINPHZrmkz = 13798,
  VMINPHZrr = 13799,
  VMINPHZrrb = 13800,
  VMINPHZrrbk = 13801,
  VMINPHZrrbkz = 13802,
  VMINPHZrrk = 13803,
  VMINPHZrrkz = 13804,
  VMINPSYrm = 13805,
  VMINPSYrr = 13806,
  VMINPSZ128rm = 13807,
  VMINPSZ128rmb = 13808,
  VMINPSZ128rmbk = 13809,
  VMINPSZ128rmbkz = 13810,
  VMINPSZ128rmk = 13811,
  VMINPSZ128rmkz = 13812,
  VMINPSZ128rr = 13813,
  VMINPSZ128rrk = 13814,
  VMINPSZ128rrkz = 13815,
  VMINPSZ256rm = 13816,
  VMINPSZ256rmb = 13817,
  VMINPSZ256rmbk = 13818,
  VMINPSZ256rmbkz = 13819,
  VMINPSZ256rmk = 13820,
  VMINPSZ256rmkz = 13821,
  VMINPSZ256rr = 13822,
  VMINPSZ256rrb = 13823,
  VMINPSZ256rrbk = 13824,
  VMINPSZ256rrbkz = 13825,
  VMINPSZ256rrk = 13826,
  VMINPSZ256rrkz = 13827,
  VMINPSZrm = 13828,
  VMINPSZrmb = 13829,
  VMINPSZrmbk = 13830,
  VMINPSZrmbkz = 13831,
  VMINPSZrmk = 13832,
  VMINPSZrmkz = 13833,
  VMINPSZrr = 13834,
  VMINPSZrrb = 13835,
  VMINPSZrrbk = 13836,
  VMINPSZrrbkz = 13837,
  VMINPSZrrk = 13838,
  VMINPSZrrkz = 13839,
  VMINPSrm = 13840,
  VMINPSrr = 13841,
  VMINSDZrm = 13842,
  VMINSDZrm_Int = 13843,
  VMINSDZrmk_Int = 13844,
  VMINSDZrmkz_Int = 13845,
  VMINSDZrr = 13846,
  VMINSDZrr_Int = 13847,
  VMINSDZrrb_Int = 13848,
  VMINSDZrrbk_Int = 13849,
  VMINSDZrrbkz_Int = 13850,
  VMINSDZrrk_Int = 13851,
  VMINSDZrrkz_Int = 13852,
  VMINSDrm = 13853,
  VMINSDrm_Int = 13854,
  VMINSDrr = 13855,
  VMINSDrr_Int = 13856,
  VMINSHZrm = 13857,
  VMINSHZrm_Int = 13858,
  VMINSHZrmk_Int = 13859,
  VMINSHZrmkz_Int = 13860,
  VMINSHZrr = 13861,
  VMINSHZrr_Int = 13862,
  VMINSHZrrb_Int = 13863,
  VMINSHZrrbk_Int = 13864,
  VMINSHZrrbkz_Int = 13865,
  VMINSHZrrk_Int = 13866,
  VMINSHZrrkz_Int = 13867,
  VMINSSZrm = 13868,
  VMINSSZrm_Int = 13869,
  VMINSSZrmk_Int = 13870,
  VMINSSZrmkz_Int = 13871,
  VMINSSZrr = 13872,
  VMINSSZrr_Int = 13873,
  VMINSSZrrb_Int = 13874,
  VMINSSZrrbk_Int = 13875,
  VMINSSZrrbkz_Int = 13876,
  VMINSSZrrk_Int = 13877,
  VMINSSZrrkz_Int = 13878,
  VMINSSrm = 13879,
  VMINSSrm_Int = 13880,
  VMINSSrr = 13881,
  VMINSSrr_Int = 13882,
  VMLAUNCH = 13883,
  VMLOAD32 = 13884,
  VMLOAD64 = 13885,
  VMMCALL = 13886,
  VMOV64toPQIZrm = 13887,
  VMOV64toPQIZrr = 13888,
  VMOV64toPQIrm = 13889,
  VMOV64toPQIrr = 13890,
  VMOV64toSDZrr = 13891,
  VMOV64toSDrr = 13892,
  VMOVAPDYmr = 13893,
  VMOVAPDYrm = 13894,
  VMOVAPDYrr = 13895,
  VMOVAPDYrr_REV = 13896,
  VMOVAPDZ128mr = 13897,
  VMOVAPDZ128mrk = 13898,
  VMOVAPDZ128rm = 13899,
  VMOVAPDZ128rmk = 13900,
  VMOVAPDZ128rmkz = 13901,
  VMOVAPDZ128rr = 13902,
  VMOVAPDZ128rr_REV = 13903,
  VMOVAPDZ128rrk = 13904,
  VMOVAPDZ128rrk_REV = 13905,
  VMOVAPDZ128rrkz = 13906,
  VMOVAPDZ128rrkz_REV = 13907,
  VMOVAPDZ256mr = 13908,
  VMOVAPDZ256mrk = 13909,
  VMOVAPDZ256rm = 13910,
  VMOVAPDZ256rmk = 13911,
  VMOVAPDZ256rmkz = 13912,
  VMOVAPDZ256rr = 13913,
  VMOVAPDZ256rr_REV = 13914,
  VMOVAPDZ256rrk = 13915,
  VMOVAPDZ256rrk_REV = 13916,
  VMOVAPDZ256rrkz = 13917,
  VMOVAPDZ256rrkz_REV = 13918,
  VMOVAPDZmr = 13919,
  VMOVAPDZmrk = 13920,
  VMOVAPDZrm = 13921,
  VMOVAPDZrmk = 13922,
  VMOVAPDZrmkz = 13923,
  VMOVAPDZrr = 13924,
  VMOVAPDZrr_REV = 13925,
  VMOVAPDZrrk = 13926,
  VMOVAPDZrrk_REV = 13927,
  VMOVAPDZrrkz = 13928,
  VMOVAPDZrrkz_REV = 13929,
  VMOVAPDmr = 13930,
  VMOVAPDrm = 13931,
  VMOVAPDrr = 13932,
  VMOVAPDrr_REV = 13933,
  VMOVAPSYmr = 13934,
  VMOVAPSYrm = 13935,
  VMOVAPSYrr = 13936,
  VMOVAPSYrr_REV = 13937,
  VMOVAPSZ128mr = 13938,
  VMOVAPSZ128mrk = 13939,
  VMOVAPSZ128rm = 13940,
  VMOVAPSZ128rmk = 13941,
  VMOVAPSZ128rmkz = 13942,
  VMOVAPSZ128rr = 13943,
  VMOVAPSZ128rr_REV = 13944,
  VMOVAPSZ128rrk = 13945,
  VMOVAPSZ128rrk_REV = 13946,
  VMOVAPSZ128rrkz = 13947,
  VMOVAPSZ128rrkz_REV = 13948,
  VMOVAPSZ256mr = 13949,
  VMOVAPSZ256mrk = 13950,
  VMOVAPSZ256rm = 13951,
  VMOVAPSZ256rmk = 13952,
  VMOVAPSZ256rmkz = 13953,
  VMOVAPSZ256rr = 13954,
  VMOVAPSZ256rr_REV = 13955,
  VMOVAPSZ256rrk = 13956,
  VMOVAPSZ256rrk_REV = 13957,
  VMOVAPSZ256rrkz = 13958,
  VMOVAPSZ256rrkz_REV = 13959,
  VMOVAPSZmr = 13960,
  VMOVAPSZmrk = 13961,
  VMOVAPSZrm = 13962,
  VMOVAPSZrmk = 13963,
  VMOVAPSZrmkz = 13964,
  VMOVAPSZrr = 13965,
  VMOVAPSZrr_REV = 13966,
  VMOVAPSZrrk = 13967,
  VMOVAPSZrrk_REV = 13968,
  VMOVAPSZrrkz = 13969,
  VMOVAPSZrrkz_REV = 13970,
  VMOVAPSmr = 13971,
  VMOVAPSrm = 13972,
  VMOVAPSrr = 13973,
  VMOVAPSrr_REV = 13974,
  VMOVDDUPYrm = 13975,
  VMOVDDUPYrr = 13976,
  VMOVDDUPZ128rm = 13977,
  VMOVDDUPZ128rmk = 13978,
  VMOVDDUPZ128rmkz = 13979,
  VMOVDDUPZ128rr = 13980,
  VMOVDDUPZ128rrk = 13981,
  VMOVDDUPZ128rrkz = 13982,
  VMOVDDUPZ256rm = 13983,
  VMOVDDUPZ256rmk = 13984,
  VMOVDDUPZ256rmkz = 13985,
  VMOVDDUPZ256rr = 13986,
  VMOVDDUPZ256rrk = 13987,
  VMOVDDUPZ256rrkz = 13988,
  VMOVDDUPZrm = 13989,
  VMOVDDUPZrmk = 13990,
  VMOVDDUPZrmkz = 13991,
  VMOVDDUPZrr = 13992,
  VMOVDDUPZrrk = 13993,
  VMOVDDUPZrrkz = 13994,
  VMOVDDUPrm = 13995,
  VMOVDDUPrr = 13996,
  VMOVDI2PDIZrm = 13997,
  VMOVDI2PDIZrr = 13998,
  VMOVDI2PDIrm = 13999,
  VMOVDI2PDIrr = 14000,
  VMOVDI2SSZrr = 14001,
  VMOVDI2SSrr = 14002,
  VMOVDQA32Z128mr = 14003,
  VMOVDQA32Z128mrk = 14004,
  VMOVDQA32Z128rm = 14005,
  VMOVDQA32Z128rmk = 14006,
  VMOVDQA32Z128rmkz = 14007,
  VMOVDQA32Z128rr = 14008,
  VMOVDQA32Z128rr_REV = 14009,
  VMOVDQA32Z128rrk = 14010,
  VMOVDQA32Z128rrk_REV = 14011,
  VMOVDQA32Z128rrkz = 14012,
  VMOVDQA32Z128rrkz_REV = 14013,
  VMOVDQA32Z256mr = 14014,
  VMOVDQA32Z256mrk = 14015,
  VMOVDQA32Z256rm = 14016,
  VMOVDQA32Z256rmk = 14017,
  VMOVDQA32Z256rmkz = 14018,
  VMOVDQA32Z256rr = 14019,
  VMOVDQA32Z256rr_REV = 14020,
  VMOVDQA32Z256rrk = 14021,
  VMOVDQA32Z256rrk_REV = 14022,
  VMOVDQA32Z256rrkz = 14023,
  VMOVDQA32Z256rrkz_REV = 14024,
  VMOVDQA32Zmr = 14025,
  VMOVDQA32Zmrk = 14026,
  VMOVDQA32Zrm = 14027,
  VMOVDQA32Zrmk = 14028,
  VMOVDQA32Zrmkz = 14029,
  VMOVDQA32Zrr = 14030,
  VMOVDQA32Zrr_REV = 14031,
  VMOVDQA32Zrrk = 14032,
  VMOVDQA32Zrrk_REV = 14033,
  VMOVDQA32Zrrkz = 14034,
  VMOVDQA32Zrrkz_REV = 14035,
  VMOVDQA64Z128mr = 14036,
  VMOVDQA64Z128mrk = 14037,
  VMOVDQA64Z128rm = 14038,
  VMOVDQA64Z128rmk = 14039,
  VMOVDQA64Z128rmkz = 14040,
  VMOVDQA64Z128rr = 14041,
  VMOVDQA64Z128rr_REV = 14042,
  VMOVDQA64Z128rrk = 14043,
  VMOVDQA64Z128rrk_REV = 14044,
  VMOVDQA64Z128rrkz = 14045,
  VMOVDQA64Z128rrkz_REV = 14046,
  VMOVDQA64Z256mr = 14047,
  VMOVDQA64Z256mrk = 14048,
  VMOVDQA64Z256rm = 14049,
  VMOVDQA64Z256rmk = 14050,
  VMOVDQA64Z256rmkz = 14051,
  VMOVDQA64Z256rr = 14052,
  VMOVDQA64Z256rr_REV = 14053,
  VMOVDQA64Z256rrk = 14054,
  VMOVDQA64Z256rrk_REV = 14055,
  VMOVDQA64Z256rrkz = 14056,
  VMOVDQA64Z256rrkz_REV = 14057,
  VMOVDQA64Zmr = 14058,
  VMOVDQA64Zmrk = 14059,
  VMOVDQA64Zrm = 14060,
  VMOVDQA64Zrmk = 14061,
  VMOVDQA64Zrmkz = 14062,
  VMOVDQA64Zrr = 14063,
  VMOVDQA64Zrr_REV = 14064,
  VMOVDQA64Zrrk = 14065,
  VMOVDQA64Zrrk_REV = 14066,
  VMOVDQA64Zrrkz = 14067,
  VMOVDQA64Zrrkz_REV = 14068,
  VMOVDQAYmr = 14069,
  VMOVDQAYrm = 14070,
  VMOVDQAYrr = 14071,
  VMOVDQAYrr_REV = 14072,
  VMOVDQAmr = 14073,
  VMOVDQArm = 14074,
  VMOVDQArr = 14075,
  VMOVDQArr_REV = 14076,
  VMOVDQU16Z128mr = 14077,
  VMOVDQU16Z128mrk = 14078,
  VMOVDQU16Z128rm = 14079,
  VMOVDQU16Z128rmk = 14080,
  VMOVDQU16Z128rmkz = 14081,
  VMOVDQU16Z128rr = 14082,
  VMOVDQU16Z128rr_REV = 14083,
  VMOVDQU16Z128rrk = 14084,
  VMOVDQU16Z128rrk_REV = 14085,
  VMOVDQU16Z128rrkz = 14086,
  VMOVDQU16Z128rrkz_REV = 14087,
  VMOVDQU16Z256mr = 14088,
  VMOVDQU16Z256mrk = 14089,
  VMOVDQU16Z256rm = 14090,
  VMOVDQU16Z256rmk = 14091,
  VMOVDQU16Z256rmkz = 14092,
  VMOVDQU16Z256rr = 14093,
  VMOVDQU16Z256rr_REV = 14094,
  VMOVDQU16Z256rrk = 14095,
  VMOVDQU16Z256rrk_REV = 14096,
  VMOVDQU16Z256rrkz = 14097,
  VMOVDQU16Z256rrkz_REV = 14098,
  VMOVDQU16Zmr = 14099,
  VMOVDQU16Zmrk = 14100,
  VMOVDQU16Zrm = 14101,
  VMOVDQU16Zrmk = 14102,
  VMOVDQU16Zrmkz = 14103,
  VMOVDQU16Zrr = 14104,
  VMOVDQU16Zrr_REV = 14105,
  VMOVDQU16Zrrk = 14106,
  VMOVDQU16Zrrk_REV = 14107,
  VMOVDQU16Zrrkz = 14108,
  VMOVDQU16Zrrkz_REV = 14109,
  VMOVDQU32Z128mr = 14110,
  VMOVDQU32Z128mrk = 14111,
  VMOVDQU32Z128rm = 14112,
  VMOVDQU32Z128rmk = 14113,
  VMOVDQU32Z128rmkz = 14114,
  VMOVDQU32Z128rr = 14115,
  VMOVDQU32Z128rr_REV = 14116,
  VMOVDQU32Z128rrk = 14117,
  VMOVDQU32Z128rrk_REV = 14118,
  VMOVDQU32Z128rrkz = 14119,
  VMOVDQU32Z128rrkz_REV = 14120,
  VMOVDQU32Z256mr = 14121,
  VMOVDQU32Z256mrk = 14122,
  VMOVDQU32Z256rm = 14123,
  VMOVDQU32Z256rmk = 14124,
  VMOVDQU32Z256rmkz = 14125,
  VMOVDQU32Z256rr = 14126,
  VMOVDQU32Z256rr_REV = 14127,
  VMOVDQU32Z256rrk = 14128,
  VMOVDQU32Z256rrk_REV = 14129,
  VMOVDQU32Z256rrkz = 14130,
  VMOVDQU32Z256rrkz_REV = 14131,
  VMOVDQU32Zmr = 14132,
  VMOVDQU32Zmrk = 14133,
  VMOVDQU32Zrm = 14134,
  VMOVDQU32Zrmk = 14135,
  VMOVDQU32Zrmkz = 14136,
  VMOVDQU32Zrr = 14137,
  VMOVDQU32Zrr_REV = 14138,
  VMOVDQU32Zrrk = 14139,
  VMOVDQU32Zrrk_REV = 14140,
  VMOVDQU32Zrrkz = 14141,
  VMOVDQU32Zrrkz_REV = 14142,
  VMOVDQU64Z128mr = 14143,
  VMOVDQU64Z128mrk = 14144,
  VMOVDQU64Z128rm = 14145,
  VMOVDQU64Z128rmk = 14146,
  VMOVDQU64Z128rmkz = 14147,
  VMOVDQU64Z128rr = 14148,
  VMOVDQU64Z128rr_REV = 14149,
  VMOVDQU64Z128rrk = 14150,
  VMOVDQU64Z128rrk_REV = 14151,
  VMOVDQU64Z128rrkz = 14152,
  VMOVDQU64Z128rrkz_REV = 14153,
  VMOVDQU64Z256mr = 14154,
  VMOVDQU64Z256mrk = 14155,
  VMOVDQU64Z256rm = 14156,
  VMOVDQU64Z256rmk = 14157,
  VMOVDQU64Z256rmkz = 14158,
  VMOVDQU64Z256rr = 14159,
  VMOVDQU64Z256rr_REV = 14160,
  VMOVDQU64Z256rrk = 14161,
  VMOVDQU64Z256rrk_REV = 14162,
  VMOVDQU64Z256rrkz = 14163,
  VMOVDQU64Z256rrkz_REV = 14164,
  VMOVDQU64Zmr = 14165,
  VMOVDQU64Zmrk = 14166,
  VMOVDQU64Zrm = 14167,
  VMOVDQU64Zrmk = 14168,
  VMOVDQU64Zrmkz = 14169,
  VMOVDQU64Zrr = 14170,
  VMOVDQU64Zrr_REV = 14171,
  VMOVDQU64Zrrk = 14172,
  VMOVDQU64Zrrk_REV = 14173,
  VMOVDQU64Zrrkz = 14174,
  VMOVDQU64Zrrkz_REV = 14175,
  VMOVDQU8Z128mr = 14176,
  VMOVDQU8Z128mrk = 14177,
  VMOVDQU8Z128rm = 14178,
  VMOVDQU8Z128rmk = 14179,
  VMOVDQU8Z128rmkz = 14180,
  VMOVDQU8Z128rr = 14181,
  VMOVDQU8Z128rr_REV = 14182,
  VMOVDQU8Z128rrk = 14183,
  VMOVDQU8Z128rrk_REV = 14184,
  VMOVDQU8Z128rrkz = 14185,
  VMOVDQU8Z128rrkz_REV = 14186,
  VMOVDQU8Z256mr = 14187,
  VMOVDQU8Z256mrk = 14188,
  VMOVDQU8Z256rm = 14189,
  VMOVDQU8Z256rmk = 14190,
  VMOVDQU8Z256rmkz = 14191,
  VMOVDQU8Z256rr = 14192,
  VMOVDQU8Z256rr_REV = 14193,
  VMOVDQU8Z256rrk = 14194,
  VMOVDQU8Z256rrk_REV = 14195,
  VMOVDQU8Z256rrkz = 14196,
  VMOVDQU8Z256rrkz_REV = 14197,
  VMOVDQU8Zmr = 14198,
  VMOVDQU8Zmrk = 14199,
  VMOVDQU8Zrm = 14200,
  VMOVDQU8Zrmk = 14201,
  VMOVDQU8Zrmkz = 14202,
  VMOVDQU8Zrr = 14203,
  VMOVDQU8Zrr_REV = 14204,
  VMOVDQU8Zrrk = 14205,
  VMOVDQU8Zrrk_REV = 14206,
  VMOVDQU8Zrrkz = 14207,
  VMOVDQU8Zrrkz_REV = 14208,
  VMOVDQUYmr = 14209,
  VMOVDQUYrm = 14210,
  VMOVDQUYrr = 14211,
  VMOVDQUYrr_REV = 14212,
  VMOVDQUmr = 14213,
  VMOVDQUrm = 14214,
  VMOVDQUrr = 14215,
  VMOVDQUrr_REV = 14216,
  VMOVHLPSZrr = 14217,
  VMOVHLPSrr = 14218,
  VMOVHPDZ128mr = 14219,
  VMOVHPDZ128rm = 14220,
  VMOVHPDmr = 14221,
  VMOVHPDrm = 14222,
  VMOVHPSZ128mr = 14223,
  VMOVHPSZ128rm = 14224,
  VMOVHPSmr = 14225,
  VMOVHPSrm = 14226,
  VMOVLHPSZrr = 14227,
  VMOVLHPSrr = 14228,
  VMOVLPDZ128mr = 14229,
  VMOVLPDZ128rm = 14230,
  VMOVLPDmr = 14231,
  VMOVLPDrm = 14232,
  VMOVLPSZ128mr = 14233,
  VMOVLPSZ128rm = 14234,
  VMOVLPSmr = 14235,
  VMOVLPSrm = 14236,
  VMOVMSKPDYrr = 14237,
  VMOVMSKPDrr = 14238,
  VMOVMSKPSYrr = 14239,
  VMOVMSKPSrr = 14240,
  VMOVNTDQAYrm = 14241,
  VMOVNTDQAZ128rm = 14242,
  VMOVNTDQAZ256rm = 14243,
  VMOVNTDQAZrm = 14244,
  VMOVNTDQArm = 14245,
  VMOVNTDQYmr = 14246,
  VMOVNTDQZ128mr = 14247,
  VMOVNTDQZ256mr = 14248,
  VMOVNTDQZmr = 14249,
  VMOVNTDQmr = 14250,
  VMOVNTPDYmr = 14251,
  VMOVNTPDZ128mr = 14252,
  VMOVNTPDZ256mr = 14253,
  VMOVNTPDZmr = 14254,
  VMOVNTPDmr = 14255,
  VMOVNTPSYmr = 14256,
  VMOVNTPSZ128mr = 14257,
  VMOVNTPSZ256mr = 14258,
  VMOVNTPSZmr = 14259,
  VMOVNTPSmr = 14260,
  VMOVPDI2DIZmr = 14261,
  VMOVPDI2DIZrr = 14262,
  VMOVPDI2DImr = 14263,
  VMOVPDI2DIrr = 14264,
  VMOVPQI2QIZmr = 14265,
  VMOVPQI2QIZrr = 14266,
  VMOVPQI2QImr = 14267,
  VMOVPQI2QIrr = 14268,
  VMOVPQIto64Zmr = 14269,
  VMOVPQIto64Zrr = 14270,
  VMOVPQIto64mr = 14271,
  VMOVPQIto64rr = 14272,
  VMOVQI2PQIZrm = 14273,
  VMOVQI2PQIrm = 14274,
  VMOVRSBZ128m = 14275,
  VMOVRSBZ128mk = 14276,
  VMOVRSBZ128mkz = 14277,
  VMOVRSBZ256m = 14278,
  VMOVRSBZ256mk = 14279,
  VMOVRSBZ256mkz = 14280,
  VMOVRSBZm = 14281,
  VMOVRSBZmk = 14282,
  VMOVRSBZmkz = 14283,
  VMOVRSDZ128m = 14284,
  VMOVRSDZ128mk = 14285,
  VMOVRSDZ128mkz = 14286,
  VMOVRSDZ256m = 14287,
  VMOVRSDZ256mk = 14288,
  VMOVRSDZ256mkz = 14289,
  VMOVRSDZm = 14290,
  VMOVRSDZmk = 14291,
  VMOVRSDZmkz = 14292,
  VMOVRSQZ128m = 14293,
  VMOVRSQZ128mk = 14294,
  VMOVRSQZ128mkz = 14295,
  VMOVRSQZ256m = 14296,
  VMOVRSQZ256mk = 14297,
  VMOVRSQZ256mkz = 14298,
  VMOVRSQZm = 14299,
  VMOVRSQZmk = 14300,
  VMOVRSQZmkz = 14301,
  VMOVRSWZ128m = 14302,
  VMOVRSWZ128mk = 14303,
  VMOVRSWZ128mkz = 14304,
  VMOVRSWZ256m = 14305,
  VMOVRSWZ256mk = 14306,
  VMOVRSWZ256mkz = 14307,
  VMOVRSWZm = 14308,
  VMOVRSWZmk = 14309,
  VMOVRSWZmkz = 14310,
  VMOVSDZmr = 14311,
  VMOVSDZmrk = 14312,
  VMOVSDZrm = 14313,
  VMOVSDZrm_alt = 14314,
  VMOVSDZrmk = 14315,
  VMOVSDZrmkz = 14316,
  VMOVSDZrr = 14317,
  VMOVSDZrr_REV = 14318,
  VMOVSDZrrk = 14319,
  VMOVSDZrrk_REV = 14320,
  VMOVSDZrrkz = 14321,
  VMOVSDZrrkz_REV = 14322,
  VMOVSDmr = 14323,
  VMOVSDrm = 14324,
  VMOVSDrm_alt = 14325,
  VMOVSDrr = 14326,
  VMOVSDrr_REV = 14327,
  VMOVSDto64Zrr = 14328,
  VMOVSDto64rr = 14329,
  VMOVSH2Wrr = 14330,
  VMOVSHDUPYrm = 14331,
  VMOVSHDUPYrr = 14332,
  VMOVSHDUPZ128rm = 14333,
  VMOVSHDUPZ128rmk = 14334,
  VMOVSHDUPZ128rmkz = 14335,
  VMOVSHDUPZ128rr = 14336,
  VMOVSHDUPZ128rrk = 14337,
  VMOVSHDUPZ128rrkz = 14338,
  VMOVSHDUPZ256rm = 14339,
  VMOVSHDUPZ256rmk = 14340,
  VMOVSHDUPZ256rmkz = 14341,
  VMOVSHDUPZ256rr = 14342,
  VMOVSHDUPZ256rrk = 14343,
  VMOVSHDUPZ256rrkz = 14344,
  VMOVSHDUPZrm = 14345,
  VMOVSHDUPZrmk = 14346,
  VMOVSHDUPZrmkz = 14347,
  VMOVSHDUPZrr = 14348,
  VMOVSHDUPZrrk = 14349,
  VMOVSHDUPZrrkz = 14350,
  VMOVSHDUPrm = 14351,
  VMOVSHDUPrr = 14352,
  VMOVSHZmr = 14353,
  VMOVSHZmrk = 14354,
  VMOVSHZrm = 14355,
  VMOVSHZrm_alt = 14356,
  VMOVSHZrmk = 14357,
  VMOVSHZrmkz = 14358,
  VMOVSHZrr = 14359,
  VMOVSHZrr_REV = 14360,
  VMOVSHZrrk = 14361,
  VMOVSHZrrk_REV = 14362,
  VMOVSHZrrkz = 14363,
  VMOVSHZrrkz_REV = 14364,
  VMOVSHtoW64rr = 14365,
  VMOVSLDUPYrm = 14366,
  VMOVSLDUPYrr = 14367,
  VMOVSLDUPZ128rm = 14368,
  VMOVSLDUPZ128rmk = 14369,
  VMOVSLDUPZ128rmkz = 14370,
  VMOVSLDUPZ128rr = 14371,
  VMOVSLDUPZ128rrk = 14372,
  VMOVSLDUPZ128rrkz = 14373,
  VMOVSLDUPZ256rm = 14374,
  VMOVSLDUPZ256rmk = 14375,
  VMOVSLDUPZ256rmkz = 14376,
  VMOVSLDUPZ256rr = 14377,
  VMOVSLDUPZ256rrk = 14378,
  VMOVSLDUPZ256rrkz = 14379,
  VMOVSLDUPZrm = 14380,
  VMOVSLDUPZrmk = 14381,
  VMOVSLDUPZrmkz = 14382,
  VMOVSLDUPZrr = 14383,
  VMOVSLDUPZrrk = 14384,
  VMOVSLDUPZrrkz = 14385,
  VMOVSLDUPrm = 14386,
  VMOVSLDUPrr = 14387,
  VMOVSS2DIZrr = 14388,
  VMOVSS2DIrr = 14389,
  VMOVSSZmr = 14390,
  VMOVSSZmrk = 14391,
  VMOVSSZrm = 14392,
  VMOVSSZrm_alt = 14393,
  VMOVSSZrmk = 14394,
  VMOVSSZrmkz = 14395,
  VMOVSSZrr = 14396,
  VMOVSSZrr_REV = 14397,
  VMOVSSZrrk = 14398,
  VMOVSSZrrk_REV = 14399,
  VMOVSSZrrkz = 14400,
  VMOVSSZrrkz_REV = 14401,
  VMOVSSmr = 14402,
  VMOVSSrm = 14403,
  VMOVSSrm_alt = 14404,
  VMOVSSrr = 14405,
  VMOVSSrr_REV = 14406,
  VMOVUPDYmr = 14407,
  VMOVUPDYrm = 14408,
  VMOVUPDYrr = 14409,
  VMOVUPDYrr_REV = 14410,
  VMOVUPDZ128mr = 14411,
  VMOVUPDZ128mrk = 14412,
  VMOVUPDZ128rm = 14413,
  VMOVUPDZ128rmk = 14414,
  VMOVUPDZ128rmkz = 14415,
  VMOVUPDZ128rr = 14416,
  VMOVUPDZ128rr_REV = 14417,
  VMOVUPDZ128rrk = 14418,
  VMOVUPDZ128rrk_REV = 14419,
  VMOVUPDZ128rrkz = 14420,
  VMOVUPDZ128rrkz_REV = 14421,
  VMOVUPDZ256mr = 14422,
  VMOVUPDZ256mrk = 14423,
  VMOVUPDZ256rm = 14424,
  VMOVUPDZ256rmk = 14425,
  VMOVUPDZ256rmkz = 14426,
  VMOVUPDZ256rr = 14427,
  VMOVUPDZ256rr_REV = 14428,
  VMOVUPDZ256rrk = 14429,
  VMOVUPDZ256rrk_REV = 14430,
  VMOVUPDZ256rrkz = 14431,
  VMOVUPDZ256rrkz_REV = 14432,
  VMOVUPDZmr = 14433,
  VMOVUPDZmrk = 14434,
  VMOVUPDZrm = 14435,
  VMOVUPDZrmk = 14436,
  VMOVUPDZrmkz = 14437,
  VMOVUPDZrr = 14438,
  VMOVUPDZrr_REV = 14439,
  VMOVUPDZrrk = 14440,
  VMOVUPDZrrk_REV = 14441,
  VMOVUPDZrrkz = 14442,
  VMOVUPDZrrkz_REV = 14443,
  VMOVUPDmr = 14444,
  VMOVUPDrm = 14445,
  VMOVUPDrr = 14446,
  VMOVUPDrr_REV = 14447,
  VMOVUPSYmr = 14448,
  VMOVUPSYrm = 14449,
  VMOVUPSYrr = 14450,
  VMOVUPSYrr_REV = 14451,
  VMOVUPSZ128mr = 14452,
  VMOVUPSZ128mrk = 14453,
  VMOVUPSZ128rm = 14454,
  VMOVUPSZ128rmk = 14455,
  VMOVUPSZ128rmkz = 14456,
  VMOVUPSZ128rr = 14457,
  VMOVUPSZ128rr_REV = 14458,
  VMOVUPSZ128rrk = 14459,
  VMOVUPSZ128rrk_REV = 14460,
  VMOVUPSZ128rrkz = 14461,
  VMOVUPSZ128rrkz_REV = 14462,
  VMOVUPSZ256mr = 14463,
  VMOVUPSZ256mrk = 14464,
  VMOVUPSZ256rm = 14465,
  VMOVUPSZ256rmk = 14466,
  VMOVUPSZ256rmkz = 14467,
  VMOVUPSZ256rr = 14468,
  VMOVUPSZ256rr_REV = 14469,
  VMOVUPSZ256rrk = 14470,
  VMOVUPSZ256rrk_REV = 14471,
  VMOVUPSZ256rrkz = 14472,
  VMOVUPSZ256rrkz_REV = 14473,
  VMOVUPSZmr = 14474,
  VMOVUPSZmrk = 14475,
  VMOVUPSZrm = 14476,
  VMOVUPSZrmk = 14477,
  VMOVUPSZrmkz = 14478,
  VMOVUPSZrr = 14479,
  VMOVUPSZrr_REV = 14480,
  VMOVUPSZrrk = 14481,
  VMOVUPSZrrk_REV = 14482,
  VMOVUPSZrrkz = 14483,
  VMOVUPSZrrkz_REV = 14484,
  VMOVUPSmr = 14485,
  VMOVUPSrm = 14486,
  VMOVUPSrr = 14487,
  VMOVUPSrr_REV = 14488,
  VMOVW2SHrr = 14489,
  VMOVW64toSHrr = 14490,
  VMOVWmr = 14491,
  VMOVWrm = 14492,
  VMOVZPDILo2PDIZmr = 14493,
  VMOVZPDILo2PDIZrm = 14494,
  VMOVZPDILo2PDIZrr = 14495,
  VMOVZPDILo2PDIZrr2 = 14496,
  VMOVZPQILo2PQIZrr = 14497,
  VMOVZPQILo2PQIrr = 14498,
  VMOVZPWILo2PWIZmr = 14499,
  VMOVZPWILo2PWIZrm = 14500,
  VMOVZPWILo2PWIZrr = 14501,
  VMOVZPWILo2PWIZrr2 = 14502,
  VMPSADBWYrmi = 14503,
  VMPSADBWYrri = 14504,
  VMPSADBWZ128rmi = 14505,
  VMPSADBWZ128rmik = 14506,
  VMPSADBWZ128rmikz = 14507,
  VMPSADBWZ128rri = 14508,
  VMPSADBWZ128rrik = 14509,
  VMPSADBWZ128rrikz = 14510,
  VMPSADBWZ256rmi = 14511,
  VMPSADBWZ256rmik = 14512,
  VMPSADBWZ256rmikz = 14513,
  VMPSADBWZ256rri = 14514,
  VMPSADBWZ256rrik = 14515,
  VMPSADBWZ256rrikz = 14516,
  VMPSADBWZrmi = 14517,
  VMPSADBWZrmik = 14518,
  VMPSADBWZrmikz = 14519,
  VMPSADBWZrri = 14520,
  VMPSADBWZrrik = 14521,
  VMPSADBWZrrikz = 14522,
  VMPSADBWrmi = 14523,
  VMPSADBWrri = 14524,
  VMPTRLDm = 14525,
  VMPTRSTm = 14526,
  VMREAD32mr = 14527,
  VMREAD32rr = 14528,
  VMREAD64mr = 14529,
  VMREAD64rr = 14530,
  VMRESUME = 14531,
  VMRUN32 = 14532,
  VMRUN64 = 14533,
  VMSAVE32 = 14534,
  VMSAVE64 = 14535,
  VMULBF16Z128rm = 14536,
  VMULBF16Z128rmb = 14537,
  VMULBF16Z128rmbk = 14538,
  VMULBF16Z128rmbkz = 14539,
  VMULBF16Z128rmk = 14540,
  VMULBF16Z128rmkz = 14541,
  VMULBF16Z128rr = 14542,
  VMULBF16Z128rrk = 14543,
  VMULBF16Z128rrkz = 14544,
  VMULBF16Z256rm = 14545,
  VMULBF16Z256rmb = 14546,
  VMULBF16Z256rmbk = 14547,
  VMULBF16Z256rmbkz = 14548,
  VMULBF16Z256rmk = 14549,
  VMULBF16Z256rmkz = 14550,
  VMULBF16Z256rr = 14551,
  VMULBF16Z256rrk = 14552,
  VMULBF16Z256rrkz = 14553,
  VMULBF16Zrm = 14554,
  VMULBF16Zrmb = 14555,
  VMULBF16Zrmbk = 14556,
  VMULBF16Zrmbkz = 14557,
  VMULBF16Zrmk = 14558,
  VMULBF16Zrmkz = 14559,
  VMULBF16Zrr = 14560,
  VMULBF16Zrrk = 14561,
  VMULBF16Zrrkz = 14562,
  VMULPDYrm = 14563,
  VMULPDYrr = 14564,
  VMULPDZ128rm = 14565,
  VMULPDZ128rmb = 14566,
  VMULPDZ128rmbk = 14567,
  VMULPDZ128rmbkz = 14568,
  VMULPDZ128rmk = 14569,
  VMULPDZ128rmkz = 14570,
  VMULPDZ128rr = 14571,
  VMULPDZ128rrk = 14572,
  VMULPDZ128rrkz = 14573,
  VMULPDZ256rm = 14574,
  VMULPDZ256rmb = 14575,
  VMULPDZ256rmbk = 14576,
  VMULPDZ256rmbkz = 14577,
  VMULPDZ256rmk = 14578,
  VMULPDZ256rmkz = 14579,
  VMULPDZ256rr = 14580,
  VMULPDZ256rrb = 14581,
  VMULPDZ256rrbk = 14582,
  VMULPDZ256rrbkz = 14583,
  VMULPDZ256rrk = 14584,
  VMULPDZ256rrkz = 14585,
  VMULPDZrm = 14586,
  VMULPDZrmb = 14587,
  VMULPDZrmbk = 14588,
  VMULPDZrmbkz = 14589,
  VMULPDZrmk = 14590,
  VMULPDZrmkz = 14591,
  VMULPDZrr = 14592,
  VMULPDZrrb = 14593,
  VMULPDZrrbk = 14594,
  VMULPDZrrbkz = 14595,
  VMULPDZrrk = 14596,
  VMULPDZrrkz = 14597,
  VMULPDrm = 14598,
  VMULPDrr = 14599,
  VMULPHZ128rm = 14600,
  VMULPHZ128rmb = 14601,
  VMULPHZ128rmbk = 14602,
  VMULPHZ128rmbkz = 14603,
  VMULPHZ128rmk = 14604,
  VMULPHZ128rmkz = 14605,
  VMULPHZ128rr = 14606,
  VMULPHZ128rrk = 14607,
  VMULPHZ128rrkz = 14608,
  VMULPHZ256rm = 14609,
  VMULPHZ256rmb = 14610,
  VMULPHZ256rmbk = 14611,
  VMULPHZ256rmbkz = 14612,
  VMULPHZ256rmk = 14613,
  VMULPHZ256rmkz = 14614,
  VMULPHZ256rr = 14615,
  VMULPHZ256rrb = 14616,
  VMULPHZ256rrbk = 14617,
  VMULPHZ256rrbkz = 14618,
  VMULPHZ256rrk = 14619,
  VMULPHZ256rrkz = 14620,
  VMULPHZrm = 14621,
  VMULPHZrmb = 14622,
  VMULPHZrmbk = 14623,
  VMULPHZrmbkz = 14624,
  VMULPHZrmk = 14625,
  VMULPHZrmkz = 14626,
  VMULPHZrr = 14627,
  VMULPHZrrb = 14628,
  VMULPHZrrbk = 14629,
  VMULPHZrrbkz = 14630,
  VMULPHZrrk = 14631,
  VMULPHZrrkz = 14632,
  VMULPSYrm = 14633,
  VMULPSYrr = 14634,
  VMULPSZ128rm = 14635,
  VMULPSZ128rmb = 14636,
  VMULPSZ128rmbk = 14637,
  VMULPSZ128rmbkz = 14638,
  VMULPSZ128rmk = 14639,
  VMULPSZ128rmkz = 14640,
  VMULPSZ128rr = 14641,
  VMULPSZ128rrk = 14642,
  VMULPSZ128rrkz = 14643,
  VMULPSZ256rm = 14644,
  VMULPSZ256rmb = 14645,
  VMULPSZ256rmbk = 14646,
  VMULPSZ256rmbkz = 14647,
  VMULPSZ256rmk = 14648,
  VMULPSZ256rmkz = 14649,
  VMULPSZ256rr = 14650,
  VMULPSZ256rrb = 14651,
  VMULPSZ256rrbk = 14652,
  VMULPSZ256rrbkz = 14653,
  VMULPSZ256rrk = 14654,
  VMULPSZ256rrkz = 14655,
  VMULPSZrm = 14656,
  VMULPSZrmb = 14657,
  VMULPSZrmbk = 14658,
  VMULPSZrmbkz = 14659,
  VMULPSZrmk = 14660,
  VMULPSZrmkz = 14661,
  VMULPSZrr = 14662,
  VMULPSZrrb = 14663,
  VMULPSZrrbk = 14664,
  VMULPSZrrbkz = 14665,
  VMULPSZrrk = 14666,
  VMULPSZrrkz = 14667,
  VMULPSrm = 14668,
  VMULPSrr = 14669,
  VMULSDZrm = 14670,
  VMULSDZrm_Int = 14671,
  VMULSDZrmk_Int = 14672,
  VMULSDZrmkz_Int = 14673,
  VMULSDZrr = 14674,
  VMULSDZrr_Int = 14675,
  VMULSDZrrb_Int = 14676,
  VMULSDZrrbk_Int = 14677,
  VMULSDZrrbkz_Int = 14678,
  VMULSDZrrk_Int = 14679,
  VMULSDZrrkz_Int = 14680,
  VMULSDrm = 14681,
  VMULSDrm_Int = 14682,
  VMULSDrr = 14683,
  VMULSDrr_Int = 14684,
  VMULSHZrm = 14685,
  VMULSHZrm_Int = 14686,
  VMULSHZrmk_Int = 14687,
  VMULSHZrmkz_Int = 14688,
  VMULSHZrr = 14689,
  VMULSHZrr_Int = 14690,
  VMULSHZrrb_Int = 14691,
  VMULSHZrrbk_Int = 14692,
  VMULSHZrrbkz_Int = 14693,
  VMULSHZrrk_Int = 14694,
  VMULSHZrrkz_Int = 14695,
  VMULSSZrm = 14696,
  VMULSSZrm_Int = 14697,
  VMULSSZrmk_Int = 14698,
  VMULSSZrmkz_Int = 14699,
  VMULSSZrr = 14700,
  VMULSSZrr_Int = 14701,
  VMULSSZrrb_Int = 14702,
  VMULSSZrrbk_Int = 14703,
  VMULSSZrrbkz_Int = 14704,
  VMULSSZrrk_Int = 14705,
  VMULSSZrrkz_Int = 14706,
  VMULSSrm = 14707,
  VMULSSrm_Int = 14708,
  VMULSSrr = 14709,
  VMULSSrr_Int = 14710,
  VMWRITE32rm = 14711,
  VMWRITE32rr = 14712,
  VMWRITE64rm = 14713,
  VMWRITE64rr = 14714,
  VMXOFF = 14715,
  VMXON = 14716,
  VORPDYrm = 14717,
  VORPDYrr = 14718,
  VORPDZ128rm = 14719,
  VORPDZ128rmb = 14720,
  VORPDZ128rmbk = 14721,
  VORPDZ128rmbkz = 14722,
  VORPDZ128rmk = 14723,
  VORPDZ128rmkz = 14724,
  VORPDZ128rr = 14725,
  VORPDZ128rrk = 14726,
  VORPDZ128rrkz = 14727,
  VORPDZ256rm = 14728,
  VORPDZ256rmb = 14729,
  VORPDZ256rmbk = 14730,
  VORPDZ256rmbkz = 14731,
  VORPDZ256rmk = 14732,
  VORPDZ256rmkz = 14733,
  VORPDZ256rr = 14734,
  VORPDZ256rrk = 14735,
  VORPDZ256rrkz = 14736,
  VORPDZrm = 14737,
  VORPDZrmb = 14738,
  VORPDZrmbk = 14739,
  VORPDZrmbkz = 14740,
  VORPDZrmk = 14741,
  VORPDZrmkz = 14742,
  VORPDZrr = 14743,
  VORPDZrrk = 14744,
  VORPDZrrkz = 14745,
  VORPDrm = 14746,
  VORPDrr = 14747,
  VORPSYrm = 14748,
  VORPSYrr = 14749,
  VORPSZ128rm = 14750,
  VORPSZ128rmb = 14751,
  VORPSZ128rmbk = 14752,
  VORPSZ128rmbkz = 14753,
  VORPSZ128rmk = 14754,
  VORPSZ128rmkz = 14755,
  VORPSZ128rr = 14756,
  VORPSZ128rrk = 14757,
  VORPSZ128rrkz = 14758,
  VORPSZ256rm = 14759,
  VORPSZ256rmb = 14760,
  VORPSZ256rmbk = 14761,
  VORPSZ256rmbkz = 14762,
  VORPSZ256rmk = 14763,
  VORPSZ256rmkz = 14764,
  VORPSZ256rr = 14765,
  VORPSZ256rrk = 14766,
  VORPSZ256rrkz = 14767,
  VORPSZrm = 14768,
  VORPSZrmb = 14769,
  VORPSZrmbk = 14770,
  VORPSZrmbkz = 14771,
  VORPSZrmk = 14772,
  VORPSZrmkz = 14773,
  VORPSZrr = 14774,
  VORPSZrrk = 14775,
  VORPSZrrkz = 14776,
  VORPSrm = 14777,
  VORPSrr = 14778,
  VP2INTERSECTDZ128rm = 14779,
  VP2INTERSECTDZ128rmb = 14780,
  VP2INTERSECTDZ128rr = 14781,
  VP2INTERSECTDZ256rm = 14782,
  VP2INTERSECTDZ256rmb = 14783,
  VP2INTERSECTDZ256rr = 14784,
  VP2INTERSECTDZrm = 14785,
  VP2INTERSECTDZrmb = 14786,
  VP2INTERSECTDZrr = 14787,
  VP2INTERSECTQZ128rm = 14788,
  VP2INTERSECTQZ128rmb = 14789,
  VP2INTERSECTQZ128rr = 14790,
  VP2INTERSECTQZ256rm = 14791,
  VP2INTERSECTQZ256rmb = 14792,
  VP2INTERSECTQZ256rr = 14793,
  VP2INTERSECTQZrm = 14794,
  VP2INTERSECTQZrmb = 14795,
  VP2INTERSECTQZrr = 14796,
  VP4DPWSSDSrm = 14797,
  VP4DPWSSDSrmk = 14798,
  VP4DPWSSDSrmkz = 14799,
  VP4DPWSSDrm = 14800,
  VP4DPWSSDrmk = 14801,
  VP4DPWSSDrmkz = 14802,
  VPABSBYrm = 14803,
  VPABSBYrr = 14804,
  VPABSBZ128rm = 14805,
  VPABSBZ128rmk = 14806,
  VPABSBZ128rmkz = 14807,
  VPABSBZ128rr = 14808,
  VPABSBZ128rrk = 14809,
  VPABSBZ128rrkz = 14810,
  VPABSBZ256rm = 14811,
  VPABSBZ256rmk = 14812,
  VPABSBZ256rmkz = 14813,
  VPABSBZ256rr = 14814,
  VPABSBZ256rrk = 14815,
  VPABSBZ256rrkz = 14816,
  VPABSBZrm = 14817,
  VPABSBZrmk = 14818,
  VPABSBZrmkz = 14819,
  VPABSBZrr = 14820,
  VPABSBZrrk = 14821,
  VPABSBZrrkz = 14822,
  VPABSBrm = 14823,
  VPABSBrr = 14824,
  VPABSDYrm = 14825,
  VPABSDYrr = 14826,
  VPABSDZ128rm = 14827,
  VPABSDZ128rmb = 14828,
  VPABSDZ128rmbk = 14829,
  VPABSDZ128rmbkz = 14830,
  VPABSDZ128rmk = 14831,
  VPABSDZ128rmkz = 14832,
  VPABSDZ128rr = 14833,
  VPABSDZ128rrk = 14834,
  VPABSDZ128rrkz = 14835,
  VPABSDZ256rm = 14836,
  VPABSDZ256rmb = 14837,
  VPABSDZ256rmbk = 14838,
  VPABSDZ256rmbkz = 14839,
  VPABSDZ256rmk = 14840,
  VPABSDZ256rmkz = 14841,
  VPABSDZ256rr = 14842,
  VPABSDZ256rrk = 14843,
  VPABSDZ256rrkz = 14844,
  VPABSDZrm = 14845,
  VPABSDZrmb = 14846,
  VPABSDZrmbk = 14847,
  VPABSDZrmbkz = 14848,
  VPABSDZrmk = 14849,
  VPABSDZrmkz = 14850,
  VPABSDZrr = 14851,
  VPABSDZrrk = 14852,
  VPABSDZrrkz = 14853,
  VPABSDrm = 14854,
  VPABSDrr = 14855,
  VPABSQZ128rm = 14856,
  VPABSQZ128rmb = 14857,
  VPABSQZ128rmbk = 14858,
  VPABSQZ128rmbkz = 14859,
  VPABSQZ128rmk = 14860,
  VPABSQZ128rmkz = 14861,
  VPABSQZ128rr = 14862,
  VPABSQZ128rrk = 14863,
  VPABSQZ128rrkz = 14864,
  VPABSQZ256rm = 14865,
  VPABSQZ256rmb = 14866,
  VPABSQZ256rmbk = 14867,
  VPABSQZ256rmbkz = 14868,
  VPABSQZ256rmk = 14869,
  VPABSQZ256rmkz = 14870,
  VPABSQZ256rr = 14871,
  VPABSQZ256rrk = 14872,
  VPABSQZ256rrkz = 14873,
  VPABSQZrm = 14874,
  VPABSQZrmb = 14875,
  VPABSQZrmbk = 14876,
  VPABSQZrmbkz = 14877,
  VPABSQZrmk = 14878,
  VPABSQZrmkz = 14879,
  VPABSQZrr = 14880,
  VPABSQZrrk = 14881,
  VPABSQZrrkz = 14882,
  VPABSWYrm = 14883,
  VPABSWYrr = 14884,
  VPABSWZ128rm = 14885,
  VPABSWZ128rmk = 14886,
  VPABSWZ128rmkz = 14887,
  VPABSWZ128rr = 14888,
  VPABSWZ128rrk = 14889,
  VPABSWZ128rrkz = 14890,
  VPABSWZ256rm = 14891,
  VPABSWZ256rmk = 14892,
  VPABSWZ256rmkz = 14893,
  VPABSWZ256rr = 14894,
  VPABSWZ256rrk = 14895,
  VPABSWZ256rrkz = 14896,
  VPABSWZrm = 14897,
  VPABSWZrmk = 14898,
  VPABSWZrmkz = 14899,
  VPABSWZrr = 14900,
  VPABSWZrrk = 14901,
  VPABSWZrrkz = 14902,
  VPABSWrm = 14903,
  VPABSWrr = 14904,
  VPACKSSDWYrm = 14905,
  VPACKSSDWYrr = 14906,
  VPACKSSDWZ128rm = 14907,
  VPACKSSDWZ128rmb = 14908,
  VPACKSSDWZ128rmbk = 14909,
  VPACKSSDWZ128rmbkz = 14910,
  VPACKSSDWZ128rmk = 14911,
  VPACKSSDWZ128rmkz = 14912,
  VPACKSSDWZ128rr = 14913,
  VPACKSSDWZ128rrk = 14914,
  VPACKSSDWZ128rrkz = 14915,
  VPACKSSDWZ256rm = 14916,
  VPACKSSDWZ256rmb = 14917,
  VPACKSSDWZ256rmbk = 14918,
  VPACKSSDWZ256rmbkz = 14919,
  VPACKSSDWZ256rmk = 14920,
  VPACKSSDWZ256rmkz = 14921,
  VPACKSSDWZ256rr = 14922,
  VPACKSSDWZ256rrk = 14923,
  VPACKSSDWZ256rrkz = 14924,
  VPACKSSDWZrm = 14925,
  VPACKSSDWZrmb = 14926,
  VPACKSSDWZrmbk = 14927,
  VPACKSSDWZrmbkz = 14928,
  VPACKSSDWZrmk = 14929,
  VPACKSSDWZrmkz = 14930,
  VPACKSSDWZrr = 14931,
  VPACKSSDWZrrk = 14932,
  VPACKSSDWZrrkz = 14933,
  VPACKSSDWrm = 14934,
  VPACKSSDWrr = 14935,
  VPACKSSWBYrm = 14936,
  VPACKSSWBYrr = 14937,
  VPACKSSWBZ128rm = 14938,
  VPACKSSWBZ128rmk = 14939,
  VPACKSSWBZ128rmkz = 14940,
  VPACKSSWBZ128rr = 14941,
  VPACKSSWBZ128rrk = 14942,
  VPACKSSWBZ128rrkz = 14943,
  VPACKSSWBZ256rm = 14944,
  VPACKSSWBZ256rmk = 14945,
  VPACKSSWBZ256rmkz = 14946,
  VPACKSSWBZ256rr = 14947,
  VPACKSSWBZ256rrk = 14948,
  VPACKSSWBZ256rrkz = 14949,
  VPACKSSWBZrm = 14950,
  VPACKSSWBZrmk = 14951,
  VPACKSSWBZrmkz = 14952,
  VPACKSSWBZrr = 14953,
  VPACKSSWBZrrk = 14954,
  VPACKSSWBZrrkz = 14955,
  VPACKSSWBrm = 14956,
  VPACKSSWBrr = 14957,
  VPACKUSDWYrm = 14958,
  VPACKUSDWYrr = 14959,
  VPACKUSDWZ128rm = 14960,
  VPACKUSDWZ128rmb = 14961,
  VPACKUSDWZ128rmbk = 14962,
  VPACKUSDWZ128rmbkz = 14963,
  VPACKUSDWZ128rmk = 14964,
  VPACKUSDWZ128rmkz = 14965,
  VPACKUSDWZ128rr = 14966,
  VPACKUSDWZ128rrk = 14967,
  VPACKUSDWZ128rrkz = 14968,
  VPACKUSDWZ256rm = 14969,
  VPACKUSDWZ256rmb = 14970,
  VPACKUSDWZ256rmbk = 14971,
  VPACKUSDWZ256rmbkz = 14972,
  VPACKUSDWZ256rmk = 14973,
  VPACKUSDWZ256rmkz = 14974,
  VPACKUSDWZ256rr = 14975,
  VPACKUSDWZ256rrk = 14976,
  VPACKUSDWZ256rrkz = 14977,
  VPACKUSDWZrm = 14978,
  VPACKUSDWZrmb = 14979,
  VPACKUSDWZrmbk = 14980,
  VPACKUSDWZrmbkz = 14981,
  VPACKUSDWZrmk = 14982,
  VPACKUSDWZrmkz = 14983,
  VPACKUSDWZrr = 14984,
  VPACKUSDWZrrk = 14985,
  VPACKUSDWZrrkz = 14986,
  VPACKUSDWrm = 14987,
  VPACKUSDWrr = 14988,
  VPACKUSWBYrm = 14989,
  VPACKUSWBYrr = 14990,
  VPACKUSWBZ128rm = 14991,
  VPACKUSWBZ128rmk = 14992,
  VPACKUSWBZ128rmkz = 14993,
  VPACKUSWBZ128rr = 14994,
  VPACKUSWBZ128rrk = 14995,
  VPACKUSWBZ128rrkz = 14996,
  VPACKUSWBZ256rm = 14997,
  VPACKUSWBZ256rmk = 14998,
  VPACKUSWBZ256rmkz = 14999,
  VPACKUSWBZ256rr = 15000,
  VPACKUSWBZ256rrk = 15001,
  VPACKUSWBZ256rrkz = 15002,
  VPACKUSWBZrm = 15003,
  VPACKUSWBZrmk = 15004,
  VPACKUSWBZrmkz = 15005,
  VPACKUSWBZrr = 15006,
  VPACKUSWBZrrk = 15007,
  VPACKUSWBZrrkz = 15008,
  VPACKUSWBrm = 15009,
  VPACKUSWBrr = 15010,
  VPADDBYrm = 15011,
  VPADDBYrr = 15012,
  VPADDBZ128rm = 15013,
  VPADDBZ128rmk = 15014,
  VPADDBZ128rmkz = 15015,
  VPADDBZ128rr = 15016,
  VPADDBZ128rrk = 15017,
  VPADDBZ128rrkz = 15018,
  VPADDBZ256rm = 15019,
  VPADDBZ256rmk = 15020,
  VPADDBZ256rmkz = 15021,
  VPADDBZ256rr = 15022,
  VPADDBZ256rrk = 15023,
  VPADDBZ256rrkz = 15024,
  VPADDBZrm = 15025,
  VPADDBZrmk = 15026,
  VPADDBZrmkz = 15027,
  VPADDBZrr = 15028,
  VPADDBZrrk = 15029,
  VPADDBZrrkz = 15030,
  VPADDBrm = 15031,
  VPADDBrr = 15032,
  VPADDDYrm = 15033,
  VPADDDYrr = 15034,
  VPADDDZ128rm = 15035,
  VPADDDZ128rmb = 15036,
  VPADDDZ128rmbk = 15037,
  VPADDDZ128rmbkz = 15038,
  VPADDDZ128rmk = 15039,
  VPADDDZ128rmkz = 15040,
  VPADDDZ128rr = 15041,
  VPADDDZ128rrk = 15042,
  VPADDDZ128rrkz = 15043,
  VPADDDZ256rm = 15044,
  VPADDDZ256rmb = 15045,
  VPADDDZ256rmbk = 15046,
  VPADDDZ256rmbkz = 15047,
  VPADDDZ256rmk = 15048,
  VPADDDZ256rmkz = 15049,
  VPADDDZ256rr = 15050,
  VPADDDZ256rrk = 15051,
  VPADDDZ256rrkz = 15052,
  VPADDDZrm = 15053,
  VPADDDZrmb = 15054,
  VPADDDZrmbk = 15055,
  VPADDDZrmbkz = 15056,
  VPADDDZrmk = 15057,
  VPADDDZrmkz = 15058,
  VPADDDZrr = 15059,
  VPADDDZrrk = 15060,
  VPADDDZrrkz = 15061,
  VPADDDrm = 15062,
  VPADDDrr = 15063,
  VPADDQYrm = 15064,
  VPADDQYrr = 15065,
  VPADDQZ128rm = 15066,
  VPADDQZ128rmb = 15067,
  VPADDQZ128rmbk = 15068,
  VPADDQZ128rmbkz = 15069,
  VPADDQZ128rmk = 15070,
  VPADDQZ128rmkz = 15071,
  VPADDQZ128rr = 15072,
  VPADDQZ128rrk = 15073,
  VPADDQZ128rrkz = 15074,
  VPADDQZ256rm = 15075,
  VPADDQZ256rmb = 15076,
  VPADDQZ256rmbk = 15077,
  VPADDQZ256rmbkz = 15078,
  VPADDQZ256rmk = 15079,
  VPADDQZ256rmkz = 15080,
  VPADDQZ256rr = 15081,
  VPADDQZ256rrk = 15082,
  VPADDQZ256rrkz = 15083,
  VPADDQZrm = 15084,
  VPADDQZrmb = 15085,
  VPADDQZrmbk = 15086,
  VPADDQZrmbkz = 15087,
  VPADDQZrmk = 15088,
  VPADDQZrmkz = 15089,
  VPADDQZrr = 15090,
  VPADDQZrrk = 15091,
  VPADDQZrrkz = 15092,
  VPADDQrm = 15093,
  VPADDQrr = 15094,
  VPADDSBYrm = 15095,
  VPADDSBYrr = 15096,
  VPADDSBZ128rm = 15097,
  VPADDSBZ128rmk = 15098,
  VPADDSBZ128rmkz = 15099,
  VPADDSBZ128rr = 15100,
  VPADDSBZ128rrk = 15101,
  VPADDSBZ128rrkz = 15102,
  VPADDSBZ256rm = 15103,
  VPADDSBZ256rmk = 15104,
  VPADDSBZ256rmkz = 15105,
  VPADDSBZ256rr = 15106,
  VPADDSBZ256rrk = 15107,
  VPADDSBZ256rrkz = 15108,
  VPADDSBZrm = 15109,
  VPADDSBZrmk = 15110,
  VPADDSBZrmkz = 15111,
  VPADDSBZrr = 15112,
  VPADDSBZrrk = 15113,
  VPADDSBZrrkz = 15114,
  VPADDSBrm = 15115,
  VPADDSBrr = 15116,
  VPADDSWYrm = 15117,
  VPADDSWYrr = 15118,
  VPADDSWZ128rm = 15119,
  VPADDSWZ128rmk = 15120,
  VPADDSWZ128rmkz = 15121,
  VPADDSWZ128rr = 15122,
  VPADDSWZ128rrk = 15123,
  VPADDSWZ128rrkz = 15124,
  VPADDSWZ256rm = 15125,
  VPADDSWZ256rmk = 15126,
  VPADDSWZ256rmkz = 15127,
  VPADDSWZ256rr = 15128,
  VPADDSWZ256rrk = 15129,
  VPADDSWZ256rrkz = 15130,
  VPADDSWZrm = 15131,
  VPADDSWZrmk = 15132,
  VPADDSWZrmkz = 15133,
  VPADDSWZrr = 15134,
  VPADDSWZrrk = 15135,
  VPADDSWZrrkz = 15136,
  VPADDSWrm = 15137,
  VPADDSWrr = 15138,
  VPADDUSBYrm = 15139,
  VPADDUSBYrr = 15140,
  VPADDUSBZ128rm = 15141,
  VPADDUSBZ128rmk = 15142,
  VPADDUSBZ128rmkz = 15143,
  VPADDUSBZ128rr = 15144,
  VPADDUSBZ128rrk = 15145,
  VPADDUSBZ128rrkz = 15146,
  VPADDUSBZ256rm = 15147,
  VPADDUSBZ256rmk = 15148,
  VPADDUSBZ256rmkz = 15149,
  VPADDUSBZ256rr = 15150,
  VPADDUSBZ256rrk = 15151,
  VPADDUSBZ256rrkz = 15152,
  VPADDUSBZrm = 15153,
  VPADDUSBZrmk = 15154,
  VPADDUSBZrmkz = 15155,
  VPADDUSBZrr = 15156,
  VPADDUSBZrrk = 15157,
  VPADDUSBZrrkz = 15158,
  VPADDUSBrm = 15159,
  VPADDUSBrr = 15160,
  VPADDUSWYrm = 15161,
  VPADDUSWYrr = 15162,
  VPADDUSWZ128rm = 15163,
  VPADDUSWZ128rmk = 15164,
  VPADDUSWZ128rmkz = 15165,
  VPADDUSWZ128rr = 15166,
  VPADDUSWZ128rrk = 15167,
  VPADDUSWZ128rrkz = 15168,
  VPADDUSWZ256rm = 15169,
  VPADDUSWZ256rmk = 15170,
  VPADDUSWZ256rmkz = 15171,
  VPADDUSWZ256rr = 15172,
  VPADDUSWZ256rrk = 15173,
  VPADDUSWZ256rrkz = 15174,
  VPADDUSWZrm = 15175,
  VPADDUSWZrmk = 15176,
  VPADDUSWZrmkz = 15177,
  VPADDUSWZrr = 15178,
  VPADDUSWZrrk = 15179,
  VPADDUSWZrrkz = 15180,
  VPADDUSWrm = 15181,
  VPADDUSWrr = 15182,
  VPADDWYrm = 15183,
  VPADDWYrr = 15184,
  VPADDWZ128rm = 15185,
  VPADDWZ128rmk = 15186,
  VPADDWZ128rmkz = 15187,
  VPADDWZ128rr = 15188,
  VPADDWZ128rrk = 15189,
  VPADDWZ128rrkz = 15190,
  VPADDWZ256rm = 15191,
  VPADDWZ256rmk = 15192,
  VPADDWZ256rmkz = 15193,
  VPADDWZ256rr = 15194,
  VPADDWZ256rrk = 15195,
  VPADDWZ256rrkz = 15196,
  VPADDWZrm = 15197,
  VPADDWZrmk = 15198,
  VPADDWZrmkz = 15199,
  VPADDWZrr = 15200,
  VPADDWZrrk = 15201,
  VPADDWZrrkz = 15202,
  VPADDWrm = 15203,
  VPADDWrr = 15204,
  VPALIGNRYrmi = 15205,
  VPALIGNRYrri = 15206,
  VPALIGNRZ128rmi = 15207,
  VPALIGNRZ128rmik = 15208,
  VPALIGNRZ128rmikz = 15209,
  VPALIGNRZ128rri = 15210,
  VPALIGNRZ128rrik = 15211,
  VPALIGNRZ128rrikz = 15212,
  VPALIGNRZ256rmi = 15213,
  VPALIGNRZ256rmik = 15214,
  VPALIGNRZ256rmikz = 15215,
  VPALIGNRZ256rri = 15216,
  VPALIGNRZ256rrik = 15217,
  VPALIGNRZ256rrikz = 15218,
  VPALIGNRZrmi = 15219,
  VPALIGNRZrmik = 15220,
  VPALIGNRZrmikz = 15221,
  VPALIGNRZrri = 15222,
  VPALIGNRZrrik = 15223,
  VPALIGNRZrrikz = 15224,
  VPALIGNRrmi = 15225,
  VPALIGNRrri = 15226,
  VPANDDZ128rm = 15227,
  VPANDDZ128rmb = 15228,
  VPANDDZ128rmbk = 15229,
  VPANDDZ128rmbkz = 15230,
  VPANDDZ128rmk = 15231,
  VPANDDZ128rmkz = 15232,
  VPANDDZ128rr = 15233,
  VPANDDZ128rrk = 15234,
  VPANDDZ128rrkz = 15235,
  VPANDDZ256rm = 15236,
  VPANDDZ256rmb = 15237,
  VPANDDZ256rmbk = 15238,
  VPANDDZ256rmbkz = 15239,
  VPANDDZ256rmk = 15240,
  VPANDDZ256rmkz = 15241,
  VPANDDZ256rr = 15242,
  VPANDDZ256rrk = 15243,
  VPANDDZ256rrkz = 15244,
  VPANDDZrm = 15245,
  VPANDDZrmb = 15246,
  VPANDDZrmbk = 15247,
  VPANDDZrmbkz = 15248,
  VPANDDZrmk = 15249,
  VPANDDZrmkz = 15250,
  VPANDDZrr = 15251,
  VPANDDZrrk = 15252,
  VPANDDZrrkz = 15253,
  VPANDNDZ128rm = 15254,
  VPANDNDZ128rmb = 15255,
  VPANDNDZ128rmbk = 15256,
  VPANDNDZ128rmbkz = 15257,
  VPANDNDZ128rmk = 15258,
  VPANDNDZ128rmkz = 15259,
  VPANDNDZ128rr = 15260,
  VPANDNDZ128rrk = 15261,
  VPANDNDZ128rrkz = 15262,
  VPANDNDZ256rm = 15263,
  VPANDNDZ256rmb = 15264,
  VPANDNDZ256rmbk = 15265,
  VPANDNDZ256rmbkz = 15266,
  VPANDNDZ256rmk = 15267,
  VPANDNDZ256rmkz = 15268,
  VPANDNDZ256rr = 15269,
  VPANDNDZ256rrk = 15270,
  VPANDNDZ256rrkz = 15271,
  VPANDNDZrm = 15272,
  VPANDNDZrmb = 15273,
  VPANDNDZrmbk = 15274,
  VPANDNDZrmbkz = 15275,
  VPANDNDZrmk = 15276,
  VPANDNDZrmkz = 15277,
  VPANDNDZrr = 15278,
  VPANDNDZrrk = 15279,
  VPANDNDZrrkz = 15280,
  VPANDNQZ128rm = 15281,
  VPANDNQZ128rmb = 15282,
  VPANDNQZ128rmbk = 15283,
  VPANDNQZ128rmbkz = 15284,
  VPANDNQZ128rmk = 15285,
  VPANDNQZ128rmkz = 15286,
  VPANDNQZ128rr = 15287,
  VPANDNQZ128rrk = 15288,
  VPANDNQZ128rrkz = 15289,
  VPANDNQZ256rm = 15290,
  VPANDNQZ256rmb = 15291,
  VPANDNQZ256rmbk = 15292,
  VPANDNQZ256rmbkz = 15293,
  VPANDNQZ256rmk = 15294,
  VPANDNQZ256rmkz = 15295,
  VPANDNQZ256rr = 15296,
  VPANDNQZ256rrk = 15297,
  VPANDNQZ256rrkz = 15298,
  VPANDNQZrm = 15299,
  VPANDNQZrmb = 15300,
  VPANDNQZrmbk = 15301,
  VPANDNQZrmbkz = 15302,
  VPANDNQZrmk = 15303,
  VPANDNQZrmkz = 15304,
  VPANDNQZrr = 15305,
  VPANDNQZrrk = 15306,
  VPANDNQZrrkz = 15307,
  VPANDNYrm = 15308,
  VPANDNYrr = 15309,
  VPANDNrm = 15310,
  VPANDNrr = 15311,
  VPANDQZ128rm = 15312,
  VPANDQZ128rmb = 15313,
  VPANDQZ128rmbk = 15314,
  VPANDQZ128rmbkz = 15315,
  VPANDQZ128rmk = 15316,
  VPANDQZ128rmkz = 15317,
  VPANDQZ128rr = 15318,
  VPANDQZ128rrk = 15319,
  VPANDQZ128rrkz = 15320,
  VPANDQZ256rm = 15321,
  VPANDQZ256rmb = 15322,
  VPANDQZ256rmbk = 15323,
  VPANDQZ256rmbkz = 15324,
  VPANDQZ256rmk = 15325,
  VPANDQZ256rmkz = 15326,
  VPANDQZ256rr = 15327,
  VPANDQZ256rrk = 15328,
  VPANDQZ256rrkz = 15329,
  VPANDQZrm = 15330,
  VPANDQZrmb = 15331,
  VPANDQZrmbk = 15332,
  VPANDQZrmbkz = 15333,
  VPANDQZrmk = 15334,
  VPANDQZrmkz = 15335,
  VPANDQZrr = 15336,
  VPANDQZrrk = 15337,
  VPANDQZrrkz = 15338,
  VPANDYrm = 15339,
  VPANDYrr = 15340,
  VPANDrm = 15341,
  VPANDrr = 15342,
  VPAVGBYrm = 15343,
  VPAVGBYrr = 15344,
  VPAVGBZ128rm = 15345,
  VPAVGBZ128rmk = 15346,
  VPAVGBZ128rmkz = 15347,
  VPAVGBZ128rr = 15348,
  VPAVGBZ128rrk = 15349,
  VPAVGBZ128rrkz = 15350,
  VPAVGBZ256rm = 15351,
  VPAVGBZ256rmk = 15352,
  VPAVGBZ256rmkz = 15353,
  VPAVGBZ256rr = 15354,
  VPAVGBZ256rrk = 15355,
  VPAVGBZ256rrkz = 15356,
  VPAVGBZrm = 15357,
  VPAVGBZrmk = 15358,
  VPAVGBZrmkz = 15359,
  VPAVGBZrr = 15360,
  VPAVGBZrrk = 15361,
  VPAVGBZrrkz = 15362,
  VPAVGBrm = 15363,
  VPAVGBrr = 15364,
  VPAVGWYrm = 15365,
  VPAVGWYrr = 15366,
  VPAVGWZ128rm = 15367,
  VPAVGWZ128rmk = 15368,
  VPAVGWZ128rmkz = 15369,
  VPAVGWZ128rr = 15370,
  VPAVGWZ128rrk = 15371,
  VPAVGWZ128rrkz = 15372,
  VPAVGWZ256rm = 15373,
  VPAVGWZ256rmk = 15374,
  VPAVGWZ256rmkz = 15375,
  VPAVGWZ256rr = 15376,
  VPAVGWZ256rrk = 15377,
  VPAVGWZ256rrkz = 15378,
  VPAVGWZrm = 15379,
  VPAVGWZrmk = 15380,
  VPAVGWZrmkz = 15381,
  VPAVGWZrr = 15382,
  VPAVGWZrrk = 15383,
  VPAVGWZrrkz = 15384,
  VPAVGWrm = 15385,
  VPAVGWrr = 15386,
  VPBLENDDYrmi = 15387,
  VPBLENDDYrri = 15388,
  VPBLENDDrmi = 15389,
  VPBLENDDrri = 15390,
  VPBLENDMBZ128rm = 15391,
  VPBLENDMBZ128rmk = 15392,
  VPBLENDMBZ128rmkz = 15393,
  VPBLENDMBZ128rr = 15394,
  VPBLENDMBZ128rrk = 15395,
  VPBLENDMBZ128rrkz = 15396,
  VPBLENDMBZ256rm = 15397,
  VPBLENDMBZ256rmk = 15398,
  VPBLENDMBZ256rmkz = 15399,
  VPBLENDMBZ256rr = 15400,
  VPBLENDMBZ256rrk = 15401,
  VPBLENDMBZ256rrkz = 15402,
  VPBLENDMBZrm = 15403,
  VPBLENDMBZrmk = 15404,
  VPBLENDMBZrmkz = 15405,
  VPBLENDMBZrr = 15406,
  VPBLENDMBZrrk = 15407,
  VPBLENDMBZrrkz = 15408,
  VPBLENDMDZ128rm = 15409,
  VPBLENDMDZ128rmb = 15410,
  VPBLENDMDZ128rmbk = 15411,
  VPBLENDMDZ128rmbkz = 15412,
  VPBLENDMDZ128rmk = 15413,
  VPBLENDMDZ128rmkz = 15414,
  VPBLENDMDZ128rr = 15415,
  VPBLENDMDZ128rrk = 15416,
  VPBLENDMDZ128rrkz = 15417,
  VPBLENDMDZ256rm = 15418,
  VPBLENDMDZ256rmb = 15419,
  VPBLENDMDZ256rmbk = 15420,
  VPBLENDMDZ256rmbkz = 15421,
  VPBLENDMDZ256rmk = 15422,
  VPBLENDMDZ256rmkz = 15423,
  VPBLENDMDZ256rr = 15424,
  VPBLENDMDZ256rrk = 15425,
  VPBLENDMDZ256rrkz = 15426,
  VPBLENDMDZrm = 15427,
  VPBLENDMDZrmb = 15428,
  VPBLENDMDZrmbk = 15429,
  VPBLENDMDZrmbkz = 15430,
  VPBLENDMDZrmk = 15431,
  VPBLENDMDZrmkz = 15432,
  VPBLENDMDZrr = 15433,
  VPBLENDMDZrrk = 15434,
  VPBLENDMDZrrkz = 15435,
  VPBLENDMQZ128rm = 15436,
  VPBLENDMQZ128rmb = 15437,
  VPBLENDMQZ128rmbk = 15438,
  VPBLENDMQZ128rmbkz = 15439,
  VPBLENDMQZ128rmk = 15440,
  VPBLENDMQZ128rmkz = 15441,
  VPBLENDMQZ128rr = 15442,
  VPBLENDMQZ128rrk = 15443,
  VPBLENDMQZ128rrkz = 15444,
  VPBLENDMQZ256rm = 15445,
  VPBLENDMQZ256rmb = 15446,
  VPBLENDMQZ256rmbk = 15447,
  VPBLENDMQZ256rmbkz = 15448,
  VPBLENDMQZ256rmk = 15449,
  VPBLENDMQZ256rmkz = 15450,
  VPBLENDMQZ256rr = 15451,
  VPBLENDMQZ256rrk = 15452,
  VPBLENDMQZ256rrkz = 15453,
  VPBLENDMQZrm = 15454,
  VPBLENDMQZrmb = 15455,
  VPBLENDMQZrmbk = 15456,
  VPBLENDMQZrmbkz = 15457,
  VPBLENDMQZrmk = 15458,
  VPBLENDMQZrmkz = 15459,
  VPBLENDMQZrr = 15460,
  VPBLENDMQZrrk = 15461,
  VPBLENDMQZrrkz = 15462,
  VPBLENDMWZ128rm = 15463,
  VPBLENDMWZ128rmk = 15464,
  VPBLENDMWZ128rmkz = 15465,
  VPBLENDMWZ128rr = 15466,
  VPBLENDMWZ128rrk = 15467,
  VPBLENDMWZ128rrkz = 15468,
  VPBLENDMWZ256rm = 15469,
  VPBLENDMWZ256rmk = 15470,
  VPBLENDMWZ256rmkz = 15471,
  VPBLENDMWZ256rr = 15472,
  VPBLENDMWZ256rrk = 15473,
  VPBLENDMWZ256rrkz = 15474,
  VPBLENDMWZrm = 15475,
  VPBLENDMWZrmk = 15476,
  VPBLENDMWZrmkz = 15477,
  VPBLENDMWZrr = 15478,
  VPBLENDMWZrrk = 15479,
  VPBLENDMWZrrkz = 15480,
  VPBLENDVBYrmr = 15481,
  VPBLENDVBYrrr = 15482,
  VPBLENDVBrmr = 15483,
  VPBLENDVBrrr = 15484,
  VPBLENDWYrmi = 15485,
  VPBLENDWYrri = 15486,
  VPBLENDWrmi = 15487,
  VPBLENDWrri = 15488,
  VPBROADCASTBYrm = 15489,
  VPBROADCASTBYrr = 15490,
  VPBROADCASTBZ128rm = 15491,
  VPBROADCASTBZ128rmk = 15492,
  VPBROADCASTBZ128rmkz = 15493,
  VPBROADCASTBZ128rr = 15494,
  VPBROADCASTBZ128rrk = 15495,
  VPBROADCASTBZ128rrkz = 15496,
  VPBROADCASTBZ256rm = 15497,
  VPBROADCASTBZ256rmk = 15498,
  VPBROADCASTBZ256rmkz = 15499,
  VPBROADCASTBZ256rr = 15500,
  VPBROADCASTBZ256rrk = 15501,
  VPBROADCASTBZ256rrkz = 15502,
  VPBROADCASTBZrm = 15503,
  VPBROADCASTBZrmk = 15504,
  VPBROADCASTBZrmkz = 15505,
  VPBROADCASTBZrr = 15506,
  VPBROADCASTBZrrk = 15507,
  VPBROADCASTBZrrkz = 15508,
  VPBROADCASTBrZ128rr = 15509,
  VPBROADCASTBrZ128rrk = 15510,
  VPBROADCASTBrZ128rrkz = 15511,
  VPBROADCASTBrZ256rr = 15512,
  VPBROADCASTBrZ256rrk = 15513,
  VPBROADCASTBrZ256rrkz = 15514,
  VPBROADCASTBrZrr = 15515,
  VPBROADCASTBrZrrk = 15516,
  VPBROADCASTBrZrrkz = 15517,
  VPBROADCASTBrm = 15518,
  VPBROADCASTBrr = 15519,
  VPBROADCASTDYrm = 15520,
  VPBROADCASTDYrr = 15521,
  VPBROADCASTDZ128rm = 15522,
  VPBROADCASTDZ128rmk = 15523,
  VPBROADCASTDZ128rmkz = 15524,
  VPBROADCASTDZ128rr = 15525,
  VPBROADCASTDZ128rrk = 15526,
  VPBROADCASTDZ128rrkz = 15527,
  VPBROADCASTDZ256rm = 15528,
  VPBROADCASTDZ256rmk = 15529,
  VPBROADCASTDZ256rmkz = 15530,
  VPBROADCASTDZ256rr = 15531,
  VPBROADCASTDZ256rrk = 15532,
  VPBROADCASTDZ256rrkz = 15533,
  VPBROADCASTDZrm = 15534,
  VPBROADCASTDZrmk = 15535,
  VPBROADCASTDZrmkz = 15536,
  VPBROADCASTDZrr = 15537,
  VPBROADCASTDZrrk = 15538,
  VPBROADCASTDZrrkz = 15539,
  VPBROADCASTDrZ128rr = 15540,
  VPBROADCASTDrZ128rrk = 15541,
  VPBROADCASTDrZ128rrkz = 15542,
  VPBROADCASTDrZ256rr = 15543,
  VPBROADCASTDrZ256rrk = 15544,
  VPBROADCASTDrZ256rrkz = 15545,
  VPBROADCASTDrZrr = 15546,
  VPBROADCASTDrZrrk = 15547,
  VPBROADCASTDrZrrkz = 15548,
  VPBROADCASTDrm = 15549,
  VPBROADCASTDrr = 15550,
  VPBROADCASTMB2QZ128rr = 15551,
  VPBROADCASTMB2QZ256rr = 15552,
  VPBROADCASTMB2QZrr = 15553,
  VPBROADCASTMW2DZ128rr = 15554,
  VPBROADCASTMW2DZ256rr = 15555,
  VPBROADCASTMW2DZrr = 15556,
  VPBROADCASTQYrm = 15557,
  VPBROADCASTQYrr = 15558,
  VPBROADCASTQZ128rm = 15559,
  VPBROADCASTQZ128rmk = 15560,
  VPBROADCASTQZ128rmkz = 15561,
  VPBROADCASTQZ128rr = 15562,
  VPBROADCASTQZ128rrk = 15563,
  VPBROADCASTQZ128rrkz = 15564,
  VPBROADCASTQZ256rm = 15565,
  VPBROADCASTQZ256rmk = 15566,
  VPBROADCASTQZ256rmkz = 15567,
  VPBROADCASTQZ256rr = 15568,
  VPBROADCASTQZ256rrk = 15569,
  VPBROADCASTQZ256rrkz = 15570,
  VPBROADCASTQZrm = 15571,
  VPBROADCASTQZrmk = 15572,
  VPBROADCASTQZrmkz = 15573,
  VPBROADCASTQZrr = 15574,
  VPBROADCASTQZrrk = 15575,
  VPBROADCASTQZrrkz = 15576,
  VPBROADCASTQrZ128rr = 15577,
  VPBROADCASTQrZ128rrk = 15578,
  VPBROADCASTQrZ128rrkz = 15579,
  VPBROADCASTQrZ256rr = 15580,
  VPBROADCASTQrZ256rrk = 15581,
  VPBROADCASTQrZ256rrkz = 15582,
  VPBROADCASTQrZrr = 15583,
  VPBROADCASTQrZrrk = 15584,
  VPBROADCASTQrZrrkz = 15585,
  VPBROADCASTQrm = 15586,
  VPBROADCASTQrr = 15587,
  VPBROADCASTWYrm = 15588,
  VPBROADCASTWYrr = 15589,
  VPBROADCASTWZ128rm = 15590,
  VPBROADCASTWZ128rmk = 15591,
  VPBROADCASTWZ128rmkz = 15592,
  VPBROADCASTWZ128rr = 15593,
  VPBROADCASTWZ128rrk = 15594,
  VPBROADCASTWZ128rrkz = 15595,
  VPBROADCASTWZ256rm = 15596,
  VPBROADCASTWZ256rmk = 15597,
  VPBROADCASTWZ256rmkz = 15598,
  VPBROADCASTWZ256rr = 15599,
  VPBROADCASTWZ256rrk = 15600,
  VPBROADCASTWZ256rrkz = 15601,
  VPBROADCASTWZrm = 15602,
  VPBROADCASTWZrmk = 15603,
  VPBROADCASTWZrmkz = 15604,
  VPBROADCASTWZrr = 15605,
  VPBROADCASTWZrrk = 15606,
  VPBROADCASTWZrrkz = 15607,
  VPBROADCASTWrZ128rr = 15608,
  VPBROADCASTWrZ128rrk = 15609,
  VPBROADCASTWrZ128rrkz = 15610,
  VPBROADCASTWrZ256rr = 15611,
  VPBROADCASTWrZ256rrk = 15612,
  VPBROADCASTWrZ256rrkz = 15613,
  VPBROADCASTWrZrr = 15614,
  VPBROADCASTWrZrrk = 15615,
  VPBROADCASTWrZrrkz = 15616,
  VPBROADCASTWrm = 15617,
  VPBROADCASTWrr = 15618,
  VPCLMULQDQYrmi = 15619,
  VPCLMULQDQYrri = 15620,
  VPCLMULQDQZ128rmi = 15621,
  VPCLMULQDQZ128rri = 15622,
  VPCLMULQDQZ256rmi = 15623,
  VPCLMULQDQZ256rri = 15624,
  VPCLMULQDQZrmi = 15625,
  VPCLMULQDQZrri = 15626,
  VPCLMULQDQrmi = 15627,
  VPCLMULQDQrri = 15628,
  VPCMOVYrmr = 15629,
  VPCMOVYrrm = 15630,
  VPCMOVYrrr = 15631,
  VPCMOVYrrr_REV = 15632,
  VPCMOVrmr = 15633,
  VPCMOVrrm = 15634,
  VPCMOVrrr = 15635,
  VPCMOVrrr_REV = 15636,
  VPCMPBZ128rmi = 15637,
  VPCMPBZ128rmik = 15638,
  VPCMPBZ128rri = 15639,
  VPCMPBZ128rrik = 15640,
  VPCMPBZ256rmi = 15641,
  VPCMPBZ256rmik = 15642,
  VPCMPBZ256rri = 15643,
  VPCMPBZ256rrik = 15644,
  VPCMPBZrmi = 15645,
  VPCMPBZrmik = 15646,
  VPCMPBZrri = 15647,
  VPCMPBZrrik = 15648,
  VPCMPDZ128rmbi = 15649,
  VPCMPDZ128rmbik = 15650,
  VPCMPDZ128rmi = 15651,
  VPCMPDZ128rmik = 15652,
  VPCMPDZ128rri = 15653,
  VPCMPDZ128rrik = 15654,
  VPCMPDZ256rmbi = 15655,
  VPCMPDZ256rmbik = 15656,
  VPCMPDZ256rmi = 15657,
  VPCMPDZ256rmik = 15658,
  VPCMPDZ256rri = 15659,
  VPCMPDZ256rrik = 15660,
  VPCMPDZrmbi = 15661,
  VPCMPDZrmbik = 15662,
  VPCMPDZrmi = 15663,
  VPCMPDZrmik = 15664,
  VPCMPDZrri = 15665,
  VPCMPDZrrik = 15666,
  VPCMPEQBYrm = 15667,
  VPCMPEQBYrr = 15668,
  VPCMPEQBZ128rm = 15669,
  VPCMPEQBZ128rmk = 15670,
  VPCMPEQBZ128rr = 15671,
  VPCMPEQBZ128rrk = 15672,
  VPCMPEQBZ256rm = 15673,
  VPCMPEQBZ256rmk = 15674,
  VPCMPEQBZ256rr = 15675,
  VPCMPEQBZ256rrk = 15676,
  VPCMPEQBZrm = 15677,
  VPCMPEQBZrmk = 15678,
  VPCMPEQBZrr = 15679,
  VPCMPEQBZrrk = 15680,
  VPCMPEQBrm = 15681,
  VPCMPEQBrr = 15682,
  VPCMPEQDYrm = 15683,
  VPCMPEQDYrr = 15684,
  VPCMPEQDZ128rm = 15685,
  VPCMPEQDZ128rmb = 15686,
  VPCMPEQDZ128rmbk = 15687,
  VPCMPEQDZ128rmk = 15688,
  VPCMPEQDZ128rr = 15689,
  VPCMPEQDZ128rrk = 15690,
  VPCMPEQDZ256rm = 15691,
  VPCMPEQDZ256rmb = 15692,
  VPCMPEQDZ256rmbk = 15693,
  VPCMPEQDZ256rmk = 15694,
  VPCMPEQDZ256rr = 15695,
  VPCMPEQDZ256rrk = 15696,
  VPCMPEQDZrm = 15697,
  VPCMPEQDZrmb = 15698,
  VPCMPEQDZrmbk = 15699,
  VPCMPEQDZrmk = 15700,
  VPCMPEQDZrr = 15701,
  VPCMPEQDZrrk = 15702,
  VPCMPEQDrm = 15703,
  VPCMPEQDrr = 15704,
  VPCMPEQQYrm = 15705,
  VPCMPEQQYrr = 15706,
  VPCMPEQQZ128rm = 15707,
  VPCMPEQQZ128rmb = 15708,
  VPCMPEQQZ128rmbk = 15709,
  VPCMPEQQZ128rmk = 15710,
  VPCMPEQQZ128rr = 15711,
  VPCMPEQQZ128rrk = 15712,
  VPCMPEQQZ256rm = 15713,
  VPCMPEQQZ256rmb = 15714,
  VPCMPEQQZ256rmbk = 15715,
  VPCMPEQQZ256rmk = 15716,
  VPCMPEQQZ256rr = 15717,
  VPCMPEQQZ256rrk = 15718,
  VPCMPEQQZrm = 15719,
  VPCMPEQQZrmb = 15720,
  VPCMPEQQZrmbk = 15721,
  VPCMPEQQZrmk = 15722,
  VPCMPEQQZrr = 15723,
  VPCMPEQQZrrk = 15724,
  VPCMPEQQrm = 15725,
  VPCMPEQQrr = 15726,
  VPCMPEQWYrm = 15727,
  VPCMPEQWYrr = 15728,
  VPCMPEQWZ128rm = 15729,
  VPCMPEQWZ128rmk = 15730,
  VPCMPEQWZ128rr = 15731,
  VPCMPEQWZ128rrk = 15732,
  VPCMPEQWZ256rm = 15733,
  VPCMPEQWZ256rmk = 15734,
  VPCMPEQWZ256rr = 15735,
  VPCMPEQWZ256rrk = 15736,
  VPCMPEQWZrm = 15737,
  VPCMPEQWZrmk = 15738,
  VPCMPEQWZrr = 15739,
  VPCMPEQWZrrk = 15740,
  VPCMPEQWrm = 15741,
  VPCMPEQWrr = 15742,
  VPCMPESTRIrmi = 15743,
  VPCMPESTRIrri = 15744,
  VPCMPESTRMrmi = 15745,
  VPCMPESTRMrri = 15746,
  VPCMPGTBYrm = 15747,
  VPCMPGTBYrr = 15748,
  VPCMPGTBZ128rm = 15749,
  VPCMPGTBZ128rmk = 15750,
  VPCMPGTBZ128rr = 15751,
  VPCMPGTBZ128rrk = 15752,
  VPCMPGTBZ256rm = 15753,
  VPCMPGTBZ256rmk = 15754,
  VPCMPGTBZ256rr = 15755,
  VPCMPGTBZ256rrk = 15756,
  VPCMPGTBZrm = 15757,
  VPCMPGTBZrmk = 15758,
  VPCMPGTBZrr = 15759,
  VPCMPGTBZrrk = 15760,
  VPCMPGTBrm = 15761,
  VPCMPGTBrr = 15762,
  VPCMPGTDYrm = 15763,
  VPCMPGTDYrr = 15764,
  VPCMPGTDZ128rm = 15765,
  VPCMPGTDZ128rmb = 15766,
  VPCMPGTDZ128rmbk = 15767,
  VPCMPGTDZ128rmk = 15768,
  VPCMPGTDZ128rr = 15769,
  VPCMPGTDZ128rrk = 15770,
  VPCMPGTDZ256rm = 15771,
  VPCMPGTDZ256rmb = 15772,
  VPCMPGTDZ256rmbk = 15773,
  VPCMPGTDZ256rmk = 15774,
  VPCMPGTDZ256rr = 15775,
  VPCMPGTDZ256rrk = 15776,
  VPCMPGTDZrm = 15777,
  VPCMPGTDZrmb = 15778,
  VPCMPGTDZrmbk = 15779,
  VPCMPGTDZrmk = 15780,
  VPCMPGTDZrr = 15781,
  VPCMPGTDZrrk = 15782,
  VPCMPGTDrm = 15783,
  VPCMPGTDrr = 15784,
  VPCMPGTQYrm = 15785,
  VPCMPGTQYrr = 15786,
  VPCMPGTQZ128rm = 15787,
  VPCMPGTQZ128rmb = 15788,
  VPCMPGTQZ128rmbk = 15789,
  VPCMPGTQZ128rmk = 15790,
  VPCMPGTQZ128rr = 15791,
  VPCMPGTQZ128rrk = 15792,
  VPCMPGTQZ256rm = 15793,
  VPCMPGTQZ256rmb = 15794,
  VPCMPGTQZ256rmbk = 15795,
  VPCMPGTQZ256rmk = 15796,
  VPCMPGTQZ256rr = 15797,
  VPCMPGTQZ256rrk = 15798,
  VPCMPGTQZrm = 15799,
  VPCMPGTQZrmb = 15800,
  VPCMPGTQZrmbk = 15801,
  VPCMPGTQZrmk = 15802,
  VPCMPGTQZrr = 15803,
  VPCMPGTQZrrk = 15804,
  VPCMPGTQrm = 15805,
  VPCMPGTQrr = 15806,
  VPCMPGTWYrm = 15807,
  VPCMPGTWYrr = 15808,
  VPCMPGTWZ128rm = 15809,
  VPCMPGTWZ128rmk = 15810,
  VPCMPGTWZ128rr = 15811,
  VPCMPGTWZ128rrk = 15812,
  VPCMPGTWZ256rm = 15813,
  VPCMPGTWZ256rmk = 15814,
  VPCMPGTWZ256rr = 15815,
  VPCMPGTWZ256rrk = 15816,
  VPCMPGTWZrm = 15817,
  VPCMPGTWZrmk = 15818,
  VPCMPGTWZrr = 15819,
  VPCMPGTWZrrk = 15820,
  VPCMPGTWrm = 15821,
  VPCMPGTWrr = 15822,
  VPCMPISTRIrmi = 15823,
  VPCMPISTRIrri = 15824,
  VPCMPISTRMrmi = 15825,
  VPCMPISTRMrri = 15826,
  VPCMPQZ128rmbi = 15827,
  VPCMPQZ128rmbik = 15828,
  VPCMPQZ128rmi = 15829,
  VPCMPQZ128rmik = 15830,
  VPCMPQZ128rri = 15831,
  VPCMPQZ128rrik = 15832,
  VPCMPQZ256rmbi = 15833,
  VPCMPQZ256rmbik = 15834,
  VPCMPQZ256rmi = 15835,
  VPCMPQZ256rmik = 15836,
  VPCMPQZ256rri = 15837,
  VPCMPQZ256rrik = 15838,
  VPCMPQZrmbi = 15839,
  VPCMPQZrmbik = 15840,
  VPCMPQZrmi = 15841,
  VPCMPQZrmik = 15842,
  VPCMPQZrri = 15843,
  VPCMPQZrrik = 15844,
  VPCMPUBZ128rmi = 15845,
  VPCMPUBZ128rmik = 15846,
  VPCMPUBZ128rri = 15847,
  VPCMPUBZ128rrik = 15848,
  VPCMPUBZ256rmi = 15849,
  VPCMPUBZ256rmik = 15850,
  VPCMPUBZ256rri = 15851,
  VPCMPUBZ256rrik = 15852,
  VPCMPUBZrmi = 15853,
  VPCMPUBZrmik = 15854,
  VPCMPUBZrri = 15855,
  VPCMPUBZrrik = 15856,
  VPCMPUDZ128rmbi = 15857,
  VPCMPUDZ128rmbik = 15858,
  VPCMPUDZ128rmi = 15859,
  VPCMPUDZ128rmik = 15860,
  VPCMPUDZ128rri = 15861,
  VPCMPUDZ128rrik = 15862,
  VPCMPUDZ256rmbi = 15863,
  VPCMPUDZ256rmbik = 15864,
  VPCMPUDZ256rmi = 15865,
  VPCMPUDZ256rmik = 15866,
  VPCMPUDZ256rri = 15867,
  VPCMPUDZ256rrik = 15868,
  VPCMPUDZrmbi = 15869,
  VPCMPUDZrmbik = 15870,
  VPCMPUDZrmi = 15871,
  VPCMPUDZrmik = 15872,
  VPCMPUDZrri = 15873,
  VPCMPUDZrrik = 15874,
  VPCMPUQZ128rmbi = 15875,
  VPCMPUQZ128rmbik = 15876,
  VPCMPUQZ128rmi = 15877,
  VPCMPUQZ128rmik = 15878,
  VPCMPUQZ128rri = 15879,
  VPCMPUQZ128rrik = 15880,
  VPCMPUQZ256rmbi = 15881,
  VPCMPUQZ256rmbik = 15882,
  VPCMPUQZ256rmi = 15883,
  VPCMPUQZ256rmik = 15884,
  VPCMPUQZ256rri = 15885,
  VPCMPUQZ256rrik = 15886,
  VPCMPUQZrmbi = 15887,
  VPCMPUQZrmbik = 15888,
  VPCMPUQZrmi = 15889,
  VPCMPUQZrmik = 15890,
  VPCMPUQZrri = 15891,
  VPCMPUQZrrik = 15892,
  VPCMPUWZ128rmi = 15893,
  VPCMPUWZ128rmik = 15894,
  VPCMPUWZ128rri = 15895,
  VPCMPUWZ128rrik = 15896,
  VPCMPUWZ256rmi = 15897,
  VPCMPUWZ256rmik = 15898,
  VPCMPUWZ256rri = 15899,
  VPCMPUWZ256rrik = 15900,
  VPCMPUWZrmi = 15901,
  VPCMPUWZrmik = 15902,
  VPCMPUWZrri = 15903,
  VPCMPUWZrrik = 15904,
  VPCMPWZ128rmi = 15905,
  VPCMPWZ128rmik = 15906,
  VPCMPWZ128rri = 15907,
  VPCMPWZ128rrik = 15908,
  VPCMPWZ256rmi = 15909,
  VPCMPWZ256rmik = 15910,
  VPCMPWZ256rri = 15911,
  VPCMPWZ256rrik = 15912,
  VPCMPWZrmi = 15913,
  VPCMPWZrmik = 15914,
  VPCMPWZrri = 15915,
  VPCMPWZrrik = 15916,
  VPCOMBmi = 15917,
  VPCOMBri = 15918,
  VPCOMDmi = 15919,
  VPCOMDri = 15920,
  VPCOMPRESSBZ128mr = 15921,
  VPCOMPRESSBZ128mrk = 15922,
  VPCOMPRESSBZ128rr = 15923,
  VPCOMPRESSBZ128rrk = 15924,
  VPCOMPRESSBZ128rrkz = 15925,
  VPCOMPRESSBZ256mr = 15926,
  VPCOMPRESSBZ256mrk = 15927,
  VPCOMPRESSBZ256rr = 15928,
  VPCOMPRESSBZ256rrk = 15929,
  VPCOMPRESSBZ256rrkz = 15930,
  VPCOMPRESSBZmr = 15931,
  VPCOMPRESSBZmrk = 15932,
  VPCOMPRESSBZrr = 15933,
  VPCOMPRESSBZrrk = 15934,
  VPCOMPRESSBZrrkz = 15935,
  VPCOMPRESSDZ128mr = 15936,
  VPCOMPRESSDZ128mrk = 15937,
  VPCOMPRESSDZ128rr = 15938,
  VPCOMPRESSDZ128rrk = 15939,
  VPCOMPRESSDZ128rrkz = 15940,
  VPCOMPRESSDZ256mr = 15941,
  VPCOMPRESSDZ256mrk = 15942,
  VPCOMPRESSDZ256rr = 15943,
  VPCOMPRESSDZ256rrk = 15944,
  VPCOMPRESSDZ256rrkz = 15945,
  VPCOMPRESSDZmr = 15946,
  VPCOMPRESSDZmrk = 15947,
  VPCOMPRESSDZrr = 15948,
  VPCOMPRESSDZrrk = 15949,
  VPCOMPRESSDZrrkz = 15950,
  VPCOMPRESSQZ128mr = 15951,
  VPCOMPRESSQZ128mrk = 15952,
  VPCOMPRESSQZ128rr = 15953,
  VPCOMPRESSQZ128rrk = 15954,
  VPCOMPRESSQZ128rrkz = 15955,
  VPCOMPRESSQZ256mr = 15956,
  VPCOMPRESSQZ256mrk = 15957,
  VPCOMPRESSQZ256rr = 15958,
  VPCOMPRESSQZ256rrk = 15959,
  VPCOMPRESSQZ256rrkz = 15960,
  VPCOMPRESSQZmr = 15961,
  VPCOMPRESSQZmrk = 15962,
  VPCOMPRESSQZrr = 15963,
  VPCOMPRESSQZrrk = 15964,
  VPCOMPRESSQZrrkz = 15965,
  VPCOMPRESSWZ128mr = 15966,
  VPCOMPRESSWZ128mrk = 15967,
  VPCOMPRESSWZ128rr = 15968,
  VPCOMPRESSWZ128rrk = 15969,
  VPCOMPRESSWZ128rrkz = 15970,
  VPCOMPRESSWZ256mr = 15971,
  VPCOMPRESSWZ256mrk = 15972,
  VPCOMPRESSWZ256rr = 15973,
  VPCOMPRESSWZ256rrk = 15974,
  VPCOMPRESSWZ256rrkz = 15975,
  VPCOMPRESSWZmr = 15976,
  VPCOMPRESSWZmrk = 15977,
  VPCOMPRESSWZrr = 15978,
  VPCOMPRESSWZrrk = 15979,
  VPCOMPRESSWZrrkz = 15980,
  VPCOMQmi = 15981,
  VPCOMQri = 15982,
  VPCOMUBmi = 15983,
  VPCOMUBri = 15984,
  VPCOMUDmi = 15985,
  VPCOMUDri = 15986,
  VPCOMUQmi = 15987,
  VPCOMUQri = 15988,
  VPCOMUWmi = 15989,
  VPCOMUWri = 15990,
  VPCOMWmi = 15991,
  VPCOMWri = 15992,
  VPCONFLICTDZ128rm = 15993,
  VPCONFLICTDZ128rmb = 15994,
  VPCONFLICTDZ128rmbk = 15995,
  VPCONFLICTDZ128rmbkz = 15996,
  VPCONFLICTDZ128rmk = 15997,
  VPCONFLICTDZ128rmkz = 15998,
  VPCONFLICTDZ128rr = 15999,
  VPCONFLICTDZ128rrk = 16000,
  VPCONFLICTDZ128rrkz = 16001,
  VPCONFLICTDZ256rm = 16002,
  VPCONFLICTDZ256rmb = 16003,
  VPCONFLICTDZ256rmbk = 16004,
  VPCONFLICTDZ256rmbkz = 16005,
  VPCONFLICTDZ256rmk = 16006,
  VPCONFLICTDZ256rmkz = 16007,
  VPCONFLICTDZ256rr = 16008,
  VPCONFLICTDZ256rrk = 16009,
  VPCONFLICTDZ256rrkz = 16010,
  VPCONFLICTDZrm = 16011,
  VPCONFLICTDZrmb = 16012,
  VPCONFLICTDZrmbk = 16013,
  VPCONFLICTDZrmbkz = 16014,
  VPCONFLICTDZrmk = 16015,
  VPCONFLICTDZrmkz = 16016,
  VPCONFLICTDZrr = 16017,
  VPCONFLICTDZrrk = 16018,
  VPCONFLICTDZrrkz = 16019,
  VPCONFLICTQZ128rm = 16020,
  VPCONFLICTQZ128rmb = 16021,
  VPCONFLICTQZ128rmbk = 16022,
  VPCONFLICTQZ128rmbkz = 16023,
  VPCONFLICTQZ128rmk = 16024,
  VPCONFLICTQZ128rmkz = 16025,
  VPCONFLICTQZ128rr = 16026,
  VPCONFLICTQZ128rrk = 16027,
  VPCONFLICTQZ128rrkz = 16028,
  VPCONFLICTQZ256rm = 16029,
  VPCONFLICTQZ256rmb = 16030,
  VPCONFLICTQZ256rmbk = 16031,
  VPCONFLICTQZ256rmbkz = 16032,
  VPCONFLICTQZ256rmk = 16033,
  VPCONFLICTQZ256rmkz = 16034,
  VPCONFLICTQZ256rr = 16035,
  VPCONFLICTQZ256rrk = 16036,
  VPCONFLICTQZ256rrkz = 16037,
  VPCONFLICTQZrm = 16038,
  VPCONFLICTQZrmb = 16039,
  VPCONFLICTQZrmbk = 16040,
  VPCONFLICTQZrmbkz = 16041,
  VPCONFLICTQZrmk = 16042,
  VPCONFLICTQZrmkz = 16043,
  VPCONFLICTQZrr = 16044,
  VPCONFLICTQZrrk = 16045,
  VPCONFLICTQZrrkz = 16046,
  VPDPBSSDSYrm = 16047,
  VPDPBSSDSYrr = 16048,
  VPDPBSSDSZ128m = 16049,
  VPDPBSSDSZ128mb = 16050,
  VPDPBSSDSZ128mbk = 16051,
  VPDPBSSDSZ128mbkz = 16052,
  VPDPBSSDSZ128mk = 16053,
  VPDPBSSDSZ128mkz = 16054,
  VPDPBSSDSZ128r = 16055,
  VPDPBSSDSZ128rk = 16056,
  VPDPBSSDSZ128rkz = 16057,
  VPDPBSSDSZ256m = 16058,
  VPDPBSSDSZ256mb = 16059,
  VPDPBSSDSZ256mbk = 16060,
  VPDPBSSDSZ256mbkz = 16061,
  VPDPBSSDSZ256mk = 16062,
  VPDPBSSDSZ256mkz = 16063,
  VPDPBSSDSZ256r = 16064,
  VPDPBSSDSZ256rk = 16065,
  VPDPBSSDSZ256rkz = 16066,
  VPDPBSSDSZm = 16067,
  VPDPBSSDSZmb = 16068,
  VPDPBSSDSZmbk = 16069,
  VPDPBSSDSZmbkz = 16070,
  VPDPBSSDSZmk = 16071,
  VPDPBSSDSZmkz = 16072,
  VPDPBSSDSZr = 16073,
  VPDPBSSDSZrk = 16074,
  VPDPBSSDSZrkz = 16075,
  VPDPBSSDSrm = 16076,
  VPDPBSSDSrr = 16077,
  VPDPBSSDYrm = 16078,
  VPDPBSSDYrr = 16079,
  VPDPBSSDZ128m = 16080,
  VPDPBSSDZ128mb = 16081,
  VPDPBSSDZ128mbk = 16082,
  VPDPBSSDZ128mbkz = 16083,
  VPDPBSSDZ128mk = 16084,
  VPDPBSSDZ128mkz = 16085,
  VPDPBSSDZ128r = 16086,
  VPDPBSSDZ128rk = 16087,
  VPDPBSSDZ128rkz = 16088,
  VPDPBSSDZ256m = 16089,
  VPDPBSSDZ256mb = 16090,
  VPDPBSSDZ256mbk = 16091,
  VPDPBSSDZ256mbkz = 16092,
  VPDPBSSDZ256mk = 16093,
  VPDPBSSDZ256mkz = 16094,
  VPDPBSSDZ256r = 16095,
  VPDPBSSDZ256rk = 16096,
  VPDPBSSDZ256rkz = 16097,
  VPDPBSSDZm = 16098,
  VPDPBSSDZmb = 16099,
  VPDPBSSDZmbk = 16100,
  VPDPBSSDZmbkz = 16101,
  VPDPBSSDZmk = 16102,
  VPDPBSSDZmkz = 16103,
  VPDPBSSDZr = 16104,
  VPDPBSSDZrk = 16105,
  VPDPBSSDZrkz = 16106,
  VPDPBSSDrm = 16107,
  VPDPBSSDrr = 16108,
  VPDPBSUDSYrm = 16109,
  VPDPBSUDSYrr = 16110,
  VPDPBSUDSZ128m = 16111,
  VPDPBSUDSZ128mb = 16112,
  VPDPBSUDSZ128mbk = 16113,
  VPDPBSUDSZ128mbkz = 16114,
  VPDPBSUDSZ128mk = 16115,
  VPDPBSUDSZ128mkz = 16116,
  VPDPBSUDSZ128r = 16117,
  VPDPBSUDSZ128rk = 16118,
  VPDPBSUDSZ128rkz = 16119,
  VPDPBSUDSZ256m = 16120,
  VPDPBSUDSZ256mb = 16121,
  VPDPBSUDSZ256mbk = 16122,
  VPDPBSUDSZ256mbkz = 16123,
  VPDPBSUDSZ256mk = 16124,
  VPDPBSUDSZ256mkz = 16125,
  VPDPBSUDSZ256r = 16126,
  VPDPBSUDSZ256rk = 16127,
  VPDPBSUDSZ256rkz = 16128,
  VPDPBSUDSZm = 16129,
  VPDPBSUDSZmb = 16130,
  VPDPBSUDSZmbk = 16131,
  VPDPBSUDSZmbkz = 16132,
  VPDPBSUDSZmk = 16133,
  VPDPBSUDSZmkz = 16134,
  VPDPBSUDSZr = 16135,
  VPDPBSUDSZrk = 16136,
  VPDPBSUDSZrkz = 16137,
  VPDPBSUDSrm = 16138,
  VPDPBSUDSrr = 16139,
  VPDPBSUDYrm = 16140,
  VPDPBSUDYrr = 16141,
  VPDPBSUDZ128m = 16142,
  VPDPBSUDZ128mb = 16143,
  VPDPBSUDZ128mbk = 16144,
  VPDPBSUDZ128mbkz = 16145,
  VPDPBSUDZ128mk = 16146,
  VPDPBSUDZ128mkz = 16147,
  VPDPBSUDZ128r = 16148,
  VPDPBSUDZ128rk = 16149,
  VPDPBSUDZ128rkz = 16150,
  VPDPBSUDZ256m = 16151,
  VPDPBSUDZ256mb = 16152,
  VPDPBSUDZ256mbk = 16153,
  VPDPBSUDZ256mbkz = 16154,
  VPDPBSUDZ256mk = 16155,
  VPDPBSUDZ256mkz = 16156,
  VPDPBSUDZ256r = 16157,
  VPDPBSUDZ256rk = 16158,
  VPDPBSUDZ256rkz = 16159,
  VPDPBSUDZm = 16160,
  VPDPBSUDZmb = 16161,
  VPDPBSUDZmbk = 16162,
  VPDPBSUDZmbkz = 16163,
  VPDPBSUDZmk = 16164,
  VPDPBSUDZmkz = 16165,
  VPDPBSUDZr = 16166,
  VPDPBSUDZrk = 16167,
  VPDPBSUDZrkz = 16168,
  VPDPBSUDrm = 16169,
  VPDPBSUDrr = 16170,
  VPDPBUSDSYrm = 16171,
  VPDPBUSDSYrr = 16172,
  VPDPBUSDSZ128m = 16173,
  VPDPBUSDSZ128mb = 16174,
  VPDPBUSDSZ128mbk = 16175,
  VPDPBUSDSZ128mbkz = 16176,
  VPDPBUSDSZ128mk = 16177,
  VPDPBUSDSZ128mkz = 16178,
  VPDPBUSDSZ128r = 16179,
  VPDPBUSDSZ128rk = 16180,
  VPDPBUSDSZ128rkz = 16181,
  VPDPBUSDSZ256m = 16182,
  VPDPBUSDSZ256mb = 16183,
  VPDPBUSDSZ256mbk = 16184,
  VPDPBUSDSZ256mbkz = 16185,
  VPDPBUSDSZ256mk = 16186,
  VPDPBUSDSZ256mkz = 16187,
  VPDPBUSDSZ256r = 16188,
  VPDPBUSDSZ256rk = 16189,
  VPDPBUSDSZ256rkz = 16190,
  VPDPBUSDSZm = 16191,
  VPDPBUSDSZmb = 16192,
  VPDPBUSDSZmbk = 16193,
  VPDPBUSDSZmbkz = 16194,
  VPDPBUSDSZmk = 16195,
  VPDPBUSDSZmkz = 16196,
  VPDPBUSDSZr = 16197,
  VPDPBUSDSZrk = 16198,
  VPDPBUSDSZrkz = 16199,
  VPDPBUSDSrm = 16200,
  VPDPBUSDSrr = 16201,
  VPDPBUSDYrm = 16202,
  VPDPBUSDYrr = 16203,
  VPDPBUSDZ128m = 16204,
  VPDPBUSDZ128mb = 16205,
  VPDPBUSDZ128mbk = 16206,
  VPDPBUSDZ128mbkz = 16207,
  VPDPBUSDZ128mk = 16208,
  VPDPBUSDZ128mkz = 16209,
  VPDPBUSDZ128r = 16210,
  VPDPBUSDZ128rk = 16211,
  VPDPBUSDZ128rkz = 16212,
  VPDPBUSDZ256m = 16213,
  VPDPBUSDZ256mb = 16214,
  VPDPBUSDZ256mbk = 16215,
  VPDPBUSDZ256mbkz = 16216,
  VPDPBUSDZ256mk = 16217,
  VPDPBUSDZ256mkz = 16218,
  VPDPBUSDZ256r = 16219,
  VPDPBUSDZ256rk = 16220,
  VPDPBUSDZ256rkz = 16221,
  VPDPBUSDZm = 16222,
  VPDPBUSDZmb = 16223,
  VPDPBUSDZmbk = 16224,
  VPDPBUSDZmbkz = 16225,
  VPDPBUSDZmk = 16226,
  VPDPBUSDZmkz = 16227,
  VPDPBUSDZr = 16228,
  VPDPBUSDZrk = 16229,
  VPDPBUSDZrkz = 16230,
  VPDPBUSDrm = 16231,
  VPDPBUSDrr = 16232,
  VPDPBUUDSYrm = 16233,
  VPDPBUUDSYrr = 16234,
  VPDPBUUDSZ128m = 16235,
  VPDPBUUDSZ128mb = 16236,
  VPDPBUUDSZ128mbk = 16237,
  VPDPBUUDSZ128mbkz = 16238,
  VPDPBUUDSZ128mk = 16239,
  VPDPBUUDSZ128mkz = 16240,
  VPDPBUUDSZ128r = 16241,
  VPDPBUUDSZ128rk = 16242,
  VPDPBUUDSZ128rkz = 16243,
  VPDPBUUDSZ256m = 16244,
  VPDPBUUDSZ256mb = 16245,
  VPDPBUUDSZ256mbk = 16246,
  VPDPBUUDSZ256mbkz = 16247,
  VPDPBUUDSZ256mk = 16248,
  VPDPBUUDSZ256mkz = 16249,
  VPDPBUUDSZ256r = 16250,
  VPDPBUUDSZ256rk = 16251,
  VPDPBUUDSZ256rkz = 16252,
  VPDPBUUDSZm = 16253,
  VPDPBUUDSZmb = 16254,
  VPDPBUUDSZmbk = 16255,
  VPDPBUUDSZmbkz = 16256,
  VPDPBUUDSZmk = 16257,
  VPDPBUUDSZmkz = 16258,
  VPDPBUUDSZr = 16259,
  VPDPBUUDSZrk = 16260,
  VPDPBUUDSZrkz = 16261,
  VPDPBUUDSrm = 16262,
  VPDPBUUDSrr = 16263,
  VPDPBUUDYrm = 16264,
  VPDPBUUDYrr = 16265,
  VPDPBUUDZ128m = 16266,
  VPDPBUUDZ128mb = 16267,
  VPDPBUUDZ128mbk = 16268,
  VPDPBUUDZ128mbkz = 16269,
  VPDPBUUDZ128mk = 16270,
  VPDPBUUDZ128mkz = 16271,
  VPDPBUUDZ128r = 16272,
  VPDPBUUDZ128rk = 16273,
  VPDPBUUDZ128rkz = 16274,
  VPDPBUUDZ256m = 16275,
  VPDPBUUDZ256mb = 16276,
  VPDPBUUDZ256mbk = 16277,
  VPDPBUUDZ256mbkz = 16278,
  VPDPBUUDZ256mk = 16279,
  VPDPBUUDZ256mkz = 16280,
  VPDPBUUDZ256r = 16281,
  VPDPBUUDZ256rk = 16282,
  VPDPBUUDZ256rkz = 16283,
  VPDPBUUDZm = 16284,
  VPDPBUUDZmb = 16285,
  VPDPBUUDZmbk = 16286,
  VPDPBUUDZmbkz = 16287,
  VPDPBUUDZmk = 16288,
  VPDPBUUDZmkz = 16289,
  VPDPBUUDZr = 16290,
  VPDPBUUDZrk = 16291,
  VPDPBUUDZrkz = 16292,
  VPDPBUUDrm = 16293,
  VPDPBUUDrr = 16294,
  VPDPWSSDSYrm = 16295,
  VPDPWSSDSYrr = 16296,
  VPDPWSSDSZ128m = 16297,
  VPDPWSSDSZ128mb = 16298,
  VPDPWSSDSZ128mbk = 16299,
  VPDPWSSDSZ128mbkz = 16300,
  VPDPWSSDSZ128mk = 16301,
  VPDPWSSDSZ128mkz = 16302,
  VPDPWSSDSZ128r = 16303,
  VPDPWSSDSZ128rk = 16304,
  VPDPWSSDSZ128rkz = 16305,
  VPDPWSSDSZ256m = 16306,
  VPDPWSSDSZ256mb = 16307,
  VPDPWSSDSZ256mbk = 16308,
  VPDPWSSDSZ256mbkz = 16309,
  VPDPWSSDSZ256mk = 16310,
  VPDPWSSDSZ256mkz = 16311,
  VPDPWSSDSZ256r = 16312,
  VPDPWSSDSZ256rk = 16313,
  VPDPWSSDSZ256rkz = 16314,
  VPDPWSSDSZm = 16315,
  VPDPWSSDSZmb = 16316,
  VPDPWSSDSZmbk = 16317,
  VPDPWSSDSZmbkz = 16318,
  VPDPWSSDSZmk = 16319,
  VPDPWSSDSZmkz = 16320,
  VPDPWSSDSZr = 16321,
  VPDPWSSDSZrk = 16322,
  VPDPWSSDSZrkz = 16323,
  VPDPWSSDSrm = 16324,
  VPDPWSSDSrr = 16325,
  VPDPWSSDYrm = 16326,
  VPDPWSSDYrr = 16327,
  VPDPWSSDZ128m = 16328,
  VPDPWSSDZ128mb = 16329,
  VPDPWSSDZ128mbk = 16330,
  VPDPWSSDZ128mbkz = 16331,
  VPDPWSSDZ128mk = 16332,
  VPDPWSSDZ128mkz = 16333,
  VPDPWSSDZ128r = 16334,
  VPDPWSSDZ128rk = 16335,
  VPDPWSSDZ128rkz = 16336,
  VPDPWSSDZ256m = 16337,
  VPDPWSSDZ256mb = 16338,
  VPDPWSSDZ256mbk = 16339,
  VPDPWSSDZ256mbkz = 16340,
  VPDPWSSDZ256mk = 16341,
  VPDPWSSDZ256mkz = 16342,
  VPDPWSSDZ256r = 16343,
  VPDPWSSDZ256rk = 16344,
  VPDPWSSDZ256rkz = 16345,
  VPDPWSSDZm = 16346,
  VPDPWSSDZmb = 16347,
  VPDPWSSDZmbk = 16348,
  VPDPWSSDZmbkz = 16349,
  VPDPWSSDZmk = 16350,
  VPDPWSSDZmkz = 16351,
  VPDPWSSDZr = 16352,
  VPDPWSSDZrk = 16353,
  VPDPWSSDZrkz = 16354,
  VPDPWSSDrm = 16355,
  VPDPWSSDrr = 16356,
  VPDPWSUDSYrm = 16357,
  VPDPWSUDSYrr = 16358,
  VPDPWSUDSZ128m = 16359,
  VPDPWSUDSZ128mb = 16360,
  VPDPWSUDSZ128mbk = 16361,
  VPDPWSUDSZ128mbkz = 16362,
  VPDPWSUDSZ128mk = 16363,
  VPDPWSUDSZ128mkz = 16364,
  VPDPWSUDSZ128r = 16365,
  VPDPWSUDSZ128rk = 16366,
  VPDPWSUDSZ128rkz = 16367,
  VPDPWSUDSZ256m = 16368,
  VPDPWSUDSZ256mb = 16369,
  VPDPWSUDSZ256mbk = 16370,
  VPDPWSUDSZ256mbkz = 16371,
  VPDPWSUDSZ256mk = 16372,
  VPDPWSUDSZ256mkz = 16373,
  VPDPWSUDSZ256r = 16374,
  VPDPWSUDSZ256rk = 16375,
  VPDPWSUDSZ256rkz = 16376,
  VPDPWSUDSZm = 16377,
  VPDPWSUDSZmb = 16378,
  VPDPWSUDSZmbk = 16379,
  VPDPWSUDSZmbkz = 16380,
  VPDPWSUDSZmk = 16381,
  VPDPWSUDSZmkz = 16382,
  VPDPWSUDSZr = 16383,
  VPDPWSUDSZrk = 16384,
  VPDPWSUDSZrkz = 16385,
  VPDPWSUDSrm = 16386,
  VPDPWSUDSrr = 16387,
  VPDPWSUDYrm = 16388,
  VPDPWSUDYrr = 16389,
  VPDPWSUDZ128m = 16390,
  VPDPWSUDZ128mb = 16391,
  VPDPWSUDZ128mbk = 16392,
  VPDPWSUDZ128mbkz = 16393,
  VPDPWSUDZ128mk = 16394,
  VPDPWSUDZ128mkz = 16395,
  VPDPWSUDZ128r = 16396,
  VPDPWSUDZ128rk = 16397,
  VPDPWSUDZ128rkz = 16398,
  VPDPWSUDZ256m = 16399,
  VPDPWSUDZ256mb = 16400,
  VPDPWSUDZ256mbk = 16401,
  VPDPWSUDZ256mbkz = 16402,
  VPDPWSUDZ256mk = 16403,
  VPDPWSUDZ256mkz = 16404,
  VPDPWSUDZ256r = 16405,
  VPDPWSUDZ256rk = 16406,
  VPDPWSUDZ256rkz = 16407,
  VPDPWSUDZm = 16408,
  VPDPWSUDZmb = 16409,
  VPDPWSUDZmbk = 16410,
  VPDPWSUDZmbkz = 16411,
  VPDPWSUDZmk = 16412,
  VPDPWSUDZmkz = 16413,
  VPDPWSUDZr = 16414,
  VPDPWSUDZrk = 16415,
  VPDPWSUDZrkz = 16416,
  VPDPWSUDrm = 16417,
  VPDPWSUDrr = 16418,
  VPDPWUSDSYrm = 16419,
  VPDPWUSDSYrr = 16420,
  VPDPWUSDSZ128m = 16421,
  VPDPWUSDSZ128mb = 16422,
  VPDPWUSDSZ128mbk = 16423,
  VPDPWUSDSZ128mbkz = 16424,
  VPDPWUSDSZ128mk = 16425,
  VPDPWUSDSZ128mkz = 16426,
  VPDPWUSDSZ128r = 16427,
  VPDPWUSDSZ128rk = 16428,
  VPDPWUSDSZ128rkz = 16429,
  VPDPWUSDSZ256m = 16430,
  VPDPWUSDSZ256mb = 16431,
  VPDPWUSDSZ256mbk = 16432,
  VPDPWUSDSZ256mbkz = 16433,
  VPDPWUSDSZ256mk = 16434,
  VPDPWUSDSZ256mkz = 16435,
  VPDPWUSDSZ256r = 16436,
  VPDPWUSDSZ256rk = 16437,
  VPDPWUSDSZ256rkz = 16438,
  VPDPWUSDSZm = 16439,
  VPDPWUSDSZmb = 16440,
  VPDPWUSDSZmbk = 16441,
  VPDPWUSDSZmbkz = 16442,
  VPDPWUSDSZmk = 16443,
  VPDPWUSDSZmkz = 16444,
  VPDPWUSDSZr = 16445,
  VPDPWUSDSZrk = 16446,
  VPDPWUSDSZrkz = 16447,
  VPDPWUSDSrm = 16448,
  VPDPWUSDSrr = 16449,
  VPDPWUSDYrm = 16450,
  VPDPWUSDYrr = 16451,
  VPDPWUSDZ128m = 16452,
  VPDPWUSDZ128mb = 16453,
  VPDPWUSDZ128mbk = 16454,
  VPDPWUSDZ128mbkz = 16455,
  VPDPWUSDZ128mk = 16456,
  VPDPWUSDZ128mkz = 16457,
  VPDPWUSDZ128r = 16458,
  VPDPWUSDZ128rk = 16459,
  VPDPWUSDZ128rkz = 16460,
  VPDPWUSDZ256m = 16461,
  VPDPWUSDZ256mb = 16462,
  VPDPWUSDZ256mbk = 16463,
  VPDPWUSDZ256mbkz = 16464,
  VPDPWUSDZ256mk = 16465,
  VPDPWUSDZ256mkz = 16466,
  VPDPWUSDZ256r = 16467,
  VPDPWUSDZ256rk = 16468,
  VPDPWUSDZ256rkz = 16469,
  VPDPWUSDZm = 16470,
  VPDPWUSDZmb = 16471,
  VPDPWUSDZmbk = 16472,
  VPDPWUSDZmbkz = 16473,
  VPDPWUSDZmk = 16474,
  VPDPWUSDZmkz = 16475,
  VPDPWUSDZr = 16476,
  VPDPWUSDZrk = 16477,
  VPDPWUSDZrkz = 16478,
  VPDPWUSDrm = 16479,
  VPDPWUSDrr = 16480,
  VPDPWUUDSYrm = 16481,
  VPDPWUUDSYrr = 16482,
  VPDPWUUDSZ128m = 16483,
  VPDPWUUDSZ128mb = 16484,
  VPDPWUUDSZ128mbk = 16485,
  VPDPWUUDSZ128mbkz = 16486,
  VPDPWUUDSZ128mk = 16487,
  VPDPWUUDSZ128mkz = 16488,
  VPDPWUUDSZ128r = 16489,
  VPDPWUUDSZ128rk = 16490,
  VPDPWUUDSZ128rkz = 16491,
  VPDPWUUDSZ256m = 16492,
  VPDPWUUDSZ256mb = 16493,
  VPDPWUUDSZ256mbk = 16494,
  VPDPWUUDSZ256mbkz = 16495,
  VPDPWUUDSZ256mk = 16496,
  VPDPWUUDSZ256mkz = 16497,
  VPDPWUUDSZ256r = 16498,
  VPDPWUUDSZ256rk = 16499,
  VPDPWUUDSZ256rkz = 16500,
  VPDPWUUDSZm = 16501,
  VPDPWUUDSZmb = 16502,
  VPDPWUUDSZmbk = 16503,
  VPDPWUUDSZmbkz = 16504,
  VPDPWUUDSZmk = 16505,
  VPDPWUUDSZmkz = 16506,
  VPDPWUUDSZr = 16507,
  VPDPWUUDSZrk = 16508,
  VPDPWUUDSZrkz = 16509,
  VPDPWUUDSrm = 16510,
  VPDPWUUDSrr = 16511,
  VPDPWUUDYrm = 16512,
  VPDPWUUDYrr = 16513,
  VPDPWUUDZ128m = 16514,
  VPDPWUUDZ128mb = 16515,
  VPDPWUUDZ128mbk = 16516,
  VPDPWUUDZ128mbkz = 16517,
  VPDPWUUDZ128mk = 16518,
  VPDPWUUDZ128mkz = 16519,
  VPDPWUUDZ128r = 16520,
  VPDPWUUDZ128rk = 16521,
  VPDPWUUDZ128rkz = 16522,
  VPDPWUUDZ256m = 16523,
  VPDPWUUDZ256mb = 16524,
  VPDPWUUDZ256mbk = 16525,
  VPDPWUUDZ256mbkz = 16526,
  VPDPWUUDZ256mk = 16527,
  VPDPWUUDZ256mkz = 16528,
  VPDPWUUDZ256r = 16529,
  VPDPWUUDZ256rk = 16530,
  VPDPWUUDZ256rkz = 16531,
  VPDPWUUDZm = 16532,
  VPDPWUUDZmb = 16533,
  VPDPWUUDZmbk = 16534,
  VPDPWUUDZmbkz = 16535,
  VPDPWUUDZmk = 16536,
  VPDPWUUDZmkz = 16537,
  VPDPWUUDZr = 16538,
  VPDPWUUDZrk = 16539,
  VPDPWUUDZrkz = 16540,
  VPDPWUUDrm = 16541,
  VPDPWUUDrr = 16542,
  VPERM2F128rmi = 16543,
  VPERM2F128rri = 16544,
  VPERM2I128rmi = 16545,
  VPERM2I128rri = 16546,
  VPERMBZ128rm = 16547,
  VPERMBZ128rmk = 16548,
  VPERMBZ128rmkz = 16549,
  VPERMBZ128rr = 16550,
  VPERMBZ128rrk = 16551,
  VPERMBZ128rrkz = 16552,
  VPERMBZ256rm = 16553,
  VPERMBZ256rmk = 16554,
  VPERMBZ256rmkz = 16555,
  VPERMBZ256rr = 16556,
  VPERMBZ256rrk = 16557,
  VPERMBZ256rrkz = 16558,
  VPERMBZrm = 16559,
  VPERMBZrmk = 16560,
  VPERMBZrmkz = 16561,
  VPERMBZrr = 16562,
  VPERMBZrrk = 16563,
  VPERMBZrrkz = 16564,
  VPERMDYrm = 16565,
  VPERMDYrr = 16566,
  VPERMDZ256rm = 16567,
  VPERMDZ256rmb = 16568,
  VPERMDZ256rmbk = 16569,
  VPERMDZ256rmbkz = 16570,
  VPERMDZ256rmk = 16571,
  VPERMDZ256rmkz = 16572,
  VPERMDZ256rr = 16573,
  VPERMDZ256rrk = 16574,
  VPERMDZ256rrkz = 16575,
  VPERMDZrm = 16576,
  VPERMDZrmb = 16577,
  VPERMDZrmbk = 16578,
  VPERMDZrmbkz = 16579,
  VPERMDZrmk = 16580,
  VPERMDZrmkz = 16581,
  VPERMDZrr = 16582,
  VPERMDZrrk = 16583,
  VPERMDZrrkz = 16584,
  VPERMI2BZ128rm = 16585,
  VPERMI2BZ128rmk = 16586,
  VPERMI2BZ128rmkz = 16587,
  VPERMI2BZ128rr = 16588,
  VPERMI2BZ128rrk = 16589,
  VPERMI2BZ128rrkz = 16590,
  VPERMI2BZ256rm = 16591,
  VPERMI2BZ256rmk = 16592,
  VPERMI2BZ256rmkz = 16593,
  VPERMI2BZ256rr = 16594,
  VPERMI2BZ256rrk = 16595,
  VPERMI2BZ256rrkz = 16596,
  VPERMI2BZrm = 16597,
  VPERMI2BZrmk = 16598,
  VPERMI2BZrmkz = 16599,
  VPERMI2BZrr = 16600,
  VPERMI2BZrrk = 16601,
  VPERMI2BZrrkz = 16602,
  VPERMI2DZ128rm = 16603,
  VPERMI2DZ128rmb = 16604,
  VPERMI2DZ128rmbk = 16605,
  VPERMI2DZ128rmbkz = 16606,
  VPERMI2DZ128rmk = 16607,
  VPERMI2DZ128rmkz = 16608,
  VPERMI2DZ128rr = 16609,
  VPERMI2DZ128rrk = 16610,
  VPERMI2DZ128rrkz = 16611,
  VPERMI2DZ256rm = 16612,
  VPERMI2DZ256rmb = 16613,
  VPERMI2DZ256rmbk = 16614,
  VPERMI2DZ256rmbkz = 16615,
  VPERMI2DZ256rmk = 16616,
  VPERMI2DZ256rmkz = 16617,
  VPERMI2DZ256rr = 16618,
  VPERMI2DZ256rrk = 16619,
  VPERMI2DZ256rrkz = 16620,
  VPERMI2DZrm = 16621,
  VPERMI2DZrmb = 16622,
  VPERMI2DZrmbk = 16623,
  VPERMI2DZrmbkz = 16624,
  VPERMI2DZrmk = 16625,
  VPERMI2DZrmkz = 16626,
  VPERMI2DZrr = 16627,
  VPERMI2DZrrk = 16628,
  VPERMI2DZrrkz = 16629,
  VPERMI2PDZ128rm = 16630,
  VPERMI2PDZ128rmb = 16631,
  VPERMI2PDZ128rmbk = 16632,
  VPERMI2PDZ128rmbkz = 16633,
  VPERMI2PDZ128rmk = 16634,
  VPERMI2PDZ128rmkz = 16635,
  VPERMI2PDZ128rr = 16636,
  VPERMI2PDZ128rrk = 16637,
  VPERMI2PDZ128rrkz = 16638,
  VPERMI2PDZ256rm = 16639,
  VPERMI2PDZ256rmb = 16640,
  VPERMI2PDZ256rmbk = 16641,
  VPERMI2PDZ256rmbkz = 16642,
  VPERMI2PDZ256rmk = 16643,
  VPERMI2PDZ256rmkz = 16644,
  VPERMI2PDZ256rr = 16645,
  VPERMI2PDZ256rrk = 16646,
  VPERMI2PDZ256rrkz = 16647,
  VPERMI2PDZrm = 16648,
  VPERMI2PDZrmb = 16649,
  VPERMI2PDZrmbk = 16650,
  VPERMI2PDZrmbkz = 16651,
  VPERMI2PDZrmk = 16652,
  VPERMI2PDZrmkz = 16653,
  VPERMI2PDZrr = 16654,
  VPERMI2PDZrrk = 16655,
  VPERMI2PDZrrkz = 16656,
  VPERMI2PSZ128rm = 16657,
  VPERMI2PSZ128rmb = 16658,
  VPERMI2PSZ128rmbk = 16659,
  VPERMI2PSZ128rmbkz = 16660,
  VPERMI2PSZ128rmk = 16661,
  VPERMI2PSZ128rmkz = 16662,
  VPERMI2PSZ128rr = 16663,
  VPERMI2PSZ128rrk = 16664,
  VPERMI2PSZ128rrkz = 16665,
  VPERMI2PSZ256rm = 16666,
  VPERMI2PSZ256rmb = 16667,
  VPERMI2PSZ256rmbk = 16668,
  VPERMI2PSZ256rmbkz = 16669,
  VPERMI2PSZ256rmk = 16670,
  VPERMI2PSZ256rmkz = 16671,
  VPERMI2PSZ256rr = 16672,
  VPERMI2PSZ256rrk = 16673,
  VPERMI2PSZ256rrkz = 16674,
  VPERMI2PSZrm = 16675,
  VPERMI2PSZrmb = 16676,
  VPERMI2PSZrmbk = 16677,
  VPERMI2PSZrmbkz = 16678,
  VPERMI2PSZrmk = 16679,
  VPERMI2PSZrmkz = 16680,
  VPERMI2PSZrr = 16681,
  VPERMI2PSZrrk = 16682,
  VPERMI2PSZrrkz = 16683,
  VPERMI2QZ128rm = 16684,
  VPERMI2QZ128rmb = 16685,
  VPERMI2QZ128rmbk = 16686,
  VPERMI2QZ128rmbkz = 16687,
  VPERMI2QZ128rmk = 16688,
  VPERMI2QZ128rmkz = 16689,
  VPERMI2QZ128rr = 16690,
  VPERMI2QZ128rrk = 16691,
  VPERMI2QZ128rrkz = 16692,
  VPERMI2QZ256rm = 16693,
  VPERMI2QZ256rmb = 16694,
  VPERMI2QZ256rmbk = 16695,
  VPERMI2QZ256rmbkz = 16696,
  VPERMI2QZ256rmk = 16697,
  VPERMI2QZ256rmkz = 16698,
  VPERMI2QZ256rr = 16699,
  VPERMI2QZ256rrk = 16700,
  VPERMI2QZ256rrkz = 16701,
  VPERMI2QZrm = 16702,
  VPERMI2QZrmb = 16703,
  VPERMI2QZrmbk = 16704,
  VPERMI2QZrmbkz = 16705,
  VPERMI2QZrmk = 16706,
  VPERMI2QZrmkz = 16707,
  VPERMI2QZrr = 16708,
  VPERMI2QZrrk = 16709,
  VPERMI2QZrrkz = 16710,
  VPERMI2WZ128rm = 16711,
  VPERMI2WZ128rmk = 16712,
  VPERMI2WZ128rmkz = 16713,
  VPERMI2WZ128rr = 16714,
  VPERMI2WZ128rrk = 16715,
  VPERMI2WZ128rrkz = 16716,
  VPERMI2WZ256rm = 16717,
  VPERMI2WZ256rmk = 16718,
  VPERMI2WZ256rmkz = 16719,
  VPERMI2WZ256rr = 16720,
  VPERMI2WZ256rrk = 16721,
  VPERMI2WZ256rrkz = 16722,
  VPERMI2WZrm = 16723,
  VPERMI2WZrmk = 16724,
  VPERMI2WZrmkz = 16725,
  VPERMI2WZrr = 16726,
  VPERMI2WZrrk = 16727,
  VPERMI2WZrrkz = 16728,
  VPERMIL2PDYmr = 16729,
  VPERMIL2PDYrm = 16730,
  VPERMIL2PDYrr = 16731,
  VPERMIL2PDYrr_REV = 16732,
  VPERMIL2PDmr = 16733,
  VPERMIL2PDrm = 16734,
  VPERMIL2PDrr = 16735,
  VPERMIL2PDrr_REV = 16736,
  VPERMIL2PSYmr = 16737,
  VPERMIL2PSYrm = 16738,
  VPERMIL2PSYrr = 16739,
  VPERMIL2PSYrr_REV = 16740,
  VPERMIL2PSmr = 16741,
  VPERMIL2PSrm = 16742,
  VPERMIL2PSrr = 16743,
  VPERMIL2PSrr_REV = 16744,
  VPERMILPDYmi = 16745,
  VPERMILPDYri = 16746,
  VPERMILPDYrm = 16747,
  VPERMILPDYrr = 16748,
  VPERMILPDZ128mbi = 16749,
  VPERMILPDZ128mbik = 16750,
  VPERMILPDZ128mbikz = 16751,
  VPERMILPDZ128mi = 16752,
  VPERMILPDZ128mik = 16753,
  VPERMILPDZ128mikz = 16754,
  VPERMILPDZ128ri = 16755,
  VPERMILPDZ128rik = 16756,
  VPERMILPDZ128rikz = 16757,
  VPERMILPDZ128rm = 16758,
  VPERMILPDZ128rmb = 16759,
  VPERMILPDZ128rmbk = 16760,
  VPERMILPDZ128rmbkz = 16761,
  VPERMILPDZ128rmk = 16762,
  VPERMILPDZ128rmkz = 16763,
  VPERMILPDZ128rr = 16764,
  VPERMILPDZ128rrk = 16765,
  VPERMILPDZ128rrkz = 16766,
  VPERMILPDZ256mbi = 16767,
  VPERMILPDZ256mbik = 16768,
  VPERMILPDZ256mbikz = 16769,
  VPERMILPDZ256mi = 16770,
  VPERMILPDZ256mik = 16771,
  VPERMILPDZ256mikz = 16772,
  VPERMILPDZ256ri = 16773,
  VPERMILPDZ256rik = 16774,
  VPERMILPDZ256rikz = 16775,
  VPERMILPDZ256rm = 16776,
  VPERMILPDZ256rmb = 16777,
  VPERMILPDZ256rmbk = 16778,
  VPERMILPDZ256rmbkz = 16779,
  VPERMILPDZ256rmk = 16780,
  VPERMILPDZ256rmkz = 16781,
  VPERMILPDZ256rr = 16782,
  VPERMILPDZ256rrk = 16783,
  VPERMILPDZ256rrkz = 16784,
  VPERMILPDZmbi = 16785,
  VPERMILPDZmbik = 16786,
  VPERMILPDZmbikz = 16787,
  VPERMILPDZmi = 16788,
  VPERMILPDZmik = 16789,
  VPERMILPDZmikz = 16790,
  VPERMILPDZri = 16791,
  VPERMILPDZrik = 16792,
  VPERMILPDZrikz = 16793,
  VPERMILPDZrm = 16794,
  VPERMILPDZrmb = 16795,
  VPERMILPDZrmbk = 16796,
  VPERMILPDZrmbkz = 16797,
  VPERMILPDZrmk = 16798,
  VPERMILPDZrmkz = 16799,
  VPERMILPDZrr = 16800,
  VPERMILPDZrrk = 16801,
  VPERMILPDZrrkz = 16802,
  VPERMILPDmi = 16803,
  VPERMILPDri = 16804,
  VPERMILPDrm = 16805,
  VPERMILPDrr = 16806,
  VPERMILPSYmi = 16807,
  VPERMILPSYri = 16808,
  VPERMILPSYrm = 16809,
  VPERMILPSYrr = 16810,
  VPERMILPSZ128mbi = 16811,
  VPERMILPSZ128mbik = 16812,
  VPERMILPSZ128mbikz = 16813,
  VPERMILPSZ128mi = 16814,
  VPERMILPSZ128mik = 16815,
  VPERMILPSZ128mikz = 16816,
  VPERMILPSZ128ri = 16817,
  VPERMILPSZ128rik = 16818,
  VPERMILPSZ128rikz = 16819,
  VPERMILPSZ128rm = 16820,
  VPERMILPSZ128rmb = 16821,
  VPERMILPSZ128rmbk = 16822,
  VPERMILPSZ128rmbkz = 16823,
  VPERMILPSZ128rmk = 16824,
  VPERMILPSZ128rmkz = 16825,
  VPERMILPSZ128rr = 16826,
  VPERMILPSZ128rrk = 16827,
  VPERMILPSZ128rrkz = 16828,
  VPERMILPSZ256mbi = 16829,
  VPERMILPSZ256mbik = 16830,
  VPERMILPSZ256mbikz = 16831,
  VPERMILPSZ256mi = 16832,
  VPERMILPSZ256mik = 16833,
  VPERMILPSZ256mikz = 16834,
  VPERMILPSZ256ri = 16835,
  VPERMILPSZ256rik = 16836,
  VPERMILPSZ256rikz = 16837,
  VPERMILPSZ256rm = 16838,
  VPERMILPSZ256rmb = 16839,
  VPERMILPSZ256rmbk = 16840,
  VPERMILPSZ256rmbkz = 16841,
  VPERMILPSZ256rmk = 16842,
  VPERMILPSZ256rmkz = 16843,
  VPERMILPSZ256rr = 16844,
  VPERMILPSZ256rrk = 16845,
  VPERMILPSZ256rrkz = 16846,
  VPERMILPSZmbi = 16847,
  VPERMILPSZmbik = 16848,
  VPERMILPSZmbikz = 16849,
  VPERMILPSZmi = 16850,
  VPERMILPSZmik = 16851,
  VPERMILPSZmikz = 16852,
  VPERMILPSZri = 16853,
  VPERMILPSZrik = 16854,
  VPERMILPSZrikz = 16855,
  VPERMILPSZrm = 16856,
  VPERMILPSZrmb = 16857,
  VPERMILPSZrmbk = 16858,
  VPERMILPSZrmbkz = 16859,
  VPERMILPSZrmk = 16860,
  VPERMILPSZrmkz = 16861,
  VPERMILPSZrr = 16862,
  VPERMILPSZrrk = 16863,
  VPERMILPSZrrkz = 16864,
  VPERMILPSmi = 16865,
  VPERMILPSri = 16866,
  VPERMILPSrm = 16867,
  VPERMILPSrr = 16868,
  VPERMPDYmi = 16869,
  VPERMPDYri = 16870,
  VPERMPDZ256mbi = 16871,
  VPERMPDZ256mbik = 16872,
  VPERMPDZ256mbikz = 16873,
  VPERMPDZ256mi = 16874,
  VPERMPDZ256mik = 16875,
  VPERMPDZ256mikz = 16876,
  VPERMPDZ256ri = 16877,
  VPERMPDZ256rik = 16878,
  VPERMPDZ256rikz = 16879,
  VPERMPDZ256rm = 16880,
  VPERMPDZ256rmb = 16881,
  VPERMPDZ256rmbk = 16882,
  VPERMPDZ256rmbkz = 16883,
  VPERMPDZ256rmk = 16884,
  VPERMPDZ256rmkz = 16885,
  VPERMPDZ256rr = 16886,
  VPERMPDZ256rrk = 16887,
  VPERMPDZ256rrkz = 16888,
  VPERMPDZmbi = 16889,
  VPERMPDZmbik = 16890,
  VPERMPDZmbikz = 16891,
  VPERMPDZmi = 16892,
  VPERMPDZmik = 16893,
  VPERMPDZmikz = 16894,
  VPERMPDZri = 16895,
  VPERMPDZrik = 16896,
  VPERMPDZrikz = 16897,
  VPERMPDZrm = 16898,
  VPERMPDZrmb = 16899,
  VPERMPDZrmbk = 16900,
  VPERMPDZrmbkz = 16901,
  VPERMPDZrmk = 16902,
  VPERMPDZrmkz = 16903,
  VPERMPDZrr = 16904,
  VPERMPDZrrk = 16905,
  VPERMPDZrrkz = 16906,
  VPERMPSYrm = 16907,
  VPERMPSYrr = 16908,
  VPERMPSZ256rm = 16909,
  VPERMPSZ256rmb = 16910,
  VPERMPSZ256rmbk = 16911,
  VPERMPSZ256rmbkz = 16912,
  VPERMPSZ256rmk = 16913,
  VPERMPSZ256rmkz = 16914,
  VPERMPSZ256rr = 16915,
  VPERMPSZ256rrk = 16916,
  VPERMPSZ256rrkz = 16917,
  VPERMPSZrm = 16918,
  VPERMPSZrmb = 16919,
  VPERMPSZrmbk = 16920,
  VPERMPSZrmbkz = 16921,
  VPERMPSZrmk = 16922,
  VPERMPSZrmkz = 16923,
  VPERMPSZrr = 16924,
  VPERMPSZrrk = 16925,
  VPERMPSZrrkz = 16926,
  VPERMQYmi = 16927,
  VPERMQYri = 16928,
  VPERMQZ256mbi = 16929,
  VPERMQZ256mbik = 16930,
  VPERMQZ256mbikz = 16931,
  VPERMQZ256mi = 16932,
  VPERMQZ256mik = 16933,
  VPERMQZ256mikz = 16934,
  VPERMQZ256ri = 16935,
  VPERMQZ256rik = 16936,
  VPERMQZ256rikz = 16937,
  VPERMQZ256rm = 16938,
  VPERMQZ256rmb = 16939,
  VPERMQZ256rmbk = 16940,
  VPERMQZ256rmbkz = 16941,
  VPERMQZ256rmk = 16942,
  VPERMQZ256rmkz = 16943,
  VPERMQZ256rr = 16944,
  VPERMQZ256rrk = 16945,
  VPERMQZ256rrkz = 16946,
  VPERMQZmbi = 16947,
  VPERMQZmbik = 16948,
  VPERMQZmbikz = 16949,
  VPERMQZmi = 16950,
  VPERMQZmik = 16951,
  VPERMQZmikz = 16952,
  VPERMQZri = 16953,
  VPERMQZrik = 16954,
  VPERMQZrikz = 16955,
  VPERMQZrm = 16956,
  VPERMQZrmb = 16957,
  VPERMQZrmbk = 16958,
  VPERMQZrmbkz = 16959,
  VPERMQZrmk = 16960,
  VPERMQZrmkz = 16961,
  VPERMQZrr = 16962,
  VPERMQZrrk = 16963,
  VPERMQZrrkz = 16964,
  VPERMT2BZ128rm = 16965,
  VPERMT2BZ128rmk = 16966,
  VPERMT2BZ128rmkz = 16967,
  VPERMT2BZ128rr = 16968,
  VPERMT2BZ128rrk = 16969,
  VPERMT2BZ128rrkz = 16970,
  VPERMT2BZ256rm = 16971,
  VPERMT2BZ256rmk = 16972,
  VPERMT2BZ256rmkz = 16973,
  VPERMT2BZ256rr = 16974,
  VPERMT2BZ256rrk = 16975,
  VPERMT2BZ256rrkz = 16976,
  VPERMT2BZrm = 16977,
  VPERMT2BZrmk = 16978,
  VPERMT2BZrmkz = 16979,
  VPERMT2BZrr = 16980,
  VPERMT2BZrrk = 16981,
  VPERMT2BZrrkz = 16982,
  VPERMT2DZ128rm = 16983,
  VPERMT2DZ128rmb = 16984,
  VPERMT2DZ128rmbk = 16985,
  VPERMT2DZ128rmbkz = 16986,
  VPERMT2DZ128rmk = 16987,
  VPERMT2DZ128rmkz = 16988,
  VPERMT2DZ128rr = 16989,
  VPERMT2DZ128rrk = 16990,
  VPERMT2DZ128rrkz = 16991,
  VPERMT2DZ256rm = 16992,
  VPERMT2DZ256rmb = 16993,
  VPERMT2DZ256rmbk = 16994,
  VPERMT2DZ256rmbkz = 16995,
  VPERMT2DZ256rmk = 16996,
  VPERMT2DZ256rmkz = 16997,
  VPERMT2DZ256rr = 16998,
  VPERMT2DZ256rrk = 16999,
  VPERMT2DZ256rrkz = 17000,
  VPERMT2DZrm = 17001,
  VPERMT2DZrmb = 17002,
  VPERMT2DZrmbk = 17003,
  VPERMT2DZrmbkz = 17004,
  VPERMT2DZrmk = 17005,
  VPERMT2DZrmkz = 17006,
  VPERMT2DZrr = 17007,
  VPERMT2DZrrk = 17008,
  VPERMT2DZrrkz = 17009,
  VPERMT2PDZ128rm = 17010,
  VPERMT2PDZ128rmb = 17011,
  VPERMT2PDZ128rmbk = 17012,
  VPERMT2PDZ128rmbkz = 17013,
  VPERMT2PDZ128rmk = 17014,
  VPERMT2PDZ128rmkz = 17015,
  VPERMT2PDZ128rr = 17016,
  VPERMT2PDZ128rrk = 17017,
  VPERMT2PDZ128rrkz = 17018,
  VPERMT2PDZ256rm = 17019,
  VPERMT2PDZ256rmb = 17020,
  VPERMT2PDZ256rmbk = 17021,
  VPERMT2PDZ256rmbkz = 17022,
  VPERMT2PDZ256rmk = 17023,
  VPERMT2PDZ256rmkz = 17024,
  VPERMT2PDZ256rr = 17025,
  VPERMT2PDZ256rrk = 17026,
  VPERMT2PDZ256rrkz = 17027,
  VPERMT2PDZrm = 17028,
  VPERMT2PDZrmb = 17029,
  VPERMT2PDZrmbk = 17030,
  VPERMT2PDZrmbkz = 17031,
  VPERMT2PDZrmk = 17032,
  VPERMT2PDZrmkz = 17033,
  VPERMT2PDZrr = 17034,
  VPERMT2PDZrrk = 17035,
  VPERMT2PDZrrkz = 17036,
  VPERMT2PSZ128rm = 17037,
  VPERMT2PSZ128rmb = 17038,
  VPERMT2PSZ128rmbk = 17039,
  VPERMT2PSZ128rmbkz = 17040,
  VPERMT2PSZ128rmk = 17041,
  VPERMT2PSZ128rmkz = 17042,
  VPERMT2PSZ128rr = 17043,
  VPERMT2PSZ128rrk = 17044,
  VPERMT2PSZ128rrkz = 17045,
  VPERMT2PSZ256rm = 17046,
  VPERMT2PSZ256rmb = 17047,
  VPERMT2PSZ256rmbk = 17048,
  VPERMT2PSZ256rmbkz = 17049,
  VPERMT2PSZ256rmk = 17050,
  VPERMT2PSZ256rmkz = 17051,
  VPERMT2PSZ256rr = 17052,
  VPERMT2PSZ256rrk = 17053,
  VPERMT2PSZ256rrkz = 17054,
  VPERMT2PSZrm = 17055,
  VPERMT2PSZrmb = 17056,
  VPERMT2PSZrmbk = 17057,
  VPERMT2PSZrmbkz = 17058,
  VPERMT2PSZrmk = 17059,
  VPERMT2PSZrmkz = 17060,
  VPERMT2PSZrr = 17061,
  VPERMT2PSZrrk = 17062,
  VPERMT2PSZrrkz = 17063,
  VPERMT2QZ128rm = 17064,
  VPERMT2QZ128rmb = 17065,
  VPERMT2QZ128rmbk = 17066,
  VPERMT2QZ128rmbkz = 17067,
  VPERMT2QZ128rmk = 17068,
  VPERMT2QZ128rmkz = 17069,
  VPERMT2QZ128rr = 17070,
  VPERMT2QZ128rrk = 17071,
  VPERMT2QZ128rrkz = 17072,
  VPERMT2QZ256rm = 17073,
  VPERMT2QZ256rmb = 17074,
  VPERMT2QZ256rmbk = 17075,
  VPERMT2QZ256rmbkz = 17076,
  VPERMT2QZ256rmk = 17077,
  VPERMT2QZ256rmkz = 17078,
  VPERMT2QZ256rr = 17079,
  VPERMT2QZ256rrk = 17080,
  VPERMT2QZ256rrkz = 17081,
  VPERMT2QZrm = 17082,
  VPERMT2QZrmb = 17083,
  VPERMT2QZrmbk = 17084,
  VPERMT2QZrmbkz = 17085,
  VPERMT2QZrmk = 17086,
  VPERMT2QZrmkz = 17087,
  VPERMT2QZrr = 17088,
  VPERMT2QZrrk = 17089,
  VPERMT2QZrrkz = 17090,
  VPERMT2WZ128rm = 17091,
  VPERMT2WZ128rmk = 17092,
  VPERMT2WZ128rmkz = 17093,
  VPERMT2WZ128rr = 17094,
  VPERMT2WZ128rrk = 17095,
  VPERMT2WZ128rrkz = 17096,
  VPERMT2WZ256rm = 17097,
  VPERMT2WZ256rmk = 17098,
  VPERMT2WZ256rmkz = 17099,
  VPERMT2WZ256rr = 17100,
  VPERMT2WZ256rrk = 17101,
  VPERMT2WZ256rrkz = 17102,
  VPERMT2WZrm = 17103,
  VPERMT2WZrmk = 17104,
  VPERMT2WZrmkz = 17105,
  VPERMT2WZrr = 17106,
  VPERMT2WZrrk = 17107,
  VPERMT2WZrrkz = 17108,
  VPERMWZ128rm = 17109,
  VPERMWZ128rmk = 17110,
  VPERMWZ128rmkz = 17111,
  VPERMWZ128rr = 17112,
  VPERMWZ128rrk = 17113,
  VPERMWZ128rrkz = 17114,
  VPERMWZ256rm = 17115,
  VPERMWZ256rmk = 17116,
  VPERMWZ256rmkz = 17117,
  VPERMWZ256rr = 17118,
  VPERMWZ256rrk = 17119,
  VPERMWZ256rrkz = 17120,
  VPERMWZrm = 17121,
  VPERMWZrmk = 17122,
  VPERMWZrmkz = 17123,
  VPERMWZrr = 17124,
  VPERMWZrrk = 17125,
  VPERMWZrrkz = 17126,
  VPEXPANDBZ128rm = 17127,
  VPEXPANDBZ128rmk = 17128,
  VPEXPANDBZ128rmkz = 17129,
  VPEXPANDBZ128rr = 17130,
  VPEXPANDBZ128rrk = 17131,
  VPEXPANDBZ128rrkz = 17132,
  VPEXPANDBZ256rm = 17133,
  VPEXPANDBZ256rmk = 17134,
  VPEXPANDBZ256rmkz = 17135,
  VPEXPANDBZ256rr = 17136,
  VPEXPANDBZ256rrk = 17137,
  VPEXPANDBZ256rrkz = 17138,
  VPEXPANDBZrm = 17139,
  VPEXPANDBZrmk = 17140,
  VPEXPANDBZrmkz = 17141,
  VPEXPANDBZrr = 17142,
  VPEXPANDBZrrk = 17143,
  VPEXPANDBZrrkz = 17144,
  VPEXPANDDZ128rm = 17145,
  VPEXPANDDZ128rmk = 17146,
  VPEXPANDDZ128rmkz = 17147,
  VPEXPANDDZ128rr = 17148,
  VPEXPANDDZ128rrk = 17149,
  VPEXPANDDZ128rrkz = 17150,
  VPEXPANDDZ256rm = 17151,
  VPEXPANDDZ256rmk = 17152,
  VPEXPANDDZ256rmkz = 17153,
  VPEXPANDDZ256rr = 17154,
  VPEXPANDDZ256rrk = 17155,
  VPEXPANDDZ256rrkz = 17156,
  VPEXPANDDZrm = 17157,
  VPEXPANDDZrmk = 17158,
  VPEXPANDDZrmkz = 17159,
  VPEXPANDDZrr = 17160,
  VPEXPANDDZrrk = 17161,
  VPEXPANDDZrrkz = 17162,
  VPEXPANDQZ128rm = 17163,
  VPEXPANDQZ128rmk = 17164,
  VPEXPANDQZ128rmkz = 17165,
  VPEXPANDQZ128rr = 17166,
  VPEXPANDQZ128rrk = 17167,
  VPEXPANDQZ128rrkz = 17168,
  VPEXPANDQZ256rm = 17169,
  VPEXPANDQZ256rmk = 17170,
  VPEXPANDQZ256rmkz = 17171,
  VPEXPANDQZ256rr = 17172,
  VPEXPANDQZ256rrk = 17173,
  VPEXPANDQZ256rrkz = 17174,
  VPEXPANDQZrm = 17175,
  VPEXPANDQZrmk = 17176,
  VPEXPANDQZrmkz = 17177,
  VPEXPANDQZrr = 17178,
  VPEXPANDQZrrk = 17179,
  VPEXPANDQZrrkz = 17180,
  VPEXPANDWZ128rm = 17181,
  VPEXPANDWZ128rmk = 17182,
  VPEXPANDWZ128rmkz = 17183,
  VPEXPANDWZ128rr = 17184,
  VPEXPANDWZ128rrk = 17185,
  VPEXPANDWZ128rrkz = 17186,
  VPEXPANDWZ256rm = 17187,
  VPEXPANDWZ256rmk = 17188,
  VPEXPANDWZ256rmkz = 17189,
  VPEXPANDWZ256rr = 17190,
  VPEXPANDWZ256rrk = 17191,
  VPEXPANDWZ256rrkz = 17192,
  VPEXPANDWZrm = 17193,
  VPEXPANDWZrmk = 17194,
  VPEXPANDWZrmkz = 17195,
  VPEXPANDWZrr = 17196,
  VPEXPANDWZrrk = 17197,
  VPEXPANDWZrrkz = 17198,
  VPEXTRBZmri = 17199,
  VPEXTRBZrri = 17200,
  VPEXTRBmri = 17201,
  VPEXTRBrri = 17202,
  VPEXTRDZmri = 17203,
  VPEXTRDZrri = 17204,
  VPEXTRDmri = 17205,
  VPEXTRDrri = 17206,
  VPEXTRQZmri = 17207,
  VPEXTRQZrri = 17208,
  VPEXTRQmri = 17209,
  VPEXTRQrri = 17210,
  VPEXTRWZmri = 17211,
  VPEXTRWZrri = 17212,
  VPEXTRWZrri_REV = 17213,
  VPEXTRWmri = 17214,
  VPEXTRWrri = 17215,
  VPEXTRWrri_REV = 17216,
  VPGATHERDDYrm = 17217,
  VPGATHERDDZ128rm = 17218,
  VPGATHERDDZ256rm = 17219,
  VPGATHERDDZrm = 17220,
  VPGATHERDDrm = 17221,
  VPGATHERDQYrm = 17222,
  VPGATHERDQZ128rm = 17223,
  VPGATHERDQZ256rm = 17224,
  VPGATHERDQZrm = 17225,
  VPGATHERDQrm = 17226,
  VPGATHERQDYrm = 17227,
  VPGATHERQDZ128rm = 17228,
  VPGATHERQDZ256rm = 17229,
  VPGATHERQDZrm = 17230,
  VPGATHERQDrm = 17231,
  VPGATHERQQYrm = 17232,
  VPGATHERQQZ128rm = 17233,
  VPGATHERQQZ256rm = 17234,
  VPGATHERQQZrm = 17235,
  VPGATHERQQrm = 17236,
  VPHADDBDrm = 17237,
  VPHADDBDrr = 17238,
  VPHADDBQrm = 17239,
  VPHADDBQrr = 17240,
  VPHADDBWrm = 17241,
  VPHADDBWrr = 17242,
  VPHADDDQrm = 17243,
  VPHADDDQrr = 17244,
  VPHADDDYrm = 17245,
  VPHADDDYrr = 17246,
  VPHADDDrm = 17247,
  VPHADDDrr = 17248,
  VPHADDSWYrm = 17249,
  VPHADDSWYrr = 17250,
  VPHADDSWrm = 17251,
  VPHADDSWrr = 17252,
  VPHADDUBDrm = 17253,
  VPHADDUBDrr = 17254,
  VPHADDUBQrm = 17255,
  VPHADDUBQrr = 17256,
  VPHADDUBWrm = 17257,
  VPHADDUBWrr = 17258,
  VPHADDUDQrm = 17259,
  VPHADDUDQrr = 17260,
  VPHADDUWDrm = 17261,
  VPHADDUWDrr = 17262,
  VPHADDUWQrm = 17263,
  VPHADDUWQrr = 17264,
  VPHADDWDrm = 17265,
  VPHADDWDrr = 17266,
  VPHADDWQrm = 17267,
  VPHADDWQrr = 17268,
  VPHADDWYrm = 17269,
  VPHADDWYrr = 17270,
  VPHADDWrm = 17271,
  VPHADDWrr = 17272,
  VPHMINPOSUWrm = 17273,
  VPHMINPOSUWrr = 17274,
  VPHSUBBWrm = 17275,
  VPHSUBBWrr = 17276,
  VPHSUBDQrm = 17277,
  VPHSUBDQrr = 17278,
  VPHSUBDYrm = 17279,
  VPHSUBDYrr = 17280,
  VPHSUBDrm = 17281,
  VPHSUBDrr = 17282,
  VPHSUBSWYrm = 17283,
  VPHSUBSWYrr = 17284,
  VPHSUBSWrm = 17285,
  VPHSUBSWrr = 17286,
  VPHSUBWDrm = 17287,
  VPHSUBWDrr = 17288,
  VPHSUBWYrm = 17289,
  VPHSUBWYrr = 17290,
  VPHSUBWrm = 17291,
  VPHSUBWrr = 17292,
  VPINSRBZrmi = 17293,
  VPINSRBZrri = 17294,
  VPINSRBrmi = 17295,
  VPINSRBrri = 17296,
  VPINSRDZrmi = 17297,
  VPINSRDZrri = 17298,
  VPINSRDrmi = 17299,
  VPINSRDrri = 17300,
  VPINSRQZrmi = 17301,
  VPINSRQZrri = 17302,
  VPINSRQrmi = 17303,
  VPINSRQrri = 17304,
  VPINSRWZrmi = 17305,
  VPINSRWZrri = 17306,
  VPINSRWrmi = 17307,
  VPINSRWrri = 17308,
  VPLZCNTDZ128rm = 17309,
  VPLZCNTDZ128rmb = 17310,
  VPLZCNTDZ128rmbk = 17311,
  VPLZCNTDZ128rmbkz = 17312,
  VPLZCNTDZ128rmk = 17313,
  VPLZCNTDZ128rmkz = 17314,
  VPLZCNTDZ128rr = 17315,
  VPLZCNTDZ128rrk = 17316,
  VPLZCNTDZ128rrkz = 17317,
  VPLZCNTDZ256rm = 17318,
  VPLZCNTDZ256rmb = 17319,
  VPLZCNTDZ256rmbk = 17320,
  VPLZCNTDZ256rmbkz = 17321,
  VPLZCNTDZ256rmk = 17322,
  VPLZCNTDZ256rmkz = 17323,
  VPLZCNTDZ256rr = 17324,
  VPLZCNTDZ256rrk = 17325,
  VPLZCNTDZ256rrkz = 17326,
  VPLZCNTDZrm = 17327,
  VPLZCNTDZrmb = 17328,
  VPLZCNTDZrmbk = 17329,
  VPLZCNTDZrmbkz = 17330,
  VPLZCNTDZrmk = 17331,
  VPLZCNTDZrmkz = 17332,
  VPLZCNTDZrr = 17333,
  VPLZCNTDZrrk = 17334,
  VPLZCNTDZrrkz = 17335,
  VPLZCNTQZ128rm = 17336,
  VPLZCNTQZ128rmb = 17337,
  VPLZCNTQZ128rmbk = 17338,
  VPLZCNTQZ128rmbkz = 17339,
  VPLZCNTQZ128rmk = 17340,
  VPLZCNTQZ128rmkz = 17341,
  VPLZCNTQZ128rr = 17342,
  VPLZCNTQZ128rrk = 17343,
  VPLZCNTQZ128rrkz = 17344,
  VPLZCNTQZ256rm = 17345,
  VPLZCNTQZ256rmb = 17346,
  VPLZCNTQZ256rmbk = 17347,
  VPLZCNTQZ256rmbkz = 17348,
  VPLZCNTQZ256rmk = 17349,
  VPLZCNTQZ256rmkz = 17350,
  VPLZCNTQZ256rr = 17351,
  VPLZCNTQZ256rrk = 17352,
  VPLZCNTQZ256rrkz = 17353,
  VPLZCNTQZrm = 17354,
  VPLZCNTQZrmb = 17355,
  VPLZCNTQZrmbk = 17356,
  VPLZCNTQZrmbkz = 17357,
  VPLZCNTQZrmk = 17358,
  VPLZCNTQZrmkz = 17359,
  VPLZCNTQZrr = 17360,
  VPLZCNTQZrrk = 17361,
  VPLZCNTQZrrkz = 17362,
  VPMACSDDrm = 17363,
  VPMACSDDrr = 17364,
  VPMACSDQHrm = 17365,
  VPMACSDQHrr = 17366,
  VPMACSDQLrm = 17367,
  VPMACSDQLrr = 17368,
  VPMACSSDDrm = 17369,
  VPMACSSDDrr = 17370,
  VPMACSSDQHrm = 17371,
  VPMACSSDQHrr = 17372,
  VPMACSSDQLrm = 17373,
  VPMACSSDQLrr = 17374,
  VPMACSSWDrm = 17375,
  VPMACSSWDrr = 17376,
  VPMACSSWWrm = 17377,
  VPMACSSWWrr = 17378,
  VPMACSWDrm = 17379,
  VPMACSWDrr = 17380,
  VPMACSWWrm = 17381,
  VPMACSWWrr = 17382,
  VPMADCSSWDrm = 17383,
  VPMADCSSWDrr = 17384,
  VPMADCSWDrm = 17385,
  VPMADCSWDrr = 17386,
  VPMADD52HUQYrm = 17387,
  VPMADD52HUQYrr = 17388,
  VPMADD52HUQZ128m = 17389,
  VPMADD52HUQZ128mb = 17390,
  VPMADD52HUQZ128mbk = 17391,
  VPMADD52HUQZ128mbkz = 17392,
  VPMADD52HUQZ128mk = 17393,
  VPMADD52HUQZ128mkz = 17394,
  VPMADD52HUQZ128r = 17395,
  VPMADD52HUQZ128rk = 17396,
  VPMADD52HUQZ128rkz = 17397,
  VPMADD52HUQZ256m = 17398,
  VPMADD52HUQZ256mb = 17399,
  VPMADD52HUQZ256mbk = 17400,
  VPMADD52HUQZ256mbkz = 17401,
  VPMADD52HUQZ256mk = 17402,
  VPMADD52HUQZ256mkz = 17403,
  VPMADD52HUQZ256r = 17404,
  VPMADD52HUQZ256rk = 17405,
  VPMADD52HUQZ256rkz = 17406,
  VPMADD52HUQZm = 17407,
  VPMADD52HUQZmb = 17408,
  VPMADD52HUQZmbk = 17409,
  VPMADD52HUQZmbkz = 17410,
  VPMADD52HUQZmk = 17411,
  VPMADD52HUQZmkz = 17412,
  VPMADD52HUQZr = 17413,
  VPMADD52HUQZrk = 17414,
  VPMADD52HUQZrkz = 17415,
  VPMADD52HUQrm = 17416,
  VPMADD52HUQrr = 17417,
  VPMADD52LUQYrm = 17418,
  VPMADD52LUQYrr = 17419,
  VPMADD52LUQZ128m = 17420,
  VPMADD52LUQZ128mb = 17421,
  VPMADD52LUQZ128mbk = 17422,
  VPMADD52LUQZ128mbkz = 17423,
  VPMADD52LUQZ128mk = 17424,
  VPMADD52LUQZ128mkz = 17425,
  VPMADD52LUQZ128r = 17426,
  VPMADD52LUQZ128rk = 17427,
  VPMADD52LUQZ128rkz = 17428,
  VPMADD52LUQZ256m = 17429,
  VPMADD52LUQZ256mb = 17430,
  VPMADD52LUQZ256mbk = 17431,
  VPMADD52LUQZ256mbkz = 17432,
  VPMADD52LUQZ256mk = 17433,
  VPMADD52LUQZ256mkz = 17434,
  VPMADD52LUQZ256r = 17435,
  VPMADD52LUQZ256rk = 17436,
  VPMADD52LUQZ256rkz = 17437,
  VPMADD52LUQZm = 17438,
  VPMADD52LUQZmb = 17439,
  VPMADD52LUQZmbk = 17440,
  VPMADD52LUQZmbkz = 17441,
  VPMADD52LUQZmk = 17442,
  VPMADD52LUQZmkz = 17443,
  VPMADD52LUQZr = 17444,
  VPMADD52LUQZrk = 17445,
  VPMADD52LUQZrkz = 17446,
  VPMADD52LUQrm = 17447,
  VPMADD52LUQrr = 17448,
  VPMADDUBSWYrm = 17449,
  VPMADDUBSWYrr = 17450,
  VPMADDUBSWZ128rm = 17451,
  VPMADDUBSWZ128rmk = 17452,
  VPMADDUBSWZ128rmkz = 17453,
  VPMADDUBSWZ128rr = 17454,
  VPMADDUBSWZ128rrk = 17455,
  VPMADDUBSWZ128rrkz = 17456,
  VPMADDUBSWZ256rm = 17457,
  VPMADDUBSWZ256rmk = 17458,
  VPMADDUBSWZ256rmkz = 17459,
  VPMADDUBSWZ256rr = 17460,
  VPMADDUBSWZ256rrk = 17461,
  VPMADDUBSWZ256rrkz = 17462,
  VPMADDUBSWZrm = 17463,
  VPMADDUBSWZrmk = 17464,
  VPMADDUBSWZrmkz = 17465,
  VPMADDUBSWZrr = 17466,
  VPMADDUBSWZrrk = 17467,
  VPMADDUBSWZrrkz = 17468,
  VPMADDUBSWrm = 17469,
  VPMADDUBSWrr = 17470,
  VPMADDWDYrm = 17471,
  VPMADDWDYrr = 17472,
  VPMADDWDZ128rm = 17473,
  VPMADDWDZ128rmk = 17474,
  VPMADDWDZ128rmkz = 17475,
  VPMADDWDZ128rr = 17476,
  VPMADDWDZ128rrk = 17477,
  VPMADDWDZ128rrkz = 17478,
  VPMADDWDZ256rm = 17479,
  VPMADDWDZ256rmk = 17480,
  VPMADDWDZ256rmkz = 17481,
  VPMADDWDZ256rr = 17482,
  VPMADDWDZ256rrk = 17483,
  VPMADDWDZ256rrkz = 17484,
  VPMADDWDZrm = 17485,
  VPMADDWDZrmk = 17486,
  VPMADDWDZrmkz = 17487,
  VPMADDWDZrr = 17488,
  VPMADDWDZrrk = 17489,
  VPMADDWDZrrkz = 17490,
  VPMADDWDrm = 17491,
  VPMADDWDrr = 17492,
  VPMASKMOVDYmr = 17493,
  VPMASKMOVDYrm = 17494,
  VPMASKMOVDmr = 17495,
  VPMASKMOVDrm = 17496,
  VPMASKMOVQYmr = 17497,
  VPMASKMOVQYrm = 17498,
  VPMASKMOVQmr = 17499,
  VPMASKMOVQrm = 17500,
  VPMAXSBYrm = 17501,
  VPMAXSBYrr = 17502,
  VPMAXSBZ128rm = 17503,
  VPMAXSBZ128rmk = 17504,
  VPMAXSBZ128rmkz = 17505,
  VPMAXSBZ128rr = 17506,
  VPMAXSBZ128rrk = 17507,
  VPMAXSBZ128rrkz = 17508,
  VPMAXSBZ256rm = 17509,
  VPMAXSBZ256rmk = 17510,
  VPMAXSBZ256rmkz = 17511,
  VPMAXSBZ256rr = 17512,
  VPMAXSBZ256rrk = 17513,
  VPMAXSBZ256rrkz = 17514,
  VPMAXSBZrm = 17515,
  VPMAXSBZrmk = 17516,
  VPMAXSBZrmkz = 17517,
  VPMAXSBZrr = 17518,
  VPMAXSBZrrk = 17519,
  VPMAXSBZrrkz = 17520,
  VPMAXSBrm = 17521,
  VPMAXSBrr = 17522,
  VPMAXSDYrm = 17523,
  VPMAXSDYrr = 17524,
  VPMAXSDZ128rm = 17525,
  VPMAXSDZ128rmb = 17526,
  VPMAXSDZ128rmbk = 17527,
  VPMAXSDZ128rmbkz = 17528,
  VPMAXSDZ128rmk = 17529,
  VPMAXSDZ128rmkz = 17530,
  VPMAXSDZ128rr = 17531,
  VPMAXSDZ128rrk = 17532,
  VPMAXSDZ128rrkz = 17533,
  VPMAXSDZ256rm = 17534,
  VPMAXSDZ256rmb = 17535,
  VPMAXSDZ256rmbk = 17536,
  VPMAXSDZ256rmbkz = 17537,
  VPMAXSDZ256rmk = 17538,
  VPMAXSDZ256rmkz = 17539,
  VPMAXSDZ256rr = 17540,
  VPMAXSDZ256rrk = 17541,
  VPMAXSDZ256rrkz = 17542,
  VPMAXSDZrm = 17543,
  VPMAXSDZrmb = 17544,
  VPMAXSDZrmbk = 17545,
  VPMAXSDZrmbkz = 17546,
  VPMAXSDZrmk = 17547,
  VPMAXSDZrmkz = 17548,
  VPMAXSDZrr = 17549,
  VPMAXSDZrrk = 17550,
  VPMAXSDZrrkz = 17551,
  VPMAXSDrm = 17552,
  VPMAXSDrr = 17553,
  VPMAXSQZ128rm = 17554,
  VPMAXSQZ128rmb = 17555,
  VPMAXSQZ128rmbk = 17556,
  VPMAXSQZ128rmbkz = 17557,
  VPMAXSQZ128rmk = 17558,
  VPMAXSQZ128rmkz = 17559,
  VPMAXSQZ128rr = 17560,
  VPMAXSQZ128rrk = 17561,
  VPMAXSQZ128rrkz = 17562,
  VPMAXSQZ256rm = 17563,
  VPMAXSQZ256rmb = 17564,
  VPMAXSQZ256rmbk = 17565,
  VPMAXSQZ256rmbkz = 17566,
  VPMAXSQZ256rmk = 17567,
  VPMAXSQZ256rmkz = 17568,
  VPMAXSQZ256rr = 17569,
  VPMAXSQZ256rrk = 17570,
  VPMAXSQZ256rrkz = 17571,
  VPMAXSQZrm = 17572,
  VPMAXSQZrmb = 17573,
  VPMAXSQZrmbk = 17574,
  VPMAXSQZrmbkz = 17575,
  VPMAXSQZrmk = 17576,
  VPMAXSQZrmkz = 17577,
  VPMAXSQZrr = 17578,
  VPMAXSQZrrk = 17579,
  VPMAXSQZrrkz = 17580,
  VPMAXSWYrm = 17581,
  VPMAXSWYrr = 17582,
  VPMAXSWZ128rm = 17583,
  VPMAXSWZ128rmk = 17584,
  VPMAXSWZ128rmkz = 17585,
  VPMAXSWZ128rr = 17586,
  VPMAXSWZ128rrk = 17587,
  VPMAXSWZ128rrkz = 17588,
  VPMAXSWZ256rm = 17589,
  VPMAXSWZ256rmk = 17590,
  VPMAXSWZ256rmkz = 17591,
  VPMAXSWZ256rr = 17592,
  VPMAXSWZ256rrk = 17593,
  VPMAXSWZ256rrkz = 17594,
  VPMAXSWZrm = 17595,
  VPMAXSWZrmk = 17596,
  VPMAXSWZrmkz = 17597,
  VPMAXSWZrr = 17598,
  VPMAXSWZrrk = 17599,
  VPMAXSWZrrkz = 17600,
  VPMAXSWrm = 17601,
  VPMAXSWrr = 17602,
  VPMAXUBYrm = 17603,
  VPMAXUBYrr = 17604,
  VPMAXUBZ128rm = 17605,
  VPMAXUBZ128rmk = 17606,
  VPMAXUBZ128rmkz = 17607,
  VPMAXUBZ128rr = 17608,
  VPMAXUBZ128rrk = 17609,
  VPMAXUBZ128rrkz = 17610,
  VPMAXUBZ256rm = 17611,
  VPMAXUBZ256rmk = 17612,
  VPMAXUBZ256rmkz = 17613,
  VPMAXUBZ256rr = 17614,
  VPMAXUBZ256rrk = 17615,
  VPMAXUBZ256rrkz = 17616,
  VPMAXUBZrm = 17617,
  VPMAXUBZrmk = 17618,
  VPMAXUBZrmkz = 17619,
  VPMAXUBZrr = 17620,
  VPMAXUBZrrk = 17621,
  VPMAXUBZrrkz = 17622,
  VPMAXUBrm = 17623,
  VPMAXUBrr = 17624,
  VPMAXUDYrm = 17625,
  VPMAXUDYrr = 17626,
  VPMAXUDZ128rm = 17627,
  VPMAXUDZ128rmb = 17628,
  VPMAXUDZ128rmbk = 17629,
  VPMAXUDZ128rmbkz = 17630,
  VPMAXUDZ128rmk = 17631,
  VPMAXUDZ128rmkz = 17632,
  VPMAXUDZ128rr = 17633,
  VPMAXUDZ128rrk = 17634,
  VPMAXUDZ128rrkz = 17635,
  VPMAXUDZ256rm = 17636,
  VPMAXUDZ256rmb = 17637,
  VPMAXUDZ256rmbk = 17638,
  VPMAXUDZ256rmbkz = 17639,
  VPMAXUDZ256rmk = 17640,
  VPMAXUDZ256rmkz = 17641,
  VPMAXUDZ256rr = 17642,
  VPMAXUDZ256rrk = 17643,
  VPMAXUDZ256rrkz = 17644,
  VPMAXUDZrm = 17645,
  VPMAXUDZrmb = 17646,
  VPMAXUDZrmbk = 17647,
  VPMAXUDZrmbkz = 17648,
  VPMAXUDZrmk = 17649,
  VPMAXUDZrmkz = 17650,
  VPMAXUDZrr = 17651,
  VPMAXUDZrrk = 17652,
  VPMAXUDZrrkz = 17653,
  VPMAXUDrm = 17654,
  VPMAXUDrr = 17655,
  VPMAXUQZ128rm = 17656,
  VPMAXUQZ128rmb = 17657,
  VPMAXUQZ128rmbk = 17658,
  VPMAXUQZ128rmbkz = 17659,
  VPMAXUQZ128rmk = 17660,
  VPMAXUQZ128rmkz = 17661,
  VPMAXUQZ128rr = 17662,
  VPMAXUQZ128rrk = 17663,
  VPMAXUQZ128rrkz = 17664,
  VPMAXUQZ256rm = 17665,
  VPMAXUQZ256rmb = 17666,
  VPMAXUQZ256rmbk = 17667,
  VPMAXUQZ256rmbkz = 17668,
  VPMAXUQZ256rmk = 17669,
  VPMAXUQZ256rmkz = 17670,
  VPMAXUQZ256rr = 17671,
  VPMAXUQZ256rrk = 17672,
  VPMAXUQZ256rrkz = 17673,
  VPMAXUQZrm = 17674,
  VPMAXUQZrmb = 17675,
  VPMAXUQZrmbk = 17676,
  VPMAXUQZrmbkz = 17677,
  VPMAXUQZrmk = 17678,
  VPMAXUQZrmkz = 17679,
  VPMAXUQZrr = 17680,
  VPMAXUQZrrk = 17681,
  VPMAXUQZrrkz = 17682,
  VPMAXUWYrm = 17683,
  VPMAXUWYrr = 17684,
  VPMAXUWZ128rm = 17685,
  VPMAXUWZ128rmk = 17686,
  VPMAXUWZ128rmkz = 17687,
  VPMAXUWZ128rr = 17688,
  VPMAXUWZ128rrk = 17689,
  VPMAXUWZ128rrkz = 17690,
  VPMAXUWZ256rm = 17691,
  VPMAXUWZ256rmk = 17692,
  VPMAXUWZ256rmkz = 17693,
  VPMAXUWZ256rr = 17694,
  VPMAXUWZ256rrk = 17695,
  VPMAXUWZ256rrkz = 17696,
  VPMAXUWZrm = 17697,
  VPMAXUWZrmk = 17698,
  VPMAXUWZrmkz = 17699,
  VPMAXUWZrr = 17700,
  VPMAXUWZrrk = 17701,
  VPMAXUWZrrkz = 17702,
  VPMAXUWrm = 17703,
  VPMAXUWrr = 17704,
  VPMINSBYrm = 17705,
  VPMINSBYrr = 17706,
  VPMINSBZ128rm = 17707,
  VPMINSBZ128rmk = 17708,
  VPMINSBZ128rmkz = 17709,
  VPMINSBZ128rr = 17710,
  VPMINSBZ128rrk = 17711,
  VPMINSBZ128rrkz = 17712,
  VPMINSBZ256rm = 17713,
  VPMINSBZ256rmk = 17714,
  VPMINSBZ256rmkz = 17715,
  VPMINSBZ256rr = 17716,
  VPMINSBZ256rrk = 17717,
  VPMINSBZ256rrkz = 17718,
  VPMINSBZrm = 17719,
  VPMINSBZrmk = 17720,
  VPMINSBZrmkz = 17721,
  VPMINSBZrr = 17722,
  VPMINSBZrrk = 17723,
  VPMINSBZrrkz = 17724,
  VPMINSBrm = 17725,
  VPMINSBrr = 17726,
  VPMINSDYrm = 17727,
  VPMINSDYrr = 17728,
  VPMINSDZ128rm = 17729,
  VPMINSDZ128rmb = 17730,
  VPMINSDZ128rmbk = 17731,
  VPMINSDZ128rmbkz = 17732,
  VPMINSDZ128rmk = 17733,
  VPMINSDZ128rmkz = 17734,
  VPMINSDZ128rr = 17735,
  VPMINSDZ128rrk = 17736,
  VPMINSDZ128rrkz = 17737,
  VPMINSDZ256rm = 17738,
  VPMINSDZ256rmb = 17739,
  VPMINSDZ256rmbk = 17740,
  VPMINSDZ256rmbkz = 17741,
  VPMINSDZ256rmk = 17742,
  VPMINSDZ256rmkz = 17743,
  VPMINSDZ256rr = 17744,
  VPMINSDZ256rrk = 17745,
  VPMINSDZ256rrkz = 17746,
  VPMINSDZrm = 17747,
  VPMINSDZrmb = 17748,
  VPMINSDZrmbk = 17749,
  VPMINSDZrmbkz = 17750,
  VPMINSDZrmk = 17751,
  VPMINSDZrmkz = 17752,
  VPMINSDZrr = 17753,
  VPMINSDZrrk = 17754,
  VPMINSDZrrkz = 17755,
  VPMINSDrm = 17756,
  VPMINSDrr = 17757,
  VPMINSQZ128rm = 17758,
  VPMINSQZ128rmb = 17759,
  VPMINSQZ128rmbk = 17760,
  VPMINSQZ128rmbkz = 17761,
  VPMINSQZ128rmk = 17762,
  VPMINSQZ128rmkz = 17763,
  VPMINSQZ128rr = 17764,
  VPMINSQZ128rrk = 17765,
  VPMINSQZ128rrkz = 17766,
  VPMINSQZ256rm = 17767,
  VPMINSQZ256rmb = 17768,
  VPMINSQZ256rmbk = 17769,
  VPMINSQZ256rmbkz = 17770,
  VPMINSQZ256rmk = 17771,
  VPMINSQZ256rmkz = 17772,
  VPMINSQZ256rr = 17773,
  VPMINSQZ256rrk = 17774,
  VPMINSQZ256rrkz = 17775,
  VPMINSQZrm = 17776,
  VPMINSQZrmb = 17777,
  VPMINSQZrmbk = 17778,
  VPMINSQZrmbkz = 17779,
  VPMINSQZrmk = 17780,
  VPMINSQZrmkz = 17781,
  VPMINSQZrr = 17782,
  VPMINSQZrrk = 17783,
  VPMINSQZrrkz = 17784,
  VPMINSWYrm = 17785,
  VPMINSWYrr = 17786,
  VPMINSWZ128rm = 17787,
  VPMINSWZ128rmk = 17788,
  VPMINSWZ128rmkz = 17789,
  VPMINSWZ128rr = 17790,
  VPMINSWZ128rrk = 17791,
  VPMINSWZ128rrkz = 17792,
  VPMINSWZ256rm = 17793,
  VPMINSWZ256rmk = 17794,
  VPMINSWZ256rmkz = 17795,
  VPMINSWZ256rr = 17796,
  VPMINSWZ256rrk = 17797,
  VPMINSWZ256rrkz = 17798,
  VPMINSWZrm = 17799,
  VPMINSWZrmk = 17800,
  VPMINSWZrmkz = 17801,
  VPMINSWZrr = 17802,
  VPMINSWZrrk = 17803,
  VPMINSWZrrkz = 17804,
  VPMINSWrm = 17805,
  VPMINSWrr = 17806,
  VPMINUBYrm = 17807,
  VPMINUBYrr = 17808,
  VPMINUBZ128rm = 17809,
  VPMINUBZ128rmk = 17810,
  VPMINUBZ128rmkz = 17811,
  VPMINUBZ128rr = 17812,
  VPMINUBZ128rrk = 17813,
  VPMINUBZ128rrkz = 17814,
  VPMINUBZ256rm = 17815,
  VPMINUBZ256rmk = 17816,
  VPMINUBZ256rmkz = 17817,
  VPMINUBZ256rr = 17818,
  VPMINUBZ256rrk = 17819,
  VPMINUBZ256rrkz = 17820,
  VPMINUBZrm = 17821,
  VPMINUBZrmk = 17822,
  VPMINUBZrmkz = 17823,
  VPMINUBZrr = 17824,
  VPMINUBZrrk = 17825,
  VPMINUBZrrkz = 17826,
  VPMINUBrm = 17827,
  VPMINUBrr = 17828,
  VPMINUDYrm = 17829,
  VPMINUDYrr = 17830,
  VPMINUDZ128rm = 17831,
  VPMINUDZ128rmb = 17832,
  VPMINUDZ128rmbk = 17833,
  VPMINUDZ128rmbkz = 17834,
  VPMINUDZ128rmk = 17835,
  VPMINUDZ128rmkz = 17836,
  VPMINUDZ128rr = 17837,
  VPMINUDZ128rrk = 17838,
  VPMINUDZ128rrkz = 17839,
  VPMINUDZ256rm = 17840,
  VPMINUDZ256rmb = 17841,
  VPMINUDZ256rmbk = 17842,
  VPMINUDZ256rmbkz = 17843,
  VPMINUDZ256rmk = 17844,
  VPMINUDZ256rmkz = 17845,
  VPMINUDZ256rr = 17846,
  VPMINUDZ256rrk = 17847,
  VPMINUDZ256rrkz = 17848,
  VPMINUDZrm = 17849,
  VPMINUDZrmb = 17850,
  VPMINUDZrmbk = 17851,
  VPMINUDZrmbkz = 17852,
  VPMINUDZrmk = 17853,
  VPMINUDZrmkz = 17854,
  VPMINUDZrr = 17855,
  VPMINUDZrrk = 17856,
  VPMINUDZrrkz = 17857,
  VPMINUDrm = 17858,
  VPMINUDrr = 17859,
  VPMINUQZ128rm = 17860,
  VPMINUQZ128rmb = 17861,
  VPMINUQZ128rmbk = 17862,
  VPMINUQZ128rmbkz = 17863,
  VPMINUQZ128rmk = 17864,
  VPMINUQZ128rmkz = 17865,
  VPMINUQZ128rr = 17866,
  VPMINUQZ128rrk = 17867,
  VPMINUQZ128rrkz = 17868,
  VPMINUQZ256rm = 17869,
  VPMINUQZ256rmb = 17870,
  VPMINUQZ256rmbk = 17871,
  VPMINUQZ256rmbkz = 17872,
  VPMINUQZ256rmk = 17873,
  VPMINUQZ256rmkz = 17874,
  VPMINUQZ256rr = 17875,
  VPMINUQZ256rrk = 17876,
  VPMINUQZ256rrkz = 17877,
  VPMINUQZrm = 17878,
  VPMINUQZrmb = 17879,
  VPMINUQZrmbk = 17880,
  VPMINUQZrmbkz = 17881,
  VPMINUQZrmk = 17882,
  VPMINUQZrmkz = 17883,
  VPMINUQZrr = 17884,
  VPMINUQZrrk = 17885,
  VPMINUQZrrkz = 17886,
  VPMINUWYrm = 17887,
  VPMINUWYrr = 17888,
  VPMINUWZ128rm = 17889,
  VPMINUWZ128rmk = 17890,
  VPMINUWZ128rmkz = 17891,
  VPMINUWZ128rr = 17892,
  VPMINUWZ128rrk = 17893,
  VPMINUWZ128rrkz = 17894,
  VPMINUWZ256rm = 17895,
  VPMINUWZ256rmk = 17896,
  VPMINUWZ256rmkz = 17897,
  VPMINUWZ256rr = 17898,
  VPMINUWZ256rrk = 17899,
  VPMINUWZ256rrkz = 17900,
  VPMINUWZrm = 17901,
  VPMINUWZrmk = 17902,
  VPMINUWZrmkz = 17903,
  VPMINUWZrr = 17904,
  VPMINUWZrrk = 17905,
  VPMINUWZrrkz = 17906,
  VPMINUWrm = 17907,
  VPMINUWrr = 17908,
  VPMOVB2MZ128kr = 17909,
  VPMOVB2MZ256kr = 17910,
  VPMOVB2MZkr = 17911,
  VPMOVD2MZ128kr = 17912,
  VPMOVD2MZ256kr = 17913,
  VPMOVD2MZkr = 17914,
  VPMOVDBZ128mr = 17915,
  VPMOVDBZ128mrk = 17916,
  VPMOVDBZ128rr = 17917,
  VPMOVDBZ128rrk = 17918,
  VPMOVDBZ128rrkz = 17919,
  VPMOVDBZ256mr = 17920,
  VPMOVDBZ256mrk = 17921,
  VPMOVDBZ256rr = 17922,
  VPMOVDBZ256rrk = 17923,
  VPMOVDBZ256rrkz = 17924,
  VPMOVDBZmr = 17925,
  VPMOVDBZmrk = 17926,
  VPMOVDBZrr = 17927,
  VPMOVDBZrrk = 17928,
  VPMOVDBZrrkz = 17929,
  VPMOVDWZ128mr = 17930,
  VPMOVDWZ128mrk = 17931,
  VPMOVDWZ128rr = 17932,
  VPMOVDWZ128rrk = 17933,
  VPMOVDWZ128rrkz = 17934,
  VPMOVDWZ256mr = 17935,
  VPMOVDWZ256mrk = 17936,
  VPMOVDWZ256rr = 17937,
  VPMOVDWZ256rrk = 17938,
  VPMOVDWZ256rrkz = 17939,
  VPMOVDWZmr = 17940,
  VPMOVDWZmrk = 17941,
  VPMOVDWZrr = 17942,
  VPMOVDWZrrk = 17943,
  VPMOVDWZrrkz = 17944,
  VPMOVM2BZ128rk = 17945,
  VPMOVM2BZ256rk = 17946,
  VPMOVM2BZrk = 17947,
  VPMOVM2DZ128rk = 17948,
  VPMOVM2DZ256rk = 17949,
  VPMOVM2DZrk = 17950,
  VPMOVM2QZ128rk = 17951,
  VPMOVM2QZ256rk = 17952,
  VPMOVM2QZrk = 17953,
  VPMOVM2WZ128rk = 17954,
  VPMOVM2WZ256rk = 17955,
  VPMOVM2WZrk = 17956,
  VPMOVMSKBYrr = 17957,
  VPMOVMSKBrr = 17958,
  VPMOVQ2MZ128kr = 17959,
  VPMOVQ2MZ256kr = 17960,
  VPMOVQ2MZkr = 17961,
  VPMOVQBZ128mr = 17962,
  VPMOVQBZ128mrk = 17963,
  VPMOVQBZ128rr = 17964,
  VPMOVQBZ128rrk = 17965,
  VPMOVQBZ128rrkz = 17966,
  VPMOVQBZ256mr = 17967,
  VPMOVQBZ256mrk = 17968,
  VPMOVQBZ256rr = 17969,
  VPMOVQBZ256rrk = 17970,
  VPMOVQBZ256rrkz = 17971,
  VPMOVQBZmr = 17972,
  VPMOVQBZmrk = 17973,
  VPMOVQBZrr = 17974,
  VPMOVQBZrrk = 17975,
  VPMOVQBZrrkz = 17976,
  VPMOVQDZ128mr = 17977,
  VPMOVQDZ128mrk = 17978,
  VPMOVQDZ128rr = 17979,
  VPMOVQDZ128rrk = 17980,
  VPMOVQDZ128rrkz = 17981,
  VPMOVQDZ256mr = 17982,
  VPMOVQDZ256mrk = 17983,
  VPMOVQDZ256rr = 17984,
  VPMOVQDZ256rrk = 17985,
  VPMOVQDZ256rrkz = 17986,
  VPMOVQDZmr = 17987,
  VPMOVQDZmrk = 17988,
  VPMOVQDZrr = 17989,
  VPMOVQDZrrk = 17990,
  VPMOVQDZrrkz = 17991,
  VPMOVQWZ128mr = 17992,
  VPMOVQWZ128mrk = 17993,
  VPMOVQWZ128rr = 17994,
  VPMOVQWZ128rrk = 17995,
  VPMOVQWZ128rrkz = 17996,
  VPMOVQWZ256mr = 17997,
  VPMOVQWZ256mrk = 17998,
  VPMOVQWZ256rr = 17999,
  VPMOVQWZ256rrk = 18000,
  VPMOVQWZ256rrkz = 18001,
  VPMOVQWZmr = 18002,
  VPMOVQWZmrk = 18003,
  VPMOVQWZrr = 18004,
  VPMOVQWZrrk = 18005,
  VPMOVQWZrrkz = 18006,
  VPMOVSDBZ128mr = 18007,
  VPMOVSDBZ128mrk = 18008,
  VPMOVSDBZ128rr = 18009,
  VPMOVSDBZ128rrk = 18010,
  VPMOVSDBZ128rrkz = 18011,
  VPMOVSDBZ256mr = 18012,
  VPMOVSDBZ256mrk = 18013,
  VPMOVSDBZ256rr = 18014,
  VPMOVSDBZ256rrk = 18015,
  VPMOVSDBZ256rrkz = 18016,
  VPMOVSDBZmr = 18017,
  VPMOVSDBZmrk = 18018,
  VPMOVSDBZrr = 18019,
  VPMOVSDBZrrk = 18020,
  VPMOVSDBZrrkz = 18021,
  VPMOVSDWZ128mr = 18022,
  VPMOVSDWZ128mrk = 18023,
  VPMOVSDWZ128rr = 18024,
  VPMOVSDWZ128rrk = 18025,
  VPMOVSDWZ128rrkz = 18026,
  VPMOVSDWZ256mr = 18027,
  VPMOVSDWZ256mrk = 18028,
  VPMOVSDWZ256rr = 18029,
  VPMOVSDWZ256rrk = 18030,
  VPMOVSDWZ256rrkz = 18031,
  VPMOVSDWZmr = 18032,
  VPMOVSDWZmrk = 18033,
  VPMOVSDWZrr = 18034,
  VPMOVSDWZrrk = 18035,
  VPMOVSDWZrrkz = 18036,
  VPMOVSQBZ128mr = 18037,
  VPMOVSQBZ128mrk = 18038,
  VPMOVSQBZ128rr = 18039,
  VPMOVSQBZ128rrk = 18040,
  VPMOVSQBZ128rrkz = 18041,
  VPMOVSQBZ256mr = 18042,
  VPMOVSQBZ256mrk = 18043,
  VPMOVSQBZ256rr = 18044,
  VPMOVSQBZ256rrk = 18045,
  VPMOVSQBZ256rrkz = 18046,
  VPMOVSQBZmr = 18047,
  VPMOVSQBZmrk = 18048,
  VPMOVSQBZrr = 18049,
  VPMOVSQBZrrk = 18050,
  VPMOVSQBZrrkz = 18051,
  VPMOVSQDZ128mr = 18052,
  VPMOVSQDZ128mrk = 18053,
  VPMOVSQDZ128rr = 18054,
  VPMOVSQDZ128rrk = 18055,
  VPMOVSQDZ128rrkz = 18056,
  VPMOVSQDZ256mr = 18057,
  VPMOVSQDZ256mrk = 18058,
  VPMOVSQDZ256rr = 18059,
  VPMOVSQDZ256rrk = 18060,
  VPMOVSQDZ256rrkz = 18061,
  VPMOVSQDZmr = 18062,
  VPMOVSQDZmrk = 18063,
  VPMOVSQDZrr = 18064,
  VPMOVSQDZrrk = 18065,
  VPMOVSQDZrrkz = 18066,
  VPMOVSQWZ128mr = 18067,
  VPMOVSQWZ128mrk = 18068,
  VPMOVSQWZ128rr = 18069,
  VPMOVSQWZ128rrk = 18070,
  VPMOVSQWZ128rrkz = 18071,
  VPMOVSQWZ256mr = 18072,
  VPMOVSQWZ256mrk = 18073,
  VPMOVSQWZ256rr = 18074,
  VPMOVSQWZ256rrk = 18075,
  VPMOVSQWZ256rrkz = 18076,
  VPMOVSQWZmr = 18077,
  VPMOVSQWZmrk = 18078,
  VPMOVSQWZrr = 18079,
  VPMOVSQWZrrk = 18080,
  VPMOVSQWZrrkz = 18081,
  VPMOVSWBZ128mr = 18082,
  VPMOVSWBZ128mrk = 18083,
  VPMOVSWBZ128rr = 18084,
  VPMOVSWBZ128rrk = 18085,
  VPMOVSWBZ128rrkz = 18086,
  VPMOVSWBZ256mr = 18087,
  VPMOVSWBZ256mrk = 18088,
  VPMOVSWBZ256rr = 18089,
  VPMOVSWBZ256rrk = 18090,
  VPMOVSWBZ256rrkz = 18091,
  VPMOVSWBZmr = 18092,
  VPMOVSWBZmrk = 18093,
  VPMOVSWBZrr = 18094,
  VPMOVSWBZrrk = 18095,
  VPMOVSWBZrrkz = 18096,
  VPMOVSXBDYrm = 18097,
  VPMOVSXBDYrr = 18098,
  VPMOVSXBDZ128rm = 18099,
  VPMOVSXBDZ128rmk = 18100,
  VPMOVSXBDZ128rmkz = 18101,
  VPMOVSXBDZ128rr = 18102,
  VPMOVSXBDZ128rrk = 18103,
  VPMOVSXBDZ128rrkz = 18104,
  VPMOVSXBDZ256rm = 18105,
  VPMOVSXBDZ256rmk = 18106,
  VPMOVSXBDZ256rmkz = 18107,
  VPMOVSXBDZ256rr = 18108,
  VPMOVSXBDZ256rrk = 18109,
  VPMOVSXBDZ256rrkz = 18110,
  VPMOVSXBDZrm = 18111,
  VPMOVSXBDZrmk = 18112,
  VPMOVSXBDZrmkz = 18113,
  VPMOVSXBDZrr = 18114,
  VPMOVSXBDZrrk = 18115,
  VPMOVSXBDZrrkz = 18116,
  VPMOVSXBDrm = 18117,
  VPMOVSXBDrr = 18118,
  VPMOVSXBQYrm = 18119,
  VPMOVSXBQYrr = 18120,
  VPMOVSXBQZ128rm = 18121,
  VPMOVSXBQZ128rmk = 18122,
  VPMOVSXBQZ128rmkz = 18123,
  VPMOVSXBQZ128rr = 18124,
  VPMOVSXBQZ128rrk = 18125,
  VPMOVSXBQZ128rrkz = 18126,
  VPMOVSXBQZ256rm = 18127,
  VPMOVSXBQZ256rmk = 18128,
  VPMOVSXBQZ256rmkz = 18129,
  VPMOVSXBQZ256rr = 18130,
  VPMOVSXBQZ256rrk = 18131,
  VPMOVSXBQZ256rrkz = 18132,
  VPMOVSXBQZrm = 18133,
  VPMOVSXBQZrmk = 18134,
  VPMOVSXBQZrmkz = 18135,
  VPMOVSXBQZrr = 18136,
  VPMOVSXBQZrrk = 18137,
  VPMOVSXBQZrrkz = 18138,
  VPMOVSXBQrm = 18139,
  VPMOVSXBQrr = 18140,
  VPMOVSXBWYrm = 18141,
  VPMOVSXBWYrr = 18142,
  VPMOVSXBWZ128rm = 18143,
  VPMOVSXBWZ128rmk = 18144,
  VPMOVSXBWZ128rmkz = 18145,
  VPMOVSXBWZ128rr = 18146,
  VPMOVSXBWZ128rrk = 18147,
  VPMOVSXBWZ128rrkz = 18148,
  VPMOVSXBWZ256rm = 18149,
  VPMOVSXBWZ256rmk = 18150,
  VPMOVSXBWZ256rmkz = 18151,
  VPMOVSXBWZ256rr = 18152,
  VPMOVSXBWZ256rrk = 18153,
  VPMOVSXBWZ256rrkz = 18154,
  VPMOVSXBWZrm = 18155,
  VPMOVSXBWZrmk = 18156,
  VPMOVSXBWZrmkz = 18157,
  VPMOVSXBWZrr = 18158,
  VPMOVSXBWZrrk = 18159,
  VPMOVSXBWZrrkz = 18160,
  VPMOVSXBWrm = 18161,
  VPMOVSXBWrr = 18162,
  VPMOVSXDQYrm = 18163,
  VPMOVSXDQYrr = 18164,
  VPMOVSXDQZ128rm = 18165,
  VPMOVSXDQZ128rmk = 18166,
  VPMOVSXDQZ128rmkz = 18167,
  VPMOVSXDQZ128rr = 18168,
  VPMOVSXDQZ128rrk = 18169,
  VPMOVSXDQZ128rrkz = 18170,
  VPMOVSXDQZ256rm = 18171,
  VPMOVSXDQZ256rmk = 18172,
  VPMOVSXDQZ256rmkz = 18173,
  VPMOVSXDQZ256rr = 18174,
  VPMOVSXDQZ256rrk = 18175,
  VPMOVSXDQZ256rrkz = 18176,
  VPMOVSXDQZrm = 18177,
  VPMOVSXDQZrmk = 18178,
  VPMOVSXDQZrmkz = 18179,
  VPMOVSXDQZrr = 18180,
  VPMOVSXDQZrrk = 18181,
  VPMOVSXDQZrrkz = 18182,
  VPMOVSXDQrm = 18183,
  VPMOVSXDQrr = 18184,
  VPMOVSXWDYrm = 18185,
  VPMOVSXWDYrr = 18186,
  VPMOVSXWDZ128rm = 18187,
  VPMOVSXWDZ128rmk = 18188,
  VPMOVSXWDZ128rmkz = 18189,
  VPMOVSXWDZ128rr = 18190,
  VPMOVSXWDZ128rrk = 18191,
  VPMOVSXWDZ128rrkz = 18192,
  VPMOVSXWDZ256rm = 18193,
  VPMOVSXWDZ256rmk = 18194,
  VPMOVSXWDZ256rmkz = 18195,
  VPMOVSXWDZ256rr = 18196,
  VPMOVSXWDZ256rrk = 18197,
  VPMOVSXWDZ256rrkz = 18198,
  VPMOVSXWDZrm = 18199,
  VPMOVSXWDZrmk = 18200,
  VPMOVSXWDZrmkz = 18201,
  VPMOVSXWDZrr = 18202,
  VPMOVSXWDZrrk = 18203,
  VPMOVSXWDZrrkz = 18204,
  VPMOVSXWDrm = 18205,
  VPMOVSXWDrr = 18206,
  VPMOVSXWQYrm = 18207,
  VPMOVSXWQYrr = 18208,
  VPMOVSXWQZ128rm = 18209,
  VPMOVSXWQZ128rmk = 18210,
  VPMOVSXWQZ128rmkz = 18211,
  VPMOVSXWQZ128rr = 18212,
  VPMOVSXWQZ128rrk = 18213,
  VPMOVSXWQZ128rrkz = 18214,
  VPMOVSXWQZ256rm = 18215,
  VPMOVSXWQZ256rmk = 18216,
  VPMOVSXWQZ256rmkz = 18217,
  VPMOVSXWQZ256rr = 18218,
  VPMOVSXWQZ256rrk = 18219,
  VPMOVSXWQZ256rrkz = 18220,
  VPMOVSXWQZrm = 18221,
  VPMOVSXWQZrmk = 18222,
  VPMOVSXWQZrmkz = 18223,
  VPMOVSXWQZrr = 18224,
  VPMOVSXWQZrrk = 18225,
  VPMOVSXWQZrrkz = 18226,
  VPMOVSXWQrm = 18227,
  VPMOVSXWQrr = 18228,
  VPMOVUSDBZ128mr = 18229,
  VPMOVUSDBZ128mrk = 18230,
  VPMOVUSDBZ128rr = 18231,
  VPMOVUSDBZ128rrk = 18232,
  VPMOVUSDBZ128rrkz = 18233,
  VPMOVUSDBZ256mr = 18234,
  VPMOVUSDBZ256mrk = 18235,
  VPMOVUSDBZ256rr = 18236,
  VPMOVUSDBZ256rrk = 18237,
  VPMOVUSDBZ256rrkz = 18238,
  VPMOVUSDBZmr = 18239,
  VPMOVUSDBZmrk = 18240,
  VPMOVUSDBZrr = 18241,
  VPMOVUSDBZrrk = 18242,
  VPMOVUSDBZrrkz = 18243,
  VPMOVUSDWZ128mr = 18244,
  VPMOVUSDWZ128mrk = 18245,
  VPMOVUSDWZ128rr = 18246,
  VPMOVUSDWZ128rrk = 18247,
  VPMOVUSDWZ128rrkz = 18248,
  VPMOVUSDWZ256mr = 18249,
  VPMOVUSDWZ256mrk = 18250,
  VPMOVUSDWZ256rr = 18251,
  VPMOVUSDWZ256rrk = 18252,
  VPMOVUSDWZ256rrkz = 18253,
  VPMOVUSDWZmr = 18254,
  VPMOVUSDWZmrk = 18255,
  VPMOVUSDWZrr = 18256,
  VPMOVUSDWZrrk = 18257,
  VPMOVUSDWZrrkz = 18258,
  VPMOVUSQBZ128mr = 18259,
  VPMOVUSQBZ128mrk = 18260,
  VPMOVUSQBZ128rr = 18261,
  VPMOVUSQBZ128rrk = 18262,
  VPMOVUSQBZ128rrkz = 18263,
  VPMOVUSQBZ256mr = 18264,
  VPMOVUSQBZ256mrk = 18265,
  VPMOVUSQBZ256rr = 18266,
  VPMOVUSQBZ256rrk = 18267,
  VPMOVUSQBZ256rrkz = 18268,
  VPMOVUSQBZmr = 18269,
  VPMOVUSQBZmrk = 18270,
  VPMOVUSQBZrr = 18271,
  VPMOVUSQBZrrk = 18272,
  VPMOVUSQBZrrkz = 18273,
  VPMOVUSQDZ128mr = 18274,
  VPMOVUSQDZ128mrk = 18275,
  VPMOVUSQDZ128rr = 18276,
  VPMOVUSQDZ128rrk = 18277,
  VPMOVUSQDZ128rrkz = 18278,
  VPMOVUSQDZ256mr = 18279,
  VPMOVUSQDZ256mrk = 18280,
  VPMOVUSQDZ256rr = 18281,
  VPMOVUSQDZ256rrk = 18282,
  VPMOVUSQDZ256rrkz = 18283,
  VPMOVUSQDZmr = 18284,
  VPMOVUSQDZmrk = 18285,
  VPMOVUSQDZrr = 18286,
  VPMOVUSQDZrrk = 18287,
  VPMOVUSQDZrrkz = 18288,
  VPMOVUSQWZ128mr = 18289,
  VPMOVUSQWZ128mrk = 18290,
  VPMOVUSQWZ128rr = 18291,
  VPMOVUSQWZ128rrk = 18292,
  VPMOVUSQWZ128rrkz = 18293,
  VPMOVUSQWZ256mr = 18294,
  VPMOVUSQWZ256mrk = 18295,
  VPMOVUSQWZ256rr = 18296,
  VPMOVUSQWZ256rrk = 18297,
  VPMOVUSQWZ256rrkz = 18298,
  VPMOVUSQWZmr = 18299,
  VPMOVUSQWZmrk = 18300,
  VPMOVUSQWZrr = 18301,
  VPMOVUSQWZrrk = 18302,
  VPMOVUSQWZrrkz = 18303,
  VPMOVUSWBZ128mr = 18304,
  VPMOVUSWBZ128mrk = 18305,
  VPMOVUSWBZ128rr = 18306,
  VPMOVUSWBZ128rrk = 18307,
  VPMOVUSWBZ128rrkz = 18308,
  VPMOVUSWBZ256mr = 18309,
  VPMOVUSWBZ256mrk = 18310,
  VPMOVUSWBZ256rr = 18311,
  VPMOVUSWBZ256rrk = 18312,
  VPMOVUSWBZ256rrkz = 18313,
  VPMOVUSWBZmr = 18314,
  VPMOVUSWBZmrk = 18315,
  VPMOVUSWBZrr = 18316,
  VPMOVUSWBZrrk = 18317,
  VPMOVUSWBZrrkz = 18318,
  VPMOVW2MZ128kr = 18319,
  VPMOVW2MZ256kr = 18320,
  VPMOVW2MZkr = 18321,
  VPMOVWBZ128mr = 18322,
  VPMOVWBZ128mrk = 18323,
  VPMOVWBZ128rr = 18324,
  VPMOVWBZ128rrk = 18325,
  VPMOVWBZ128rrkz = 18326,
  VPMOVWBZ256mr = 18327,
  VPMOVWBZ256mrk = 18328,
  VPMOVWBZ256rr = 18329,
  VPMOVWBZ256rrk = 18330,
  VPMOVWBZ256rrkz = 18331,
  VPMOVWBZmr = 18332,
  VPMOVWBZmrk = 18333,
  VPMOVWBZrr = 18334,
  VPMOVWBZrrk = 18335,
  VPMOVWBZrrkz = 18336,
  VPMOVZXBDYrm = 18337,
  VPMOVZXBDYrr = 18338,
  VPMOVZXBDZ128rm = 18339,
  VPMOVZXBDZ128rmk = 18340,
  VPMOVZXBDZ128rmkz = 18341,
  VPMOVZXBDZ128rr = 18342,
  VPMOVZXBDZ128rrk = 18343,
  VPMOVZXBDZ128rrkz = 18344,
  VPMOVZXBDZ256rm = 18345,
  VPMOVZXBDZ256rmk = 18346,
  VPMOVZXBDZ256rmkz = 18347,
  VPMOVZXBDZ256rr = 18348,
  VPMOVZXBDZ256rrk = 18349,
  VPMOVZXBDZ256rrkz = 18350,
  VPMOVZXBDZrm = 18351,
  VPMOVZXBDZrmk = 18352,
  VPMOVZXBDZrmkz = 18353,
  VPMOVZXBDZrr = 18354,
  VPMOVZXBDZrrk = 18355,
  VPMOVZXBDZrrkz = 18356,
  VPMOVZXBDrm = 18357,
  VPMOVZXBDrr = 18358,
  VPMOVZXBQYrm = 18359,
  VPMOVZXBQYrr = 18360,
  VPMOVZXBQZ128rm = 18361,
  VPMOVZXBQZ128rmk = 18362,
  VPMOVZXBQZ128rmkz = 18363,
  VPMOVZXBQZ128rr = 18364,
  VPMOVZXBQZ128rrk = 18365,
  VPMOVZXBQZ128rrkz = 18366,
  VPMOVZXBQZ256rm = 18367,
  VPMOVZXBQZ256rmk = 18368,
  VPMOVZXBQZ256rmkz = 18369,
  VPMOVZXBQZ256rr = 18370,
  VPMOVZXBQZ256rrk = 18371,
  VPMOVZXBQZ256rrkz = 18372,
  VPMOVZXBQZrm = 18373,
  VPMOVZXBQZrmk = 18374,
  VPMOVZXBQZrmkz = 18375,
  VPMOVZXBQZrr = 18376,
  VPMOVZXBQZrrk = 18377,
  VPMOVZXBQZrrkz = 18378,
  VPMOVZXBQrm = 18379,
  VPMOVZXBQrr = 18380,
  VPMOVZXBWYrm = 18381,
  VPMOVZXBWYrr = 18382,
  VPMOVZXBWZ128rm = 18383,
  VPMOVZXBWZ128rmk = 18384,
  VPMOVZXBWZ128rmkz = 18385,
  VPMOVZXBWZ128rr = 18386,
  VPMOVZXBWZ128rrk = 18387,
  VPMOVZXBWZ128rrkz = 18388,
  VPMOVZXBWZ256rm = 18389,
  VPMOVZXBWZ256rmk = 18390,
  VPMOVZXBWZ256rmkz = 18391,
  VPMOVZXBWZ256rr = 18392,
  VPMOVZXBWZ256rrk = 18393,
  VPMOVZXBWZ256rrkz = 18394,
  VPMOVZXBWZrm = 18395,
  VPMOVZXBWZrmk = 18396,
  VPMOVZXBWZrmkz = 18397,
  VPMOVZXBWZrr = 18398,
  VPMOVZXBWZrrk = 18399,
  VPMOVZXBWZrrkz = 18400,
  VPMOVZXBWrm = 18401,
  VPMOVZXBWrr = 18402,
  VPMOVZXDQYrm = 18403,
  VPMOVZXDQYrr = 18404,
  VPMOVZXDQZ128rm = 18405,
  VPMOVZXDQZ128rmk = 18406,
  VPMOVZXDQZ128rmkz = 18407,
  VPMOVZXDQZ128rr = 18408,
  VPMOVZXDQZ128rrk = 18409,
  VPMOVZXDQZ128rrkz = 18410,
  VPMOVZXDQZ256rm = 18411,
  VPMOVZXDQZ256rmk = 18412,
  VPMOVZXDQZ256rmkz = 18413,
  VPMOVZXDQZ256rr = 18414,
  VPMOVZXDQZ256rrk = 18415,
  VPMOVZXDQZ256rrkz = 18416,
  VPMOVZXDQZrm = 18417,
  VPMOVZXDQZrmk = 18418,
  VPMOVZXDQZrmkz = 18419,
  VPMOVZXDQZrr = 18420,
  VPMOVZXDQZrrk = 18421,
  VPMOVZXDQZrrkz = 18422,
  VPMOVZXDQrm = 18423,
  VPMOVZXDQrr = 18424,
  VPMOVZXWDYrm = 18425,
  VPMOVZXWDYrr = 18426,
  VPMOVZXWDZ128rm = 18427,
  VPMOVZXWDZ128rmk = 18428,
  VPMOVZXWDZ128rmkz = 18429,
  VPMOVZXWDZ128rr = 18430,
  VPMOVZXWDZ128rrk = 18431,
  VPMOVZXWDZ128rrkz = 18432,
  VPMOVZXWDZ256rm = 18433,
  VPMOVZXWDZ256rmk = 18434,
  VPMOVZXWDZ256rmkz = 18435,
  VPMOVZXWDZ256rr = 18436,
  VPMOVZXWDZ256rrk = 18437,
  VPMOVZXWDZ256rrkz = 18438,
  VPMOVZXWDZrm = 18439,
  VPMOVZXWDZrmk = 18440,
  VPMOVZXWDZrmkz = 18441,
  VPMOVZXWDZrr = 18442,
  VPMOVZXWDZrrk = 18443,
  VPMOVZXWDZrrkz = 18444,
  VPMOVZXWDrm = 18445,
  VPMOVZXWDrr = 18446,
  VPMOVZXWQYrm = 18447,
  VPMOVZXWQYrr = 18448,
  VPMOVZXWQZ128rm = 18449,
  VPMOVZXWQZ128rmk = 18450,
  VPMOVZXWQZ128rmkz = 18451,
  VPMOVZXWQZ128rr = 18452,
  VPMOVZXWQZ128rrk = 18453,
  VPMOVZXWQZ128rrkz = 18454,
  VPMOVZXWQZ256rm = 18455,
  VPMOVZXWQZ256rmk = 18456,
  VPMOVZXWQZ256rmkz = 18457,
  VPMOVZXWQZ256rr = 18458,
  VPMOVZXWQZ256rrk = 18459,
  VPMOVZXWQZ256rrkz = 18460,
  VPMOVZXWQZrm = 18461,
  VPMOVZXWQZrmk = 18462,
  VPMOVZXWQZrmkz = 18463,
  VPMOVZXWQZrr = 18464,
  VPMOVZXWQZrrk = 18465,
  VPMOVZXWQZrrkz = 18466,
  VPMOVZXWQrm = 18467,
  VPMOVZXWQrr = 18468,
  VPMULDQYrm = 18469,
  VPMULDQYrr = 18470,
  VPMULDQZ128rm = 18471,
  VPMULDQZ128rmb = 18472,
  VPMULDQZ128rmbk = 18473,
  VPMULDQZ128rmbkz = 18474,
  VPMULDQZ128rmk = 18475,
  VPMULDQZ128rmkz = 18476,
  VPMULDQZ128rr = 18477,
  VPMULDQZ128rrk = 18478,
  VPMULDQZ128rrkz = 18479,
  VPMULDQZ256rm = 18480,
  VPMULDQZ256rmb = 18481,
  VPMULDQZ256rmbk = 18482,
  VPMULDQZ256rmbkz = 18483,
  VPMULDQZ256rmk = 18484,
  VPMULDQZ256rmkz = 18485,
  VPMULDQZ256rr = 18486,
  VPMULDQZ256rrk = 18487,
  VPMULDQZ256rrkz = 18488,
  VPMULDQZrm = 18489,
  VPMULDQZrmb = 18490,
  VPMULDQZrmbk = 18491,
  VPMULDQZrmbkz = 18492,
  VPMULDQZrmk = 18493,
  VPMULDQZrmkz = 18494,
  VPMULDQZrr = 18495,
  VPMULDQZrrk = 18496,
  VPMULDQZrrkz = 18497,
  VPMULDQrm = 18498,
  VPMULDQrr = 18499,
  VPMULHRSWYrm = 18500,
  VPMULHRSWYrr = 18501,
  VPMULHRSWZ128rm = 18502,
  VPMULHRSWZ128rmk = 18503,
  VPMULHRSWZ128rmkz = 18504,
  VPMULHRSWZ128rr = 18505,
  VPMULHRSWZ128rrk = 18506,
  VPMULHRSWZ128rrkz = 18507,
  VPMULHRSWZ256rm = 18508,
  VPMULHRSWZ256rmk = 18509,
  VPMULHRSWZ256rmkz = 18510,
  VPMULHRSWZ256rr = 18511,
  VPMULHRSWZ256rrk = 18512,
  VPMULHRSWZ256rrkz = 18513,
  VPMULHRSWZrm = 18514,
  VPMULHRSWZrmk = 18515,
  VPMULHRSWZrmkz = 18516,
  VPMULHRSWZrr = 18517,
  VPMULHRSWZrrk = 18518,
  VPMULHRSWZrrkz = 18519,
  VPMULHRSWrm = 18520,
  VPMULHRSWrr = 18521,
  VPMULHUWYrm = 18522,
  VPMULHUWYrr = 18523,
  VPMULHUWZ128rm = 18524,
  VPMULHUWZ128rmk = 18525,
  VPMULHUWZ128rmkz = 18526,
  VPMULHUWZ128rr = 18527,
  VPMULHUWZ128rrk = 18528,
  VPMULHUWZ128rrkz = 18529,
  VPMULHUWZ256rm = 18530,
  VPMULHUWZ256rmk = 18531,
  VPMULHUWZ256rmkz = 18532,
  VPMULHUWZ256rr = 18533,
  VPMULHUWZ256rrk = 18534,
  VPMULHUWZ256rrkz = 18535,
  VPMULHUWZrm = 18536,
  VPMULHUWZrmk = 18537,
  VPMULHUWZrmkz = 18538,
  VPMULHUWZrr = 18539,
  VPMULHUWZrrk = 18540,
  VPMULHUWZrrkz = 18541,
  VPMULHUWrm = 18542,
  VPMULHUWrr = 18543,
  VPMULHWYrm = 18544,
  VPMULHWYrr = 18545,
  VPMULHWZ128rm = 18546,
  VPMULHWZ128rmk = 18547,
  VPMULHWZ128rmkz = 18548,
  VPMULHWZ128rr = 18549,
  VPMULHWZ128rrk = 18550,
  VPMULHWZ128rrkz = 18551,
  VPMULHWZ256rm = 18552,
  VPMULHWZ256rmk = 18553,
  VPMULHWZ256rmkz = 18554,
  VPMULHWZ256rr = 18555,
  VPMULHWZ256rrk = 18556,
  VPMULHWZ256rrkz = 18557,
  VPMULHWZrm = 18558,
  VPMULHWZrmk = 18559,
  VPMULHWZrmkz = 18560,
  VPMULHWZrr = 18561,
  VPMULHWZrrk = 18562,
  VPMULHWZrrkz = 18563,
  VPMULHWrm = 18564,
  VPMULHWrr = 18565,
  VPMULLDYrm = 18566,
  VPMULLDYrr = 18567,
  VPMULLDZ128rm = 18568,
  VPMULLDZ128rmb = 18569,
  VPMULLDZ128rmbk = 18570,
  VPMULLDZ128rmbkz = 18571,
  VPMULLDZ128rmk = 18572,
  VPMULLDZ128rmkz = 18573,
  VPMULLDZ128rr = 18574,
  VPMULLDZ128rrk = 18575,
  VPMULLDZ128rrkz = 18576,
  VPMULLDZ256rm = 18577,
  VPMULLDZ256rmb = 18578,
  VPMULLDZ256rmbk = 18579,
  VPMULLDZ256rmbkz = 18580,
  VPMULLDZ256rmk = 18581,
  VPMULLDZ256rmkz = 18582,
  VPMULLDZ256rr = 18583,
  VPMULLDZ256rrk = 18584,
  VPMULLDZ256rrkz = 18585,
  VPMULLDZrm = 18586,
  VPMULLDZrmb = 18587,
  VPMULLDZrmbk = 18588,
  VPMULLDZrmbkz = 18589,
  VPMULLDZrmk = 18590,
  VPMULLDZrmkz = 18591,
  VPMULLDZrr = 18592,
  VPMULLDZrrk = 18593,
  VPMULLDZrrkz = 18594,
  VPMULLDrm = 18595,
  VPMULLDrr = 18596,
  VPMULLQZ128rm = 18597,
  VPMULLQZ128rmb = 18598,
  VPMULLQZ128rmbk = 18599,
  VPMULLQZ128rmbkz = 18600,
  VPMULLQZ128rmk = 18601,
  VPMULLQZ128rmkz = 18602,
  VPMULLQZ128rr = 18603,
  VPMULLQZ128rrk = 18604,
  VPMULLQZ128rrkz = 18605,
  VPMULLQZ256rm = 18606,
  VPMULLQZ256rmb = 18607,
  VPMULLQZ256rmbk = 18608,
  VPMULLQZ256rmbkz = 18609,
  VPMULLQZ256rmk = 18610,
  VPMULLQZ256rmkz = 18611,
  VPMULLQZ256rr = 18612,
  VPMULLQZ256rrk = 18613,
  VPMULLQZ256rrkz = 18614,
  VPMULLQZrm = 18615,
  VPMULLQZrmb = 18616,
  VPMULLQZrmbk = 18617,
  VPMULLQZrmbkz = 18618,
  VPMULLQZrmk = 18619,
  VPMULLQZrmkz = 18620,
  VPMULLQZrr = 18621,
  VPMULLQZrrk = 18622,
  VPMULLQZrrkz = 18623,
  VPMULLWYrm = 18624,
  VPMULLWYrr = 18625,
  VPMULLWZ128rm = 18626,
  VPMULLWZ128rmk = 18627,
  VPMULLWZ128rmkz = 18628,
  VPMULLWZ128rr = 18629,
  VPMULLWZ128rrk = 18630,
  VPMULLWZ128rrkz = 18631,
  VPMULLWZ256rm = 18632,
  VPMULLWZ256rmk = 18633,
  VPMULLWZ256rmkz = 18634,
  VPMULLWZ256rr = 18635,
  VPMULLWZ256rrk = 18636,
  VPMULLWZ256rrkz = 18637,
  VPMULLWZrm = 18638,
  VPMULLWZrmk = 18639,
  VPMULLWZrmkz = 18640,
  VPMULLWZrr = 18641,
  VPMULLWZrrk = 18642,
  VPMULLWZrrkz = 18643,
  VPMULLWrm = 18644,
  VPMULLWrr = 18645,
  VPMULTISHIFTQBZ128rm = 18646,
  VPMULTISHIFTQBZ128rmb = 18647,
  VPMULTISHIFTQBZ128rmbk = 18648,
  VPMULTISHIFTQBZ128rmbkz = 18649,
  VPMULTISHIFTQBZ128rmk = 18650,
  VPMULTISHIFTQBZ128rmkz = 18651,
  VPMULTISHIFTQBZ128rr = 18652,
  VPMULTISHIFTQBZ128rrk = 18653,
  VPMULTISHIFTQBZ128rrkz = 18654,
  VPMULTISHIFTQBZ256rm = 18655,
  VPMULTISHIFTQBZ256rmb = 18656,
  VPMULTISHIFTQBZ256rmbk = 18657,
  VPMULTISHIFTQBZ256rmbkz = 18658,
  VPMULTISHIFTQBZ256rmk = 18659,
  VPMULTISHIFTQBZ256rmkz = 18660,
  VPMULTISHIFTQBZ256rr = 18661,
  VPMULTISHIFTQBZ256rrk = 18662,
  VPMULTISHIFTQBZ256rrkz = 18663,
  VPMULTISHIFTQBZrm = 18664,
  VPMULTISHIFTQBZrmb = 18665,
  VPMULTISHIFTQBZrmbk = 18666,
  VPMULTISHIFTQBZrmbkz = 18667,
  VPMULTISHIFTQBZrmk = 18668,
  VPMULTISHIFTQBZrmkz = 18669,
  VPMULTISHIFTQBZrr = 18670,
  VPMULTISHIFTQBZrrk = 18671,
  VPMULTISHIFTQBZrrkz = 18672,
  VPMULUDQYrm = 18673,
  VPMULUDQYrr = 18674,
  VPMULUDQZ128rm = 18675,
  VPMULUDQZ128rmb = 18676,
  VPMULUDQZ128rmbk = 18677,
  VPMULUDQZ128rmbkz = 18678,
  VPMULUDQZ128rmk = 18679,
  VPMULUDQZ128rmkz = 18680,
  VPMULUDQZ128rr = 18681,
  VPMULUDQZ128rrk = 18682,
  VPMULUDQZ128rrkz = 18683,
  VPMULUDQZ256rm = 18684,
  VPMULUDQZ256rmb = 18685,
  VPMULUDQZ256rmbk = 18686,
  VPMULUDQZ256rmbkz = 18687,
  VPMULUDQZ256rmk = 18688,
  VPMULUDQZ256rmkz = 18689,
  VPMULUDQZ256rr = 18690,
  VPMULUDQZ256rrk = 18691,
  VPMULUDQZ256rrkz = 18692,
  VPMULUDQZrm = 18693,
  VPMULUDQZrmb = 18694,
  VPMULUDQZrmbk = 18695,
  VPMULUDQZrmbkz = 18696,
  VPMULUDQZrmk = 18697,
  VPMULUDQZrmkz = 18698,
  VPMULUDQZrr = 18699,
  VPMULUDQZrrk = 18700,
  VPMULUDQZrrkz = 18701,
  VPMULUDQrm = 18702,
  VPMULUDQrr = 18703,
  VPOPCNTBZ128rm = 18704,
  VPOPCNTBZ128rmk = 18705,
  VPOPCNTBZ128rmkz = 18706,
  VPOPCNTBZ128rr = 18707,
  VPOPCNTBZ128rrk = 18708,
  VPOPCNTBZ128rrkz = 18709,
  VPOPCNTBZ256rm = 18710,
  VPOPCNTBZ256rmk = 18711,
  VPOPCNTBZ256rmkz = 18712,
  VPOPCNTBZ256rr = 18713,
  VPOPCNTBZ256rrk = 18714,
  VPOPCNTBZ256rrkz = 18715,
  VPOPCNTBZrm = 18716,
  VPOPCNTBZrmk = 18717,
  VPOPCNTBZrmkz = 18718,
  VPOPCNTBZrr = 18719,
  VPOPCNTBZrrk = 18720,
  VPOPCNTBZrrkz = 18721,
  VPOPCNTDZ128rm = 18722,
  VPOPCNTDZ128rmb = 18723,
  VPOPCNTDZ128rmbk = 18724,
  VPOPCNTDZ128rmbkz = 18725,
  VPOPCNTDZ128rmk = 18726,
  VPOPCNTDZ128rmkz = 18727,
  VPOPCNTDZ128rr = 18728,
  VPOPCNTDZ128rrk = 18729,
  VPOPCNTDZ128rrkz = 18730,
  VPOPCNTDZ256rm = 18731,
  VPOPCNTDZ256rmb = 18732,
  VPOPCNTDZ256rmbk = 18733,
  VPOPCNTDZ256rmbkz = 18734,
  VPOPCNTDZ256rmk = 18735,
  VPOPCNTDZ256rmkz = 18736,
  VPOPCNTDZ256rr = 18737,
  VPOPCNTDZ256rrk = 18738,
  VPOPCNTDZ256rrkz = 18739,
  VPOPCNTDZrm = 18740,
  VPOPCNTDZrmb = 18741,
  VPOPCNTDZrmbk = 18742,
  VPOPCNTDZrmbkz = 18743,
  VPOPCNTDZrmk = 18744,
  VPOPCNTDZrmkz = 18745,
  VPOPCNTDZrr = 18746,
  VPOPCNTDZrrk = 18747,
  VPOPCNTDZrrkz = 18748,
  VPOPCNTQZ128rm = 18749,
  VPOPCNTQZ128rmb = 18750,
  VPOPCNTQZ128rmbk = 18751,
  VPOPCNTQZ128rmbkz = 18752,
  VPOPCNTQZ128rmk = 18753,
  VPOPCNTQZ128rmkz = 18754,
  VPOPCNTQZ128rr = 18755,
  VPOPCNTQZ128rrk = 18756,
  VPOPCNTQZ128rrkz = 18757,
  VPOPCNTQZ256rm = 18758,
  VPOPCNTQZ256rmb = 18759,
  VPOPCNTQZ256rmbk = 18760,
  VPOPCNTQZ256rmbkz = 18761,
  VPOPCNTQZ256rmk = 18762,
  VPOPCNTQZ256rmkz = 18763,
  VPOPCNTQZ256rr = 18764,
  VPOPCNTQZ256rrk = 18765,
  VPOPCNTQZ256rrkz = 18766,
  VPOPCNTQZrm = 18767,
  VPOPCNTQZrmb = 18768,
  VPOPCNTQZrmbk = 18769,
  VPOPCNTQZrmbkz = 18770,
  VPOPCNTQZrmk = 18771,
  VPOPCNTQZrmkz = 18772,
  VPOPCNTQZrr = 18773,
  VPOPCNTQZrrk = 18774,
  VPOPCNTQZrrkz = 18775,
  VPOPCNTWZ128rm = 18776,
  VPOPCNTWZ128rmk = 18777,
  VPOPCNTWZ128rmkz = 18778,
  VPOPCNTWZ128rr = 18779,
  VPOPCNTWZ128rrk = 18780,
  VPOPCNTWZ128rrkz = 18781,
  VPOPCNTWZ256rm = 18782,
  VPOPCNTWZ256rmk = 18783,
  VPOPCNTWZ256rmkz = 18784,
  VPOPCNTWZ256rr = 18785,
  VPOPCNTWZ256rrk = 18786,
  VPOPCNTWZ256rrkz = 18787,
  VPOPCNTWZrm = 18788,
  VPOPCNTWZrmk = 18789,
  VPOPCNTWZrmkz = 18790,
  VPOPCNTWZrr = 18791,
  VPOPCNTWZrrk = 18792,
  VPOPCNTWZrrkz = 18793,
  VPORDZ128rm = 18794,
  VPORDZ128rmb = 18795,
  VPORDZ128rmbk = 18796,
  VPORDZ128rmbkz = 18797,
  VPORDZ128rmk = 18798,
  VPORDZ128rmkz = 18799,
  VPORDZ128rr = 18800,
  VPORDZ128rrk = 18801,
  VPORDZ128rrkz = 18802,
  VPORDZ256rm = 18803,
  VPORDZ256rmb = 18804,
  VPORDZ256rmbk = 18805,
  VPORDZ256rmbkz = 18806,
  VPORDZ256rmk = 18807,
  VPORDZ256rmkz = 18808,
  VPORDZ256rr = 18809,
  VPORDZ256rrk = 18810,
  VPORDZ256rrkz = 18811,
  VPORDZrm = 18812,
  VPORDZrmb = 18813,
  VPORDZrmbk = 18814,
  VPORDZrmbkz = 18815,
  VPORDZrmk = 18816,
  VPORDZrmkz = 18817,
  VPORDZrr = 18818,
  VPORDZrrk = 18819,
  VPORDZrrkz = 18820,
  VPORQZ128rm = 18821,
  VPORQZ128rmb = 18822,
  VPORQZ128rmbk = 18823,
  VPORQZ128rmbkz = 18824,
  VPORQZ128rmk = 18825,
  VPORQZ128rmkz = 18826,
  VPORQZ128rr = 18827,
  VPORQZ128rrk = 18828,
  VPORQZ128rrkz = 18829,
  VPORQZ256rm = 18830,
  VPORQZ256rmb = 18831,
  VPORQZ256rmbk = 18832,
  VPORQZ256rmbkz = 18833,
  VPORQZ256rmk = 18834,
  VPORQZ256rmkz = 18835,
  VPORQZ256rr = 18836,
  VPORQZ256rrk = 18837,
  VPORQZ256rrkz = 18838,
  VPORQZrm = 18839,
  VPORQZrmb = 18840,
  VPORQZrmbk = 18841,
  VPORQZrmbkz = 18842,
  VPORQZrmk = 18843,
  VPORQZrmkz = 18844,
  VPORQZrr = 18845,
  VPORQZrrk = 18846,
  VPORQZrrkz = 18847,
  VPORYrm = 18848,
  VPORYrr = 18849,
  VPORrm = 18850,
  VPORrr = 18851,
  VPPERMrmr = 18852,
  VPPERMrrm = 18853,
  VPPERMrrr = 18854,
  VPPERMrrr_REV = 18855,
  VPROLDZ128mbi = 18856,
  VPROLDZ128mbik = 18857,
  VPROLDZ128mbikz = 18858,
  VPROLDZ128mi = 18859,
  VPROLDZ128mik = 18860,
  VPROLDZ128mikz = 18861,
  VPROLDZ128ri = 18862,
  VPROLDZ128rik = 18863,
  VPROLDZ128rikz = 18864,
  VPROLDZ256mbi = 18865,
  VPROLDZ256mbik = 18866,
  VPROLDZ256mbikz = 18867,
  VPROLDZ256mi = 18868,
  VPROLDZ256mik = 18869,
  VPROLDZ256mikz = 18870,
  VPROLDZ256ri = 18871,
  VPROLDZ256rik = 18872,
  VPROLDZ256rikz = 18873,
  VPROLDZmbi = 18874,
  VPROLDZmbik = 18875,
  VPROLDZmbikz = 18876,
  VPROLDZmi = 18877,
  VPROLDZmik = 18878,
  VPROLDZmikz = 18879,
  VPROLDZri = 18880,
  VPROLDZrik = 18881,
  VPROLDZrikz = 18882,
  VPROLQZ128mbi = 18883,
  VPROLQZ128mbik = 18884,
  VPROLQZ128mbikz = 18885,
  VPROLQZ128mi = 18886,
  VPROLQZ128mik = 18887,
  VPROLQZ128mikz = 18888,
  VPROLQZ128ri = 18889,
  VPROLQZ128rik = 18890,
  VPROLQZ128rikz = 18891,
  VPROLQZ256mbi = 18892,
  VPROLQZ256mbik = 18893,
  VPROLQZ256mbikz = 18894,
  VPROLQZ256mi = 18895,
  VPROLQZ256mik = 18896,
  VPROLQZ256mikz = 18897,
  VPROLQZ256ri = 18898,
  VPROLQZ256rik = 18899,
  VPROLQZ256rikz = 18900,
  VPROLQZmbi = 18901,
  VPROLQZmbik = 18902,
  VPROLQZmbikz = 18903,
  VPROLQZmi = 18904,
  VPROLQZmik = 18905,
  VPROLQZmikz = 18906,
  VPROLQZri = 18907,
  VPROLQZrik = 18908,
  VPROLQZrikz = 18909,
  VPROLVDZ128rm = 18910,
  VPROLVDZ128rmb = 18911,
  VPROLVDZ128rmbk = 18912,
  VPROLVDZ128rmbkz = 18913,
  VPROLVDZ128rmk = 18914,
  VPROLVDZ128rmkz = 18915,
  VPROLVDZ128rr = 18916,
  VPROLVDZ128rrk = 18917,
  VPROLVDZ128rrkz = 18918,
  VPROLVDZ256rm = 18919,
  VPROLVDZ256rmb = 18920,
  VPROLVDZ256rmbk = 18921,
  VPROLVDZ256rmbkz = 18922,
  VPROLVDZ256rmk = 18923,
  VPROLVDZ256rmkz = 18924,
  VPROLVDZ256rr = 18925,
  VPROLVDZ256rrk = 18926,
  VPROLVDZ256rrkz = 18927,
  VPROLVDZrm = 18928,
  VPROLVDZrmb = 18929,
  VPROLVDZrmbk = 18930,
  VPROLVDZrmbkz = 18931,
  VPROLVDZrmk = 18932,
  VPROLVDZrmkz = 18933,
  VPROLVDZrr = 18934,
  VPROLVDZrrk = 18935,
  VPROLVDZrrkz = 18936,
  VPROLVQZ128rm = 18937,
  VPROLVQZ128rmb = 18938,
  VPROLVQZ128rmbk = 18939,
  VPROLVQZ128rmbkz = 18940,
  VPROLVQZ128rmk = 18941,
  VPROLVQZ128rmkz = 18942,
  VPROLVQZ128rr = 18943,
  VPROLVQZ128rrk = 18944,
  VPROLVQZ128rrkz = 18945,
  VPROLVQZ256rm = 18946,
  VPROLVQZ256rmb = 18947,
  VPROLVQZ256rmbk = 18948,
  VPROLVQZ256rmbkz = 18949,
  VPROLVQZ256rmk = 18950,
  VPROLVQZ256rmkz = 18951,
  VPROLVQZ256rr = 18952,
  VPROLVQZ256rrk = 18953,
  VPROLVQZ256rrkz = 18954,
  VPROLVQZrm = 18955,
  VPROLVQZrmb = 18956,
  VPROLVQZrmbk = 18957,
  VPROLVQZrmbkz = 18958,
  VPROLVQZrmk = 18959,
  VPROLVQZrmkz = 18960,
  VPROLVQZrr = 18961,
  VPROLVQZrrk = 18962,
  VPROLVQZrrkz = 18963,
  VPRORDZ128mbi = 18964,
  VPRORDZ128mbik = 18965,
  VPRORDZ128mbikz = 18966,
  VPRORDZ128mi = 18967,
  VPRORDZ128mik = 18968,
  VPRORDZ128mikz = 18969,
  VPRORDZ128ri = 18970,
  VPRORDZ128rik = 18971,
  VPRORDZ128rikz = 18972,
  VPRORDZ256mbi = 18973,
  VPRORDZ256mbik = 18974,
  VPRORDZ256mbikz = 18975,
  VPRORDZ256mi = 18976,
  VPRORDZ256mik = 18977,
  VPRORDZ256mikz = 18978,
  VPRORDZ256ri = 18979,
  VPRORDZ256rik = 18980,
  VPRORDZ256rikz = 18981,
  VPRORDZmbi = 18982,
  VPRORDZmbik = 18983,
  VPRORDZmbikz = 18984,
  VPRORDZmi = 18985,
  VPRORDZmik = 18986,
  VPRORDZmikz = 18987,
  VPRORDZri = 18988,
  VPRORDZrik = 18989,
  VPRORDZrikz = 18990,
  VPRORQZ128mbi = 18991,
  VPRORQZ128mbik = 18992,
  VPRORQZ128mbikz = 18993,
  VPRORQZ128mi = 18994,
  VPRORQZ128mik = 18995,
  VPRORQZ128mikz = 18996,
  VPRORQZ128ri = 18997,
  VPRORQZ128rik = 18998,
  VPRORQZ128rikz = 18999,
  VPRORQZ256mbi = 19000,
  VPRORQZ256mbik = 19001,
  VPRORQZ256mbikz = 19002,
  VPRORQZ256mi = 19003,
  VPRORQZ256mik = 19004,
  VPRORQZ256mikz = 19005,
  VPRORQZ256ri = 19006,
  VPRORQZ256rik = 19007,
  VPRORQZ256rikz = 19008,
  VPRORQZmbi = 19009,
  VPRORQZmbik = 19010,
  VPRORQZmbikz = 19011,
  VPRORQZmi = 19012,
  VPRORQZmik = 19013,
  VPRORQZmikz = 19014,
  VPRORQZri = 19015,
  VPRORQZrik = 19016,
  VPRORQZrikz = 19017,
  VPRORVDZ128rm = 19018,
  VPRORVDZ128rmb = 19019,
  VPRORVDZ128rmbk = 19020,
  VPRORVDZ128rmbkz = 19021,
  VPRORVDZ128rmk = 19022,
  VPRORVDZ128rmkz = 19023,
  VPRORVDZ128rr = 19024,
  VPRORVDZ128rrk = 19025,
  VPRORVDZ128rrkz = 19026,
  VPRORVDZ256rm = 19027,
  VPRORVDZ256rmb = 19028,
  VPRORVDZ256rmbk = 19029,
  VPRORVDZ256rmbkz = 19030,
  VPRORVDZ256rmk = 19031,
  VPRORVDZ256rmkz = 19032,
  VPRORVDZ256rr = 19033,
  VPRORVDZ256rrk = 19034,
  VPRORVDZ256rrkz = 19035,
  VPRORVDZrm = 19036,
  VPRORVDZrmb = 19037,
  VPRORVDZrmbk = 19038,
  VPRORVDZrmbkz = 19039,
  VPRORVDZrmk = 19040,
  VPRORVDZrmkz = 19041,
  VPRORVDZrr = 19042,
  VPRORVDZrrk = 19043,
  VPRORVDZrrkz = 19044,
  VPRORVQZ128rm = 19045,
  VPRORVQZ128rmb = 19046,
  VPRORVQZ128rmbk = 19047,
  VPRORVQZ128rmbkz = 19048,
  VPRORVQZ128rmk = 19049,
  VPRORVQZ128rmkz = 19050,
  VPRORVQZ128rr = 19051,
  VPRORVQZ128rrk = 19052,
  VPRORVQZ128rrkz = 19053,
  VPRORVQZ256rm = 19054,
  VPRORVQZ256rmb = 19055,
  VPRORVQZ256rmbk = 19056,
  VPRORVQZ256rmbkz = 19057,
  VPRORVQZ256rmk = 19058,
  VPRORVQZ256rmkz = 19059,
  VPRORVQZ256rr = 19060,
  VPRORVQZ256rrk = 19061,
  VPRORVQZ256rrkz = 19062,
  VPRORVQZrm = 19063,
  VPRORVQZrmb = 19064,
  VPRORVQZrmbk = 19065,
  VPRORVQZrmbkz = 19066,
  VPRORVQZrmk = 19067,
  VPRORVQZrmkz = 19068,
  VPRORVQZrr = 19069,
  VPRORVQZrrk = 19070,
  VPRORVQZrrkz = 19071,
  VPROTBmi = 19072,
  VPROTBmr = 19073,
  VPROTBri = 19074,
  VPROTBrm = 19075,
  VPROTBrr = 19076,
  VPROTBrr_REV = 19077,
  VPROTDmi = 19078,
  VPROTDmr = 19079,
  VPROTDri = 19080,
  VPROTDrm = 19081,
  VPROTDrr = 19082,
  VPROTDrr_REV = 19083,
  VPROTQmi = 19084,
  VPROTQmr = 19085,
  VPROTQri = 19086,
  VPROTQrm = 19087,
  VPROTQrr = 19088,
  VPROTQrr_REV = 19089,
  VPROTWmi = 19090,
  VPROTWmr = 19091,
  VPROTWri = 19092,
  VPROTWrm = 19093,
  VPROTWrr = 19094,
  VPROTWrr_REV = 19095,
  VPSADBWYrm = 19096,
  VPSADBWYrr = 19097,
  VPSADBWZ128rm = 19098,
  VPSADBWZ128rr = 19099,
  VPSADBWZ256rm = 19100,
  VPSADBWZ256rr = 19101,
  VPSADBWZrm = 19102,
  VPSADBWZrr = 19103,
  VPSADBWrm = 19104,
  VPSADBWrr = 19105,
  VPSCATTERDDZ128mr = 19106,
  VPSCATTERDDZ256mr = 19107,
  VPSCATTERDDZmr = 19108,
  VPSCATTERDQZ128mr = 19109,
  VPSCATTERDQZ256mr = 19110,
  VPSCATTERDQZmr = 19111,
  VPSCATTERQDZ128mr = 19112,
  VPSCATTERQDZ256mr = 19113,
  VPSCATTERQDZmr = 19114,
  VPSCATTERQQZ128mr = 19115,
  VPSCATTERQQZ256mr = 19116,
  VPSCATTERQQZmr = 19117,
  VPSHABmr = 19118,
  VPSHABrm = 19119,
  VPSHABrr = 19120,
  VPSHABrr_REV = 19121,
  VPSHADmr = 19122,
  VPSHADrm = 19123,
  VPSHADrr = 19124,
  VPSHADrr_REV = 19125,
  VPSHAQmr = 19126,
  VPSHAQrm = 19127,
  VPSHAQrr = 19128,
  VPSHAQrr_REV = 19129,
  VPSHAWmr = 19130,
  VPSHAWrm = 19131,
  VPSHAWrr = 19132,
  VPSHAWrr_REV = 19133,
  VPSHLBmr = 19134,
  VPSHLBrm = 19135,
  VPSHLBrr = 19136,
  VPSHLBrr_REV = 19137,
  VPSHLDDZ128rmbi = 19138,
  VPSHLDDZ128rmbik = 19139,
  VPSHLDDZ128rmbikz = 19140,
  VPSHLDDZ128rmi = 19141,
  VPSHLDDZ128rmik = 19142,
  VPSHLDDZ128rmikz = 19143,
  VPSHLDDZ128rri = 19144,
  VPSHLDDZ128rrik = 19145,
  VPSHLDDZ128rrikz = 19146,
  VPSHLDDZ256rmbi = 19147,
  VPSHLDDZ256rmbik = 19148,
  VPSHLDDZ256rmbikz = 19149,
  VPSHLDDZ256rmi = 19150,
  VPSHLDDZ256rmik = 19151,
  VPSHLDDZ256rmikz = 19152,
  VPSHLDDZ256rri = 19153,
  VPSHLDDZ256rrik = 19154,
  VPSHLDDZ256rrikz = 19155,
  VPSHLDDZrmbi = 19156,
  VPSHLDDZrmbik = 19157,
  VPSHLDDZrmbikz = 19158,
  VPSHLDDZrmi = 19159,
  VPSHLDDZrmik = 19160,
  VPSHLDDZrmikz = 19161,
  VPSHLDDZrri = 19162,
  VPSHLDDZrrik = 19163,
  VPSHLDDZrrikz = 19164,
  VPSHLDQZ128rmbi = 19165,
  VPSHLDQZ128rmbik = 19166,
  VPSHLDQZ128rmbikz = 19167,
  VPSHLDQZ128rmi = 19168,
  VPSHLDQZ128rmik = 19169,
  VPSHLDQZ128rmikz = 19170,
  VPSHLDQZ128rri = 19171,
  VPSHLDQZ128rrik = 19172,
  VPSHLDQZ128rrikz = 19173,
  VPSHLDQZ256rmbi = 19174,
  VPSHLDQZ256rmbik = 19175,
  VPSHLDQZ256rmbikz = 19176,
  VPSHLDQZ256rmi = 19177,
  VPSHLDQZ256rmik = 19178,
  VPSHLDQZ256rmikz = 19179,
  VPSHLDQZ256rri = 19180,
  VPSHLDQZ256rrik = 19181,
  VPSHLDQZ256rrikz = 19182,
  VPSHLDQZrmbi = 19183,
  VPSHLDQZrmbik = 19184,
  VPSHLDQZrmbikz = 19185,
  VPSHLDQZrmi = 19186,
  VPSHLDQZrmik = 19187,
  VPSHLDQZrmikz = 19188,
  VPSHLDQZrri = 19189,
  VPSHLDQZrrik = 19190,
  VPSHLDQZrrikz = 19191,
  VPSHLDVDZ128m = 19192,
  VPSHLDVDZ128mb = 19193,
  VPSHLDVDZ128mbk = 19194,
  VPSHLDVDZ128mbkz = 19195,
  VPSHLDVDZ128mk = 19196,
  VPSHLDVDZ128mkz = 19197,
  VPSHLDVDZ128r = 19198,
  VPSHLDVDZ128rk = 19199,
  VPSHLDVDZ128rkz = 19200,
  VPSHLDVDZ256m = 19201,
  VPSHLDVDZ256mb = 19202,
  VPSHLDVDZ256mbk = 19203,
  VPSHLDVDZ256mbkz = 19204,
  VPSHLDVDZ256mk = 19205,
  VPSHLDVDZ256mkz = 19206,
  VPSHLDVDZ256r = 19207,
  VPSHLDVDZ256rk = 19208,
  VPSHLDVDZ256rkz = 19209,
  VPSHLDVDZm = 19210,
  VPSHLDVDZmb = 19211,
  VPSHLDVDZmbk = 19212,
  VPSHLDVDZmbkz = 19213,
  VPSHLDVDZmk = 19214,
  VPSHLDVDZmkz = 19215,
  VPSHLDVDZr = 19216,
  VPSHLDVDZrk = 19217,
  VPSHLDVDZrkz = 19218,
  VPSHLDVQZ128m = 19219,
  VPSHLDVQZ128mb = 19220,
  VPSHLDVQZ128mbk = 19221,
  VPSHLDVQZ128mbkz = 19222,
  VPSHLDVQZ128mk = 19223,
  VPSHLDVQZ128mkz = 19224,
  VPSHLDVQZ128r = 19225,
  VPSHLDVQZ128rk = 19226,
  VPSHLDVQZ128rkz = 19227,
  VPSHLDVQZ256m = 19228,
  VPSHLDVQZ256mb = 19229,
  VPSHLDVQZ256mbk = 19230,
  VPSHLDVQZ256mbkz = 19231,
  VPSHLDVQZ256mk = 19232,
  VPSHLDVQZ256mkz = 19233,
  VPSHLDVQZ256r = 19234,
  VPSHLDVQZ256rk = 19235,
  VPSHLDVQZ256rkz = 19236,
  VPSHLDVQZm = 19237,
  VPSHLDVQZmb = 19238,
  VPSHLDVQZmbk = 19239,
  VPSHLDVQZmbkz = 19240,
  VPSHLDVQZmk = 19241,
  VPSHLDVQZmkz = 19242,
  VPSHLDVQZr = 19243,
  VPSHLDVQZrk = 19244,
  VPSHLDVQZrkz = 19245,
  VPSHLDVWZ128m = 19246,
  VPSHLDVWZ128mk = 19247,
  VPSHLDVWZ128mkz = 19248,
  VPSHLDVWZ128r = 19249,
  VPSHLDVWZ128rk = 19250,
  VPSHLDVWZ128rkz = 19251,
  VPSHLDVWZ256m = 19252,
  VPSHLDVWZ256mk = 19253,
  VPSHLDVWZ256mkz = 19254,
  VPSHLDVWZ256r = 19255,
  VPSHLDVWZ256rk = 19256,
  VPSHLDVWZ256rkz = 19257,
  VPSHLDVWZm = 19258,
  VPSHLDVWZmk = 19259,
  VPSHLDVWZmkz = 19260,
  VPSHLDVWZr = 19261,
  VPSHLDVWZrk = 19262,
  VPSHLDVWZrkz = 19263,
  VPSHLDWZ128rmi = 19264,
  VPSHLDWZ128rmik = 19265,
  VPSHLDWZ128rmikz = 19266,
  VPSHLDWZ128rri = 19267,
  VPSHLDWZ128rrik = 19268,
  VPSHLDWZ128rrikz = 19269,
  VPSHLDWZ256rmi = 19270,
  VPSHLDWZ256rmik = 19271,
  VPSHLDWZ256rmikz = 19272,
  VPSHLDWZ256rri = 19273,
  VPSHLDWZ256rrik = 19274,
  VPSHLDWZ256rrikz = 19275,
  VPSHLDWZrmi = 19276,
  VPSHLDWZrmik = 19277,
  VPSHLDWZrmikz = 19278,
  VPSHLDWZrri = 19279,
  VPSHLDWZrrik = 19280,
  VPSHLDWZrrikz = 19281,
  VPSHLDmr = 19282,
  VPSHLDrm = 19283,
  VPSHLDrr = 19284,
  VPSHLDrr_REV = 19285,
  VPSHLQmr = 19286,
  VPSHLQrm = 19287,
  VPSHLQrr = 19288,
  VPSHLQrr_REV = 19289,
  VPSHLWmr = 19290,
  VPSHLWrm = 19291,
  VPSHLWrr = 19292,
  VPSHLWrr_REV = 19293,
  VPSHRDDZ128rmbi = 19294,
  VPSHRDDZ128rmbik = 19295,
  VPSHRDDZ128rmbikz = 19296,
  VPSHRDDZ128rmi = 19297,
  VPSHRDDZ128rmik = 19298,
  VPSHRDDZ128rmikz = 19299,
  VPSHRDDZ128rri = 19300,
  VPSHRDDZ128rrik = 19301,
  VPSHRDDZ128rrikz = 19302,
  VPSHRDDZ256rmbi = 19303,
  VPSHRDDZ256rmbik = 19304,
  VPSHRDDZ256rmbikz = 19305,
  VPSHRDDZ256rmi = 19306,
  VPSHRDDZ256rmik = 19307,
  VPSHRDDZ256rmikz = 19308,
  VPSHRDDZ256rri = 19309,
  VPSHRDDZ256rrik = 19310,
  VPSHRDDZ256rrikz = 19311,
  VPSHRDDZrmbi = 19312,
  VPSHRDDZrmbik = 19313,
  VPSHRDDZrmbikz = 19314,
  VPSHRDDZrmi = 19315,
  VPSHRDDZrmik = 19316,
  VPSHRDDZrmikz = 19317,
  VPSHRDDZrri = 19318,
  VPSHRDDZrrik = 19319,
  VPSHRDDZrrikz = 19320,
  VPSHRDQZ128rmbi = 19321,
  VPSHRDQZ128rmbik = 19322,
  VPSHRDQZ128rmbikz = 19323,
  VPSHRDQZ128rmi = 19324,
  VPSHRDQZ128rmik = 19325,
  VPSHRDQZ128rmikz = 19326,
  VPSHRDQZ128rri = 19327,
  VPSHRDQZ128rrik = 19328,
  VPSHRDQZ128rrikz = 19329,
  VPSHRDQZ256rmbi = 19330,
  VPSHRDQZ256rmbik = 19331,
  VPSHRDQZ256rmbikz = 19332,
  VPSHRDQZ256rmi = 19333,
  VPSHRDQZ256rmik = 19334,
  VPSHRDQZ256rmikz = 19335,
  VPSHRDQZ256rri = 19336,
  VPSHRDQZ256rrik = 19337,
  VPSHRDQZ256rrikz = 19338,
  VPSHRDQZrmbi = 19339,
  VPSHRDQZrmbik = 19340,
  VPSHRDQZrmbikz = 19341,
  VPSHRDQZrmi = 19342,
  VPSHRDQZrmik = 19343,
  VPSHRDQZrmikz = 19344,
  VPSHRDQZrri = 19345,
  VPSHRDQZrrik = 19346,
  VPSHRDQZrrikz = 19347,
  VPSHRDVDZ128m = 19348,
  VPSHRDVDZ128mb = 19349,
  VPSHRDVDZ128mbk = 19350,
  VPSHRDVDZ128mbkz = 19351,
  VPSHRDVDZ128mk = 19352,
  VPSHRDVDZ128mkz = 19353,
  VPSHRDVDZ128r = 19354,
  VPSHRDVDZ128rk = 19355,
  VPSHRDVDZ128rkz = 19356,
  VPSHRDVDZ256m = 19357,
  VPSHRDVDZ256mb = 19358,
  VPSHRDVDZ256mbk = 19359,
  VPSHRDVDZ256mbkz = 19360,
  VPSHRDVDZ256mk = 19361,
  VPSHRDVDZ256mkz = 19362,
  VPSHRDVDZ256r = 19363,
  VPSHRDVDZ256rk = 19364,
  VPSHRDVDZ256rkz = 19365,
  VPSHRDVDZm = 19366,
  VPSHRDVDZmb = 19367,
  VPSHRDVDZmbk = 19368,
  VPSHRDVDZmbkz = 19369,
  VPSHRDVDZmk = 19370,
  VPSHRDVDZmkz = 19371,
  VPSHRDVDZr = 19372,
  VPSHRDVDZrk = 19373,
  VPSHRDVDZrkz = 19374,
  VPSHRDVQZ128m = 19375,
  VPSHRDVQZ128mb = 19376,
  VPSHRDVQZ128mbk = 19377,
  VPSHRDVQZ128mbkz = 19378,
  VPSHRDVQZ128mk = 19379,
  VPSHRDVQZ128mkz = 19380,
  VPSHRDVQZ128r = 19381,
  VPSHRDVQZ128rk = 19382,
  VPSHRDVQZ128rkz = 19383,
  VPSHRDVQZ256m = 19384,
  VPSHRDVQZ256mb = 19385,
  VPSHRDVQZ256mbk = 19386,
  VPSHRDVQZ256mbkz = 19387,
  VPSHRDVQZ256mk = 19388,
  VPSHRDVQZ256mkz = 19389,
  VPSHRDVQZ256r = 19390,
  VPSHRDVQZ256rk = 19391,
  VPSHRDVQZ256rkz = 19392,
  VPSHRDVQZm = 19393,
  VPSHRDVQZmb = 19394,
  VPSHRDVQZmbk = 19395,
  VPSHRDVQZmbkz = 19396,
  VPSHRDVQZmk = 19397,
  VPSHRDVQZmkz = 19398,
  VPSHRDVQZr = 19399,
  VPSHRDVQZrk = 19400,
  VPSHRDVQZrkz = 19401,
  VPSHRDVWZ128m = 19402,
  VPSHRDVWZ128mk = 19403,
  VPSHRDVWZ128mkz = 19404,
  VPSHRDVWZ128r = 19405,
  VPSHRDVWZ128rk = 19406,
  VPSHRDVWZ128rkz = 19407,
  VPSHRDVWZ256m = 19408,
  VPSHRDVWZ256mk = 19409,
  VPSHRDVWZ256mkz = 19410,
  VPSHRDVWZ256r = 19411,
  VPSHRDVWZ256rk = 19412,
  VPSHRDVWZ256rkz = 19413,
  VPSHRDVWZm = 19414,
  VPSHRDVWZmk = 19415,
  VPSHRDVWZmkz = 19416,
  VPSHRDVWZr = 19417,
  VPSHRDVWZrk = 19418,
  VPSHRDVWZrkz = 19419,
  VPSHRDWZ128rmi = 19420,
  VPSHRDWZ128rmik = 19421,
  VPSHRDWZ128rmikz = 19422,
  VPSHRDWZ128rri = 19423,
  VPSHRDWZ128rrik = 19424,
  VPSHRDWZ128rrikz = 19425,
  VPSHRDWZ256rmi = 19426,
  VPSHRDWZ256rmik = 19427,
  VPSHRDWZ256rmikz = 19428,
  VPSHRDWZ256rri = 19429,
  VPSHRDWZ256rrik = 19430,
  VPSHRDWZ256rrikz = 19431,
  VPSHRDWZrmi = 19432,
  VPSHRDWZrmik = 19433,
  VPSHRDWZrmikz = 19434,
  VPSHRDWZrri = 19435,
  VPSHRDWZrrik = 19436,
  VPSHRDWZrrikz = 19437,
  VPSHUFBITQMBZ128rm = 19438,
  VPSHUFBITQMBZ128rmk = 19439,
  VPSHUFBITQMBZ128rr = 19440,
  VPSHUFBITQMBZ128rrk = 19441,
  VPSHUFBITQMBZ256rm = 19442,
  VPSHUFBITQMBZ256rmk = 19443,
  VPSHUFBITQMBZ256rr = 19444,
  VPSHUFBITQMBZ256rrk = 19445,
  VPSHUFBITQMBZrm = 19446,
  VPSHUFBITQMBZrmk = 19447,
  VPSHUFBITQMBZrr = 19448,
  VPSHUFBITQMBZrrk = 19449,
  VPSHUFBYrm = 19450,
  VPSHUFBYrr = 19451,
  VPSHUFBZ128rm = 19452,
  VPSHUFBZ128rmk = 19453,
  VPSHUFBZ128rmkz = 19454,
  VPSHUFBZ128rr = 19455,
  VPSHUFBZ128rrk = 19456,
  VPSHUFBZ128rrkz = 19457,
  VPSHUFBZ256rm = 19458,
  VPSHUFBZ256rmk = 19459,
  VPSHUFBZ256rmkz = 19460,
  VPSHUFBZ256rr = 19461,
  VPSHUFBZ256rrk = 19462,
  VPSHUFBZ256rrkz = 19463,
  VPSHUFBZrm = 19464,
  VPSHUFBZrmk = 19465,
  VPSHUFBZrmkz = 19466,
  VPSHUFBZrr = 19467,
  VPSHUFBZrrk = 19468,
  VPSHUFBZrrkz = 19469,
  VPSHUFBrm = 19470,
  VPSHUFBrr = 19471,
  VPSHUFDYmi = 19472,
  VPSHUFDYri = 19473,
  VPSHUFDZ128mbi = 19474,
  VPSHUFDZ128mbik = 19475,
  VPSHUFDZ128mbikz = 19476,
  VPSHUFDZ128mi = 19477,
  VPSHUFDZ128mik = 19478,
  VPSHUFDZ128mikz = 19479,
  VPSHUFDZ128ri = 19480,
  VPSHUFDZ128rik = 19481,
  VPSHUFDZ128rikz = 19482,
  VPSHUFDZ256mbi = 19483,
  VPSHUFDZ256mbik = 19484,
  VPSHUFDZ256mbikz = 19485,
  VPSHUFDZ256mi = 19486,
  VPSHUFDZ256mik = 19487,
  VPSHUFDZ256mikz = 19488,
  VPSHUFDZ256ri = 19489,
  VPSHUFDZ256rik = 19490,
  VPSHUFDZ256rikz = 19491,
  VPSHUFDZmbi = 19492,
  VPSHUFDZmbik = 19493,
  VPSHUFDZmbikz = 19494,
  VPSHUFDZmi = 19495,
  VPSHUFDZmik = 19496,
  VPSHUFDZmikz = 19497,
  VPSHUFDZri = 19498,
  VPSHUFDZrik = 19499,
  VPSHUFDZrikz = 19500,
  VPSHUFDmi = 19501,
  VPSHUFDri = 19502,
  VPSHUFHWYmi = 19503,
  VPSHUFHWYri = 19504,
  VPSHUFHWZ128mi = 19505,
  VPSHUFHWZ128mik = 19506,
  VPSHUFHWZ128mikz = 19507,
  VPSHUFHWZ128ri = 19508,
  VPSHUFHWZ128rik = 19509,
  VPSHUFHWZ128rikz = 19510,
  VPSHUFHWZ256mi = 19511,
  VPSHUFHWZ256mik = 19512,
  VPSHUFHWZ256mikz = 19513,
  VPSHUFHWZ256ri = 19514,
  VPSHUFHWZ256rik = 19515,
  VPSHUFHWZ256rikz = 19516,
  VPSHUFHWZmi = 19517,
  VPSHUFHWZmik = 19518,
  VPSHUFHWZmikz = 19519,
  VPSHUFHWZri = 19520,
  VPSHUFHWZrik = 19521,
  VPSHUFHWZrikz = 19522,
  VPSHUFHWmi = 19523,
  VPSHUFHWri = 19524,
  VPSHUFLWYmi = 19525,
  VPSHUFLWYri = 19526,
  VPSHUFLWZ128mi = 19527,
  VPSHUFLWZ128mik = 19528,
  VPSHUFLWZ128mikz = 19529,
  VPSHUFLWZ128ri = 19530,
  VPSHUFLWZ128rik = 19531,
  VPSHUFLWZ128rikz = 19532,
  VPSHUFLWZ256mi = 19533,
  VPSHUFLWZ256mik = 19534,
  VPSHUFLWZ256mikz = 19535,
  VPSHUFLWZ256ri = 19536,
  VPSHUFLWZ256rik = 19537,
  VPSHUFLWZ256rikz = 19538,
  VPSHUFLWZmi = 19539,
  VPSHUFLWZmik = 19540,
  VPSHUFLWZmikz = 19541,
  VPSHUFLWZri = 19542,
  VPSHUFLWZrik = 19543,
  VPSHUFLWZrikz = 19544,
  VPSHUFLWmi = 19545,
  VPSHUFLWri = 19546,
  VPSIGNBYrm = 19547,
  VPSIGNBYrr = 19548,
  VPSIGNBrm = 19549,
  VPSIGNBrr = 19550,
  VPSIGNDYrm = 19551,
  VPSIGNDYrr = 19552,
  VPSIGNDrm = 19553,
  VPSIGNDrr = 19554,
  VPSIGNWYrm = 19555,
  VPSIGNWYrr = 19556,
  VPSIGNWrm = 19557,
  VPSIGNWrr = 19558,
  VPSLLDQYri = 19559,
  VPSLLDQZ128mi = 19560,
  VPSLLDQZ128ri = 19561,
  VPSLLDQZ256mi = 19562,
  VPSLLDQZ256ri = 19563,
  VPSLLDQZmi = 19564,
  VPSLLDQZri = 19565,
  VPSLLDQri = 19566,
  VPSLLDYri = 19567,
  VPSLLDYrm = 19568,
  VPSLLDYrr = 19569,
  VPSLLDZ128mbi = 19570,
  VPSLLDZ128mbik = 19571,
  VPSLLDZ128mbikz = 19572,
  VPSLLDZ128mi = 19573,
  VPSLLDZ128mik = 19574,
  VPSLLDZ128mikz = 19575,
  VPSLLDZ128ri = 19576,
  VPSLLDZ128rik = 19577,
  VPSLLDZ128rikz = 19578,
  VPSLLDZ128rm = 19579,
  VPSLLDZ128rmk = 19580,
  VPSLLDZ128rmkz = 19581,
  VPSLLDZ128rr = 19582,
  VPSLLDZ128rrk = 19583,
  VPSLLDZ128rrkz = 19584,
  VPSLLDZ256mbi = 19585,
  VPSLLDZ256mbik = 19586,
  VPSLLDZ256mbikz = 19587,
  VPSLLDZ256mi = 19588,
  VPSLLDZ256mik = 19589,
  VPSLLDZ256mikz = 19590,
  VPSLLDZ256ri = 19591,
  VPSLLDZ256rik = 19592,
  VPSLLDZ256rikz = 19593,
  VPSLLDZ256rm = 19594,
  VPSLLDZ256rmk = 19595,
  VPSLLDZ256rmkz = 19596,
  VPSLLDZ256rr = 19597,
  VPSLLDZ256rrk = 19598,
  VPSLLDZ256rrkz = 19599,
  VPSLLDZmbi = 19600,
  VPSLLDZmbik = 19601,
  VPSLLDZmbikz = 19602,
  VPSLLDZmi = 19603,
  VPSLLDZmik = 19604,
  VPSLLDZmikz = 19605,
  VPSLLDZri = 19606,
  VPSLLDZrik = 19607,
  VPSLLDZrikz = 19608,
  VPSLLDZrm = 19609,
  VPSLLDZrmk = 19610,
  VPSLLDZrmkz = 19611,
  VPSLLDZrr = 19612,
  VPSLLDZrrk = 19613,
  VPSLLDZrrkz = 19614,
  VPSLLDri = 19615,
  VPSLLDrm = 19616,
  VPSLLDrr = 19617,
  VPSLLQYri = 19618,
  VPSLLQYrm = 19619,
  VPSLLQYrr = 19620,
  VPSLLQZ128mbi = 19621,
  VPSLLQZ128mbik = 19622,
  VPSLLQZ128mbikz = 19623,
  VPSLLQZ128mi = 19624,
  VPSLLQZ128mik = 19625,
  VPSLLQZ128mikz = 19626,
  VPSLLQZ128ri = 19627,
  VPSLLQZ128rik = 19628,
  VPSLLQZ128rikz = 19629,
  VPSLLQZ128rm = 19630,
  VPSLLQZ128rmk = 19631,
  VPSLLQZ128rmkz = 19632,
  VPSLLQZ128rr = 19633,
  VPSLLQZ128rrk = 19634,
  VPSLLQZ128rrkz = 19635,
  VPSLLQZ256mbi = 19636,
  VPSLLQZ256mbik = 19637,
  VPSLLQZ256mbikz = 19638,
  VPSLLQZ256mi = 19639,
  VPSLLQZ256mik = 19640,
  VPSLLQZ256mikz = 19641,
  VPSLLQZ256ri = 19642,
  VPSLLQZ256rik = 19643,
  VPSLLQZ256rikz = 19644,
  VPSLLQZ256rm = 19645,
  VPSLLQZ256rmk = 19646,
  VPSLLQZ256rmkz = 19647,
  VPSLLQZ256rr = 19648,
  VPSLLQZ256rrk = 19649,
  VPSLLQZ256rrkz = 19650,
  VPSLLQZmbi = 19651,
  VPSLLQZmbik = 19652,
  VPSLLQZmbikz = 19653,
  VPSLLQZmi = 19654,
  VPSLLQZmik = 19655,
  VPSLLQZmikz = 19656,
  VPSLLQZri = 19657,
  VPSLLQZrik = 19658,
  VPSLLQZrikz = 19659,
  VPSLLQZrm = 19660,
  VPSLLQZrmk = 19661,
  VPSLLQZrmkz = 19662,
  VPSLLQZrr = 19663,
  VPSLLQZrrk = 19664,
  VPSLLQZrrkz = 19665,
  VPSLLQri = 19666,
  VPSLLQrm = 19667,
  VPSLLQrr = 19668,
  VPSLLVDYrm = 19669,
  VPSLLVDYrr = 19670,
  VPSLLVDZ128rm = 19671,
  VPSLLVDZ128rmb = 19672,
  VPSLLVDZ128rmbk = 19673,
  VPSLLVDZ128rmbkz = 19674,
  VPSLLVDZ128rmk = 19675,
  VPSLLVDZ128rmkz = 19676,
  VPSLLVDZ128rr = 19677,
  VPSLLVDZ128rrk = 19678,
  VPSLLVDZ128rrkz = 19679,
  VPSLLVDZ256rm = 19680,
  VPSLLVDZ256rmb = 19681,
  VPSLLVDZ256rmbk = 19682,
  VPSLLVDZ256rmbkz = 19683,
  VPSLLVDZ256rmk = 19684,
  VPSLLVDZ256rmkz = 19685,
  VPSLLVDZ256rr = 19686,
  VPSLLVDZ256rrk = 19687,
  VPSLLVDZ256rrkz = 19688,
  VPSLLVDZrm = 19689,
  VPSLLVDZrmb = 19690,
  VPSLLVDZrmbk = 19691,
  VPSLLVDZrmbkz = 19692,
  VPSLLVDZrmk = 19693,
  VPSLLVDZrmkz = 19694,
  VPSLLVDZrr = 19695,
  VPSLLVDZrrk = 19696,
  VPSLLVDZrrkz = 19697,
  VPSLLVDrm = 19698,
  VPSLLVDrr = 19699,
  VPSLLVQYrm = 19700,
  VPSLLVQYrr = 19701,
  VPSLLVQZ128rm = 19702,
  VPSLLVQZ128rmb = 19703,
  VPSLLVQZ128rmbk = 19704,
  VPSLLVQZ128rmbkz = 19705,
  VPSLLVQZ128rmk = 19706,
  VPSLLVQZ128rmkz = 19707,
  VPSLLVQZ128rr = 19708,
  VPSLLVQZ128rrk = 19709,
  VPSLLVQZ128rrkz = 19710,
  VPSLLVQZ256rm = 19711,
  VPSLLVQZ256rmb = 19712,
  VPSLLVQZ256rmbk = 19713,
  VPSLLVQZ256rmbkz = 19714,
  VPSLLVQZ256rmk = 19715,
  VPSLLVQZ256rmkz = 19716,
  VPSLLVQZ256rr = 19717,
  VPSLLVQZ256rrk = 19718,
  VPSLLVQZ256rrkz = 19719,
  VPSLLVQZrm = 19720,
  VPSLLVQZrmb = 19721,
  VPSLLVQZrmbk = 19722,
  VPSLLVQZrmbkz = 19723,
  VPSLLVQZrmk = 19724,
  VPSLLVQZrmkz = 19725,
  VPSLLVQZrr = 19726,
  VPSLLVQZrrk = 19727,
  VPSLLVQZrrkz = 19728,
  VPSLLVQrm = 19729,
  VPSLLVQrr = 19730,
  VPSLLVWZ128rm = 19731,
  VPSLLVWZ128rmk = 19732,
  VPSLLVWZ128rmkz = 19733,
  VPSLLVWZ128rr = 19734,
  VPSLLVWZ128rrk = 19735,
  VPSLLVWZ128rrkz = 19736,
  VPSLLVWZ256rm = 19737,
  VPSLLVWZ256rmk = 19738,
  VPSLLVWZ256rmkz = 19739,
  VPSLLVWZ256rr = 19740,
  VPSLLVWZ256rrk = 19741,
  VPSLLVWZ256rrkz = 19742,
  VPSLLVWZrm = 19743,
  VPSLLVWZrmk = 19744,
  VPSLLVWZrmkz = 19745,
  VPSLLVWZrr = 19746,
  VPSLLVWZrrk = 19747,
  VPSLLVWZrrkz = 19748,
  VPSLLWYri = 19749,
  VPSLLWYrm = 19750,
  VPSLLWYrr = 19751,
  VPSLLWZ128mi = 19752,
  VPSLLWZ128mik = 19753,
  VPSLLWZ128mikz = 19754,
  VPSLLWZ128ri = 19755,
  VPSLLWZ128rik = 19756,
  VPSLLWZ128rikz = 19757,
  VPSLLWZ128rm = 19758,
  VPSLLWZ128rmk = 19759,
  VPSLLWZ128rmkz = 19760,
  VPSLLWZ128rr = 19761,
  VPSLLWZ128rrk = 19762,
  VPSLLWZ128rrkz = 19763,
  VPSLLWZ256mi = 19764,
  VPSLLWZ256mik = 19765,
  VPSLLWZ256mikz = 19766,
  VPSLLWZ256ri = 19767,
  VPSLLWZ256rik = 19768,
  VPSLLWZ256rikz = 19769,
  VPSLLWZ256rm = 19770,
  VPSLLWZ256rmk = 19771,
  VPSLLWZ256rmkz = 19772,
  VPSLLWZ256rr = 19773,
  VPSLLWZ256rrk = 19774,
  VPSLLWZ256rrkz = 19775,
  VPSLLWZmi = 19776,
  VPSLLWZmik = 19777,
  VPSLLWZmikz = 19778,
  VPSLLWZri = 19779,
  VPSLLWZrik = 19780,
  VPSLLWZrikz = 19781,
  VPSLLWZrm = 19782,
  VPSLLWZrmk = 19783,
  VPSLLWZrmkz = 19784,
  VPSLLWZrr = 19785,
  VPSLLWZrrk = 19786,
  VPSLLWZrrkz = 19787,
  VPSLLWri = 19788,
  VPSLLWrm = 19789,
  VPSLLWrr = 19790,
  VPSRADYri = 19791,
  VPSRADYrm = 19792,
  VPSRADYrr = 19793,
  VPSRADZ128mbi = 19794,
  VPSRADZ128mbik = 19795,
  VPSRADZ128mbikz = 19796,
  VPSRADZ128mi = 19797,
  VPSRADZ128mik = 19798,
  VPSRADZ128mikz = 19799,
  VPSRADZ128ri = 19800,
  VPSRADZ128rik = 19801,
  VPSRADZ128rikz = 19802,
  VPSRADZ128rm = 19803,
  VPSRADZ128rmk = 19804,
  VPSRADZ128rmkz = 19805,
  VPSRADZ128rr = 19806,
  VPSRADZ128rrk = 19807,
  VPSRADZ128rrkz = 19808,
  VPSRADZ256mbi = 19809,
  VPSRADZ256mbik = 19810,
  VPSRADZ256mbikz = 19811,
  VPSRADZ256mi = 19812,
  VPSRADZ256mik = 19813,
  VPSRADZ256mikz = 19814,
  VPSRADZ256ri = 19815,
  VPSRADZ256rik = 19816,
  VPSRADZ256rikz = 19817,
  VPSRADZ256rm = 19818,
  VPSRADZ256rmk = 19819,
  VPSRADZ256rmkz = 19820,
  VPSRADZ256rr = 19821,
  VPSRADZ256rrk = 19822,
  VPSRADZ256rrkz = 19823,
  VPSRADZmbi = 19824,
  VPSRADZmbik = 19825,
  VPSRADZmbikz = 19826,
  VPSRADZmi = 19827,
  VPSRADZmik = 19828,
  VPSRADZmikz = 19829,
  VPSRADZri = 19830,
  VPSRADZrik = 19831,
  VPSRADZrikz = 19832,
  VPSRADZrm = 19833,
  VPSRADZrmk = 19834,
  VPSRADZrmkz = 19835,
  VPSRADZrr = 19836,
  VPSRADZrrk = 19837,
  VPSRADZrrkz = 19838,
  VPSRADri = 19839,
  VPSRADrm = 19840,
  VPSRADrr = 19841,
  VPSRAQZ128mbi = 19842,
  VPSRAQZ128mbik = 19843,
  VPSRAQZ128mbikz = 19844,
  VPSRAQZ128mi = 19845,
  VPSRAQZ128mik = 19846,
  VPSRAQZ128mikz = 19847,
  VPSRAQZ128ri = 19848,
  VPSRAQZ128rik = 19849,
  VPSRAQZ128rikz = 19850,
  VPSRAQZ128rm = 19851,
  VPSRAQZ128rmk = 19852,
  VPSRAQZ128rmkz = 19853,
  VPSRAQZ128rr = 19854,
  VPSRAQZ128rrk = 19855,
  VPSRAQZ128rrkz = 19856,
  VPSRAQZ256mbi = 19857,
  VPSRAQZ256mbik = 19858,
  VPSRAQZ256mbikz = 19859,
  VPSRAQZ256mi = 19860,
  VPSRAQZ256mik = 19861,
  VPSRAQZ256mikz = 19862,
  VPSRAQZ256ri = 19863,
  VPSRAQZ256rik = 19864,
  VPSRAQZ256rikz = 19865,
  VPSRAQZ256rm = 19866,
  VPSRAQZ256rmk = 19867,
  VPSRAQZ256rmkz = 19868,
  VPSRAQZ256rr = 19869,
  VPSRAQZ256rrk = 19870,
  VPSRAQZ256rrkz = 19871,
  VPSRAQZmbi = 19872,
  VPSRAQZmbik = 19873,
  VPSRAQZmbikz = 19874,
  VPSRAQZmi = 19875,
  VPSRAQZmik = 19876,
  VPSRAQZmikz = 19877,
  VPSRAQZri = 19878,
  VPSRAQZrik = 19879,
  VPSRAQZrikz = 19880,
  VPSRAQZrm = 19881,
  VPSRAQZrmk = 19882,
  VPSRAQZrmkz = 19883,
  VPSRAQZrr = 19884,
  VPSRAQZrrk = 19885,
  VPSRAQZrrkz = 19886,
  VPSRAVDYrm = 19887,
  VPSRAVDYrr = 19888,
  VPSRAVDZ128rm = 19889,
  VPSRAVDZ128rmb = 19890,
  VPSRAVDZ128rmbk = 19891,
  VPSRAVDZ128rmbkz = 19892,
  VPSRAVDZ128rmk = 19893,
  VPSRAVDZ128rmkz = 19894,
  VPSRAVDZ128rr = 19895,
  VPSRAVDZ128rrk = 19896,
  VPSRAVDZ128rrkz = 19897,
  VPSRAVDZ256rm = 19898,
  VPSRAVDZ256rmb = 19899,
  VPSRAVDZ256rmbk = 19900,
  VPSRAVDZ256rmbkz = 19901,
  VPSRAVDZ256rmk = 19902,
  VPSRAVDZ256rmkz = 19903,
  VPSRAVDZ256rr = 19904,
  VPSRAVDZ256rrk = 19905,
  VPSRAVDZ256rrkz = 19906,
  VPSRAVDZrm = 19907,
  VPSRAVDZrmb = 19908,
  VPSRAVDZrmbk = 19909,
  VPSRAVDZrmbkz = 19910,
  VPSRAVDZrmk = 19911,
  VPSRAVDZrmkz = 19912,
  VPSRAVDZrr = 19913,
  VPSRAVDZrrk = 19914,
  VPSRAVDZrrkz = 19915,
  VPSRAVDrm = 19916,
  VPSRAVDrr = 19917,
  VPSRAVQZ128rm = 19918,
  VPSRAVQZ128rmb = 19919,
  VPSRAVQZ128rmbk = 19920,
  VPSRAVQZ128rmbkz = 19921,
  VPSRAVQZ128rmk = 19922,
  VPSRAVQZ128rmkz = 19923,
  VPSRAVQZ128rr = 19924,
  VPSRAVQZ128rrk = 19925,
  VPSRAVQZ128rrkz = 19926,
  VPSRAVQZ256rm = 19927,
  VPSRAVQZ256rmb = 19928,
  VPSRAVQZ256rmbk = 19929,
  VPSRAVQZ256rmbkz = 19930,
  VPSRAVQZ256rmk = 19931,
  VPSRAVQZ256rmkz = 19932,
  VPSRAVQZ256rr = 19933,
  VPSRAVQZ256rrk = 19934,
  VPSRAVQZ256rrkz = 19935,
  VPSRAVQZrm = 19936,
  VPSRAVQZrmb = 19937,
  VPSRAVQZrmbk = 19938,
  VPSRAVQZrmbkz = 19939,
  VPSRAVQZrmk = 19940,
  VPSRAVQZrmkz = 19941,
  VPSRAVQZrr = 19942,
  VPSRAVQZrrk = 19943,
  VPSRAVQZrrkz = 19944,
  VPSRAVWZ128rm = 19945,
  VPSRAVWZ128rmk = 19946,
  VPSRAVWZ128rmkz = 19947,
  VPSRAVWZ128rr = 19948,
  VPSRAVWZ128rrk = 19949,
  VPSRAVWZ128rrkz = 19950,
  VPSRAVWZ256rm = 19951,
  VPSRAVWZ256rmk = 19952,
  VPSRAVWZ256rmkz = 19953,
  VPSRAVWZ256rr = 19954,
  VPSRAVWZ256rrk = 19955,
  VPSRAVWZ256rrkz = 19956,
  VPSRAVWZrm = 19957,
  VPSRAVWZrmk = 19958,
  VPSRAVWZrmkz = 19959,
  VPSRAVWZrr = 19960,
  VPSRAVWZrrk = 19961,
  VPSRAVWZrrkz = 19962,
  VPSRAWYri = 19963,
  VPSRAWYrm = 19964,
  VPSRAWYrr = 19965,
  VPSRAWZ128mi = 19966,
  VPSRAWZ128mik = 19967,
  VPSRAWZ128mikz = 19968,
  VPSRAWZ128ri = 19969,
  VPSRAWZ128rik = 19970,
  VPSRAWZ128rikz = 19971,
  VPSRAWZ128rm = 19972,
  VPSRAWZ128rmk = 19973,
  VPSRAWZ128rmkz = 19974,
  VPSRAWZ128rr = 19975,
  VPSRAWZ128rrk = 19976,
  VPSRAWZ128rrkz = 19977,
  VPSRAWZ256mi = 19978,
  VPSRAWZ256mik = 19979,
  VPSRAWZ256mikz = 19980,
  VPSRAWZ256ri = 19981,
  VPSRAWZ256rik = 19982,
  VPSRAWZ256rikz = 19983,
  VPSRAWZ256rm = 19984,
  VPSRAWZ256rmk = 19985,
  VPSRAWZ256rmkz = 19986,
  VPSRAWZ256rr = 19987,
  VPSRAWZ256rrk = 19988,
  VPSRAWZ256rrkz = 19989,
  VPSRAWZmi = 19990,
  VPSRAWZmik = 19991,
  VPSRAWZmikz = 19992,
  VPSRAWZri = 19993,
  VPSRAWZrik = 19994,
  VPSRAWZrikz = 19995,
  VPSRAWZrm = 19996,
  VPSRAWZrmk = 19997,
  VPSRAWZrmkz = 19998,
  VPSRAWZrr = 19999,
  VPSRAWZrrk = 20000,
  VPSRAWZrrkz = 20001,
  VPSRAWri = 20002,
  VPSRAWrm = 20003,
  VPSRAWrr = 20004,
  VPSRLDQYri = 20005,
  VPSRLDQZ128mi = 20006,
  VPSRLDQZ128ri = 20007,
  VPSRLDQZ256mi = 20008,
  VPSRLDQZ256ri = 20009,
  VPSRLDQZmi = 20010,
  VPSRLDQZri = 20011,
  VPSRLDQri = 20012,
  VPSRLDYri = 20013,
  VPSRLDYrm = 20014,
  VPSRLDYrr = 20015,
  VPSRLDZ128mbi = 20016,
  VPSRLDZ128mbik = 20017,
  VPSRLDZ128mbikz = 20018,
  VPSRLDZ128mi = 20019,
  VPSRLDZ128mik = 20020,
  VPSRLDZ128mikz = 20021,
  VPSRLDZ128ri = 20022,
  VPSRLDZ128rik = 20023,
  VPSRLDZ128rikz = 20024,
  VPSRLDZ128rm = 20025,
  VPSRLDZ128rmk = 20026,
  VPSRLDZ128rmkz = 20027,
  VPSRLDZ128rr = 20028,
  VPSRLDZ128rrk = 20029,
  VPSRLDZ128rrkz = 20030,
  VPSRLDZ256mbi = 20031,
  VPSRLDZ256mbik = 20032,
  VPSRLDZ256mbikz = 20033,
  VPSRLDZ256mi = 20034,
  VPSRLDZ256mik = 20035,
  VPSRLDZ256mikz = 20036,
  VPSRLDZ256ri = 20037,
  VPSRLDZ256rik = 20038,
  VPSRLDZ256rikz = 20039,
  VPSRLDZ256rm = 20040,
  VPSRLDZ256rmk = 20041,
  VPSRLDZ256rmkz = 20042,
  VPSRLDZ256rr = 20043,
  VPSRLDZ256rrk = 20044,
  VPSRLDZ256rrkz = 20045,
  VPSRLDZmbi = 20046,
  VPSRLDZmbik = 20047,
  VPSRLDZmbikz = 20048,
  VPSRLDZmi = 20049,
  VPSRLDZmik = 20050,
  VPSRLDZmikz = 20051,
  VPSRLDZri = 20052,
  VPSRLDZrik = 20053,
  VPSRLDZrikz = 20054,
  VPSRLDZrm = 20055,
  VPSRLDZrmk = 20056,
  VPSRLDZrmkz = 20057,
  VPSRLDZrr = 20058,
  VPSRLDZrrk = 20059,
  VPSRLDZrrkz = 20060,
  VPSRLDri = 20061,
  VPSRLDrm = 20062,
  VPSRLDrr = 20063,
  VPSRLQYri = 20064,
  VPSRLQYrm = 20065,
  VPSRLQYrr = 20066,
  VPSRLQZ128mbi = 20067,
  VPSRLQZ128mbik = 20068,
  VPSRLQZ128mbikz = 20069,
  VPSRLQZ128mi = 20070,
  VPSRLQZ128mik = 20071,
  VPSRLQZ128mikz = 20072,
  VPSRLQZ128ri = 20073,
  VPSRLQZ128rik = 20074,
  VPSRLQZ128rikz = 20075,
  VPSRLQZ128rm = 20076,
  VPSRLQZ128rmk = 20077,
  VPSRLQZ128rmkz = 20078,
  VPSRLQZ128rr = 20079,
  VPSRLQZ128rrk = 20080,
  VPSRLQZ128rrkz = 20081,
  VPSRLQZ256mbi = 20082,
  VPSRLQZ256mbik = 20083,
  VPSRLQZ256mbikz = 20084,
  VPSRLQZ256mi = 20085,
  VPSRLQZ256mik = 20086,
  VPSRLQZ256mikz = 20087,
  VPSRLQZ256ri = 20088,
  VPSRLQZ256rik = 20089,
  VPSRLQZ256rikz = 20090,
  VPSRLQZ256rm = 20091,
  VPSRLQZ256rmk = 20092,
  VPSRLQZ256rmkz = 20093,
  VPSRLQZ256rr = 20094,
  VPSRLQZ256rrk = 20095,
  VPSRLQZ256rrkz = 20096,
  VPSRLQZmbi = 20097,
  VPSRLQZmbik = 20098,
  VPSRLQZmbikz = 20099,
  VPSRLQZmi = 20100,
  VPSRLQZmik = 20101,
  VPSRLQZmikz = 20102,
  VPSRLQZri = 20103,
  VPSRLQZrik = 20104,
  VPSRLQZrikz = 20105,
  VPSRLQZrm = 20106,
  VPSRLQZrmk = 20107,
  VPSRLQZrmkz = 20108,
  VPSRLQZrr = 20109,
  VPSRLQZrrk = 20110,
  VPSRLQZrrkz = 20111,
  VPSRLQri = 20112,
  VPSRLQrm = 20113,
  VPSRLQrr = 20114,
  VPSRLVDYrm = 20115,
  VPSRLVDYrr = 20116,
  VPSRLVDZ128rm = 20117,
  VPSRLVDZ128rmb = 20118,
  VPSRLVDZ128rmbk = 20119,
  VPSRLVDZ128rmbkz = 20120,
  VPSRLVDZ128rmk = 20121,
  VPSRLVDZ128rmkz = 20122,
  VPSRLVDZ128rr = 20123,
  VPSRLVDZ128rrk = 20124,
  VPSRLVDZ128rrkz = 20125,
  VPSRLVDZ256rm = 20126,
  VPSRLVDZ256rmb = 20127,
  VPSRLVDZ256rmbk = 20128,
  VPSRLVDZ256rmbkz = 20129,
  VPSRLVDZ256rmk = 20130,
  VPSRLVDZ256rmkz = 20131,
  VPSRLVDZ256rr = 20132,
  VPSRLVDZ256rrk = 20133,
  VPSRLVDZ256rrkz = 20134,
  VPSRLVDZrm = 20135,
  VPSRLVDZrmb = 20136,
  VPSRLVDZrmbk = 20137,
  VPSRLVDZrmbkz = 20138,
  VPSRLVDZrmk = 20139,
  VPSRLVDZrmkz = 20140,
  VPSRLVDZrr = 20141,
  VPSRLVDZrrk = 20142,
  VPSRLVDZrrkz = 20143,
  VPSRLVDrm = 20144,
  VPSRLVDrr = 20145,
  VPSRLVQYrm = 20146,
  VPSRLVQYrr = 20147,
  VPSRLVQZ128rm = 20148,
  VPSRLVQZ128rmb = 20149,
  VPSRLVQZ128rmbk = 20150,
  VPSRLVQZ128rmbkz = 20151,
  VPSRLVQZ128rmk = 20152,
  VPSRLVQZ128rmkz = 20153,
  VPSRLVQZ128rr = 20154,
  VPSRLVQZ128rrk = 20155,
  VPSRLVQZ128rrkz = 20156,
  VPSRLVQZ256rm = 20157,
  VPSRLVQZ256rmb = 20158,
  VPSRLVQZ256rmbk = 20159,
  VPSRLVQZ256rmbkz = 20160,
  VPSRLVQZ256rmk = 20161,
  VPSRLVQZ256rmkz = 20162,
  VPSRLVQZ256rr = 20163,
  VPSRLVQZ256rrk = 20164,
  VPSRLVQZ256rrkz = 20165,
  VPSRLVQZrm = 20166,
  VPSRLVQZrmb = 20167,
  VPSRLVQZrmbk = 20168,
  VPSRLVQZrmbkz = 20169,
  VPSRLVQZrmk = 20170,
  VPSRLVQZrmkz = 20171,
  VPSRLVQZrr = 20172,
  VPSRLVQZrrk = 20173,
  VPSRLVQZrrkz = 20174,
  VPSRLVQrm = 20175,
  VPSRLVQrr = 20176,
  VPSRLVWZ128rm = 20177,
  VPSRLVWZ128rmk = 20178,
  VPSRLVWZ128rmkz = 20179,
  VPSRLVWZ128rr = 20180,
  VPSRLVWZ128rrk = 20181,
  VPSRLVWZ128rrkz = 20182,
  VPSRLVWZ256rm = 20183,
  VPSRLVWZ256rmk = 20184,
  VPSRLVWZ256rmkz = 20185,
  VPSRLVWZ256rr = 20186,
  VPSRLVWZ256rrk = 20187,
  VPSRLVWZ256rrkz = 20188,
  VPSRLVWZrm = 20189,
  VPSRLVWZrmk = 20190,
  VPSRLVWZrmkz = 20191,
  VPSRLVWZrr = 20192,
  VPSRLVWZrrk = 20193,
  VPSRLVWZrrkz = 20194,
  VPSRLWYri = 20195,
  VPSRLWYrm = 20196,
  VPSRLWYrr = 20197,
  VPSRLWZ128mi = 20198,
  VPSRLWZ128mik = 20199,
  VPSRLWZ128mikz = 20200,
  VPSRLWZ128ri = 20201,
  VPSRLWZ128rik = 20202,
  VPSRLWZ128rikz = 20203,
  VPSRLWZ128rm = 20204,
  VPSRLWZ128rmk = 20205,
  VPSRLWZ128rmkz = 20206,
  VPSRLWZ128rr = 20207,
  VPSRLWZ128rrk = 20208,
  VPSRLWZ128rrkz = 20209,
  VPSRLWZ256mi = 20210,
  VPSRLWZ256mik = 20211,
  VPSRLWZ256mikz = 20212,
  VPSRLWZ256ri = 20213,
  VPSRLWZ256rik = 20214,
  VPSRLWZ256rikz = 20215,
  VPSRLWZ256rm = 20216,
  VPSRLWZ256rmk = 20217,
  VPSRLWZ256rmkz = 20218,
  VPSRLWZ256rr = 20219,
  VPSRLWZ256rrk = 20220,
  VPSRLWZ256rrkz = 20221,
  VPSRLWZmi = 20222,
  VPSRLWZmik = 20223,
  VPSRLWZmikz = 20224,
  VPSRLWZri = 20225,
  VPSRLWZrik = 20226,
  VPSRLWZrikz = 20227,
  VPSRLWZrm = 20228,
  VPSRLWZrmk = 20229,
  VPSRLWZrmkz = 20230,
  VPSRLWZrr = 20231,
  VPSRLWZrrk = 20232,
  VPSRLWZrrkz = 20233,
  VPSRLWri = 20234,
  VPSRLWrm = 20235,
  VPSRLWrr = 20236,
  VPSUBBYrm = 20237,
  VPSUBBYrr = 20238,
  VPSUBBZ128rm = 20239,
  VPSUBBZ128rmk = 20240,
  VPSUBBZ128rmkz = 20241,
  VPSUBBZ128rr = 20242,
  VPSUBBZ128rrk = 20243,
  VPSUBBZ128rrkz = 20244,
  VPSUBBZ256rm = 20245,
  VPSUBBZ256rmk = 20246,
  VPSUBBZ256rmkz = 20247,
  VPSUBBZ256rr = 20248,
  VPSUBBZ256rrk = 20249,
  VPSUBBZ256rrkz = 20250,
  VPSUBBZrm = 20251,
  VPSUBBZrmk = 20252,
  VPSUBBZrmkz = 20253,
  VPSUBBZrr = 20254,
  VPSUBBZrrk = 20255,
  VPSUBBZrrkz = 20256,
  VPSUBBrm = 20257,
  VPSUBBrr = 20258,
  VPSUBDYrm = 20259,
  VPSUBDYrr = 20260,
  VPSUBDZ128rm = 20261,
  VPSUBDZ128rmb = 20262,
  VPSUBDZ128rmbk = 20263,
  VPSUBDZ128rmbkz = 20264,
  VPSUBDZ128rmk = 20265,
  VPSUBDZ128rmkz = 20266,
  VPSUBDZ128rr = 20267,
  VPSUBDZ128rrk = 20268,
  VPSUBDZ128rrkz = 20269,
  VPSUBDZ256rm = 20270,
  VPSUBDZ256rmb = 20271,
  VPSUBDZ256rmbk = 20272,
  VPSUBDZ256rmbkz = 20273,
  VPSUBDZ256rmk = 20274,
  VPSUBDZ256rmkz = 20275,
  VPSUBDZ256rr = 20276,
  VPSUBDZ256rrk = 20277,
  VPSUBDZ256rrkz = 20278,
  VPSUBDZrm = 20279,
  VPSUBDZrmb = 20280,
  VPSUBDZrmbk = 20281,
  VPSUBDZrmbkz = 20282,
  VPSUBDZrmk = 20283,
  VPSUBDZrmkz = 20284,
  VPSUBDZrr = 20285,
  VPSUBDZrrk = 20286,
  VPSUBDZrrkz = 20287,
  VPSUBDrm = 20288,
  VPSUBDrr = 20289,
  VPSUBQYrm = 20290,
  VPSUBQYrr = 20291,
  VPSUBQZ128rm = 20292,
  VPSUBQZ128rmb = 20293,
  VPSUBQZ128rmbk = 20294,
  VPSUBQZ128rmbkz = 20295,
  VPSUBQZ128rmk = 20296,
  VPSUBQZ128rmkz = 20297,
  VPSUBQZ128rr = 20298,
  VPSUBQZ128rrk = 20299,
  VPSUBQZ128rrkz = 20300,
  VPSUBQZ256rm = 20301,
  VPSUBQZ256rmb = 20302,
  VPSUBQZ256rmbk = 20303,
  VPSUBQZ256rmbkz = 20304,
  VPSUBQZ256rmk = 20305,
  VPSUBQZ256rmkz = 20306,
  VPSUBQZ256rr = 20307,
  VPSUBQZ256rrk = 20308,
  VPSUBQZ256rrkz = 20309,
  VPSUBQZrm = 20310,
  VPSUBQZrmb = 20311,
  VPSUBQZrmbk = 20312,
  VPSUBQZrmbkz = 20313,
  VPSUBQZrmk = 20314,
  VPSUBQZrmkz = 20315,
  VPSUBQZrr = 20316,
  VPSUBQZrrk = 20317,
  VPSUBQZrrkz = 20318,
  VPSUBQrm = 20319,
  VPSUBQrr = 20320,
  VPSUBSBYrm = 20321,
  VPSUBSBYrr = 20322,
  VPSUBSBZ128rm = 20323,
  VPSUBSBZ128rmk = 20324,
  VPSUBSBZ128rmkz = 20325,
  VPSUBSBZ128rr = 20326,
  VPSUBSBZ128rrk = 20327,
  VPSUBSBZ128rrkz = 20328,
  VPSUBSBZ256rm = 20329,
  VPSUBSBZ256rmk = 20330,
  VPSUBSBZ256rmkz = 20331,
  VPSUBSBZ256rr = 20332,
  VPSUBSBZ256rrk = 20333,
  VPSUBSBZ256rrkz = 20334,
  VPSUBSBZrm = 20335,
  VPSUBSBZrmk = 20336,
  VPSUBSBZrmkz = 20337,
  VPSUBSBZrr = 20338,
  VPSUBSBZrrk = 20339,
  VPSUBSBZrrkz = 20340,
  VPSUBSBrm = 20341,
  VPSUBSBrr = 20342,
  VPSUBSWYrm = 20343,
  VPSUBSWYrr = 20344,
  VPSUBSWZ128rm = 20345,
  VPSUBSWZ128rmk = 20346,
  VPSUBSWZ128rmkz = 20347,
  VPSUBSWZ128rr = 20348,
  VPSUBSWZ128rrk = 20349,
  VPSUBSWZ128rrkz = 20350,
  VPSUBSWZ256rm = 20351,
  VPSUBSWZ256rmk = 20352,
  VPSUBSWZ256rmkz = 20353,
  VPSUBSWZ256rr = 20354,
  VPSUBSWZ256rrk = 20355,
  VPSUBSWZ256rrkz = 20356,
  VPSUBSWZrm = 20357,
  VPSUBSWZrmk = 20358,
  VPSUBSWZrmkz = 20359,
  VPSUBSWZrr = 20360,
  VPSUBSWZrrk = 20361,
  VPSUBSWZrrkz = 20362,
  VPSUBSWrm = 20363,
  VPSUBSWrr = 20364,
  VPSUBUSBYrm = 20365,
  VPSUBUSBYrr = 20366,
  VPSUBUSBZ128rm = 20367,
  VPSUBUSBZ128rmk = 20368,
  VPSUBUSBZ128rmkz = 20369,
  VPSUBUSBZ128rr = 20370,
  VPSUBUSBZ128rrk = 20371,
  VPSUBUSBZ128rrkz = 20372,
  VPSUBUSBZ256rm = 20373,
  VPSUBUSBZ256rmk = 20374,
  VPSUBUSBZ256rmkz = 20375,
  VPSUBUSBZ256rr = 20376,
  VPSUBUSBZ256rrk = 20377,
  VPSUBUSBZ256rrkz = 20378,
  VPSUBUSBZrm = 20379,
  VPSUBUSBZrmk = 20380,
  VPSUBUSBZrmkz = 20381,
  VPSUBUSBZrr = 20382,
  VPSUBUSBZrrk = 20383,
  VPSUBUSBZrrkz = 20384,
  VPSUBUSBrm = 20385,
  VPSUBUSBrr = 20386,
  VPSUBUSWYrm = 20387,
  VPSUBUSWYrr = 20388,
  VPSUBUSWZ128rm = 20389,
  VPSUBUSWZ128rmk = 20390,
  VPSUBUSWZ128rmkz = 20391,
  VPSUBUSWZ128rr = 20392,
  VPSUBUSWZ128rrk = 20393,
  VPSUBUSWZ128rrkz = 20394,
  VPSUBUSWZ256rm = 20395,
  VPSUBUSWZ256rmk = 20396,
  VPSUBUSWZ256rmkz = 20397,
  VPSUBUSWZ256rr = 20398,
  VPSUBUSWZ256rrk = 20399,
  VPSUBUSWZ256rrkz = 20400,
  VPSUBUSWZrm = 20401,
  VPSUBUSWZrmk = 20402,
  VPSUBUSWZrmkz = 20403,
  VPSUBUSWZrr = 20404,
  VPSUBUSWZrrk = 20405,
  VPSUBUSWZrrkz = 20406,
  VPSUBUSWrm = 20407,
  VPSUBUSWrr = 20408,
  VPSUBWYrm = 20409,
  VPSUBWYrr = 20410,
  VPSUBWZ128rm = 20411,
  VPSUBWZ128rmk = 20412,
  VPSUBWZ128rmkz = 20413,
  VPSUBWZ128rr = 20414,
  VPSUBWZ128rrk = 20415,
  VPSUBWZ128rrkz = 20416,
  VPSUBWZ256rm = 20417,
  VPSUBWZ256rmk = 20418,
  VPSUBWZ256rmkz = 20419,
  VPSUBWZ256rr = 20420,
  VPSUBWZ256rrk = 20421,
  VPSUBWZ256rrkz = 20422,
  VPSUBWZrm = 20423,
  VPSUBWZrmk = 20424,
  VPSUBWZrmkz = 20425,
  VPSUBWZrr = 20426,
  VPSUBWZrrk = 20427,
  VPSUBWZrrkz = 20428,
  VPSUBWrm = 20429,
  VPSUBWrr = 20430,
  VPTERNLOGDZ128rmbi = 20431,
  VPTERNLOGDZ128rmbik = 20432,
  VPTERNLOGDZ128rmbikz = 20433,
  VPTERNLOGDZ128rmi = 20434,
  VPTERNLOGDZ128rmik = 20435,
  VPTERNLOGDZ128rmikz = 20436,
  VPTERNLOGDZ128rri = 20437,
  VPTERNLOGDZ128rrik = 20438,
  VPTERNLOGDZ128rrikz = 20439,
  VPTERNLOGDZ256rmbi = 20440,
  VPTERNLOGDZ256rmbik = 20441,
  VPTERNLOGDZ256rmbikz = 20442,
  VPTERNLOGDZ256rmi = 20443,
  VPTERNLOGDZ256rmik = 20444,
  VPTERNLOGDZ256rmikz = 20445,
  VPTERNLOGDZ256rri = 20446,
  VPTERNLOGDZ256rrik = 20447,
  VPTERNLOGDZ256rrikz = 20448,
  VPTERNLOGDZrmbi = 20449,
  VPTERNLOGDZrmbik = 20450,
  VPTERNLOGDZrmbikz = 20451,
  VPTERNLOGDZrmi = 20452,
  VPTERNLOGDZrmik = 20453,
  VPTERNLOGDZrmikz = 20454,
  VPTERNLOGDZrri = 20455,
  VPTERNLOGDZrrik = 20456,
  VPTERNLOGDZrrikz = 20457,
  VPTERNLOGQZ128rmbi = 20458,
  VPTERNLOGQZ128rmbik = 20459,
  VPTERNLOGQZ128rmbikz = 20460,
  VPTERNLOGQZ128rmi = 20461,
  VPTERNLOGQZ128rmik = 20462,
  VPTERNLOGQZ128rmikz = 20463,
  VPTERNLOGQZ128rri = 20464,
  VPTERNLOGQZ128rrik = 20465,
  VPTERNLOGQZ128rrikz = 20466,
  VPTERNLOGQZ256rmbi = 20467,
  VPTERNLOGQZ256rmbik = 20468,
  VPTERNLOGQZ256rmbikz = 20469,
  VPTERNLOGQZ256rmi = 20470,
  VPTERNLOGQZ256rmik = 20471,
  VPTERNLOGQZ256rmikz = 20472,
  VPTERNLOGQZ256rri = 20473,
  VPTERNLOGQZ256rrik = 20474,
  VPTERNLOGQZ256rrikz = 20475,
  VPTERNLOGQZrmbi = 20476,
  VPTERNLOGQZrmbik = 20477,
  VPTERNLOGQZrmbikz = 20478,
  VPTERNLOGQZrmi = 20479,
  VPTERNLOGQZrmik = 20480,
  VPTERNLOGQZrmikz = 20481,
  VPTERNLOGQZrri = 20482,
  VPTERNLOGQZrrik = 20483,
  VPTERNLOGQZrrikz = 20484,
  VPTESTMBZ128rm = 20485,
  VPTESTMBZ128rmk = 20486,
  VPTESTMBZ128rr = 20487,
  VPTESTMBZ128rrk = 20488,
  VPTESTMBZ256rm = 20489,
  VPTESTMBZ256rmk = 20490,
  VPTESTMBZ256rr = 20491,
  VPTESTMBZ256rrk = 20492,
  VPTESTMBZrm = 20493,
  VPTESTMBZrmk = 20494,
  VPTESTMBZrr = 20495,
  VPTESTMBZrrk = 20496,
  VPTESTMDZ128rm = 20497,
  VPTESTMDZ128rmb = 20498,
  VPTESTMDZ128rmbk = 20499,
  VPTESTMDZ128rmk = 20500,
  VPTESTMDZ128rr = 20501,
  VPTESTMDZ128rrk = 20502,
  VPTESTMDZ256rm = 20503,
  VPTESTMDZ256rmb = 20504,
  VPTESTMDZ256rmbk = 20505,
  VPTESTMDZ256rmk = 20506,
  VPTESTMDZ256rr = 20507,
  VPTESTMDZ256rrk = 20508,
  VPTESTMDZrm = 20509,
  VPTESTMDZrmb = 20510,
  VPTESTMDZrmbk = 20511,
  VPTESTMDZrmk = 20512,
  VPTESTMDZrr = 20513,
  VPTESTMDZrrk = 20514,
  VPTESTMQZ128rm = 20515,
  VPTESTMQZ128rmb = 20516,
  VPTESTMQZ128rmbk = 20517,
  VPTESTMQZ128rmk = 20518,
  VPTESTMQZ128rr = 20519,
  VPTESTMQZ128rrk = 20520,
  VPTESTMQZ256rm = 20521,
  VPTESTMQZ256rmb = 20522,
  VPTESTMQZ256rmbk = 20523,
  VPTESTMQZ256rmk = 20524,
  VPTESTMQZ256rr = 20525,
  VPTESTMQZ256rrk = 20526,
  VPTESTMQZrm = 20527,
  VPTESTMQZrmb = 20528,
  VPTESTMQZrmbk = 20529,
  VPTESTMQZrmk = 20530,
  VPTESTMQZrr = 20531,
  VPTESTMQZrrk = 20532,
  VPTESTMWZ128rm = 20533,
  VPTESTMWZ128rmk = 20534,
  VPTESTMWZ128rr = 20535,
  VPTESTMWZ128rrk = 20536,
  VPTESTMWZ256rm = 20537,
  VPTESTMWZ256rmk = 20538,
  VPTESTMWZ256rr = 20539,
  VPTESTMWZ256rrk = 20540,
  VPTESTMWZrm = 20541,
  VPTESTMWZrmk = 20542,
  VPTESTMWZrr = 20543,
  VPTESTMWZrrk = 20544,
  VPTESTNMBZ128rm = 20545,
  VPTESTNMBZ128rmk = 20546,
  VPTESTNMBZ128rr = 20547,
  VPTESTNMBZ128rrk = 20548,
  VPTESTNMBZ256rm = 20549,
  VPTESTNMBZ256rmk = 20550,
  VPTESTNMBZ256rr = 20551,
  VPTESTNMBZ256rrk = 20552,
  VPTESTNMBZrm = 20553,
  VPTESTNMBZrmk = 20554,
  VPTESTNMBZrr = 20555,
  VPTESTNMBZrrk = 20556,
  VPTESTNMDZ128rm = 20557,
  VPTESTNMDZ128rmb = 20558,
  VPTESTNMDZ128rmbk = 20559,
  VPTESTNMDZ128rmk = 20560,
  VPTESTNMDZ128rr = 20561,
  VPTESTNMDZ128rrk = 20562,
  VPTESTNMDZ256rm = 20563,
  VPTESTNMDZ256rmb = 20564,
  VPTESTNMDZ256rmbk = 20565,
  VPTESTNMDZ256rmk = 20566,
  VPTESTNMDZ256rr = 20567,
  VPTESTNMDZ256rrk = 20568,
  VPTESTNMDZrm = 20569,
  VPTESTNMDZrmb = 20570,
  VPTESTNMDZrmbk = 20571,
  VPTESTNMDZrmk = 20572,
  VPTESTNMDZrr = 20573,
  VPTESTNMDZrrk = 20574,
  VPTESTNMQZ128rm = 20575,
  VPTESTNMQZ128rmb = 20576,
  VPTESTNMQZ128rmbk = 20577,
  VPTESTNMQZ128rmk = 20578,
  VPTESTNMQZ128rr = 20579,
  VPTESTNMQZ128rrk = 20580,
  VPTESTNMQZ256rm = 20581,
  VPTESTNMQZ256rmb = 20582,
  VPTESTNMQZ256rmbk = 20583,
  VPTESTNMQZ256rmk = 20584,
  VPTESTNMQZ256rr = 20585,
  VPTESTNMQZ256rrk = 20586,
  VPTESTNMQZrm = 20587,
  VPTESTNMQZrmb = 20588,
  VPTESTNMQZrmbk = 20589,
  VPTESTNMQZrmk = 20590,
  VPTESTNMQZrr = 20591,
  VPTESTNMQZrrk = 20592,
  VPTESTNMWZ128rm = 20593,
  VPTESTNMWZ128rmk = 20594,
  VPTESTNMWZ128rr = 20595,
  VPTESTNMWZ128rrk = 20596,
  VPTESTNMWZ256rm = 20597,
  VPTESTNMWZ256rmk = 20598,
  VPTESTNMWZ256rr = 20599,
  VPTESTNMWZ256rrk = 20600,
  VPTESTNMWZrm = 20601,
  VPTESTNMWZrmk = 20602,
  VPTESTNMWZrr = 20603,
  VPTESTNMWZrrk = 20604,
  VPTESTYrm = 20605,
  VPTESTYrr = 20606,
  VPTESTrm = 20607,
  VPTESTrr = 20608,
  VPUNPCKHBWYrm = 20609,
  VPUNPCKHBWYrr = 20610,
  VPUNPCKHBWZ128rm = 20611,
  VPUNPCKHBWZ128rmk = 20612,
  VPUNPCKHBWZ128rmkz = 20613,
  VPUNPCKHBWZ128rr = 20614,
  VPUNPCKHBWZ128rrk = 20615,
  VPUNPCKHBWZ128rrkz = 20616,
  VPUNPCKHBWZ256rm = 20617,
  VPUNPCKHBWZ256rmk = 20618,
  VPUNPCKHBWZ256rmkz = 20619,
  VPUNPCKHBWZ256rr = 20620,
  VPUNPCKHBWZ256rrk = 20621,
  VPUNPCKHBWZ256rrkz = 20622,
  VPUNPCKHBWZrm = 20623,
  VPUNPCKHBWZrmk = 20624,
  VPUNPCKHBWZrmkz = 20625,
  VPUNPCKHBWZrr = 20626,
  VPUNPCKHBWZrrk = 20627,
  VPUNPCKHBWZrrkz = 20628,
  VPUNPCKHBWrm = 20629,
  VPUNPCKHBWrr = 20630,
  VPUNPCKHDQYrm = 20631,
  VPUNPCKHDQYrr = 20632,
  VPUNPCKHDQZ128rm = 20633,
  VPUNPCKHDQZ128rmb = 20634,
  VPUNPCKHDQZ128rmbk = 20635,
  VPUNPCKHDQZ128rmbkz = 20636,
  VPUNPCKHDQZ128rmk = 20637,
  VPUNPCKHDQZ128rmkz = 20638,
  VPUNPCKHDQZ128rr = 20639,
  VPUNPCKHDQZ128rrk = 20640,
  VPUNPCKHDQZ128rrkz = 20641,
  VPUNPCKHDQZ256rm = 20642,
  VPUNPCKHDQZ256rmb = 20643,
  VPUNPCKHDQZ256rmbk = 20644,
  VPUNPCKHDQZ256rmbkz = 20645,
  VPUNPCKHDQZ256rmk = 20646,
  VPUNPCKHDQZ256rmkz = 20647,
  VPUNPCKHDQZ256rr = 20648,
  VPUNPCKHDQZ256rrk = 20649,
  VPUNPCKHDQZ256rrkz = 20650,
  VPUNPCKHDQZrm = 20651,
  VPUNPCKHDQZrmb = 20652,
  VPUNPCKHDQZrmbk = 20653,
  VPUNPCKHDQZrmbkz = 20654,
  VPUNPCKHDQZrmk = 20655,
  VPUNPCKHDQZrmkz = 20656,
  VPUNPCKHDQZrr = 20657,
  VPUNPCKHDQZrrk = 20658,
  VPUNPCKHDQZrrkz = 20659,
  VPUNPCKHDQrm = 20660,
  VPUNPCKHDQrr = 20661,
  VPUNPCKHQDQYrm = 20662,
  VPUNPCKHQDQYrr = 20663,
  VPUNPCKHQDQZ128rm = 20664,
  VPUNPCKHQDQZ128rmb = 20665,
  VPUNPCKHQDQZ128rmbk = 20666,
  VPUNPCKHQDQZ128rmbkz = 20667,
  VPUNPCKHQDQZ128rmk = 20668,
  VPUNPCKHQDQZ128rmkz = 20669,
  VPUNPCKHQDQZ128rr = 20670,
  VPUNPCKHQDQZ128rrk = 20671,
  VPUNPCKHQDQZ128rrkz = 20672,
  VPUNPCKHQDQZ256rm = 20673,
  VPUNPCKHQDQZ256rmb = 20674,
  VPUNPCKHQDQZ256rmbk = 20675,
  VPUNPCKHQDQZ256rmbkz = 20676,
  VPUNPCKHQDQZ256rmk = 20677,
  VPUNPCKHQDQZ256rmkz = 20678,
  VPUNPCKHQDQZ256rr = 20679,
  VPUNPCKHQDQZ256rrk = 20680,
  VPUNPCKHQDQZ256rrkz = 20681,
  VPUNPCKHQDQZrm = 20682,
  VPUNPCKHQDQZrmb = 20683,
  VPUNPCKHQDQZrmbk = 20684,
  VPUNPCKHQDQZrmbkz = 20685,
  VPUNPCKHQDQZrmk = 20686,
  VPUNPCKHQDQZrmkz = 20687,
  VPUNPCKHQDQZrr = 20688,
  VPUNPCKHQDQZrrk = 20689,
  VPUNPCKHQDQZrrkz = 20690,
  VPUNPCKHQDQrm = 20691,
  VPUNPCKHQDQrr = 20692,
  VPUNPCKHWDYrm = 20693,
  VPUNPCKHWDYrr = 20694,
  VPUNPCKHWDZ128rm = 20695,
  VPUNPCKHWDZ128rmk = 20696,
  VPUNPCKHWDZ128rmkz = 20697,
  VPUNPCKHWDZ128rr = 20698,
  VPUNPCKHWDZ128rrk = 20699,
  VPUNPCKHWDZ128rrkz = 20700,
  VPUNPCKHWDZ256rm = 20701,
  VPUNPCKHWDZ256rmk = 20702,
  VPUNPCKHWDZ256rmkz = 20703,
  VPUNPCKHWDZ256rr = 20704,
  VPUNPCKHWDZ256rrk = 20705,
  VPUNPCKHWDZ256rrkz = 20706,
  VPUNPCKHWDZrm = 20707,
  VPUNPCKHWDZrmk = 20708,
  VPUNPCKHWDZrmkz = 20709,
  VPUNPCKHWDZrr = 20710,
  VPUNPCKHWDZrrk = 20711,
  VPUNPCKHWDZrrkz = 20712,
  VPUNPCKHWDrm = 20713,
  VPUNPCKHWDrr = 20714,
  VPUNPCKLBWYrm = 20715,
  VPUNPCKLBWYrr = 20716,
  VPUNPCKLBWZ128rm = 20717,
  VPUNPCKLBWZ128rmk = 20718,
  VPUNPCKLBWZ128rmkz = 20719,
  VPUNPCKLBWZ128rr = 20720,
  VPUNPCKLBWZ128rrk = 20721,
  VPUNPCKLBWZ128rrkz = 20722,
  VPUNPCKLBWZ256rm = 20723,
  VPUNPCKLBWZ256rmk = 20724,
  VPUNPCKLBWZ256rmkz = 20725,
  VPUNPCKLBWZ256rr = 20726,
  VPUNPCKLBWZ256rrk = 20727,
  VPUNPCKLBWZ256rrkz = 20728,
  VPUNPCKLBWZrm = 20729,
  VPUNPCKLBWZrmk = 20730,
  VPUNPCKLBWZrmkz = 20731,
  VPUNPCKLBWZrr = 20732,
  VPUNPCKLBWZrrk = 20733,
  VPUNPCKLBWZrrkz = 20734,
  VPUNPCKLBWrm = 20735,
  VPUNPCKLBWrr = 20736,
  VPUNPCKLDQYrm = 20737,
  VPUNPCKLDQYrr = 20738,
  VPUNPCKLDQZ128rm = 20739,
  VPUNPCKLDQZ128rmb = 20740,
  VPUNPCKLDQZ128rmbk = 20741,
  VPUNPCKLDQZ128rmbkz = 20742,
  VPUNPCKLDQZ128rmk = 20743,
  VPUNPCKLDQZ128rmkz = 20744,
  VPUNPCKLDQZ128rr = 20745,
  VPUNPCKLDQZ128rrk = 20746,
  VPUNPCKLDQZ128rrkz = 20747,
  VPUNPCKLDQZ256rm = 20748,
  VPUNPCKLDQZ256rmb = 20749,
  VPUNPCKLDQZ256rmbk = 20750,
  VPUNPCKLDQZ256rmbkz = 20751,
  VPUNPCKLDQZ256rmk = 20752,
  VPUNPCKLDQZ256rmkz = 20753,
  VPUNPCKLDQZ256rr = 20754,
  VPUNPCKLDQZ256rrk = 20755,
  VPUNPCKLDQZ256rrkz = 20756,
  VPUNPCKLDQZrm = 20757,
  VPUNPCKLDQZrmb = 20758,
  VPUNPCKLDQZrmbk = 20759,
  VPUNPCKLDQZrmbkz = 20760,
  VPUNPCKLDQZrmk = 20761,
  VPUNPCKLDQZrmkz = 20762,
  VPUNPCKLDQZrr = 20763,
  VPUNPCKLDQZrrk = 20764,
  VPUNPCKLDQZrrkz = 20765,
  VPUNPCKLDQrm = 20766,
  VPUNPCKLDQrr = 20767,
  VPUNPCKLQDQYrm = 20768,
  VPUNPCKLQDQYrr = 20769,
  VPUNPCKLQDQZ128rm = 20770,
  VPUNPCKLQDQZ128rmb = 20771,
  VPUNPCKLQDQZ128rmbk = 20772,
  VPUNPCKLQDQZ128rmbkz = 20773,
  VPUNPCKLQDQZ128rmk = 20774,
  VPUNPCKLQDQZ128rmkz = 20775,
  VPUNPCKLQDQZ128rr = 20776,
  VPUNPCKLQDQZ128rrk = 20777,
  VPUNPCKLQDQZ128rrkz = 20778,
  VPUNPCKLQDQZ256rm = 20779,
  VPUNPCKLQDQZ256rmb = 20780,
  VPUNPCKLQDQZ256rmbk = 20781,
  VPUNPCKLQDQZ256rmbkz = 20782,
  VPUNPCKLQDQZ256rmk = 20783,
  VPUNPCKLQDQZ256rmkz = 20784,
  VPUNPCKLQDQZ256rr = 20785,
  VPUNPCKLQDQZ256rrk = 20786,
  VPUNPCKLQDQZ256rrkz = 20787,
  VPUNPCKLQDQZrm = 20788,
  VPUNPCKLQDQZrmb = 20789,
  VPUNPCKLQDQZrmbk = 20790,
  VPUNPCKLQDQZrmbkz = 20791,
  VPUNPCKLQDQZrmk = 20792,
  VPUNPCKLQDQZrmkz = 20793,
  VPUNPCKLQDQZrr = 20794,
  VPUNPCKLQDQZrrk = 20795,
  VPUNPCKLQDQZrrkz = 20796,
  VPUNPCKLQDQrm = 20797,
  VPUNPCKLQDQrr = 20798,
  VPUNPCKLWDYrm = 20799,
  VPUNPCKLWDYrr = 20800,
  VPUNPCKLWDZ128rm = 20801,
  VPUNPCKLWDZ128rmk = 20802,
  VPUNPCKLWDZ128rmkz = 20803,
  VPUNPCKLWDZ128rr = 20804,
  VPUNPCKLWDZ128rrk = 20805,
  VPUNPCKLWDZ128rrkz = 20806,
  VPUNPCKLWDZ256rm = 20807,
  VPUNPCKLWDZ256rmk = 20808,
  VPUNPCKLWDZ256rmkz = 20809,
  VPUNPCKLWDZ256rr = 20810,
  VPUNPCKLWDZ256rrk = 20811,
  VPUNPCKLWDZ256rrkz = 20812,
  VPUNPCKLWDZrm = 20813,
  VPUNPCKLWDZrmk = 20814,
  VPUNPCKLWDZrmkz = 20815,
  VPUNPCKLWDZrr = 20816,
  VPUNPCKLWDZrrk = 20817,
  VPUNPCKLWDZrrkz = 20818,
  VPUNPCKLWDrm = 20819,
  VPUNPCKLWDrr = 20820,
  VPXORDZ128rm = 20821,
  VPXORDZ128rmb = 20822,
  VPXORDZ128rmbk = 20823,
  VPXORDZ128rmbkz = 20824,
  VPXORDZ128rmk = 20825,
  VPXORDZ128rmkz = 20826,
  VPXORDZ128rr = 20827,
  VPXORDZ128rrk = 20828,
  VPXORDZ128rrkz = 20829,
  VPXORDZ256rm = 20830,
  VPXORDZ256rmb = 20831,
  VPXORDZ256rmbk = 20832,
  VPXORDZ256rmbkz = 20833,
  VPXORDZ256rmk = 20834,
  VPXORDZ256rmkz = 20835,
  VPXORDZ256rr = 20836,
  VPXORDZ256rrk = 20837,
  VPXORDZ256rrkz = 20838,
  VPXORDZrm = 20839,
  VPXORDZrmb = 20840,
  VPXORDZrmbk = 20841,
  VPXORDZrmbkz = 20842,
  VPXORDZrmk = 20843,
  VPXORDZrmkz = 20844,
  VPXORDZrr = 20845,
  VPXORDZrrk = 20846,
  VPXORDZrrkz = 20847,
  VPXORQZ128rm = 20848,
  VPXORQZ128rmb = 20849,
  VPXORQZ128rmbk = 20850,
  VPXORQZ128rmbkz = 20851,
  VPXORQZ128rmk = 20852,
  VPXORQZ128rmkz = 20853,
  VPXORQZ128rr = 20854,
  VPXORQZ128rrk = 20855,
  VPXORQZ128rrkz = 20856,
  VPXORQZ256rm = 20857,
  VPXORQZ256rmb = 20858,
  VPXORQZ256rmbk = 20859,
  VPXORQZ256rmbkz = 20860,
  VPXORQZ256rmk = 20861,
  VPXORQZ256rmkz = 20862,
  VPXORQZ256rr = 20863,
  VPXORQZ256rrk = 20864,
  VPXORQZ256rrkz = 20865,
  VPXORQZrm = 20866,
  VPXORQZrmb = 20867,
  VPXORQZrmbk = 20868,
  VPXORQZrmbkz = 20869,
  VPXORQZrmk = 20870,
  VPXORQZrmkz = 20871,
  VPXORQZrr = 20872,
  VPXORQZrrk = 20873,
  VPXORQZrrkz = 20874,
  VPXORYrm = 20875,
  VPXORYrr = 20876,
  VPXORrm = 20877,
  VPXORrr = 20878,
  VRANGEPDZ128rmbi = 20879,
  VRANGEPDZ128rmbik = 20880,
  VRANGEPDZ128rmbikz = 20881,
  VRANGEPDZ128rmi = 20882,
  VRANGEPDZ128rmik = 20883,
  VRANGEPDZ128rmikz = 20884,
  VRANGEPDZ128rri = 20885,
  VRANGEPDZ128rrik = 20886,
  VRANGEPDZ128rrikz = 20887,
  VRANGEPDZ256rmbi = 20888,
  VRANGEPDZ256rmbik = 20889,
  VRANGEPDZ256rmbikz = 20890,
  VRANGEPDZ256rmi = 20891,
  VRANGEPDZ256rmik = 20892,
  VRANGEPDZ256rmikz = 20893,
  VRANGEPDZ256rri = 20894,
  VRANGEPDZ256rrib = 20895,
  VRANGEPDZ256rribk = 20896,
  VRANGEPDZ256rribkz = 20897,
  VRANGEPDZ256rrik = 20898,
  VRANGEPDZ256rrikz = 20899,
  VRANGEPDZrmbi = 20900,
  VRANGEPDZrmbik = 20901,
  VRANGEPDZrmbikz = 20902,
  VRANGEPDZrmi = 20903,
  VRANGEPDZrmik = 20904,
  VRANGEPDZrmikz = 20905,
  VRANGEPDZrri = 20906,
  VRANGEPDZrrib = 20907,
  VRANGEPDZrribk = 20908,
  VRANGEPDZrribkz = 20909,
  VRANGEPDZrrik = 20910,
  VRANGEPDZrrikz = 20911,
  VRANGEPSZ128rmbi = 20912,
  VRANGEPSZ128rmbik = 20913,
  VRANGEPSZ128rmbikz = 20914,
  VRANGEPSZ128rmi = 20915,
  VRANGEPSZ128rmik = 20916,
  VRANGEPSZ128rmikz = 20917,
  VRANGEPSZ128rri = 20918,
  VRANGEPSZ128rrik = 20919,
  VRANGEPSZ128rrikz = 20920,
  VRANGEPSZ256rmbi = 20921,
  VRANGEPSZ256rmbik = 20922,
  VRANGEPSZ256rmbikz = 20923,
  VRANGEPSZ256rmi = 20924,
  VRANGEPSZ256rmik = 20925,
  VRANGEPSZ256rmikz = 20926,
  VRANGEPSZ256rri = 20927,
  VRANGEPSZ256rrib = 20928,
  VRANGEPSZ256rribk = 20929,
  VRANGEPSZ256rribkz = 20930,
  VRANGEPSZ256rrik = 20931,
  VRANGEPSZ256rrikz = 20932,
  VRANGEPSZrmbi = 20933,
  VRANGEPSZrmbik = 20934,
  VRANGEPSZrmbikz = 20935,
  VRANGEPSZrmi = 20936,
  VRANGEPSZrmik = 20937,
  VRANGEPSZrmikz = 20938,
  VRANGEPSZrri = 20939,
  VRANGEPSZrrib = 20940,
  VRANGEPSZrribk = 20941,
  VRANGEPSZrribkz = 20942,
  VRANGEPSZrrik = 20943,
  VRANGEPSZrrikz = 20944,
  VRANGESDZrmi = 20945,
  VRANGESDZrmik = 20946,
  VRANGESDZrmikz = 20947,
  VRANGESDZrri = 20948,
  VRANGESDZrrib = 20949,
  VRANGESDZrribk = 20950,
  VRANGESDZrribkz = 20951,
  VRANGESDZrrik = 20952,
  VRANGESDZrrikz = 20953,
  VRANGESSZrmi = 20954,
  VRANGESSZrmik = 20955,
  VRANGESSZrmikz = 20956,
  VRANGESSZrri = 20957,
  VRANGESSZrrib = 20958,
  VRANGESSZrribk = 20959,
  VRANGESSZrribkz = 20960,
  VRANGESSZrrik = 20961,
  VRANGESSZrrikz = 20962,
  VRCP14PDZ128m = 20963,
  VRCP14PDZ128mb = 20964,
  VRCP14PDZ128mbk = 20965,
  VRCP14PDZ128mbkz = 20966,
  VRCP14PDZ128mk = 20967,
  VRCP14PDZ128mkz = 20968,
  VRCP14PDZ128r = 20969,
  VRCP14PDZ128rk = 20970,
  VRCP14PDZ128rkz = 20971,
  VRCP14PDZ256m = 20972,
  VRCP14PDZ256mb = 20973,
  VRCP14PDZ256mbk = 20974,
  VRCP14PDZ256mbkz = 20975,
  VRCP14PDZ256mk = 20976,
  VRCP14PDZ256mkz = 20977,
  VRCP14PDZ256r = 20978,
  VRCP14PDZ256rk = 20979,
  VRCP14PDZ256rkz = 20980,
  VRCP14PDZm = 20981,
  VRCP14PDZmb = 20982,
  VRCP14PDZmbk = 20983,
  VRCP14PDZmbkz = 20984,
  VRCP14PDZmk = 20985,
  VRCP14PDZmkz = 20986,
  VRCP14PDZr = 20987,
  VRCP14PDZrk = 20988,
  VRCP14PDZrkz = 20989,
  VRCP14PSZ128m = 20990,
  VRCP14PSZ128mb = 20991,
  VRCP14PSZ128mbk = 20992,
  VRCP14PSZ128mbkz = 20993,
  VRCP14PSZ128mk = 20994,
  VRCP14PSZ128mkz = 20995,
  VRCP14PSZ128r = 20996,
  VRCP14PSZ128rk = 20997,
  VRCP14PSZ128rkz = 20998,
  VRCP14PSZ256m = 20999,
  VRCP14PSZ256mb = 21000,
  VRCP14PSZ256mbk = 21001,
  VRCP14PSZ256mbkz = 21002,
  VRCP14PSZ256mk = 21003,
  VRCP14PSZ256mkz = 21004,
  VRCP14PSZ256r = 21005,
  VRCP14PSZ256rk = 21006,
  VRCP14PSZ256rkz = 21007,
  VRCP14PSZm = 21008,
  VRCP14PSZmb = 21009,
  VRCP14PSZmbk = 21010,
  VRCP14PSZmbkz = 21011,
  VRCP14PSZmk = 21012,
  VRCP14PSZmkz = 21013,
  VRCP14PSZr = 21014,
  VRCP14PSZrk = 21015,
  VRCP14PSZrkz = 21016,
  VRCP14SDZrm = 21017,
  VRCP14SDZrmk = 21018,
  VRCP14SDZrmkz = 21019,
  VRCP14SDZrr = 21020,
  VRCP14SDZrrk = 21021,
  VRCP14SDZrrkz = 21022,
  VRCP14SSZrm = 21023,
  VRCP14SSZrmk = 21024,
  VRCP14SSZrmkz = 21025,
  VRCP14SSZrr = 21026,
  VRCP14SSZrrk = 21027,
  VRCP14SSZrrkz = 21028,
  VRCP28PDZm = 21029,
  VRCP28PDZmb = 21030,
  VRCP28PDZmbk = 21031,
  VRCP28PDZmbkz = 21032,
  VRCP28PDZmk = 21033,
  VRCP28PDZmkz = 21034,
  VRCP28PDZr = 21035,
  VRCP28PDZrb = 21036,
  VRCP28PDZrbk = 21037,
  VRCP28PDZrbkz = 21038,
  VRCP28PDZrk = 21039,
  VRCP28PDZrkz = 21040,
  VRCP28PSZm = 21041,
  VRCP28PSZmb = 21042,
  VRCP28PSZmbk = 21043,
  VRCP28PSZmbkz = 21044,
  VRCP28PSZmk = 21045,
  VRCP28PSZmkz = 21046,
  VRCP28PSZr = 21047,
  VRCP28PSZrb = 21048,
  VRCP28PSZrbk = 21049,
  VRCP28PSZrbkz = 21050,
  VRCP28PSZrk = 21051,
  VRCP28PSZrkz = 21052,
  VRCP28SDZm = 21053,
  VRCP28SDZmk = 21054,
  VRCP28SDZmkz = 21055,
  VRCP28SDZr = 21056,
  VRCP28SDZrb = 21057,
  VRCP28SDZrbk = 21058,
  VRCP28SDZrbkz = 21059,
  VRCP28SDZrk = 21060,
  VRCP28SDZrkz = 21061,
  VRCP28SSZm = 21062,
  VRCP28SSZmk = 21063,
  VRCP28SSZmkz = 21064,
  VRCP28SSZr = 21065,
  VRCP28SSZrb = 21066,
  VRCP28SSZrbk = 21067,
  VRCP28SSZrbkz = 21068,
  VRCP28SSZrk = 21069,
  VRCP28SSZrkz = 21070,
  VRCPBF16Z128m = 21071,
  VRCPBF16Z128mb = 21072,
  VRCPBF16Z128mbk = 21073,
  VRCPBF16Z128mbkz = 21074,
  VRCPBF16Z128mk = 21075,
  VRCPBF16Z128mkz = 21076,
  VRCPBF16Z128r = 21077,
  VRCPBF16Z128rk = 21078,
  VRCPBF16Z128rkz = 21079,
  VRCPBF16Z256m = 21080,
  VRCPBF16Z256mb = 21081,
  VRCPBF16Z256mbk = 21082,
  VRCPBF16Z256mbkz = 21083,
  VRCPBF16Z256mk = 21084,
  VRCPBF16Z256mkz = 21085,
  VRCPBF16Z256r = 21086,
  VRCPBF16Z256rk = 21087,
  VRCPBF16Z256rkz = 21088,
  VRCPBF16Zm = 21089,
  VRCPBF16Zmb = 21090,
  VRCPBF16Zmbk = 21091,
  VRCPBF16Zmbkz = 21092,
  VRCPBF16Zmk = 21093,
  VRCPBF16Zmkz = 21094,
  VRCPBF16Zr = 21095,
  VRCPBF16Zrk = 21096,
  VRCPBF16Zrkz = 21097,
  VRCPPHZ128m = 21098,
  VRCPPHZ128mb = 21099,
  VRCPPHZ128mbk = 21100,
  VRCPPHZ128mbkz = 21101,
  VRCPPHZ128mk = 21102,
  VRCPPHZ128mkz = 21103,
  VRCPPHZ128r = 21104,
  VRCPPHZ128rk = 21105,
  VRCPPHZ128rkz = 21106,
  VRCPPHZ256m = 21107,
  VRCPPHZ256mb = 21108,
  VRCPPHZ256mbk = 21109,
  VRCPPHZ256mbkz = 21110,
  VRCPPHZ256mk = 21111,
  VRCPPHZ256mkz = 21112,
  VRCPPHZ256r = 21113,
  VRCPPHZ256rk = 21114,
  VRCPPHZ256rkz = 21115,
  VRCPPHZm = 21116,
  VRCPPHZmb = 21117,
  VRCPPHZmbk = 21118,
  VRCPPHZmbkz = 21119,
  VRCPPHZmk = 21120,
  VRCPPHZmkz = 21121,
  VRCPPHZr = 21122,
  VRCPPHZrk = 21123,
  VRCPPHZrkz = 21124,
  VRCPPSYm = 21125,
  VRCPPSYr = 21126,
  VRCPPSm = 21127,
  VRCPPSr = 21128,
  VRCPSHZrm = 21129,
  VRCPSHZrmk = 21130,
  VRCPSHZrmkz = 21131,
  VRCPSHZrr = 21132,
  VRCPSHZrrk = 21133,
  VRCPSHZrrkz = 21134,
  VRCPSSm = 21135,
  VRCPSSm_Int = 21136,
  VRCPSSr = 21137,
  VRCPSSr_Int = 21138,
  VREDUCEBF16Z128rmbi = 21139,
  VREDUCEBF16Z128rmbik = 21140,
  VREDUCEBF16Z128rmbikz = 21141,
  VREDUCEBF16Z128rmi = 21142,
  VREDUCEBF16Z128rmik = 21143,
  VREDUCEBF16Z128rmikz = 21144,
  VREDUCEBF16Z128rri = 21145,
  VREDUCEBF16Z128rrik = 21146,
  VREDUCEBF16Z128rrikz = 21147,
  VREDUCEBF16Z256rmbi = 21148,
  VREDUCEBF16Z256rmbik = 21149,
  VREDUCEBF16Z256rmbikz = 21150,
  VREDUCEBF16Z256rmi = 21151,
  VREDUCEBF16Z256rmik = 21152,
  VREDUCEBF16Z256rmikz = 21153,
  VREDUCEBF16Z256rri = 21154,
  VREDUCEBF16Z256rrik = 21155,
  VREDUCEBF16Z256rrikz = 21156,
  VREDUCEBF16Zrmbi = 21157,
  VREDUCEBF16Zrmbik = 21158,
  VREDUCEBF16Zrmbikz = 21159,
  VREDUCEBF16Zrmi = 21160,
  VREDUCEBF16Zrmik = 21161,
  VREDUCEBF16Zrmikz = 21162,
  VREDUCEBF16Zrri = 21163,
  VREDUCEBF16Zrrik = 21164,
  VREDUCEBF16Zrrikz = 21165,
  VREDUCEPDZ128rmbi = 21166,
  VREDUCEPDZ128rmbik = 21167,
  VREDUCEPDZ128rmbikz = 21168,
  VREDUCEPDZ128rmi = 21169,
  VREDUCEPDZ128rmik = 21170,
  VREDUCEPDZ128rmikz = 21171,
  VREDUCEPDZ128rri = 21172,
  VREDUCEPDZ128rrik = 21173,
  VREDUCEPDZ128rrikz = 21174,
  VREDUCEPDZ256rmbi = 21175,
  VREDUCEPDZ256rmbik = 21176,
  VREDUCEPDZ256rmbikz = 21177,
  VREDUCEPDZ256rmi = 21178,
  VREDUCEPDZ256rmik = 21179,
  VREDUCEPDZ256rmikz = 21180,
  VREDUCEPDZ256rri = 21181,
  VREDUCEPDZ256rrib = 21182,
  VREDUCEPDZ256rribk = 21183,
  VREDUCEPDZ256rribkz = 21184,
  VREDUCEPDZ256rrik = 21185,
  VREDUCEPDZ256rrikz = 21186,
  VREDUCEPDZrmbi = 21187,
  VREDUCEPDZrmbik = 21188,
  VREDUCEPDZrmbikz = 21189,
  VREDUCEPDZrmi = 21190,
  VREDUCEPDZrmik = 21191,
  VREDUCEPDZrmikz = 21192,
  VREDUCEPDZrri = 21193,
  VREDUCEPDZrrib = 21194,
  VREDUCEPDZrribk = 21195,
  VREDUCEPDZrribkz = 21196,
  VREDUCEPDZrrik = 21197,
  VREDUCEPDZrrikz = 21198,
  VREDUCEPHZ128rmbi = 21199,
  VREDUCEPHZ128rmbik = 21200,
  VREDUCEPHZ128rmbikz = 21201,
  VREDUCEPHZ128rmi = 21202,
  VREDUCEPHZ128rmik = 21203,
  VREDUCEPHZ128rmikz = 21204,
  VREDUCEPHZ128rri = 21205,
  VREDUCEPHZ128rrik = 21206,
  VREDUCEPHZ128rrikz = 21207,
  VREDUCEPHZ256rmbi = 21208,
  VREDUCEPHZ256rmbik = 21209,
  VREDUCEPHZ256rmbikz = 21210,
  VREDUCEPHZ256rmi = 21211,
  VREDUCEPHZ256rmik = 21212,
  VREDUCEPHZ256rmikz = 21213,
  VREDUCEPHZ256rri = 21214,
  VREDUCEPHZ256rrib = 21215,
  VREDUCEPHZ256rribk = 21216,
  VREDUCEPHZ256rribkz = 21217,
  VREDUCEPHZ256rrik = 21218,
  VREDUCEPHZ256rrikz = 21219,
  VREDUCEPHZrmbi = 21220,
  VREDUCEPHZrmbik = 21221,
  VREDUCEPHZrmbikz = 21222,
  VREDUCEPHZrmi = 21223,
  VREDUCEPHZrmik = 21224,
  VREDUCEPHZrmikz = 21225,
  VREDUCEPHZrri = 21226,
  VREDUCEPHZrrib = 21227,
  VREDUCEPHZrribk = 21228,
  VREDUCEPHZrribkz = 21229,
  VREDUCEPHZrrik = 21230,
  VREDUCEPHZrrikz = 21231,
  VREDUCEPSZ128rmbi = 21232,
  VREDUCEPSZ128rmbik = 21233,
  VREDUCEPSZ128rmbikz = 21234,
  VREDUCEPSZ128rmi = 21235,
  VREDUCEPSZ128rmik = 21236,
  VREDUCEPSZ128rmikz = 21237,
  VREDUCEPSZ128rri = 21238,
  VREDUCEPSZ128rrik = 21239,
  VREDUCEPSZ128rrikz = 21240,
  VREDUCEPSZ256rmbi = 21241,
  VREDUCEPSZ256rmbik = 21242,
  VREDUCEPSZ256rmbikz = 21243,
  VREDUCEPSZ256rmi = 21244,
  VREDUCEPSZ256rmik = 21245,
  VREDUCEPSZ256rmikz = 21246,
  VREDUCEPSZ256rri = 21247,
  VREDUCEPSZ256rrib = 21248,
  VREDUCEPSZ256rribk = 21249,
  VREDUCEPSZ256rribkz = 21250,
  VREDUCEPSZ256rrik = 21251,
  VREDUCEPSZ256rrikz = 21252,
  VREDUCEPSZrmbi = 21253,
  VREDUCEPSZrmbik = 21254,
  VREDUCEPSZrmbikz = 21255,
  VREDUCEPSZrmi = 21256,
  VREDUCEPSZrmik = 21257,
  VREDUCEPSZrmikz = 21258,
  VREDUCEPSZrri = 21259,
  VREDUCEPSZrrib = 21260,
  VREDUCEPSZrribk = 21261,
  VREDUCEPSZrribkz = 21262,
  VREDUCEPSZrrik = 21263,
  VREDUCEPSZrrikz = 21264,
  VREDUCESDZrmi = 21265,
  VREDUCESDZrmik = 21266,
  VREDUCESDZrmikz = 21267,
  VREDUCESDZrri = 21268,
  VREDUCESDZrrib = 21269,
  VREDUCESDZrribk = 21270,
  VREDUCESDZrribkz = 21271,
  VREDUCESDZrrik = 21272,
  VREDUCESDZrrikz = 21273,
  VREDUCESHZrmi = 21274,
  VREDUCESHZrmik = 21275,
  VREDUCESHZrmikz = 21276,
  VREDUCESHZrri = 21277,
  VREDUCESHZrrib = 21278,
  VREDUCESHZrribk = 21279,
  VREDUCESHZrribkz = 21280,
  VREDUCESHZrrik = 21281,
  VREDUCESHZrrikz = 21282,
  VREDUCESSZrmi = 21283,
  VREDUCESSZrmik = 21284,
  VREDUCESSZrmikz = 21285,
  VREDUCESSZrri = 21286,
  VREDUCESSZrrib = 21287,
  VREDUCESSZrribk = 21288,
  VREDUCESSZrribkz = 21289,
  VREDUCESSZrrik = 21290,
  VREDUCESSZrrikz = 21291,
  VRNDSCALEBF16Z128rmbi = 21292,
  VRNDSCALEBF16Z128rmbik = 21293,
  VRNDSCALEBF16Z128rmbikz = 21294,
  VRNDSCALEBF16Z128rmi = 21295,
  VRNDSCALEBF16Z128rmik = 21296,
  VRNDSCALEBF16Z128rmikz = 21297,
  VRNDSCALEBF16Z128rri = 21298,
  VRNDSCALEBF16Z128rrik = 21299,
  VRNDSCALEBF16Z128rrikz = 21300,
  VRNDSCALEBF16Z256rmbi = 21301,
  VRNDSCALEBF16Z256rmbik = 21302,
  VRNDSCALEBF16Z256rmbikz = 21303,
  VRNDSCALEBF16Z256rmi = 21304,
  VRNDSCALEBF16Z256rmik = 21305,
  VRNDSCALEBF16Z256rmikz = 21306,
  VRNDSCALEBF16Z256rri = 21307,
  VRNDSCALEBF16Z256rrik = 21308,
  VRNDSCALEBF16Z256rrikz = 21309,
  VRNDSCALEBF16Zrmbi = 21310,
  VRNDSCALEBF16Zrmbik = 21311,
  VRNDSCALEBF16Zrmbikz = 21312,
  VRNDSCALEBF16Zrmi = 21313,
  VRNDSCALEBF16Zrmik = 21314,
  VRNDSCALEBF16Zrmikz = 21315,
  VRNDSCALEBF16Zrri = 21316,
  VRNDSCALEBF16Zrrik = 21317,
  VRNDSCALEBF16Zrrikz = 21318,
  VRNDSCALEPDZ128rmbi = 21319,
  VRNDSCALEPDZ128rmbik = 21320,
  VRNDSCALEPDZ128rmbikz = 21321,
  VRNDSCALEPDZ128rmi = 21322,
  VRNDSCALEPDZ128rmik = 21323,
  VRNDSCALEPDZ128rmikz = 21324,
  VRNDSCALEPDZ128rri = 21325,
  VRNDSCALEPDZ128rrik = 21326,
  VRNDSCALEPDZ128rrikz = 21327,
  VRNDSCALEPDZ256rmbi = 21328,
  VRNDSCALEPDZ256rmbik = 21329,
  VRNDSCALEPDZ256rmbikz = 21330,
  VRNDSCALEPDZ256rmi = 21331,
  VRNDSCALEPDZ256rmik = 21332,
  VRNDSCALEPDZ256rmikz = 21333,
  VRNDSCALEPDZ256rri = 21334,
  VRNDSCALEPDZ256rrib = 21335,
  VRNDSCALEPDZ256rribk = 21336,
  VRNDSCALEPDZ256rribkz = 21337,
  VRNDSCALEPDZ256rrik = 21338,
  VRNDSCALEPDZ256rrikz = 21339,
  VRNDSCALEPDZrmbi = 21340,
  VRNDSCALEPDZrmbik = 21341,
  VRNDSCALEPDZrmbikz = 21342,
  VRNDSCALEPDZrmi = 21343,
  VRNDSCALEPDZrmik = 21344,
  VRNDSCALEPDZrmikz = 21345,
  VRNDSCALEPDZrri = 21346,
  VRNDSCALEPDZrrib = 21347,
  VRNDSCALEPDZrribk = 21348,
  VRNDSCALEPDZrribkz = 21349,
  VRNDSCALEPDZrrik = 21350,
  VRNDSCALEPDZrrikz = 21351,
  VRNDSCALEPHZ128rmbi = 21352,
  VRNDSCALEPHZ128rmbik = 21353,
  VRNDSCALEPHZ128rmbikz = 21354,
  VRNDSCALEPHZ128rmi = 21355,
  VRNDSCALEPHZ128rmik = 21356,
  VRNDSCALEPHZ128rmikz = 21357,
  VRNDSCALEPHZ128rri = 21358,
  VRNDSCALEPHZ128rrik = 21359,
  VRNDSCALEPHZ128rrikz = 21360,
  VRNDSCALEPHZ256rmbi = 21361,
  VRNDSCALEPHZ256rmbik = 21362,
  VRNDSCALEPHZ256rmbikz = 21363,
  VRNDSCALEPHZ256rmi = 21364,
  VRNDSCALEPHZ256rmik = 21365,
  VRNDSCALEPHZ256rmikz = 21366,
  VRNDSCALEPHZ256rri = 21367,
  VRNDSCALEPHZ256rrib = 21368,
  VRNDSCALEPHZ256rribk = 21369,
  VRNDSCALEPHZ256rribkz = 21370,
  VRNDSCALEPHZ256rrik = 21371,
  VRNDSCALEPHZ256rrikz = 21372,
  VRNDSCALEPHZrmbi = 21373,
  VRNDSCALEPHZrmbik = 21374,
  VRNDSCALEPHZrmbikz = 21375,
  VRNDSCALEPHZrmi = 21376,
  VRNDSCALEPHZrmik = 21377,
  VRNDSCALEPHZrmikz = 21378,
  VRNDSCALEPHZrri = 21379,
  VRNDSCALEPHZrrib = 21380,
  VRNDSCALEPHZrribk = 21381,
  VRNDSCALEPHZrribkz = 21382,
  VRNDSCALEPHZrrik = 21383,
  VRNDSCALEPHZrrikz = 21384,
  VRNDSCALEPSZ128rmbi = 21385,
  VRNDSCALEPSZ128rmbik = 21386,
  VRNDSCALEPSZ128rmbikz = 21387,
  VRNDSCALEPSZ128rmi = 21388,
  VRNDSCALEPSZ128rmik = 21389,
  VRNDSCALEPSZ128rmikz = 21390,
  VRNDSCALEPSZ128rri = 21391,
  VRNDSCALEPSZ128rrik = 21392,
  VRNDSCALEPSZ128rrikz = 21393,
  VRNDSCALEPSZ256rmbi = 21394,
  VRNDSCALEPSZ256rmbik = 21395,
  VRNDSCALEPSZ256rmbikz = 21396,
  VRNDSCALEPSZ256rmi = 21397,
  VRNDSCALEPSZ256rmik = 21398,
  VRNDSCALEPSZ256rmikz = 21399,
  VRNDSCALEPSZ256rri = 21400,
  VRNDSCALEPSZ256rrib = 21401,
  VRNDSCALEPSZ256rribk = 21402,
  VRNDSCALEPSZ256rribkz = 21403,
  VRNDSCALEPSZ256rrik = 21404,
  VRNDSCALEPSZ256rrikz = 21405,
  VRNDSCALEPSZrmbi = 21406,
  VRNDSCALEPSZrmbik = 21407,
  VRNDSCALEPSZrmbikz = 21408,
  VRNDSCALEPSZrmi = 21409,
  VRNDSCALEPSZrmik = 21410,
  VRNDSCALEPSZrmikz = 21411,
  VRNDSCALEPSZrri = 21412,
  VRNDSCALEPSZrrib = 21413,
  VRNDSCALEPSZrribk = 21414,
  VRNDSCALEPSZrribkz = 21415,
  VRNDSCALEPSZrrik = 21416,
  VRNDSCALEPSZrrikz = 21417,
  VRNDSCALESDZrmi = 21418,
  VRNDSCALESDZrmi_Int = 21419,
  VRNDSCALESDZrmik_Int = 21420,
  VRNDSCALESDZrmikz_Int = 21421,
  VRNDSCALESDZrri = 21422,
  VRNDSCALESDZrri_Int = 21423,
  VRNDSCALESDZrrib_Int = 21424,
  VRNDSCALESDZrribk_Int = 21425,
  VRNDSCALESDZrribkz_Int = 21426,
  VRNDSCALESDZrrik_Int = 21427,
  VRNDSCALESDZrrikz_Int = 21428,
  VRNDSCALESHZrmi = 21429,
  VRNDSCALESHZrmi_Int = 21430,
  VRNDSCALESHZrmik_Int = 21431,
  VRNDSCALESHZrmikz_Int = 21432,
  VRNDSCALESHZrri = 21433,
  VRNDSCALESHZrri_Int = 21434,
  VRNDSCALESHZrrib_Int = 21435,
  VRNDSCALESHZrribk_Int = 21436,
  VRNDSCALESHZrribkz_Int = 21437,
  VRNDSCALESHZrrik_Int = 21438,
  VRNDSCALESHZrrikz_Int = 21439,
  VRNDSCALESSZrmi = 21440,
  VRNDSCALESSZrmi_Int = 21441,
  VRNDSCALESSZrmik_Int = 21442,
  VRNDSCALESSZrmikz_Int = 21443,
  VRNDSCALESSZrri = 21444,
  VRNDSCALESSZrri_Int = 21445,
  VRNDSCALESSZrrib_Int = 21446,
  VRNDSCALESSZrribk_Int = 21447,
  VRNDSCALESSZrribkz_Int = 21448,
  VRNDSCALESSZrrik_Int = 21449,
  VRNDSCALESSZrrikz_Int = 21450,
  VROUNDPDYmi = 21451,
  VROUNDPDYri = 21452,
  VROUNDPDmi = 21453,
  VROUNDPDri = 21454,
  VROUNDPSYmi = 21455,
  VROUNDPSYri = 21456,
  VROUNDPSmi = 21457,
  VROUNDPSri = 21458,
  VROUNDSDmi = 21459,
  VROUNDSDmi_Int = 21460,
  VROUNDSDri = 21461,
  VROUNDSDri_Int = 21462,
  VROUNDSSmi = 21463,
  VROUNDSSmi_Int = 21464,
  VROUNDSSri = 21465,
  VROUNDSSri_Int = 21466,
  VRSQRT14PDZ128m = 21467,
  VRSQRT14PDZ128mb = 21468,
  VRSQRT14PDZ128mbk = 21469,
  VRSQRT14PDZ128mbkz = 21470,
  VRSQRT14PDZ128mk = 21471,
  VRSQRT14PDZ128mkz = 21472,
  VRSQRT14PDZ128r = 21473,
  VRSQRT14PDZ128rk = 21474,
  VRSQRT14PDZ128rkz = 21475,
  VRSQRT14PDZ256m = 21476,
  VRSQRT14PDZ256mb = 21477,
  VRSQRT14PDZ256mbk = 21478,
  VRSQRT14PDZ256mbkz = 21479,
  VRSQRT14PDZ256mk = 21480,
  VRSQRT14PDZ256mkz = 21481,
  VRSQRT14PDZ256r = 21482,
  VRSQRT14PDZ256rk = 21483,
  VRSQRT14PDZ256rkz = 21484,
  VRSQRT14PDZm = 21485,
  VRSQRT14PDZmb = 21486,
  VRSQRT14PDZmbk = 21487,
  VRSQRT14PDZmbkz = 21488,
  VRSQRT14PDZmk = 21489,
  VRSQRT14PDZmkz = 21490,
  VRSQRT14PDZr = 21491,
  VRSQRT14PDZrk = 21492,
  VRSQRT14PDZrkz = 21493,
  VRSQRT14PSZ128m = 21494,
  VRSQRT14PSZ128mb = 21495,
  VRSQRT14PSZ128mbk = 21496,
  VRSQRT14PSZ128mbkz = 21497,
  VRSQRT14PSZ128mk = 21498,
  VRSQRT14PSZ128mkz = 21499,
  VRSQRT14PSZ128r = 21500,
  VRSQRT14PSZ128rk = 21501,
  VRSQRT14PSZ128rkz = 21502,
  VRSQRT14PSZ256m = 21503,
  VRSQRT14PSZ256mb = 21504,
  VRSQRT14PSZ256mbk = 21505,
  VRSQRT14PSZ256mbkz = 21506,
  VRSQRT14PSZ256mk = 21507,
  VRSQRT14PSZ256mkz = 21508,
  VRSQRT14PSZ256r = 21509,
  VRSQRT14PSZ256rk = 21510,
  VRSQRT14PSZ256rkz = 21511,
  VRSQRT14PSZm = 21512,
  VRSQRT14PSZmb = 21513,
  VRSQRT14PSZmbk = 21514,
  VRSQRT14PSZmbkz = 21515,
  VRSQRT14PSZmk = 21516,
  VRSQRT14PSZmkz = 21517,
  VRSQRT14PSZr = 21518,
  VRSQRT14PSZrk = 21519,
  VRSQRT14PSZrkz = 21520,
  VRSQRT14SDZrm = 21521,
  VRSQRT14SDZrmk = 21522,
  VRSQRT14SDZrmkz = 21523,
  VRSQRT14SDZrr = 21524,
  VRSQRT14SDZrrk = 21525,
  VRSQRT14SDZrrkz = 21526,
  VRSQRT14SSZrm = 21527,
  VRSQRT14SSZrmk = 21528,
  VRSQRT14SSZrmkz = 21529,
  VRSQRT14SSZrr = 21530,
  VRSQRT14SSZrrk = 21531,
  VRSQRT14SSZrrkz = 21532,
  VRSQRT28PDZm = 21533,
  VRSQRT28PDZmb = 21534,
  VRSQRT28PDZmbk = 21535,
  VRSQRT28PDZmbkz = 21536,
  VRSQRT28PDZmk = 21537,
  VRSQRT28PDZmkz = 21538,
  VRSQRT28PDZr = 21539,
  VRSQRT28PDZrb = 21540,
  VRSQRT28PDZrbk = 21541,
  VRSQRT28PDZrbkz = 21542,
  VRSQRT28PDZrk = 21543,
  VRSQRT28PDZrkz = 21544,
  VRSQRT28PSZm = 21545,
  VRSQRT28PSZmb = 21546,
  VRSQRT28PSZmbk = 21547,
  VRSQRT28PSZmbkz = 21548,
  VRSQRT28PSZmk = 21549,
  VRSQRT28PSZmkz = 21550,
  VRSQRT28PSZr = 21551,
  VRSQRT28PSZrb = 21552,
  VRSQRT28PSZrbk = 21553,
  VRSQRT28PSZrbkz = 21554,
  VRSQRT28PSZrk = 21555,
  VRSQRT28PSZrkz = 21556,
  VRSQRT28SDZm = 21557,
  VRSQRT28SDZmk = 21558,
  VRSQRT28SDZmkz = 21559,
  VRSQRT28SDZr = 21560,
  VRSQRT28SDZrb = 21561,
  VRSQRT28SDZrbk = 21562,
  VRSQRT28SDZrbkz = 21563,
  VRSQRT28SDZrk = 21564,
  VRSQRT28SDZrkz = 21565,
  VRSQRT28SSZm = 21566,
  VRSQRT28SSZmk = 21567,
  VRSQRT28SSZmkz = 21568,
  VRSQRT28SSZr = 21569,
  VRSQRT28SSZrb = 21570,
  VRSQRT28SSZrbk = 21571,
  VRSQRT28SSZrbkz = 21572,
  VRSQRT28SSZrk = 21573,
  VRSQRT28SSZrkz = 21574,
  VRSQRTBF16Z128m = 21575,
  VRSQRTBF16Z128mb = 21576,
  VRSQRTBF16Z128mbk = 21577,
  VRSQRTBF16Z128mbkz = 21578,
  VRSQRTBF16Z128mk = 21579,
  VRSQRTBF16Z128mkz = 21580,
  VRSQRTBF16Z128r = 21581,
  VRSQRTBF16Z128rk = 21582,
  VRSQRTBF16Z128rkz = 21583,
  VRSQRTBF16Z256m = 21584,
  VRSQRTBF16Z256mb = 21585,
  VRSQRTBF16Z256mbk = 21586,
  VRSQRTBF16Z256mbkz = 21587,
  VRSQRTBF16Z256mk = 21588,
  VRSQRTBF16Z256mkz = 21589,
  VRSQRTBF16Z256r = 21590,
  VRSQRTBF16Z256rk = 21591,
  VRSQRTBF16Z256rkz = 21592,
  VRSQRTBF16Zm = 21593,
  VRSQRTBF16Zmb = 21594,
  VRSQRTBF16Zmbk = 21595,
  VRSQRTBF16Zmbkz = 21596,
  VRSQRTBF16Zmk = 21597,
  VRSQRTBF16Zmkz = 21598,
  VRSQRTBF16Zr = 21599,
  VRSQRTBF16Zrk = 21600,
  VRSQRTBF16Zrkz = 21601,
  VRSQRTPHZ128m = 21602,
  VRSQRTPHZ128mb = 21603,
  VRSQRTPHZ128mbk = 21604,
  VRSQRTPHZ128mbkz = 21605,
  VRSQRTPHZ128mk = 21606,
  VRSQRTPHZ128mkz = 21607,
  VRSQRTPHZ128r = 21608,
  VRSQRTPHZ128rk = 21609,
  VRSQRTPHZ128rkz = 21610,
  VRSQRTPHZ256m = 21611,
  VRSQRTPHZ256mb = 21612,
  VRSQRTPHZ256mbk = 21613,
  VRSQRTPHZ256mbkz = 21614,
  VRSQRTPHZ256mk = 21615,
  VRSQRTPHZ256mkz = 21616,
  VRSQRTPHZ256r = 21617,
  VRSQRTPHZ256rk = 21618,
  VRSQRTPHZ256rkz = 21619,
  VRSQRTPHZm = 21620,
  VRSQRTPHZmb = 21621,
  VRSQRTPHZmbk = 21622,
  VRSQRTPHZmbkz = 21623,
  VRSQRTPHZmk = 21624,
  VRSQRTPHZmkz = 21625,
  VRSQRTPHZr = 21626,
  VRSQRTPHZrk = 21627,
  VRSQRTPHZrkz = 21628,
  VRSQRTPSYm = 21629,
  VRSQRTPSYr = 21630,
  VRSQRTPSm = 21631,
  VRSQRTPSr = 21632,
  VRSQRTSHZrm = 21633,
  VRSQRTSHZrmk = 21634,
  VRSQRTSHZrmkz = 21635,
  VRSQRTSHZrr = 21636,
  VRSQRTSHZrrk = 21637,
  VRSQRTSHZrrkz = 21638,
  VRSQRTSSm = 21639,
  VRSQRTSSm_Int = 21640,
  VRSQRTSSr = 21641,
  VRSQRTSSr_Int = 21642,
  VSCALEFBF16Z128rm = 21643,
  VSCALEFBF16Z128rmb = 21644,
  VSCALEFBF16Z128rmbk = 21645,
  VSCALEFBF16Z128rmbkz = 21646,
  VSCALEFBF16Z128rmk = 21647,
  VSCALEFBF16Z128rmkz = 21648,
  VSCALEFBF16Z128rr = 21649,
  VSCALEFBF16Z128rrk = 21650,
  VSCALEFBF16Z128rrkz = 21651,
  VSCALEFBF16Z256rm = 21652,
  VSCALEFBF16Z256rmb = 21653,
  VSCALEFBF16Z256rmbk = 21654,
  VSCALEFBF16Z256rmbkz = 21655,
  VSCALEFBF16Z256rmk = 21656,
  VSCALEFBF16Z256rmkz = 21657,
  VSCALEFBF16Z256rr = 21658,
  VSCALEFBF16Z256rrk = 21659,
  VSCALEFBF16Z256rrkz = 21660,
  VSCALEFBF16Zrm = 21661,
  VSCALEFBF16Zrmb = 21662,
  VSCALEFBF16Zrmbk = 21663,
  VSCALEFBF16Zrmbkz = 21664,
  VSCALEFBF16Zrmk = 21665,
  VSCALEFBF16Zrmkz = 21666,
  VSCALEFBF16Zrr = 21667,
  VSCALEFBF16Zrrk = 21668,
  VSCALEFBF16Zrrkz = 21669,
  VSCALEFPDZ128rm = 21670,
  VSCALEFPDZ128rmb = 21671,
  VSCALEFPDZ128rmbk = 21672,
  VSCALEFPDZ128rmbkz = 21673,
  VSCALEFPDZ128rmk = 21674,
  VSCALEFPDZ128rmkz = 21675,
  VSCALEFPDZ128rr = 21676,
  VSCALEFPDZ128rrk = 21677,
  VSCALEFPDZ128rrkz = 21678,
  VSCALEFPDZ256rm = 21679,
  VSCALEFPDZ256rmb = 21680,
  VSCALEFPDZ256rmbk = 21681,
  VSCALEFPDZ256rmbkz = 21682,
  VSCALEFPDZ256rmk = 21683,
  VSCALEFPDZ256rmkz = 21684,
  VSCALEFPDZ256rr = 21685,
  VSCALEFPDZ256rrb = 21686,
  VSCALEFPDZ256rrbk = 21687,
  VSCALEFPDZ256rrbkz = 21688,
  VSCALEFPDZ256rrk = 21689,
  VSCALEFPDZ256rrkz = 21690,
  VSCALEFPDZrm = 21691,
  VSCALEFPDZrmb = 21692,
  VSCALEFPDZrmbk = 21693,
  VSCALEFPDZrmbkz = 21694,
  VSCALEFPDZrmk = 21695,
  VSCALEFPDZrmkz = 21696,
  VSCALEFPDZrr = 21697,
  VSCALEFPDZrrb = 21698,
  VSCALEFPDZrrbk = 21699,
  VSCALEFPDZrrbkz = 21700,
  VSCALEFPDZrrk = 21701,
  VSCALEFPDZrrkz = 21702,
  VSCALEFPHZ128rm = 21703,
  VSCALEFPHZ128rmb = 21704,
  VSCALEFPHZ128rmbk = 21705,
  VSCALEFPHZ128rmbkz = 21706,
  VSCALEFPHZ128rmk = 21707,
  VSCALEFPHZ128rmkz = 21708,
  VSCALEFPHZ128rr = 21709,
  VSCALEFPHZ128rrk = 21710,
  VSCALEFPHZ128rrkz = 21711,
  VSCALEFPHZ256rm = 21712,
  VSCALEFPHZ256rmb = 21713,
  VSCALEFPHZ256rmbk = 21714,
  VSCALEFPHZ256rmbkz = 21715,
  VSCALEFPHZ256rmk = 21716,
  VSCALEFPHZ256rmkz = 21717,
  VSCALEFPHZ256rr = 21718,
  VSCALEFPHZ256rrb = 21719,
  VSCALEFPHZ256rrbk = 21720,
  VSCALEFPHZ256rrbkz = 21721,
  VSCALEFPHZ256rrk = 21722,
  VSCALEFPHZ256rrkz = 21723,
  VSCALEFPHZrm = 21724,
  VSCALEFPHZrmb = 21725,
  VSCALEFPHZrmbk = 21726,
  VSCALEFPHZrmbkz = 21727,
  VSCALEFPHZrmk = 21728,
  VSCALEFPHZrmkz = 21729,
  VSCALEFPHZrr = 21730,
  VSCALEFPHZrrb = 21731,
  VSCALEFPHZrrbk = 21732,
  VSCALEFPHZrrbkz = 21733,
  VSCALEFPHZrrk = 21734,
  VSCALEFPHZrrkz = 21735,
  VSCALEFPSZ128rm = 21736,
  VSCALEFPSZ128rmb = 21737,
  VSCALEFPSZ128rmbk = 21738,
  VSCALEFPSZ128rmbkz = 21739,
  VSCALEFPSZ128rmk = 21740,
  VSCALEFPSZ128rmkz = 21741,
  VSCALEFPSZ128rr = 21742,
  VSCALEFPSZ128rrk = 21743,
  VSCALEFPSZ128rrkz = 21744,
  VSCALEFPSZ256rm = 21745,
  VSCALEFPSZ256rmb = 21746,
  VSCALEFPSZ256rmbk = 21747,
  VSCALEFPSZ256rmbkz = 21748,
  VSCALEFPSZ256rmk = 21749,
  VSCALEFPSZ256rmkz = 21750,
  VSCALEFPSZ256rr = 21751,
  VSCALEFPSZ256rrb = 21752,
  VSCALEFPSZ256rrbk = 21753,
  VSCALEFPSZ256rrbkz = 21754,
  VSCALEFPSZ256rrk = 21755,
  VSCALEFPSZ256rrkz = 21756,
  VSCALEFPSZrm = 21757,
  VSCALEFPSZrmb = 21758,
  VSCALEFPSZrmbk = 21759,
  VSCALEFPSZrmbkz = 21760,
  VSCALEFPSZrmk = 21761,
  VSCALEFPSZrmkz = 21762,
  VSCALEFPSZrr = 21763,
  VSCALEFPSZrrb = 21764,
  VSCALEFPSZrrbk = 21765,
  VSCALEFPSZrrbkz = 21766,
  VSCALEFPSZrrk = 21767,
  VSCALEFPSZrrkz = 21768,
  VSCALEFSDZrm = 21769,
  VSCALEFSDZrmk = 21770,
  VSCALEFSDZrmkz = 21771,
  VSCALEFSDZrr = 21772,
  VSCALEFSDZrrb_Int = 21773,
  VSCALEFSDZrrbk_Int = 21774,
  VSCALEFSDZrrbkz_Int = 21775,
  VSCALEFSDZrrk = 21776,
  VSCALEFSDZrrkz = 21777,
  VSCALEFSHZrm = 21778,
  VSCALEFSHZrmk = 21779,
  VSCALEFSHZrmkz = 21780,
  VSCALEFSHZrr = 21781,
  VSCALEFSHZrrb_Int = 21782,
  VSCALEFSHZrrbk_Int = 21783,
  VSCALEFSHZrrbkz_Int = 21784,
  VSCALEFSHZrrk = 21785,
  VSCALEFSHZrrkz = 21786,
  VSCALEFSSZrm = 21787,
  VSCALEFSSZrmk = 21788,
  VSCALEFSSZrmkz = 21789,
  VSCALEFSSZrr = 21790,
  VSCALEFSSZrrb_Int = 21791,
  VSCALEFSSZrrbk_Int = 21792,
  VSCALEFSSZrrbkz_Int = 21793,
  VSCALEFSSZrrk = 21794,
  VSCALEFSSZrrkz = 21795,
  VSCATTERDPDZ128mr = 21796,
  VSCATTERDPDZ256mr = 21797,
  VSCATTERDPDZmr = 21798,
  VSCATTERDPSZ128mr = 21799,
  VSCATTERDPSZ256mr = 21800,
  VSCATTERDPSZmr = 21801,
  VSCATTERPF0DPDm = 21802,
  VSCATTERPF0DPSm = 21803,
  VSCATTERPF0QPDm = 21804,
  VSCATTERPF0QPSm = 21805,
  VSCATTERPF1DPDm = 21806,
  VSCATTERPF1DPSm = 21807,
  VSCATTERPF1QPDm = 21808,
  VSCATTERPF1QPSm = 21809,
  VSCATTERQPDZ128mr = 21810,
  VSCATTERQPDZ256mr = 21811,
  VSCATTERQPDZmr = 21812,
  VSCATTERQPSZ128mr = 21813,
  VSCATTERQPSZ256mr = 21814,
  VSCATTERQPSZmr = 21815,
  VSHA512MSG1rr = 21816,
  VSHA512MSG2rr = 21817,
  VSHA512RNDS2rr = 21818,
  VSHUFF32X4Z256rmbi = 21819,
  VSHUFF32X4Z256rmbik = 21820,
  VSHUFF32X4Z256rmbikz = 21821,
  VSHUFF32X4Z256rmi = 21822,
  VSHUFF32X4Z256rmik = 21823,
  VSHUFF32X4Z256rmikz = 21824,
  VSHUFF32X4Z256rri = 21825,
  VSHUFF32X4Z256rrik = 21826,
  VSHUFF32X4Z256rrikz = 21827,
  VSHUFF32X4Zrmbi = 21828,
  VSHUFF32X4Zrmbik = 21829,
  VSHUFF32X4Zrmbikz = 21830,
  VSHUFF32X4Zrmi = 21831,
  VSHUFF32X4Zrmik = 21832,
  VSHUFF32X4Zrmikz = 21833,
  VSHUFF32X4Zrri = 21834,
  VSHUFF32X4Zrrik = 21835,
  VSHUFF32X4Zrrikz = 21836,
  VSHUFF64X2Z256rmbi = 21837,
  VSHUFF64X2Z256rmbik = 21838,
  VSHUFF64X2Z256rmbikz = 21839,
  VSHUFF64X2Z256rmi = 21840,
  VSHUFF64X2Z256rmik = 21841,
  VSHUFF64X2Z256rmikz = 21842,
  VSHUFF64X2Z256rri = 21843,
  VSHUFF64X2Z256rrik = 21844,
  VSHUFF64X2Z256rrikz = 21845,
  VSHUFF64X2Zrmbi = 21846,
  VSHUFF64X2Zrmbik = 21847,
  VSHUFF64X2Zrmbikz = 21848,
  VSHUFF64X2Zrmi = 21849,
  VSHUFF64X2Zrmik = 21850,
  VSHUFF64X2Zrmikz = 21851,
  VSHUFF64X2Zrri = 21852,
  VSHUFF64X2Zrrik = 21853,
  VSHUFF64X2Zrrikz = 21854,
  VSHUFI32X4Z256rmbi = 21855,
  VSHUFI32X4Z256rmbik = 21856,
  VSHUFI32X4Z256rmbikz = 21857,
  VSHUFI32X4Z256rmi = 21858,
  VSHUFI32X4Z256rmik = 21859,
  VSHUFI32X4Z256rmikz = 21860,
  VSHUFI32X4Z256rri = 21861,
  VSHUFI32X4Z256rrik = 21862,
  VSHUFI32X4Z256rrikz = 21863,
  VSHUFI32X4Zrmbi = 21864,
  VSHUFI32X4Zrmbik = 21865,
  VSHUFI32X4Zrmbikz = 21866,
  VSHUFI32X4Zrmi = 21867,
  VSHUFI32X4Zrmik = 21868,
  VSHUFI32X4Zrmikz = 21869,
  VSHUFI32X4Zrri = 21870,
  VSHUFI32X4Zrrik = 21871,
  VSHUFI32X4Zrrikz = 21872,
  VSHUFI64X2Z256rmbi = 21873,
  VSHUFI64X2Z256rmbik = 21874,
  VSHUFI64X2Z256rmbikz = 21875,
  VSHUFI64X2Z256rmi = 21876,
  VSHUFI64X2Z256rmik = 21877,
  VSHUFI64X2Z256rmikz = 21878,
  VSHUFI64X2Z256rri = 21879,
  VSHUFI64X2Z256rrik = 21880,
  VSHUFI64X2Z256rrikz = 21881,
  VSHUFI64X2Zrmbi = 21882,
  VSHUFI64X2Zrmbik = 21883,
  VSHUFI64X2Zrmbikz = 21884,
  VSHUFI64X2Zrmi = 21885,
  VSHUFI64X2Zrmik = 21886,
  VSHUFI64X2Zrmikz = 21887,
  VSHUFI64X2Zrri = 21888,
  VSHUFI64X2Zrrik = 21889,
  VSHUFI64X2Zrrikz = 21890,
  VSHUFPDYrmi = 21891,
  VSHUFPDYrri = 21892,
  VSHUFPDZ128rmbi = 21893,
  VSHUFPDZ128rmbik = 21894,
  VSHUFPDZ128rmbikz = 21895,
  VSHUFPDZ128rmi = 21896,
  VSHUFPDZ128rmik = 21897,
  VSHUFPDZ128rmikz = 21898,
  VSHUFPDZ128rri = 21899,
  VSHUFPDZ128rrik = 21900,
  VSHUFPDZ128rrikz = 21901,
  VSHUFPDZ256rmbi = 21902,
  VSHUFPDZ256rmbik = 21903,
  VSHUFPDZ256rmbikz = 21904,
  VSHUFPDZ256rmi = 21905,
  VSHUFPDZ256rmik = 21906,
  VSHUFPDZ256rmikz = 21907,
  VSHUFPDZ256rri = 21908,
  VSHUFPDZ256rrik = 21909,
  VSHUFPDZ256rrikz = 21910,
  VSHUFPDZrmbi = 21911,
  VSHUFPDZrmbik = 21912,
  VSHUFPDZrmbikz = 21913,
  VSHUFPDZrmi = 21914,
  VSHUFPDZrmik = 21915,
  VSHUFPDZrmikz = 21916,
  VSHUFPDZrri = 21917,
  VSHUFPDZrrik = 21918,
  VSHUFPDZrrikz = 21919,
  VSHUFPDrmi = 21920,
  VSHUFPDrri = 21921,
  VSHUFPSYrmi = 21922,
  VSHUFPSYrri = 21923,
  VSHUFPSZ128rmbi = 21924,
  VSHUFPSZ128rmbik = 21925,
  VSHUFPSZ128rmbikz = 21926,
  VSHUFPSZ128rmi = 21927,
  VSHUFPSZ128rmik = 21928,
  VSHUFPSZ128rmikz = 21929,
  VSHUFPSZ128rri = 21930,
  VSHUFPSZ128rrik = 21931,
  VSHUFPSZ128rrikz = 21932,
  VSHUFPSZ256rmbi = 21933,
  VSHUFPSZ256rmbik = 21934,
  VSHUFPSZ256rmbikz = 21935,
  VSHUFPSZ256rmi = 21936,
  VSHUFPSZ256rmik = 21937,
  VSHUFPSZ256rmikz = 21938,
  VSHUFPSZ256rri = 21939,
  VSHUFPSZ256rrik = 21940,
  VSHUFPSZ256rrikz = 21941,
  VSHUFPSZrmbi = 21942,
  VSHUFPSZrmbik = 21943,
  VSHUFPSZrmbikz = 21944,
  VSHUFPSZrmi = 21945,
  VSHUFPSZrmik = 21946,
  VSHUFPSZrmikz = 21947,
  VSHUFPSZrri = 21948,
  VSHUFPSZrrik = 21949,
  VSHUFPSZrrikz = 21950,
  VSHUFPSrmi = 21951,
  VSHUFPSrri = 21952,
  VSM3MSG1rm = 21953,
  VSM3MSG1rr = 21954,
  VSM3MSG2rm = 21955,
  VSM3MSG2rr = 21956,
  VSM3RNDS2rm = 21957,
  VSM3RNDS2rr = 21958,
  VSM4KEY4Yrm = 21959,
  VSM4KEY4Yrr = 21960,
  VSM4KEY4Z128rm = 21961,
  VSM4KEY4Z128rr = 21962,
  VSM4KEY4Z256rm = 21963,
  VSM4KEY4Z256rr = 21964,
  VSM4KEY4Zrm = 21965,
  VSM4KEY4Zrr = 21966,
  VSM4KEY4rm = 21967,
  VSM4KEY4rr = 21968,
  VSM4RNDS4Yrm = 21969,
  VSM4RNDS4Yrr = 21970,
  VSM4RNDS4Z128rm = 21971,
  VSM4RNDS4Z128rr = 21972,
  VSM4RNDS4Z256rm = 21973,
  VSM4RNDS4Z256rr = 21974,
  VSM4RNDS4Zrm = 21975,
  VSM4RNDS4Zrr = 21976,
  VSM4RNDS4rm = 21977,
  VSM4RNDS4rr = 21978,
  VSQRTBF16Z128m = 21979,
  VSQRTBF16Z128mb = 21980,
  VSQRTBF16Z128mbk = 21981,
  VSQRTBF16Z128mbkz = 21982,
  VSQRTBF16Z128mk = 21983,
  VSQRTBF16Z128mkz = 21984,
  VSQRTBF16Z128r = 21985,
  VSQRTBF16Z128rk = 21986,
  VSQRTBF16Z128rkz = 21987,
  VSQRTBF16Z256m = 21988,
  VSQRTBF16Z256mb = 21989,
  VSQRTBF16Z256mbk = 21990,
  VSQRTBF16Z256mbkz = 21991,
  VSQRTBF16Z256mk = 21992,
  VSQRTBF16Z256mkz = 21993,
  VSQRTBF16Z256r = 21994,
  VSQRTBF16Z256rk = 21995,
  VSQRTBF16Z256rkz = 21996,
  VSQRTBF16Zm = 21997,
  VSQRTBF16Zmb = 21998,
  VSQRTBF16Zmbk = 21999,
  VSQRTBF16Zmbkz = 22000,
  VSQRTBF16Zmk = 22001,
  VSQRTBF16Zmkz = 22002,
  VSQRTBF16Zr = 22003,
  VSQRTBF16Zrk = 22004,
  VSQRTBF16Zrkz = 22005,
  VSQRTPDYm = 22006,
  VSQRTPDYr = 22007,
  VSQRTPDZ128m = 22008,
  VSQRTPDZ128mb = 22009,
  VSQRTPDZ128mbk = 22010,
  VSQRTPDZ128mbkz = 22011,
  VSQRTPDZ128mk = 22012,
  VSQRTPDZ128mkz = 22013,
  VSQRTPDZ128r = 22014,
  VSQRTPDZ128rk = 22015,
  VSQRTPDZ128rkz = 22016,
  VSQRTPDZ256m = 22017,
  VSQRTPDZ256mb = 22018,
  VSQRTPDZ256mbk = 22019,
  VSQRTPDZ256mbkz = 22020,
  VSQRTPDZ256mk = 22021,
  VSQRTPDZ256mkz = 22022,
  VSQRTPDZ256r = 22023,
  VSQRTPDZ256rb = 22024,
  VSQRTPDZ256rbk = 22025,
  VSQRTPDZ256rbkz = 22026,
  VSQRTPDZ256rk = 22027,
  VSQRTPDZ256rkz = 22028,
  VSQRTPDZm = 22029,
  VSQRTPDZmb = 22030,
  VSQRTPDZmbk = 22031,
  VSQRTPDZmbkz = 22032,
  VSQRTPDZmk = 22033,
  VSQRTPDZmkz = 22034,
  VSQRTPDZr = 22035,
  VSQRTPDZrb = 22036,
  VSQRTPDZrbk = 22037,
  VSQRTPDZrbkz = 22038,
  VSQRTPDZrk = 22039,
  VSQRTPDZrkz = 22040,
  VSQRTPDm = 22041,
  VSQRTPDr = 22042,
  VSQRTPHZ128m = 22043,
  VSQRTPHZ128mb = 22044,
  VSQRTPHZ128mbk = 22045,
  VSQRTPHZ128mbkz = 22046,
  VSQRTPHZ128mk = 22047,
  VSQRTPHZ128mkz = 22048,
  VSQRTPHZ128r = 22049,
  VSQRTPHZ128rk = 22050,
  VSQRTPHZ128rkz = 22051,
  VSQRTPHZ256m = 22052,
  VSQRTPHZ256mb = 22053,
  VSQRTPHZ256mbk = 22054,
  VSQRTPHZ256mbkz = 22055,
  VSQRTPHZ256mk = 22056,
  VSQRTPHZ256mkz = 22057,
  VSQRTPHZ256r = 22058,
  VSQRTPHZ256rb = 22059,
  VSQRTPHZ256rbk = 22060,
  VSQRTPHZ256rbkz = 22061,
  VSQRTPHZ256rk = 22062,
  VSQRTPHZ256rkz = 22063,
  VSQRTPHZm = 22064,
  VSQRTPHZmb = 22065,
  VSQRTPHZmbk = 22066,
  VSQRTPHZmbkz = 22067,
  VSQRTPHZmk = 22068,
  VSQRTPHZmkz = 22069,
  VSQRTPHZr = 22070,
  VSQRTPHZrb = 22071,
  VSQRTPHZrbk = 22072,
  VSQRTPHZrbkz = 22073,
  VSQRTPHZrk = 22074,
  VSQRTPHZrkz = 22075,
  VSQRTPSYm = 22076,
  VSQRTPSYr = 22077,
  VSQRTPSZ128m = 22078,
  VSQRTPSZ128mb = 22079,
  VSQRTPSZ128mbk = 22080,
  VSQRTPSZ128mbkz = 22081,
  VSQRTPSZ128mk = 22082,
  VSQRTPSZ128mkz = 22083,
  VSQRTPSZ128r = 22084,
  VSQRTPSZ128rk = 22085,
  VSQRTPSZ128rkz = 22086,
  VSQRTPSZ256m = 22087,
  VSQRTPSZ256mb = 22088,
  VSQRTPSZ256mbk = 22089,
  VSQRTPSZ256mbkz = 22090,
  VSQRTPSZ256mk = 22091,
  VSQRTPSZ256mkz = 22092,
  VSQRTPSZ256r = 22093,
  VSQRTPSZ256rb = 22094,
  VSQRTPSZ256rbk = 22095,
  VSQRTPSZ256rbkz = 22096,
  VSQRTPSZ256rk = 22097,
  VSQRTPSZ256rkz = 22098,
  VSQRTPSZm = 22099,
  VSQRTPSZmb = 22100,
  VSQRTPSZmbk = 22101,
  VSQRTPSZmbkz = 22102,
  VSQRTPSZmk = 22103,
  VSQRTPSZmkz = 22104,
  VSQRTPSZr = 22105,
  VSQRTPSZrb = 22106,
  VSQRTPSZrbk = 22107,
  VSQRTPSZrbkz = 22108,
  VSQRTPSZrk = 22109,
  VSQRTPSZrkz = 22110,
  VSQRTPSm = 22111,
  VSQRTPSr = 22112,
  VSQRTSDZm = 22113,
  VSQRTSDZm_Int = 22114,
  VSQRTSDZmk_Int = 22115,
  VSQRTSDZmkz_Int = 22116,
  VSQRTSDZr = 22117,
  VSQRTSDZr_Int = 22118,
  VSQRTSDZrb_Int = 22119,
  VSQRTSDZrbk_Int = 22120,
  VSQRTSDZrbkz_Int = 22121,
  VSQRTSDZrk_Int = 22122,
  VSQRTSDZrkz_Int = 22123,
  VSQRTSDm = 22124,
  VSQRTSDm_Int = 22125,
  VSQRTSDr = 22126,
  VSQRTSDr_Int = 22127,
  VSQRTSHZm = 22128,
  VSQRTSHZm_Int = 22129,
  VSQRTSHZmk_Int = 22130,
  VSQRTSHZmkz_Int = 22131,
  VSQRTSHZr = 22132,
  VSQRTSHZr_Int = 22133,
  VSQRTSHZrb_Int = 22134,
  VSQRTSHZrbk_Int = 22135,
  VSQRTSHZrbkz_Int = 22136,
  VSQRTSHZrk_Int = 22137,
  VSQRTSHZrkz_Int = 22138,
  VSQRTSSZm = 22139,
  VSQRTSSZm_Int = 22140,
  VSQRTSSZmk_Int = 22141,
  VSQRTSSZmkz_Int = 22142,
  VSQRTSSZr = 22143,
  VSQRTSSZr_Int = 22144,
  VSQRTSSZrb_Int = 22145,
  VSQRTSSZrbk_Int = 22146,
  VSQRTSSZrbkz_Int = 22147,
  VSQRTSSZrk_Int = 22148,
  VSQRTSSZrkz_Int = 22149,
  VSQRTSSm = 22150,
  VSQRTSSm_Int = 22151,
  VSQRTSSr = 22152,
  VSQRTSSr_Int = 22153,
  VSTMXCSR = 22154,
  VSUBBF16Z128rm = 22155,
  VSUBBF16Z128rmb = 22156,
  VSUBBF16Z128rmbk = 22157,
  VSUBBF16Z128rmbkz = 22158,
  VSUBBF16Z128rmk = 22159,
  VSUBBF16Z128rmkz = 22160,
  VSUBBF16Z128rr = 22161,
  VSUBBF16Z128rrk = 22162,
  VSUBBF16Z128rrkz = 22163,
  VSUBBF16Z256rm = 22164,
  VSUBBF16Z256rmb = 22165,
  VSUBBF16Z256rmbk = 22166,
  VSUBBF16Z256rmbkz = 22167,
  VSUBBF16Z256rmk = 22168,
  VSUBBF16Z256rmkz = 22169,
  VSUBBF16Z256rr = 22170,
  VSUBBF16Z256rrk = 22171,
  VSUBBF16Z256rrkz = 22172,
  VSUBBF16Zrm = 22173,
  VSUBBF16Zrmb = 22174,
  VSUBBF16Zrmbk = 22175,
  VSUBBF16Zrmbkz = 22176,
  VSUBBF16Zrmk = 22177,
  VSUBBF16Zrmkz = 22178,
  VSUBBF16Zrr = 22179,
  VSUBBF16Zrrk = 22180,
  VSUBBF16Zrrkz = 22181,
  VSUBPDYrm = 22182,
  VSUBPDYrr = 22183,
  VSUBPDZ128rm = 22184,
  VSUBPDZ128rmb = 22185,
  VSUBPDZ128rmbk = 22186,
  VSUBPDZ128rmbkz = 22187,
  VSUBPDZ128rmk = 22188,
  VSUBPDZ128rmkz = 22189,
  VSUBPDZ128rr = 22190,
  VSUBPDZ128rrk = 22191,
  VSUBPDZ128rrkz = 22192,
  VSUBPDZ256rm = 22193,
  VSUBPDZ256rmb = 22194,
  VSUBPDZ256rmbk = 22195,
  VSUBPDZ256rmbkz = 22196,
  VSUBPDZ256rmk = 22197,
  VSUBPDZ256rmkz = 22198,
  VSUBPDZ256rr = 22199,
  VSUBPDZ256rrb = 22200,
  VSUBPDZ256rrbk = 22201,
  VSUBPDZ256rrbkz = 22202,
  VSUBPDZ256rrk = 22203,
  VSUBPDZ256rrkz = 22204,
  VSUBPDZrm = 22205,
  VSUBPDZrmb = 22206,
  VSUBPDZrmbk = 22207,
  VSUBPDZrmbkz = 22208,
  VSUBPDZrmk = 22209,
  VSUBPDZrmkz = 22210,
  VSUBPDZrr = 22211,
  VSUBPDZrrb = 22212,
  VSUBPDZrrbk = 22213,
  VSUBPDZrrbkz = 22214,
  VSUBPDZrrk = 22215,
  VSUBPDZrrkz = 22216,
  VSUBPDrm = 22217,
  VSUBPDrr = 22218,
  VSUBPHZ128rm = 22219,
  VSUBPHZ128rmb = 22220,
  VSUBPHZ128rmbk = 22221,
  VSUBPHZ128rmbkz = 22222,
  VSUBPHZ128rmk = 22223,
  VSUBPHZ128rmkz = 22224,
  VSUBPHZ128rr = 22225,
  VSUBPHZ128rrk = 22226,
  VSUBPHZ128rrkz = 22227,
  VSUBPHZ256rm = 22228,
  VSUBPHZ256rmb = 22229,
  VSUBPHZ256rmbk = 22230,
  VSUBPHZ256rmbkz = 22231,
  VSUBPHZ256rmk = 22232,
  VSUBPHZ256rmkz = 22233,
  VSUBPHZ256rr = 22234,
  VSUBPHZ256rrb = 22235,
  VSUBPHZ256rrbk = 22236,
  VSUBPHZ256rrbkz = 22237,
  VSUBPHZ256rrk = 22238,
  VSUBPHZ256rrkz = 22239,
  VSUBPHZrm = 22240,
  VSUBPHZrmb = 22241,
  VSUBPHZrmbk = 22242,
  VSUBPHZrmbkz = 22243,
  VSUBPHZrmk = 22244,
  VSUBPHZrmkz = 22245,
  VSUBPHZrr = 22246,
  VSUBPHZrrb = 22247,
  VSUBPHZrrbk = 22248,
  VSUBPHZrrbkz = 22249,
  VSUBPHZrrk = 22250,
  VSUBPHZrrkz = 22251,
  VSUBPSYrm = 22252,
  VSUBPSYrr = 22253,
  VSUBPSZ128rm = 22254,
  VSUBPSZ128rmb = 22255,
  VSUBPSZ128rmbk = 22256,
  VSUBPSZ128rmbkz = 22257,
  VSUBPSZ128rmk = 22258,
  VSUBPSZ128rmkz = 22259,
  VSUBPSZ128rr = 22260,
  VSUBPSZ128rrk = 22261,
  VSUBPSZ128rrkz = 22262,
  VSUBPSZ256rm = 22263,
  VSUBPSZ256rmb = 22264,
  VSUBPSZ256rmbk = 22265,
  VSUBPSZ256rmbkz = 22266,
  VSUBPSZ256rmk = 22267,
  VSUBPSZ256rmkz = 22268,
  VSUBPSZ256rr = 22269,
  VSUBPSZ256rrb = 22270,
  VSUBPSZ256rrbk = 22271,
  VSUBPSZ256rrbkz = 22272,
  VSUBPSZ256rrk = 22273,
  VSUBPSZ256rrkz = 22274,
  VSUBPSZrm = 22275,
  VSUBPSZrmb = 22276,
  VSUBPSZrmbk = 22277,
  VSUBPSZrmbkz = 22278,
  VSUBPSZrmk = 22279,
  VSUBPSZrmkz = 22280,
  VSUBPSZrr = 22281,
  VSUBPSZrrb = 22282,
  VSUBPSZrrbk = 22283,
  VSUBPSZrrbkz = 22284,
  VSUBPSZrrk = 22285,
  VSUBPSZrrkz = 22286,
  VSUBPSrm = 22287,
  VSUBPSrr = 22288,
  VSUBSDZrm = 22289,
  VSUBSDZrm_Int = 22290,
  VSUBSDZrmk_Int = 22291,
  VSUBSDZrmkz_Int = 22292,
  VSUBSDZrr = 22293,
  VSUBSDZrr_Int = 22294,
  VSUBSDZrrb_Int = 22295,
  VSUBSDZrrbk_Int = 22296,
  VSUBSDZrrbkz_Int = 22297,
  VSUBSDZrrk_Int = 22298,
  VSUBSDZrrkz_Int = 22299,
  VSUBSDrm = 22300,
  VSUBSDrm_Int = 22301,
  VSUBSDrr = 22302,
  VSUBSDrr_Int = 22303,
  VSUBSHZrm = 22304,
  VSUBSHZrm_Int = 22305,
  VSUBSHZrmk_Int = 22306,
  VSUBSHZrmkz_Int = 22307,
  VSUBSHZrr = 22308,
  VSUBSHZrr_Int = 22309,
  VSUBSHZrrb_Int = 22310,
  VSUBSHZrrbk_Int = 22311,
  VSUBSHZrrbkz_Int = 22312,
  VSUBSHZrrk_Int = 22313,
  VSUBSHZrrkz_Int = 22314,
  VSUBSSZrm = 22315,
  VSUBSSZrm_Int = 22316,
  VSUBSSZrmk_Int = 22317,
  VSUBSSZrmkz_Int = 22318,
  VSUBSSZrr = 22319,
  VSUBSSZrr_Int = 22320,
  VSUBSSZrrb_Int = 22321,
  VSUBSSZrrbk_Int = 22322,
  VSUBSSZrrbkz_Int = 22323,
  VSUBSSZrrk_Int = 22324,
  VSUBSSZrrkz_Int = 22325,
  VSUBSSrm = 22326,
  VSUBSSrm_Int = 22327,
  VSUBSSrr = 22328,
  VSUBSSrr_Int = 22329,
  VTESTPDYrm = 22330,
  VTESTPDYrr = 22331,
  VTESTPDrm = 22332,
  VTESTPDrr = 22333,
  VTESTPSYrm = 22334,
  VTESTPSYrr = 22335,
  VTESTPSrm = 22336,
  VTESTPSrr = 22337,
  VUCOMISDZrm = 22338,
  VUCOMISDZrm_Int = 22339,
  VUCOMISDZrr = 22340,
  VUCOMISDZrr_Int = 22341,
  VUCOMISDZrrb = 22342,
  VUCOMISDrm = 22343,
  VUCOMISDrm_Int = 22344,
  VUCOMISDrr = 22345,
  VUCOMISDrr_Int = 22346,
  VUCOMISHZrm = 22347,
  VUCOMISHZrm_Int = 22348,
  VUCOMISHZrr = 22349,
  VUCOMISHZrr_Int = 22350,
  VUCOMISHZrrb = 22351,
  VUCOMISSZrm = 22352,
  VUCOMISSZrm_Int = 22353,
  VUCOMISSZrr = 22354,
  VUCOMISSZrr_Int = 22355,
  VUCOMISSZrrb = 22356,
  VUCOMISSrm = 22357,
  VUCOMISSrm_Int = 22358,
  VUCOMISSrr = 22359,
  VUCOMISSrr_Int = 22360,
  VUCOMXSDZrm = 22361,
  VUCOMXSDZrm_Int = 22362,
  VUCOMXSDZrr = 22363,
  VUCOMXSDZrr_Int = 22364,
  VUCOMXSDZrrb_Int = 22365,
  VUCOMXSHZrm = 22366,
  VUCOMXSHZrm_Int = 22367,
  VUCOMXSHZrr = 22368,
  VUCOMXSHZrr_Int = 22369,
  VUCOMXSHZrrb_Int = 22370,
  VUCOMXSSZrm = 22371,
  VUCOMXSSZrm_Int = 22372,
  VUCOMXSSZrr = 22373,
  VUCOMXSSZrr_Int = 22374,
  VUCOMXSSZrrb_Int = 22375,
  VUNPCKHPDYrm = 22376,
  VUNPCKHPDYrr = 22377,
  VUNPCKHPDZ128rm = 22378,
  VUNPCKHPDZ128rmb = 22379,
  VUNPCKHPDZ128rmbk = 22380,
  VUNPCKHPDZ128rmbkz = 22381,
  VUNPCKHPDZ128rmk = 22382,
  VUNPCKHPDZ128rmkz = 22383,
  VUNPCKHPDZ128rr = 22384,
  VUNPCKHPDZ128rrk = 22385,
  VUNPCKHPDZ128rrkz = 22386,
  VUNPCKHPDZ256rm = 22387,
  VUNPCKHPDZ256rmb = 22388,
  VUNPCKHPDZ256rmbk = 22389,
  VUNPCKHPDZ256rmbkz = 22390,
  VUNPCKHPDZ256rmk = 22391,
  VUNPCKHPDZ256rmkz = 22392,
  VUNPCKHPDZ256rr = 22393,
  VUNPCKHPDZ256rrk = 22394,
  VUNPCKHPDZ256rrkz = 22395,
  VUNPCKHPDZrm = 22396,
  VUNPCKHPDZrmb = 22397,
  VUNPCKHPDZrmbk = 22398,
  VUNPCKHPDZrmbkz = 22399,
  VUNPCKHPDZrmk = 22400,
  VUNPCKHPDZrmkz = 22401,
  VUNPCKHPDZrr = 22402,
  VUNPCKHPDZrrk = 22403,
  VUNPCKHPDZrrkz = 22404,
  VUNPCKHPDrm = 22405,
  VUNPCKHPDrr = 22406,
  VUNPCKHPSYrm = 22407,
  VUNPCKHPSYrr = 22408,
  VUNPCKHPSZ128rm = 22409,
  VUNPCKHPSZ128rmb = 22410,
  VUNPCKHPSZ128rmbk = 22411,
  VUNPCKHPSZ128rmbkz = 22412,
  VUNPCKHPSZ128rmk = 22413,
  VUNPCKHPSZ128rmkz = 22414,
  VUNPCKHPSZ128rr = 22415,
  VUNPCKHPSZ128rrk = 22416,
  VUNPCKHPSZ128rrkz = 22417,
  VUNPCKHPSZ256rm = 22418,
  VUNPCKHPSZ256rmb = 22419,
  VUNPCKHPSZ256rmbk = 22420,
  VUNPCKHPSZ256rmbkz = 22421,
  VUNPCKHPSZ256rmk = 22422,
  VUNPCKHPSZ256rmkz = 22423,
  VUNPCKHPSZ256rr = 22424,
  VUNPCKHPSZ256rrk = 22425,
  VUNPCKHPSZ256rrkz = 22426,
  VUNPCKHPSZrm = 22427,
  VUNPCKHPSZrmb = 22428,
  VUNPCKHPSZrmbk = 22429,
  VUNPCKHPSZrmbkz = 22430,
  VUNPCKHPSZrmk = 22431,
  VUNPCKHPSZrmkz = 22432,
  VUNPCKHPSZrr = 22433,
  VUNPCKHPSZrrk = 22434,
  VUNPCKHPSZrrkz = 22435,
  VUNPCKHPSrm = 22436,
  VUNPCKHPSrr = 22437,
  VUNPCKLPDYrm = 22438,
  VUNPCKLPDYrr = 22439,
  VUNPCKLPDZ128rm = 22440,
  VUNPCKLPDZ128rmb = 22441,
  VUNPCKLPDZ128rmbk = 22442,
  VUNPCKLPDZ128rmbkz = 22443,
  VUNPCKLPDZ128rmk = 22444,
  VUNPCKLPDZ128rmkz = 22445,
  VUNPCKLPDZ128rr = 22446,
  VUNPCKLPDZ128rrk = 22447,
  VUNPCKLPDZ128rrkz = 22448,
  VUNPCKLPDZ256rm = 22449,
  VUNPCKLPDZ256rmb = 22450,
  VUNPCKLPDZ256rmbk = 22451,
  VUNPCKLPDZ256rmbkz = 22452,
  VUNPCKLPDZ256rmk = 22453,
  VUNPCKLPDZ256rmkz = 22454,
  VUNPCKLPDZ256rr = 22455,
  VUNPCKLPDZ256rrk = 22456,
  VUNPCKLPDZ256rrkz = 22457,
  VUNPCKLPDZrm = 22458,
  VUNPCKLPDZrmb = 22459,
  VUNPCKLPDZrmbk = 22460,
  VUNPCKLPDZrmbkz = 22461,
  VUNPCKLPDZrmk = 22462,
  VUNPCKLPDZrmkz = 22463,
  VUNPCKLPDZrr = 22464,
  VUNPCKLPDZrrk = 22465,
  VUNPCKLPDZrrkz = 22466,
  VUNPCKLPDrm = 22467,
  VUNPCKLPDrr = 22468,
  VUNPCKLPSYrm = 22469,
  VUNPCKLPSYrr = 22470,
  VUNPCKLPSZ128rm = 22471,
  VUNPCKLPSZ128rmb = 22472,
  VUNPCKLPSZ128rmbk = 22473,
  VUNPCKLPSZ128rmbkz = 22474,
  VUNPCKLPSZ128rmk = 22475,
  VUNPCKLPSZ128rmkz = 22476,
  VUNPCKLPSZ128rr = 22477,
  VUNPCKLPSZ128rrk = 22478,
  VUNPCKLPSZ128rrkz = 22479,
  VUNPCKLPSZ256rm = 22480,
  VUNPCKLPSZ256rmb = 22481,
  VUNPCKLPSZ256rmbk = 22482,
  VUNPCKLPSZ256rmbkz = 22483,
  VUNPCKLPSZ256rmk = 22484,
  VUNPCKLPSZ256rmkz = 22485,
  VUNPCKLPSZ256rr = 22486,
  VUNPCKLPSZ256rrk = 22487,
  VUNPCKLPSZ256rrkz = 22488,
  VUNPCKLPSZrm = 22489,
  VUNPCKLPSZrmb = 22490,
  VUNPCKLPSZrmbk = 22491,
  VUNPCKLPSZrmbkz = 22492,
  VUNPCKLPSZrmk = 22493,
  VUNPCKLPSZrmkz = 22494,
  VUNPCKLPSZrr = 22495,
  VUNPCKLPSZrrk = 22496,
  VUNPCKLPSZrrkz = 22497,
  VUNPCKLPSrm = 22498,
  VUNPCKLPSrr = 22499,
  VXORPDYrm = 22500,
  VXORPDYrr = 22501,
  VXORPDZ128rm = 22502,
  VXORPDZ128rmb = 22503,
  VXORPDZ128rmbk = 22504,
  VXORPDZ128rmbkz = 22505,
  VXORPDZ128rmk = 22506,
  VXORPDZ128rmkz = 22507,
  VXORPDZ128rr = 22508,
  VXORPDZ128rrk = 22509,
  VXORPDZ128rrkz = 22510,
  VXORPDZ256rm = 22511,
  VXORPDZ256rmb = 22512,
  VXORPDZ256rmbk = 22513,
  VXORPDZ256rmbkz = 22514,
  VXORPDZ256rmk = 22515,
  VXORPDZ256rmkz = 22516,
  VXORPDZ256rr = 22517,
  VXORPDZ256rrk = 22518,
  VXORPDZ256rrkz = 22519,
  VXORPDZrm = 22520,
  VXORPDZrmb = 22521,
  VXORPDZrmbk = 22522,
  VXORPDZrmbkz = 22523,
  VXORPDZrmk = 22524,
  VXORPDZrmkz = 22525,
  VXORPDZrr = 22526,
  VXORPDZrrk = 22527,
  VXORPDZrrkz = 22528,
  VXORPDrm = 22529,
  VXORPDrr = 22530,
  VXORPSYrm = 22531,
  VXORPSYrr = 22532,
  VXORPSZ128rm = 22533,
  VXORPSZ128rmb = 22534,
  VXORPSZ128rmbk = 22535,
  VXORPSZ128rmbkz = 22536,
  VXORPSZ128rmk = 22537,
  VXORPSZ128rmkz = 22538,
  VXORPSZ128rr = 22539,
  VXORPSZ128rrk = 22540,
  VXORPSZ128rrkz = 22541,
  VXORPSZ256rm = 22542,
  VXORPSZ256rmb = 22543,
  VXORPSZ256rmbk = 22544,
  VXORPSZ256rmbkz = 22545,
  VXORPSZ256rmk = 22546,
  VXORPSZ256rmkz = 22547,
  VXORPSZ256rr = 22548,
  VXORPSZ256rrk = 22549,
  VXORPSZ256rrkz = 22550,
  VXORPSZrm = 22551,
  VXORPSZrmb = 22552,
  VXORPSZrmbk = 22553,
  VXORPSZrmbkz = 22554,
  VXORPSZrmk = 22555,
  VXORPSZrmkz = 22556,
  VXORPSZrr = 22557,
  VXORPSZrrk = 22558,
  VXORPSZrrkz = 22559,
  VXORPSrm = 22560,
  VXORPSrr = 22561,
  VZEROALL = 22562,
  VZEROUPPER = 22563,
  WAIT = 22564,
  WBINVD = 22565,
  WBNOINVD = 22566,
  WRFSBASE = 22567,
  WRFSBASE64 = 22568,
  WRGSBASE = 22569,
  WRGSBASE64 = 22570,
  WRMSR = 22571,
  WRMSRLIST = 22572,
  WRMSRNS = 22573,
  WRMSRNSir = 22574,
  WRMSRNSir_EVEX = 22575,
  WRPKRUr = 22576,
  WRSSD = 22577,
  WRSSD_EVEX = 22578,
  WRSSQ = 22579,
  WRSSQ_EVEX = 22580,
  WRUSSD = 22581,
  WRUSSD_EVEX = 22582,
  WRUSSQ = 22583,
  WRUSSQ_EVEX = 22584,
  XABORT = 22585,
  XACQUIRE_PREFIX = 22586,
  XADD16rm = 22587,
  XADD16rr = 22588,
  XADD32rm = 22589,
  XADD32rr = 22590,
  XADD64rm = 22591,
  XADD64rr = 22592,
  XADD8rm = 22593,
  XADD8rr = 22594,
  XAM_F = 22595,
  XAM_Fp32 = 22596,
  XAM_Fp64 = 22597,
  XAM_Fp80 = 22598,
  XBEGIN = 22599,
  XBEGIN_2 = 22600,
  XBEGIN_4 = 22601,
  XCHG16ar = 22602,
  XCHG16rm = 22603,
  XCHG16rr = 22604,
  XCHG32ar = 22605,
  XCHG32rm = 22606,
  XCHG32rr = 22607,
  XCHG64ar = 22608,
  XCHG64rm = 22609,
  XCHG64rr = 22610,
  XCHG8rm = 22611,
  XCHG8rr = 22612,
  XCH_F = 22613,
  XCRYPTCBC = 22614,
  XCRYPTCFB = 22615,
  XCRYPTCTR = 22616,
  XCRYPTECB = 22617,
  XCRYPTOFB = 22618,
  XEND = 22619,
  XGETBV = 22620,
  XLAT = 22621,
  XOR16i16 = 22622,
  XOR16mi = 22623,
  XOR16mi8 = 22624,
  XOR16mi8_EVEX = 22625,
  XOR16mi8_ND = 22626,
  XOR16mi8_NF = 22627,
  XOR16mi8_NF_ND = 22628,
  XOR16mi_EVEX = 22629,
  XOR16mi_ND = 22630,
  XOR16mi_NF = 22631,
  XOR16mi_NF_ND = 22632,
  XOR16mr = 22633,
  XOR16mr_EVEX = 22634,
  XOR16mr_ND = 22635,
  XOR16mr_NF = 22636,
  XOR16mr_NF_ND = 22637,
  XOR16ri = 22638,
  XOR16ri8 = 22639,
  XOR16ri8_EVEX = 22640,
  XOR16ri8_ND = 22641,
  XOR16ri8_NF = 22642,
  XOR16ri8_NF_ND = 22643,
  XOR16ri_EVEX = 22644,
  XOR16ri_ND = 22645,
  XOR16ri_NF = 22646,
  XOR16ri_NF_ND = 22647,
  XOR16rm = 22648,
  XOR16rm_EVEX = 22649,
  XOR16rm_ND = 22650,
  XOR16rm_NF = 22651,
  XOR16rm_NF_ND = 22652,
  XOR16rr = 22653,
  XOR16rr_EVEX = 22654,
  XOR16rr_EVEX_REV = 22655,
  XOR16rr_ND = 22656,
  XOR16rr_ND_REV = 22657,
  XOR16rr_NF = 22658,
  XOR16rr_NF_ND = 22659,
  XOR16rr_NF_ND_REV = 22660,
  XOR16rr_NF_REV = 22661,
  XOR16rr_REV = 22662,
  XOR32i32 = 22663,
  XOR32mi = 22664,
  XOR32mi8 = 22665,
  XOR32mi8_EVEX = 22666,
  XOR32mi8_ND = 22667,
  XOR32mi8_NF = 22668,
  XOR32mi8_NF_ND = 22669,
  XOR32mi_EVEX = 22670,
  XOR32mi_ND = 22671,
  XOR32mi_NF = 22672,
  XOR32mi_NF_ND = 22673,
  XOR32mr = 22674,
  XOR32mr_EVEX = 22675,
  XOR32mr_ND = 22676,
  XOR32mr_NF = 22677,
  XOR32mr_NF_ND = 22678,
  XOR32ri = 22679,
  XOR32ri8 = 22680,
  XOR32ri8_EVEX = 22681,
  XOR32ri8_ND = 22682,
  XOR32ri8_NF = 22683,
  XOR32ri8_NF_ND = 22684,
  XOR32ri_EVEX = 22685,
  XOR32ri_ND = 22686,
  XOR32ri_NF = 22687,
  XOR32ri_NF_ND = 22688,
  XOR32rm = 22689,
  XOR32rm_EVEX = 22690,
  XOR32rm_ND = 22691,
  XOR32rm_NF = 22692,
  XOR32rm_NF_ND = 22693,
  XOR32rr = 22694,
  XOR32rr_EVEX = 22695,
  XOR32rr_EVEX_REV = 22696,
  XOR32rr_ND = 22697,
  XOR32rr_ND_REV = 22698,
  XOR32rr_NF = 22699,
  XOR32rr_NF_ND = 22700,
  XOR32rr_NF_ND_REV = 22701,
  XOR32rr_NF_REV = 22702,
  XOR32rr_REV = 22703,
  XOR64i32 = 22704,
  XOR64mi32 = 22705,
  XOR64mi32_EVEX = 22706,
  XOR64mi32_ND = 22707,
  XOR64mi32_NF = 22708,
  XOR64mi32_NF_ND = 22709,
  XOR64mi8 = 22710,
  XOR64mi8_EVEX = 22711,
  XOR64mi8_ND = 22712,
  XOR64mi8_NF = 22713,
  XOR64mi8_NF_ND = 22714,
  XOR64mr = 22715,
  XOR64mr_EVEX = 22716,
  XOR64mr_ND = 22717,
  XOR64mr_NF = 22718,
  XOR64mr_NF_ND = 22719,
  XOR64ri32 = 22720,
  XOR64ri32_EVEX = 22721,
  XOR64ri32_ND = 22722,
  XOR64ri32_NF = 22723,
  XOR64ri32_NF_ND = 22724,
  XOR64ri8 = 22725,
  XOR64ri8_EVEX = 22726,
  XOR64ri8_ND = 22727,
  XOR64ri8_NF = 22728,
  XOR64ri8_NF_ND = 22729,
  XOR64rm = 22730,
  XOR64rm_EVEX = 22731,
  XOR64rm_ND = 22732,
  XOR64rm_NF = 22733,
  XOR64rm_NF_ND = 22734,
  XOR64rr = 22735,
  XOR64rr_EVEX = 22736,
  XOR64rr_EVEX_REV = 22737,
  XOR64rr_ND = 22738,
  XOR64rr_ND_REV = 22739,
  XOR64rr_NF = 22740,
  XOR64rr_NF_ND = 22741,
  XOR64rr_NF_ND_REV = 22742,
  XOR64rr_NF_REV = 22743,
  XOR64rr_REV = 22744,
  XOR8i8 = 22745,
  XOR8mi = 22746,
  XOR8mi8 = 22747,
  XOR8mi_EVEX = 22748,
  XOR8mi_ND = 22749,
  XOR8mi_NF = 22750,
  XOR8mi_NF_ND = 22751,
  XOR8mr = 22752,
  XOR8mr_EVEX = 22753,
  XOR8mr_ND = 22754,
  XOR8mr_NF = 22755,
  XOR8mr_NF_ND = 22756,
  XOR8ri = 22757,
  XOR8ri8 = 22758,
  XOR8ri_EVEX = 22759,
  XOR8ri_ND = 22760,
  XOR8ri_NF = 22761,
  XOR8ri_NF_ND = 22762,
  XOR8rm = 22763,
  XOR8rm_EVEX = 22764,
  XOR8rm_ND = 22765,
  XOR8rm_NF = 22766,
  XOR8rm_NF_ND = 22767,
  XOR8rr = 22768,
  XOR8rr_EVEX = 22769,
  XOR8rr_EVEX_REV = 22770,
  XOR8rr_ND = 22771,
  XOR8rr_ND_REV = 22772,
  XOR8rr_NF = 22773,
  XOR8rr_NF_ND = 22774,
  XOR8rr_NF_ND_REV = 22775,
  XOR8rr_NF_REV = 22776,
  XOR8rr_NOREX = 22777,
  XOR8rr_REV = 22778,
  XORPDrm = 22779,
  XORPDrr = 22780,
  XORPSrm = 22781,
  XORPSrr = 22782,
  XRELEASE_PREFIX = 22783,
  XRESLDTRK = 22784,
  XRSTOR = 22785,
  XRSTOR64 = 22786,
  XRSTORS = 22787,
  XRSTORS64 = 22788,
  XSAVE = 22789,
  XSAVE64 = 22790,
  XSAVEC = 22791,
  XSAVEC64 = 22792,
  XSAVEOPT = 22793,
  XSAVEOPT64 = 22794,
  XSAVES = 22795,
  XSAVES64 = 22796,
  XSETBV = 22797,
  XSHA1 = 22798,
  XSHA256 = 22799,
  XSTORE = 22800,
  XSUSLDTRK = 22801,
  XTEST = 22802,
  INSTRUCTION_LIST_END = 22803,
};
}
}
}
#endif
